-- Map Options for Got Lakes Map Script
-- Author: Scrum Lord
-- Compatibility: Civ VI, Civ VI R&F, Civ VI GS
-- Purpose: map option constants for Got Lakes and its helper LUA files.
------------------------------------------------------------------------------
------------------------------------------------------------------------------
-- Map options
--
-- The order and numbering of these option constants must 
-- match the order in which the options appear in the 
-- CustomOptions list in OptionInfo.
------------------------------------------------------------------------------
MapOptions = 
{
	-- Adjustment options
	RESOURCES   = 1,  -- resource abundance
	START       = 2,  -- starting plots
	WORLDAGE    = 3,  -- mountains 
	SEALEVEL    = 4,  -- land vs water
	LAKELEVEL   = 5,  -- fresh lakes
	RIVERLEVEL  = 6,  -- rivers
	TEMPERATURE = 7,  -- latitude
	TUNDRALEVEL = 8,  -- latitude
	RAINFALL    = 9,  -- wet features
	CLIMGRAN    = 10, -- terrain/feature fractals
	GRASSPLAINS = 11, -- grass vs plains
	BIODIV      = 12, -- terrain/feature combos
	
	-- Got Lakes additional options
	MOUNTAINS   = 13, -- Mountain Pattern
	RIVERS      = 14, -- River Pattern
	EXTRAS      = 15, -- Additional islands/lakes
	WORLDWRAP   = 16, -- Globe vs Region
	CLIMATE     = 17, -- mostly terrain
	BIOME       = 18, -- mostly features
	SUNLIGHT    = 19, -- latitudes, terrain, start plots
	ICYPOLES    = 20, -- terrain, map sizing, start plots
	
	-- Landmass families
	CONTINENTS  = 21,
	ISLANDS     = 22,
	LAKES       = 23,
	PANGEA      = 24,
    
    -- Misc
    AHILLS      = 25,
	CONNECTSEAS = 26,
	FRESHLAKES  = 27,
	NOCOASTICE  = 28,
    NOCOASTMTS  = 29,
	NODFORESTS  = 30,
	NODJUNGLES  = 31,
	NODOASES    = 32,
	NOGJUNGLES  = 33,
	NOPMARSH    = 34,
	NOREEFS     = 35,
	NOSFORESTS  = 36,
	NOSOASES    = 37,
	NOTFORESTS  = 38,
    SCRALUX     = 39
};

FIRST_LAND_OPT    = MapOptions.CONTINENTS;
LAST_LAND_OPT     = MapOptions.PANGEA;

-- Map names for Civ 6 option lookup.
-- The order of these names must match the order of the 
--corresponding map option indices.
MapOptionNames = 
{
	-- Core options
	"resources",  
	"start",  
	"world_age",   
	"sea_level",   
	"lake_level",  
	"river_level", 
	"temperature", 
	"tundralevel", 
	"rainfall",   
	"clim_gran",  
	"grassplains",
	"biodiversity",    
	
	-- Got Lakes additional options
	"mountains",   
	"rivers",     
	"extras", 
	"world_wrap",  
	"climate",
	"biome",
	"sunlight",
	"icy_poles",
	
	-- Landmass families
	"continents",
	"islands",
	"lakes",
	"pangea",
    
    -- Misc
    "ageless_hills",
	"connect_seas",
	"fresh_lakes_landmasses",
	"no_coastal_ice",
    "no_coastal_mountains",
	"no_desert_forests",
	"no_desert_jungles",
	"no_desert_oases",
	"no_grass_jungles",
	"no_plains_marsh",
	"no_reefs",
	"no_snow_forests",
	"no_snow_oases",
	"no_tundra_forests",
    "scrambled_luxuries",
};

-- Supported landmasses (possible values of UserInput.landmass)
Landmasses = 
{
	ARCHIPELAGO = 1,  -- fractal
	BAGELS      = 2,  -- MLF bagels
	CLUSTERS    = 3,  -- MLF clusters
	CONTINENTS  = 4,  -- fractal continents
	DONUT       = 5,  -- MLF donut
	FRACTAL     = 6,  -- fractal
	INLANDSEA   = 7,  -- MLF inland sea
	INVEXTRAS   = 8,  -- MLF inverted extras
	ISLEPLATES  = 9,  -- MLF island plates
	LAKES       = 10, -- MLF lakes
	LRGISLES    = 11, -- MLF large isles
	LRGLAKES    = 12, -- MLF lakes
	MAZE        = 13, -- MLF Maze
	MINIDONUTS  = 14, -- MLF Mini Donuts
	NOODLES     = 15, -- MLF Noodles
	OVAL        = 16, -- MLF oval
	PANGEA      = 17, -- fractal pangea
	SEVENSEAS   = 18, -- MLF Lakes
	SMALLCONTS  = 19, -- fractal
	SNAKE       = 20, -- MLF Snake
};

------------------------------------------------------------------------------
-- Possible non-random values for options
------------------------------------------------------------------------------
-- Start Position.
START_BALANCED = 1;
START_NORMAL   = 2;
START_LEGEND   = 3;

-- World age
WORLDAGE_YOUNG  = 1;
WORLDAGE_NORMAL = 2;
WORLDAGE_OLD    = 3;

-- Sea level
SEALEVEL_LOW    = 1;
SEALEVEL_NORMAL = 2;
SEALEVEL_HIGH   = 3;

-- Lake level
LAKELEVEL_LOW    = 1;
LAKELEVEL_NORMAL = 2;
LAKELEVEL_HIGH   = 3;

-- River level
RIVERLEVEL_NORMAL = 2;

-- Temperature.
TEMPERATURE_NORMAL = 2;

-- Tundra level.
TUNDRALEVEL_NORMAL = 2;

-- Rainfall.
RAIN_NORMAL = 2;

-- Climate granularity
CLIMGRAN_MIXED = 4;

-- Grass/Plains mix.
GRASSPLAINS_NORMAL = 2;

Biodivs = 
{
	VERYLOW  = 1, -- no desert oases, no tundra forest
	LOW      = 2, -- base game
	STANDARD = 3, -- grass-jungles, plains-marsh
	HIGH     = 4, -- desert-jungles, snow-forest
	VERYHIGH = 5, -- desert-forest, snow-oases
	CLIMBASE = 6,
};

------------------------------------------------------------------------------
-- Biodiversity configs
-- Controls which terrain-feature combos are enabled/disabled by biodiversity.
------------------------------------------------------------------------------
BiodivInfo = 
{
	default = 
	{
		-- Standard combos for Got Lakes.
		desertOasis  = true,
		tundraForest = true,
		
		grassJungle  = true,
		plainsMarsh  = true,
	
		desertJungle = false,
		snowForest   = false,

		desertForest = false,
		snowOasis    = false,
	},
	
	veryLow = 
	{
		desertOasis  = false,
		tundraForest = false,
		
		grassJungle  = false,
		plainsMarsh  = false,
	},
	
	low = 
	{		
		grassJungle  = false,
		plainsMarsh  = false,
	},
	
	high = 
	{	
		desertJungle = true,
		snowForest   = true,
	},
	
	veryHigh = 
	{	
		desertJungle = true,
		snowForest   = true,

		desertForest = true,
		snowOasis    = true,
	},
};

-- Mountain patterns
MtnPatterns = 
{
	TECTONIC  = 1, -- tectonic a.k.a. normal
	FRACTAL   = 2, -- fractal, snaky ranges
	SCATTERED = 3, -- fractal, lone mountains and hills
	CLUSTERED = 4, -- fractal, groups of mountains / hills
	UNCANNY   = 5, -- fractal, double-ranges (valleys)
	WINDING   = 6, -- fractal, pockets of non-mountains
	ALL       = 7  -- a mixture of all mountain patterns
};

-- River patterns
RiverPatterns = 
{
	SIMPLE   = 1, -- simple, straightforward
	DETAILED = 2, -- additional branches and winding
	BRANCHY  = 3, -- extra-branchy
	SNAKY    = 4, -- extra-winding
	ALL      = 5  -- a mixture of all river patterns
};

-- Extras
ExtraIslesLakes = 
{
	NONE     = 1, -- No extra islands
	CHAINS   = 2, -- Chains of islands (based on "plus" maps)
	CLUSTERS = 3, -- Dense clusters of islands
	DONUTS   = 4, -- Mini Donuts
	SPRNKLES = 5, -- Sprinkles
	TECTONIC = 6, -- Tectonic islands
	TCHAINS  = 7, -- Chains and Tectonic islands
	ALL      = 8, -- All types of extra islands
};
NUM_EXTRAS_OPTS = ExtraIslesLakes.ALL;

-- World Wrap
WWRAP_GLOBE   = 1; -- wrap-x only
WWRAP_REGION  = 2; -- no wrap

Climates = 
{
	SNOWBALL   = 1,
	ICEAGE     = 2,
	STANDARD   = 3,
	GREENHOUSE = 4,
	SANDSTORM  = 5,
};

Biomes = 
{
	ARBOREA  = 1,
	PRAIRIE  = 2,
	STANDARD = 3,
	WETLAND  = 4,
};

Sunlights = 
{
	STANDARD = 1,
	TILTED   = 2,
	TWOSUNS  = 3,
};

ICYPOLES_CROP = 1;
ICYPOLES_FULL = 2;

-- Map Size IDs for mapping worldSize hash to a named map size.
MAPSIZE_DUEL     = "MAPSIZE_DUEL";
MAPSIZE_TINY     = "MAPSIZE_TINY";
MAPSIZE_SMALL    = "MAPSIZE_SMALL";
MAPSIZE_STANDARD = "MAPSIZE_STANDARD";
MAPSIZE_LARGE    = "MAPSIZE_LARGE";
MAPSIZE_HUGE     = "MAPSIZE_HUGE";

------------------------------------------------------------------------------
-- User input globals to indicate chosen map configuration
-- These determine various choices such as function args, 
-- method overrides, and conditional statements.
------------------------------------------------------------------------------
-- User selections for map options
UserInput = 
{
	-- Adjustments
	resources   = nil,
	start       = nil,
	worldAge    = nil,
	seaLevel    = nil,
	lakeLevel   = nil,
	riverLevel  = nil,
	temperature = nil,
	tundraLevel = nil,
	rainfall    = nil,
	climGran    = nil,
	grassPlains = nil,
	
	-- Customizations
	mountains   = nil,
	rivers      = nil,
	extras      = nil,
	worldWrap   = nil,
	climate     = nil,
	biome       = nil,
	biodiv      = nil,
	sunlight    = nil,
	icyPoles    = nil,
	
	-- Shuffle options
	landmass    = nil,
    
    -- Misc options
    aHills      = nil,
	connectSeas = nil,
	freshLakes  = nil,
	noCoastIce  = nil,
    noCoastMts  = nil,
	noDForests  = nil,
	noDJungles  = nil,
	noDOases    = nil,
	noGJungles  = nil,
	noPMarsh    = nil,
	noReefs     = nil,
	noSForests  = nil,
	noSOases    = nil,
	noTForests  = nil,
    scraLux     = nil,
};

-- Convenience vars for user's choice of extra islands/lakes.
ExtrasGot = 
{
	chains       = nil,
	clusters     = nil,
	miniDonuts   = nil,
	sprinkles    = nil,
	tectonic     = nil,
	tecAndChains = nil,
	anything     = nil,
	everything   = nil
};

-- Convenience vars for groups of options 
gotLakesFamily  = nil;
gotIceAgeFamily = nil;
gotTiltedFamily = nil;