-- Got Lakes Map Script
-- Author: Scrum Lord
-- Compatibility: Civ VI - Vanilla / Rise and Fall / Gathering Storm
-- Purpose: a highly customizable random map generator
------------------------------------------------------------------------------
------------------------------------------------------------------------------
include "NaturalWonderGenerator"
include "CoastalLowlands"
include "ResourceGenerator"
include "AssignStartingPlots"
include "GotLakes_Options"
include "GotLakes_PassMaker"
include "GotLakes_TerrainGen"
include "GotLakes_Utils"

------------------------------------------------------------------------------
-- Got Lakes version info for debugging
------------------------------------------------------------------------------
local glVersion = 27.1;
------------------------------------------------------------------------------
-- Map Option defaults
------------------------------------------------------------------------------
-- On/Off switch for UI options.
-- Set to true to control options with the Advanced Options menu.
-- Set to false to control options with hard-coded defaults.
local ENABLE_UI = true;

local GOT_ALL  = -1;
local GOT_NONE = -2;

-- Hard-Coded Defaults for development/debugging.
--
-- If ENABLE_UI is false then you can use these settings instead of the
-- Advanced Options menu. To re-roll your map, simply edit the settings, 
-- save changes, and click Restart in the in-game/WB menu.
local MapDefaults = 
{
	--------------------------------------
	-- Resources and Start
	--------------------------------------
	-- Additional values may be possible depending on what other mods you have installed.
	RESOURCES = 2, -- 1 = sparse,   2 = standard, 3 = abundant, 4 = random
	START     = 2, -- 1 = balanced, 2 = standard, 3 = legendary

	--------------------------------------
	-- Adjustments
	--------------------------------------
	WORLDAGE    = 2, -- 1 = new,    2 = standard, 3 = old,      4 = random
	SEALEVEL    = 2, -- 1 = low,    2 = standard, 3 = high,     4 = random
	LAKELEVEL   = 2, -- 1 = low,    2 = standard, 3 = high,     4 = random
	RIVERLEVEL  = 2, -- 1 = low,    2 = standard, 3 = high,     4 = random
	TEMPERATURE = 2, -- 1 = cold,   2 = standard, 3 = hot,      4 = random
	TUNDRALEVEL = 2, -- 1 = low,    2 = standard, 3 = high,     4 = random
	RAINFALL    = 2, -- 1 = dry,    2 = standard, 3 = wet,      4 = random
	CLIMGRAN    = 2, -- 1 = coarse, 2 = standard, 3 = fine,     4 = mixed,  5 = random
	GRASSPLAINS = 2, -- 1 = +grass, 2 = standard, 3 = +plains,  4 = random
	
	-- Biodiversity:
	-- 1 = very Low,        2 = low,       3 = standard,
	-- 4 = high,            5 = very high, 6 = climate based
	-- 7 = random low-high, 8 = random
	BIODIV = 6,
	
	--------------------------------------
	-- Customization
	--------------------------------------
	-- Mountains:
	-- 1 = tectonic plates, 2 = fractal ranges, 
	-- 3 = scattered crags, 4 = clustered highlands,
	-- 5 = uncanny valleys, 6 = winding canyons,
	-- 7 = everything,      8 = random
	MOUNTAINS = 1,
	
	-- Rivers:
	-- 1 = Simple, 2 = detailed,   3 = branchy, 
	-- 4 = snaky,  5 = everything, 6 = random
	RIVERS = 1,
	
	-- Extras:
	-- 1 = none,         2 = chains,     3 = clusters,     
	-- 4 = mini-donuts,  5 = sprinkles,  6 = tectonic, 
	-- 7 = tec & chains, 8 = everything, 9 = random
	EXTRAS = 1,
	
	-- World Wrap: 
	-- 1 = globe, 2 = region, 3 = random
	WORLDWRAP = 1,
	
	-- Climate:
	-- 1 = snowball,   2 = ice age,   3 = standard, 
	-- 4 = greenhouse, 5 = sandstorm, 6 = random ice age to greenhouse,
	-- 7 = random
	CLIMATE = 3,
	
	-- Biome:
	-- 1 = arborea, 2 = prairie, 3 = standard, 
	-- 4 = wetland, 5 = random
	BIOME = 3,
	
	-- Sunlight:
	-- 1 = standard, 2 = tilted Axis, 
	-- 3 = two suns, 4 = random
	SUNLIGHT = 3,
	
	-- Icy Poles:
	-- 1 = cropped, 2 = standard, 3 = random
	ICYPOLES = 2,
	
	--------------------------------------
	-- Landmasses: 
	-- use numbers, GOT_NONE, or GOT_ALL
	--------------------------------------
	CONTINENTS = GOT_NONE, -- 1 = bagels,      2 = conts,      3 = fractal, 4 = noodles, 5 = small
	ISLANDS    = GOT_NONE, -- 1 = archipelago, 2 = clusters,   3 = iplates, 4 = large,   5 = mini-donuts 
	LAKES      = GOT_NONE, -- 1 = inland sea,  2 = inv extras, 3 = lakes,   4 = large,   5 = seven seas
	PANGEA     = GOT_NONE, -- 1 = donut,       2 = maze,       3 = oval,    4 = pangea,  5 = snake
	
	--------------------------------------
	-- Misc Switches
	--------------------------------------
    AHILLS      = false, -- true = force standard world age for hills
	CONNECTSEAS = false, -- true = connect all saltwater oceans/seas with random channels
	FRESHLAKES  = false, -- true = turn all water for lakes landmasses into fresh lakes
	NOCOASTICE  = false, -- true = remove coastal ice
    NOCOASTMTS  = false, -- true = replace coastal mountains with hills
	NODFORESTS  = false, -- true = prevent forests on desert
	NODJUNGLES  = false, -- true = prevent jungles on desert
	NODOASES    = false, -- true = prevent oases on desert
	NOGJUNGLES  = false, -- true = force plains under jungle
	NOPMARSH    = false, -- true = force grass under marsh
	NOREEFS     = false, -- true = remove non-wonder reefs
	NOSFORESTS  = false, -- true = prevent forests on snow
	NOSOASES    = false, -- true = prevent oases on snow
	NOTFORESTS  = false, -- true = prevent forests on tundra
    SCRALUX     = false, -- true = scrambled land luxuries
};
------------------------------------------------------------------------------
-- Map Sizing - overrides to standard map sizes.
------------------------------------------------------------------------------
-- GL's linear scale for standard map sizing.	
local PreferredSizes = 
{
	DUEL     = {width = 44,   height = 26},
	TINY     = {width = 60,   height = 38},
	SMALL    = {width = 74,   height = 46},
	STANDARD = {width = 84,   height = 54},
	LARGE    = {width = 96,   height = 60},
	HUGE     = {width = 106,  height = 66},
	MASSIVE  = {width = 116,  height = 74},
}

-- Standard sizes mapped to GL's preferred dimensions.	
local PREFERRED_STD_SIZES = 
{
	[MAPSIZE_DUEL]      = PreferredSizes.DUEL,
	[MAPSIZE_TINY]      = PreferredSizes.TINY,
	[MAPSIZE_SMALL]     = PreferredSizes.SMALL,
	[MAPSIZE_STANDARD]  = PreferredSizes.STANDARD,
	[MAPSIZE_LARGE]     = PreferredSizes.LARGE,
	[MAPSIZE_HUGE]      = PreferredSizes.HUGE
};

-- Sizes mapped to one size larger.
-- Globe world wrap + Tilted Axis climate enlarges map size
-- to compensate for frozen / cropped-out land.
local PREFERRED_STD_SIZES_ENLARGED = 
{
	[MAPSIZE_DUEL]     = PreferredSizes.TINY,
	[MAPSIZE_TINY]     = PreferredSizes.SMALL,
	[MAPSIZE_SMALL]    = PreferredSizes.STANDARD,
	[MAPSIZE_STANDARD] = PreferredSizes.LARGE,
	[MAPSIZE_LARGE]    = PreferredSizes.HUGE,
	[MAPSIZE_HUGE]     = PreferredSizes.MASSIVE,
};

------------------------------------------------------------------------------
-- Tunable constants
------------------------------------------------------------------------------
-- Default height for the mini-donut bays fractal.
local MINIDONUT_BAYS_HEIGHT_DEFAULT = 74;

-- Miminum fraction of the total number of land tiles
-- for a pangea fractal's biggest landmass.
-- Range [0,1], where 0 effectively disables the threshold,
-- and 1 means that all tiles must be in a single chunk of land.
local PANGEA_LANDMASS_MAJORITY_MIN = 0.84;
local SNAKE_LANDMASS_MAJORITY_MIN  = 0.75;

-- Maximum number of attempts to create a pangea that satisfies
-- the minimum majority of land tiles for the biggest landmass.
local PANGEA_MAX_NUM_ATTEMPTS = 100;

-- On/Off switch for River Generator debug messages and cycle detection.
-- Useful for troubleshooting.
local ENABLE_RIVER_DEBUG = false;

-- On/Off switch for river merging, which allows for more complex river systems.
-- WARNING: enabling this may cause the game to crash on start! The chance of this increases
-- with map size. Lower chance of crash with Rivers = Simple, River Level = Low.
local ENABLE_RIVER_MERGE = false;

-- On/Off switch for randomizing the locations of poles
-- on Tilted Axis or Two Suns sunlights with regional world wrap.
local ENABLE_TILTEDREGION_RANDOM_POLES = true;

-- If random regional Tilted Axis poles are disabled, then 
-- set the south pole's distance in hexes from the center of the map.
-- Has no effect on Two Suns.
local TILTEDREGION_DEFAULT_POLE_RDIST = 0;

-- If random regional Tilted Axis / Two Suns poles are disabled, then 
-- set the south pole's angle offest in radians [0,TAU] starting east 
-- from the center of the map.
local TILTEDREGION_DEFAULT_POLE_THETA = 0;

-- Multiply this by the number of tiles in the biggest landmass
-- to get a target minimum number of reachable tiles for a major 
-- civ start.
--
-- By default, avoid starts that can only reach 1/4 the 
-- size of the biggest landmass.
--
-- A value of 0 effectively disables this.
-- A value of 1 biases starts towards the largest landmass.
-- Beware that mountain ranges can divide land into smaller chunks.
local ASP_STARTAREA_RATIO = 0.25;
------------------------------------------------------------------------------
-- Map Script globals - data that may span multiple steps of map generation
------------------------------------------------------------------------------
local ScriptData = 
{
	-- True iff the Gathering Storm expansion is enabled.
	-- False indicates either base game or Rise and Fall
	gotGatheringStorm = g_FEATURE_VOLCANO ~= nil,

	-- True iff the Rise and Fall expansion is enabled.
	-- False indicates base-game.
	gotRiseAndFall = g_FEATURE_REEF ~= nil,
	
	-- Which function to use for randomizing map configuration.
	configRandFcn = nil,

	-- Biodiversity configuration
	biodivInfo = {},

	-- Make a copy of the plot types before adding mountains, so that
	-- we know what to put back if we remove mountains.
	preMtnPlotTypes = nil,

	-- Map of mountains and hills according to the mountain pattern
	mtnPlots = {},
	
	-- Map of trenches: where to put water for inverted tectonic islands.
	trenchPlots = {},
	
	-- Map of coasts: where to add custom coasts for tectonic shallows and whatnot.
	coastPlots = {},

	-- A map of tectonic islands to avoid when adding mountains and hills.
	-- Nil means no tectonic islands.
	tectonicIslesMap = nil,

	-- A map that tracks which tiles are part of the donut filling.
	donutFillingMap = {},
	
	-- Common flags for climate fractals.
	-- Explicitly disable the polar flag 
	-- to ensure that fractals touch the N/S edges of the map.
	climateFracFlags = { FRAC_POLAR = false },
	
	-- Info for regional terrain and feature calculations.
	-- Initialized during terrain generator init.
	terrainInfo = {},

	-- World size passed into GetMapInitData()
	worldSize = nil,
	
	-- World Size configuration
	worldSizeInfo = {},
	
	-- World wrap configuration.
	wrapX = false,
	wrapY = false, -- actually this is a constant.

	-- Landmass configuration
	landInfo = {},

	-- Climate configuration	
	climateInfo  = {},
	biomeInfo    = {},
	sunlightInfo = {},
};

-- Commonly used vars, following Civ6 naming convention.
local g_iW       = 0;
local g_iH       = 0;
local g_numTiles = 0;
local g_iFlags   = {};
local g_fracXExp = -1;
local g_fracYExp = -1;

------------------------------------------------------------------------------
-- Utilities
------------------------------------------------------------------------------
function CreateClimateFractal(name)
	-- Create a fractal that controls part of the climate.
	
	-- Get climate granularity.
	local grain = UserInput.climGran;
	if (grain == CLIMGRAN_MIXED) then
		-- Mixed => random grain for each fractal.
		grain = 2 + TerrainBuilder.GetRandomNumber(3, "Mixed climate grain");
		print("Climate grain for " .. name .. ": ", grain);
	else
		-- Offset by 1 to convert [1,3] to [2,4].
		grain = grain + 1;
	end
	
	return Fractal.Create(
		g_iW, g_iH, 
		grain, 
		ScriptData.climateFracFlags, 
		g_fracXExp, g_fracYExp);
end

function GetSeaLevel()
    -- Map user's selected sea level from option # to 
    -- water percentage for a fractal world.
    local seas;
    
    if (gotIceAgeFamily) then
        -- Use Ice Age sea levels, which are lower than normal sea levels.
        print("Using ice age sea levels.");
        seas = ScriptData.landInfo.seas_iceage;
    else
        -- Use normal sea levels.
        seas = ScriptData.landInfo.seas_normal;
    end
    
    -- Map sea level option to sea level as water percent.
    local sea_level =  seas[UserInput.seaLevel] or 
                       seas[SEALEVEL_NORMAL]    or 72;
    
    print("Sea level is " .. sea_level); -- For debugging.
    
    return sea_level;
end

function IsCloseToMapEdge(x, y, d)
	-- Checks whether (x,y) is a certain number of plots away from the edge of the map.
	local d = d or 1;
	return (((ScriptData.wrapX == false) and ((x-d <= 0) or (x+d >= g_iW-1))) or 
		    ((ScriptData.wrapY == false) and ((y-d <= 0) or (y+d >= g_iH-1))) );
end
------------------------------------------------------------------------------
-- MapUtilities Overrides
--
-- Override methods in MapUtilities to avoid interference from other mods.
-- See GotLakes_Common for more info.
------------------------------------------------------------------------------
function ObtainLandmassBoundaries(iAreaID, minX, minY, maxX, maxY)
	-- Set up variables that will be returned by this function.
	local wrapsX = false;
	local wrapsY = false;

	local minX = minX or 0;
	local minY = minY or 0;
	local maxX = maxX or g_iW - 1;
	local maxY = maxY or g_iH - 1;
	
	--[[
	print("Obtaining landmass boundaries within " .. CoordString(minX, minY) ..
	      " and " .. CoordString(maxX, maxY));
	--]]
	-- Initialize boundary to the entire bounding box.
	-- If somehow there is not a single plot with matching Area ID,
	-- then the start chooser can force a start anywhere in the box.
	local iWestX = minX;
	local iEastX = maxX;
	local iSouthY = minY;
	local iNorthY = maxY;
	local iWidth  = iEastX  - iWestX  + 1;
	local iHeight = iNorthY - iSouthY + 1;	
	
	if ((ScriptData.wrapX == true) and (minX == 0) and (maxX == (g_iW-1))) then
		local foundFirstColumn = false;
		local foundLastColumn = false;
		for y = minY, maxY do
			local plotFirst = Map.GetPlot(minX, y);
			local plotLast = Map.GetPlot(maxX, y);
			local area = plotFirst:GetArea():GetID();
			if area == iAreaID then -- Found a plot belonging to iAreaID in first column.
				foundFirstColumn = true;
			end
			area = plotLast:GetArea():GetID();
			if area == iAreaID then -- Found a plot belonging to iAreaID in last column.
				foundLastColumn = true;
			end
		end
		if foundFirstColumn and foundLastColumn then -- Plot on both sides of map edge.
			wrapsX = true;
		end
	end
	
	if ((ScriptData.wrapY == true) and (minY == 0) and (maxY == (g_iH-1))) then
		local foundFirstRow = false;
		local foundLastRow = false;
		for x = minX, maxX do
			local plotFirst = Map.GetPlot(x, minY);
			local plotLast = Map.GetPlot(x, maxY);
			local area = plotFirst:GetArea():GetID();
			if area == iAreaID then -- Found a plot belonging to iAreaID in first row.
				foundFirstRow = true;
			end
			area = plotLast:GetArea():GetID();
			if area == iAreaID then -- Found a plot belonging to iAreaID in last row.
				foundLastRow = true;
			end
		end
		if foundFirstRow and foundLastRow then -- Plot on both sides of map edge.
			wrapsY = true;
		end
	end

	-- Find West and East edges of this landmass.
	if not wrapsX then -- no X wrap
		for x = minX, maxX do 
			-- Check for any area membership one column at a time, left to right.
			local foundAreaInColumn = false;
			for y = minY, maxY do -- Checking column.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, set WestX to this column.
					foundAreaInColumn = true;
					iWestX = x;
					break
				end
			end
			if foundAreaInColumn then -- Found WestX, done looking.
				break
			end
		end
		for x = maxX, minX, -1 do 
			-- Check for any area membership one column at a time, right to left.
			local foundAreaInColumn = false;
			for y = minY, maxY do -- Checking column.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, set EastX to this column.
					foundAreaInColumn = true;
					iEastX = x;
					break
				end
			end
			if foundAreaInColumn then -- Found EastX, done looking.
				break
			end
		end
	else -- Landmass Xwraps.
		local landmassSpansEntireWorldX = true;
		for x = maxX-1, minX+1, -1 do 
			-- Check for end of area membership one column at a time, right to left.
			local foundAreaInColumn = false;
			for y = minY, maxY do -- Checking column.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, will have to check the next column too.
					foundAreaInColumn = true;
				end
			end
			if not foundAreaInColumn then -- Found empty column, which is just west of WestX.
				iWestX = x + 1;
				landmassSpansEntireWorldX = false;
				break
			end
		end
		for x = minX+1, maxX-1 do 
			-- Check for end of area membership one column at a time, left to right.
			local foundAreaInColumn = false;
			for y = minY, maxY do -- Checking column.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, will have to check the next column too.
					foundAreaInColumn = true;
				end
			end
			if not foundAreaInColumn then -- Found empty column, which is just east of EastX.
				iEastX = x - 1;
				landmassSpansEntireWorldX = false;
				break
			end
		end
		-- If landmass spans entire world, we'll treat it as if it does not wrap.
		if landmassSpansEntireWorldX then
			wrapsX = false;
			iWestX = minX;
			iEastX = maxX;
		end
	end
				
	-- Find South and North edges of this landmass.
	if not wrapsY then -- no Y wrap
		for y = minY, maxY do -- Check for any area membership one row at a time, bottom to top.
			local foundAreaInRow = false;
			for x = minX, maxX do -- Checking row.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, set SouthY to this row.
					foundAreaInRow = true;
					iSouthY = y;
					break
				end
			end
			if foundAreaInRow then -- Found SouthY, done looking.
				break
			end
		end
		for y = maxY, minY, -1 do 
			-- Check for any area membership one row at a time, top to bottom.
			local foundAreaInRow = false;
			for x = minX, maxX do -- Checking row.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then
					-- Found a plot belonging to iAreaID, set NorthY to this row.
					foundAreaInRow = true;
					iNorthY = y;
					break
				end
			end
			if foundAreaInRow then -- Found NorthY, done looking.
				break
			end
		end
	else -- Landmass Ywraps.
		local landmassSpansEntireWorldY = true;
		for y = maxY-1, maxY+1, -1 do 
			-- Check for end of area membership one row at a time, top to bottom.
			local foundAreaInRow = false;
			for x = minX, maxX do -- Checking row.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, will have to check the next row too.
					foundAreaInRow = true;
				end
			end
			if not foundAreaInRow then -- Found empty row, which is just south of southY.
				iSouthY = y + 1;
				landmassSpansEntireWorldY = false;
				break
			end
		end
		for y = minY+1, maxY-1 do
			-- Check for end of area membership one row at a time, bottom to top.
			local foundAreaInRow = false;
			for x = minX, maxX do -- Checking row.
				local plot = Map.GetPlot(x, y);
				local area = plot:GetArea():GetID();
				if area == iAreaID then 
					-- Found a plot belonging to iAreaID, will have to check the next row too.
					foundAreaInRow = true;
				end
			end
			if not foundAreaInRow then -- Found empty column, which is just north of NorthY.
				iNorthY = y - 1;
				landmassSpansEntireWorldY = false;
				break
			end
		end
		-- If landmass spans entire world, we'll treat it as if it does not wrap.
		if landmassSpansEntireWorldY then
			wrapsY = false;
			iSouthY = minY;
			iNorthY = maxY;
		end
	end
	
	-- Convert EastX and NorthY into width and height.
	if wrapsX then
		iWidth = (iEastX + g_iW) - iWestX + 1;
	else
		iWidth = iEastX - iWestX + 1;
	end
	if wrapsY then
		iHeight = (iNorthY + g_iH) - iSouthY + 1;
	else
		iHeight = iNorthY - iSouthY + 1;
	end

	--[ Log dump for debug purposes only, disable otherwise.
	local plotTotal = iWidth * iHeight;
	print("Landmass bounding box: " .. CoordString(iWestX, iSouthY) .. 
	      " to " .. CoordString(iEastX, iNorthY) .. 
		  " (contains " .. plotTotal .. " plots)");
	--]]

	-- Insert data into table, then return the table.
	return {iWestX, iSouthY, iEastX, iNorthY, iWidth, iHeight, wrapsX, wrapsY};
end
------------------------------------------------------------------------------
-- TerrainGenerator Overrides (used by CoastalLowlands).
--
-- Override methods to fix bugs and to avoid interference from other mods.
------------------------------------------------------------------------------
function GetNumberAdjacentVolcanoes(iX, iY)
	return CountAdjacentVolcanoes(iX,iY);
end

function GetNumberAdjacentMountains(iX, iY)
	return CountAdjacentMountains(iX,iY);
end

function GetNumberAdjacentLakes(iX, iY)
	return CountAdjacent(iX, iY, IsLakeOrWonderLake);
end
------------------------------------------------------------------------------
-- PassMaker: a reusable reachability algorithm
--
-- Ensures that all passable tiles are reachable, regardless of the placement 
-- of impassable tiles. Creates passes if necessary.
--
-- Allows overrides to define what counts as passable or impassable.
------------------------------------------------------------------------------
function ConnectOceans(plotTypes)
	-- If applicable, connect all water tiles into a single system of oceans.
	if (not UserInput.connectSeas) then
		print("Not connecting oceans.");
		return;
	end
	
	print("Connecting oceans.");
	
	-- Use PassMaker to connect seas with random channels.
	local bridgeArgs = 
	{
		obstaclesName 		= "land",
		plotTypes           = plotTypes,
		InitReachPlot 		= PassMaker.Land_InitReachPlot,
		RemoveObstacle      = PassMaker.Land_RemoveObstacle,
	};
	EnsureReachabilityWithPassMaker(bridgeArgs);
end

function ConnectSeas()
	-- If applicable, connect all bodies of salt water into a single system of oceans.
	-- Args: 
	--   plotTypes (optional): connect all water during plot-type-gen if non-null;
	--     otherwise connect salt water via global map.
	if (not UserInput.connectSeas) then
		print("Not connecting seas.");
		return;
	end
	
	print("Connecting seas.");
	
	-- Use PassMaker to connect seas with random channels.
	local bridgeArgs = 
	{
		obstaclesName 		= "land and fresh lakes",
		InitReachPlot 		= PassMaker.NonSaltWater_InitReachPlot,
		RemoveObstacle      = PassMaker.NonSaltWater_RemoveObstacle,
	};
	EnsureReachabilityWithPassMaker(bridgeArgs);
end

function EnsureTerrainReachability()
	-- Check for areas that are completely surrounded by natural wonders.
	local reachArgs = 
	{
		obstaclesName   = "natural wonders",
		InitReachPlot   = PassMaker.Wonder_InitReachPlot,
		RemoveObstacle  = PassMaker.Wonder_RemoveObstacle,
	};
	EnsureReachabilityWithPassMaker(reachArgs);
	
	-- Reset terrain under natural wonders.
	print("Normalizing terrain under natural wonders.");
	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local plot = Map.GetPlot(x, y);
			if plot:IsNaturalWonder() then
				ResetNaturalWonderTerrain(plot);
			end
		end
	end
	
	if ScriptData.gotGatheringStorm then
		-- Check for volcanoes
		local reachArgs = 
		{
			obstaclesName   = "volcanoes",
			InitReachPlot   = PassMaker.Volcano_InitReachPlot,
			RemoveObstacle  = PassMaker.Volcano_RemoveObstacle,
		};
		EnsureReachabilityWithPassMaker(reachArgs);
	end
	
	-- Check for areas that are completely surrounded by mountains and cliffs.
	-- PassMaker's default behavior is mountain reachability.
	reachArgs = { };
	EnsureReachabilityWithPassMaker(reachArgs);
    
	-- Connect salt-water seas and oceans, if applicable.
	-- Do this after checking wonders and volcanoes.
	ConnectSeas();
	
    -- Ensure that all non-mountain tiles are still reachable despite ice.
	local reachArgs = 
	{
		obstaclesName   = "ice",
		InitReachPlot   = PassMaker.Ice_InitReachPlot,
		RemoveObstacle  = PassMaker.Ice_RemoveObstacle,
	};
	EnsureReachabilityWithPassMaker(reachArgs);
    
	-- Remove features from non-volcano mountains,
	-- and check for any former mountains that require features.
	print("Normalizing features.");
	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local plot = Map.GetPlot(x, y);
			if plot:IsMountain() and (not IsVolcano(plot)) then
				-- Remove features from regular mountains
				TerrainBuilder.SetFeatureType(plot, g_FEATURE_NONE);
				
			elseif ((not ScriptData.gotGatheringStorm) and 
					plot:IsRiver() and 
					(plot:GetTerrainType() == g_TERRAIN_TYPE_DESERT)) then
				-- Add floodplains to all river-adjacent flat-land desert plots.
				-- Not applicable to GS.
				TerrainBuilder.SetFeatureType(plot, g_FEATURE_FLOODPLAINS);
			end
		end
	end
	
    -- Some areas may have coalesced after removing obstacles.
	AreaBuilder.Recalculate();
end
------------------------------------------------------------------------------
-- Mountain Patterns for mountain/hill generation.
------------------------------------------------------------------------------
function GetMountainAdjustments()
	-- Get the "adjustment" offsets for mountain & hill fractal height 
	-- percentages.
	--
	-- Returns:
    --   mtnAdjust: the adjustment for mountains
    --   hillAdjust: the adjustment for hills
	local worldAge = UserInput.worldAge or WORLDAGE_NORMAL;
	
	local mtnAdjusts = {20,15,10};
	local mtnAdjust  = mtnAdjusts[worldAge];
	
	local hillAdjusts = {36,28,20};
    local hillAdjust  = hillAdjusts[worldAge];
    
    if (UserInput.aHills == true) then
        -- Ageless Hills enabled.
        -- Fix hills at standard age.
        hillAdjust = hillAdjusts[WORLDAGE_NORMAL];
    end
	
	if (UserInput.mountains == MtnPatterns.WINDING) then
		-- Increase mountains and hills for winding canyons.
		mtnAdjust  = mtnAdjust  + 10;
	end

	return mtnAdjust, hillAdjust;
end

function GetMountainGrain(baseGrain)
	-- Varying grains for hills/peaks per map size.
	return math.min(FRACTAL_MAX_GRAIN, baseGrain + ScriptData.worldSizeInfo.fracGrain);
end

function GetMountainFractalFlags()
    -- Return fractal flags for a mountain pattern.
    -- For fractal consistency, call this method no more than once per run.
    local fracFlags = {};
    
    fracFlags.FRAC_POLAR = RandomBool();
    
    if (ScriptData.wrapX == true) then
        -- Force the fractal to wrap in the x direction for globe maps.
        print("Forcing wrap-x for mountain fractal flags.");
        fracFlags.FRAC_WRAP_X = true;
    else
        fracFlags.FRAC_WRAP_X = RandomBool();
    end
    
    -- This assumes that maps never wrap in the y direction.
    fracFlags.FRAC_WRAP_Y = RandomBool();
    
    print("Mountain fractal flags: polar=" .. NonNilStr(fracFlags.FRAC_POLAR) .. 
        ", wrap_x=" .. NonNilStr(fracFlags.FRAC_WRAP_X) ..
        ", wrap_Y=" .. NonNilStr(fracFlags.FRAC_WRAP_Y));
    
    return fracFlags;
end

function Tectonic_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (tectonic plates).");
	
	-- The "vanilla" mountain pattern.
	local plate_multipliers = {1.5, 1.0, 0.75};
	local plate_multiplier = plate_multipliers[UserInput.worldAge] or 1.0;
		
	-- Tectonic Plate Counts, for use in generating passes through the mountains.
	local numPlates  = 9 * plate_multiplier;	
	local blendRidge = 5;
	local blendFract = 5;
	
	-- Let mountains and hills have different flags,
	-- but use the same flags for fractal-init and ridge-building.
	local mtnFlags = GetMountainFractalFlags();
	local hillFlags = GetMountainFractalFlags();
	
	-- Generate fractals to govern hills and mountains	
	local mountainsFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(3), 
		mtnFlags, 
		g_fracXExp, g_fracYExp);
		
	local hillsFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(4), 
		hillFlags, 
		g_fracXExp, g_fracYExp);
	
	-- Tectonic mountains
	mountainsFrac:BuildRidges(numPlates, mtnFlags, blendRidge, blendFract);

	-- Add ridges to hills, even for non-tectonic mountain patterns.
	hillsFrac:BuildRidges(numPlates, hillFlags, blendRidge, blendFract);
	
	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	
	-- Apply adjustment to hills and peaks settings.
	local footLevel = hillAdjust/5;
	local hillLevel = hillAdjust/5;
	
	local mtnLevel     = 100 - footLevel - mtnAdjust;
	local hillsNearMts = mtnLevel - footLevel;
	
	local hillsBottom1 = 28 - hillLevel;
	local hillsTop1    = 28 + hillLevel;
	local hillsBottom2 = 62 - hillLevel;
	local hillsTop2    = 62 + hillLevel;

	local trenches     = 30; -- Water unaffected by world age.
	
	-- Get height values for mountains and hills
	local name = "tectonic plates mtns";
	local iMountainThreshold  = GetFractalHeight(mountainsFrac, mtnLevel,     name);
	local iHillsNearMountains = GetFractalHeight(mountainsFrac, hillsNearMts, name);
	local iTrenchesTop        = GetFractalHeight(mountainsFrac, trenches,     name);
	
	local name = "tectonic plates hills";
	local iPassThreshold      = GetFractalHeight(hillsFrac, hillsNearMts, name);
	local iHillsBottom1       = GetFractalHeight(hillsFrac, hillsBottom1, name);
	local iHillsTop1          = GetFractalHeight(hillsFrac, hillsTop1,    name);
	local iHillsBottom2       = GetFractalHeight(hillsFrac, hillsBottom2, name);
	local iHillsTop2          = GetFractalHeight(hillsFrac, hillsTop2,    name);
		
	-- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local mountainVal = mountainsFrac:GetHeight(x, y);
			local hillVal = hillsFrac:GetHeight(x, y);
						
			-- Check the hill fractal first so that mountains can replace hills.
			if ((hillVal >= iHillsBottom1 and hillVal < iHillsTop1) or 
			    (hillVal >= iHillsBottom2 and hillVal < iHillsTop2)) then
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			end
			if (mountainVal >= iMountainThreshold) then
				-- Possible mountain or mountain pass
				if (hillVal >= iPassThreshold) then
					 -- Mountain Pass though the ridgeline
					mtnPlots[i] = g_PLOT_TYPE_HILLS;
				else 
					-- Mountain
					mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
				end
				
			elseif (mountainVal >= iHillsNearMountains) then
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
				
			elseif (mountainVal <= iTrenchesTop) then
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end	
end

function FRanges_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (fractal ranges).");
	
	-- Create a snaky fractal pattern without using tectonic 
	-- rifts. Instead, use the 50% percentile of a fractal's
	-- height map as the focus for mountain ranges.
			
	-- Generate fractals to govern mountain ranges
	local rangesFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(2),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
		
	local hillsFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(4),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
		
	-- Apply adjustment to hills and peaks settings.
	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	
	-- Base all ranges at the middle (50th percentile) of the fratal heights
	-- so that mountains are as snaky and non-blob-like as possible
	-- The fractal becomes blob-like at extreme values (0 and 100).
	local middle = 50;
	
	-- Get height values for mountains and hills
	local mtnLevel      = mtnAdjust/2;
	local foothillLevel = mtnLevel + (hillAdjust/6);
	local hillLevel     = hillAdjust/3;
	local trenches      = 15;
	
	local name = "fractal ranges";
	local iFoothillsBottom = GetFractalHeight(rangesFrac, middle - foothillLevel, name); 
	local iMtnsBottom      = GetFractalHeight(rangesFrac, middle - mtnLevel,      name);  
	local iMtnsTop         = GetFractalHeight(rangesFrac, middle + mtnLevel,      name);
	local iFoothillsTop    = GetFractalHeight(rangesFrac, middle + foothillLevel, name);
	local iTrenchesLow     = GetFractalHeight(rangesFrac, trenches,               name);
	local iTrenchesHigh    = GetFractalHeight(rangesFrac, 100 - trenches,         name);

	local name = "fractal ranges hills";
	local iHillsBottom  = GetFractalHeight(hillsFrac, middle - hillLevel, name); 
	local iHillsTop     = GetFractalHeight(hillsFrac, middle + hillLevel, name);  
	
	-- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local rangeVal = rangesFrac:GetHeight(x,y);
			local hillVal  = hillsFrac:GetHeight(x,y);
			
			-- Check the hill fractal first so that mountains can replace hills.
			if (iHillsBottom <= hillVal and hillVal < iHillsTop) then
				-- Hill ranges.
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			end
			if (iMtnsBottom <= rangeVal and rangeVal < iMtnsTop) then
				-- Mountains sandwiched between hills, as far as possible
				-- from fractal extrema.
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;

			elseif (iFoothillsBottom <= rangeVal and rangeVal < iFoothillsTop) then
				-- Hills surrounding and running parallel to the mountains.
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
				
			elseif (rangeVal <= iTrenchesLow or rangeVal >= iTrenchesHigh) then
				-- Trench representing water at the map's lowest altitudes.
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
end

function Scattered_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (scattered crags).");
		
	-- More granular than other mountain patterns.
	local grain = GetMountainGrain(4);
		
    local fracFlags = GetMountainFractalFlags();
    
	-- Generate fractals to govern clumps of mountains
	local mtsFrac = Fractal.Create(
		g_iW, g_iH, 
		grain,
		fracFlags, 
		g_fracXExp, g_fracYExp);
    
    local hillsFrac = Fractal.Create(
		g_iW, g_iH, 
		grain,
		fracFlags, 
		g_fracXExp, g_fracYExp);
		
	local trenchesFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(2), -- lower granularity for trenches
		fracFlags, 
		g_fracXExp, g_fracYExp);
    
    -- Apply adjustment to hills and peaks settings.
	local mtnAdjust, hillAdjust = GetMountainAdjustments();

    -- Five thin bands for mountain clumps.
    local mtsAdjust     = mtnAdjust/5;
    local mtsHalfAdjust = mtsAdjust/2;
	local mts1Bottom    = 97 - mtsAdjust;
	local mts2Top       = 75 + mtsHalfAdjust;
	local mts2Bottom    = 75 - mtsHalfAdjust;
	local mts3Top       = 50 + mtsHalfAdjust;
	local mts3Bottom    = 50 - mtsHalfAdjust;
	local mts4Top       = 25 + mtsHalfAdjust;
	local mts4Bottom    = 25 - mtsHalfAdjust;
	local mts5top       = 3  + mtsAdjust;
    
    -- Two bands for hill clumps.
	local hillsHalf   = hillAdjust*0.6; -- Compensate for overlap with mountains.
	local hillsBottom = 97 - hillsHalf;
	local hillsTop    = 3 + hillsHalf;

    -- Snaky trenches.
    -- Water unaffected by world age.
    local trenches1Bottom  = 36;
    local trenches1Top     = 64;
	
	-- Get height values for various thresholds
	local name = "scattered crags mts";
	local iMtn1Bottom = GetFractalHeight(mtsFrac, mts1Bottom, name);
	local iMtn2Top    = GetFractalHeight(mtsFrac, mts2Top,    name);
	local iMtn2Bottom = GetFractalHeight(mtsFrac, mts2Bottom, name);
	local iMtn3Top    = GetFractalHeight(mtsFrac, mts3Top,    name);
	local iMtn3Bottom = GetFractalHeight(mtsFrac, mts3Bottom, name);
	local iMtn4Top    = GetFractalHeight(mtsFrac, mts4Top,    name);
	local iMtn4Bottom = GetFractalHeight(mtsFrac, mts4Bottom, name);
	local iMtn5Top    = GetFractalHeight(mtsFrac, mts5top,    name);
    
	name = "scattered crags hills";
    local iHillsBottom     = GetFractalHeight(hillsFrac, hillsBottom,     name);
	local iHillsTop        = GetFractalHeight(hillsFrac, hillsTop,        name);
	
	name = "scattered crags trenches";
	local iTrenches1Bottom = GetFractalHeight(trenchesFrac, trenches1Bottom, name);
	local iTrenches1Top    = GetFractalHeight(trenchesFrac, trenches1Top,    name);  

    -- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local mtnVal  = mtsFrac:GetHeight(x, y);
            local hillVal = hillsFrac:GetHeight(x, y);
			local trenchVal = trenchesFrac:GetHeight(x, y);
			
			-- Check the hill fractal first so that mountains can replace hills.
			if ((hillVal >= iHillsBottom) or (hillVal <= iHillsTop)) then
                -- 2 bands of hill crags
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			end
			if ((mtnVal >= iMtn1Bottom) or (mtnVal <= iMtn5Top)) then
				-- 1st and 2nd mountain bands.
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
				
            elseif ((mtnVal >= iMtn3Bottom) and
                    (mtnVal <  iMtn3Top)) then
                -- 3rd band
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
                
            elseif ((mtnVal >= iMtn2Bottom) and
                    (mtnVal <  iMtn2Top)) then
                -- 4th band
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN; 
            
            elseif ((mtnVal >= iMtn4Bottom) and
                    (mtnVal <  iMtn4Top)) then
                -- 5th band
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
            end
			if ((trenchVal >= iTrenches1Bottom) and
                (trenchVal <  iTrenches1Top)) then
                -- Semi-snaky band of trenches
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;	
			end
		end
	end
end

function Clustered_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (clustered highlands).");
	
	-- Concentrate all of the mountains and hills into a small number of
	-- clusters.
		
	-- Generate fractals to govern mountain ranges
	local rangesFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(2),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
		
	local hillFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(4),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
	
	-- Get height values for mountains and hills
	local mtnAdjust, hillAdjust = GetMountainAdjustments();

	local mtnLevel      = 99 - mtnAdjust;
	local foothillLevel = mtnLevel - (hillAdjust/4);
	local hillLevel     = 98 - hillAdjust;
	local trenchMiddle  = 25;
	local trenches      = 14;
		
	local name = "clustered highlands";
	local iMtnsBottom      = GetFractalHeight(rangesFrac, mtnLevel,                name);
	local iFoothillsBottom = GetFractalHeight(rangesFrac, foothillLevel,           name);
    local iTrenchesBottom  = GetFractalHeight(rangesFrac, trenchMiddle - trenches, name); 
	local iTrenchesTop     = GetFractalHeight(rangesFrac, trenchMiddle + trenches, name); 

	local iHillsBottom    = GetFractalHeight(hillFrac, hillLevel, name); 

	
	-- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local rangeVal = rangesFrac:GetHeight(x,y);
			local hillVal  = hillFrac:GetHeight(x,y);
			
			-- Check the hill fractal first so that mountains can replace hills.
			if (hillVal >= iHillsBottom) then
				-- Hill cluster.
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			end
			if (rangeVal >= iMtnsBottom) then
				-- Mountain cluster
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
				
			elseif (rangeVal >= iFoothillsBottom) then
				-- Foothills
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
				
			elseif ((rangeVal >= iTrenchesBottom) and 
                    (rangeVal <  iTrenchesTop)) then	
				-- Trenches surrounding the mountain cluster
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end	
end

function Uncanny_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	-- A variant of Fractal Ranges that usually has more valleys.
	print("Generating mountains and hills (uncanny valleys).");
		
	-- Generate fractals to govern mountain ranges
	local rangesFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(2),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
		
	local hillFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(4),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
	
	-- Apply adjustment to hills and peaks settings.
	local mtnAdjust, hillAdjust = GetMountainAdjustments();	
	
	-- Base all ranges at the middle (50th percentile) of the fratal heights
	-- so that valleys are as snaky and non-blob-like as possible
	-- The fractal becomes blob-like at extreme values (0 and 100).
	local middle        = 50;
	local tValleyLevel  = 2.5;
	local valleyLevel   = 5;	
	local mtnLevel      = valleyLevel + (mtnAdjust/2);
	local foothillLevel = mtnLevel    + (hillAdjust/6);
	local trenches      = 10;
	
	local hillLevel     = valleyLevel + (hillAdjust/3);
	
	-- Get height values for mountains and hills
	local name = "uncanny valleys";
	local iTrenchesBottom = GetFractalHeight(rangesFrac, trenches,               name); 
	local iFHillsBottom   = GetFractalHeight(rangesFrac, middle - foothillLevel, name); 
	local iMtsBottom      = GetFractalHeight(rangesFrac, middle - mtnLevel,      name); 
	local iValleysBottom  = GetFractalHeight(rangesFrac, middle - valleyLevel,   name);
	local iTValleysBottom = GetFractalHeight(rangesFrac, middle - tValleyLevel,  name);  
	local iTValleysTop    = GetFractalHeight(rangesFrac, middle + tValleyLevel,  name);
	local iValleysTop     = GetFractalHeight(rangesFrac, middle + valleyLevel,   name);
	local iMtsTop         = GetFractalHeight(rangesFrac, middle + mtnLevel,      name);	
	local iFHillsTop      = GetFractalHeight(rangesFrac, middle + foothillLevel, name);
	local iTrenchesTop    = GetFractalHeight(rangesFrac, 100 - trenches,         name); 

	local name = "uncanny valleys hills";
	local iHillsBottom    = GetFractalHeight(hillFrac, middle - hillLevel,   name); 
	local iHValleysBottom = GetFractalHeight(hillFrac, middle - valleyLevel, name);  
	local iHValleysTop    = GetFractalHeight(hillFrac, middle + valleyLevel, name);
	local iHillsTop       = GetFractalHeight(hillFrac, middle + hillLevel,   name);
			
	-- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local rangeVal = rangesFrac:GetHeight(x,y);
			local hillVal  = hillFrac:GetHeight(x,y);
			
			-- Check the hill fractal first so that mountains can override hills.
			if ((iHillsBottom <= hillVal and hillVal < iHValleysBottom) or
			    (iHValleysTop <= hillVal and hillVal < iHillsTop)) then
				-- Uncanny hills
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			end				
			if (iTValleysBottom <= rangeVal and rangeVal <= iTValleysTop) then
				-- Trench in an uncanny valley between mountains.
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;

			elseif ((iMtsBottom  <= rangeVal and rangeVal < iValleysBottom) or
			        (iValleysTop <= rangeVal and rangeVal < iMtsTop)) then
				-- Mountains surrounding and running parallel to the hills.
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
				
			elseif (iFHillsBottom <= rangeVal and rangeVal < iFHillsTop) then
				-- Foothills.
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
				
			elseif (rangeVal <= iTrenchesBottom or rangeVal >= iTrenchesTop) then
				-- Trench representing water at the map's lowest altitudes.
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
end

function Winding_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (winding canyons).");
	
	-- A mountain pattern that uses a fractal to decide where
	-- *not* to put mountains. Relies on a reachabiliy algorithm
	-- to create mountain passes between canyon clumps.
		
	-- Generate fractals to govern mountain ranges
	local rangesFrac = Fractal.Create(
		g_iW, g_iH, 
		GetMountainGrain(3),
		GetMountainFractalFlags(), 
		g_fracXExp, g_fracYExp);
	
	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	
	local mtnLevel  = 98 - mtnAdjust;
	local hillLevel = mtnLevel - hillAdjust + 1;
	local trenches  = mtnLevel * 0.375;
	
	-- Get height values for mountains and hills
	local name = "winding canyons";
	local iMtnsBottom  = GetFractalHeight(rangesFrac, mtnLevel,  name);
	local iHillsBottom = GetFractalHeight(rangesFrac, hillLevel, name); 
	local iTrenchesTop = GetFractalHeight(rangesFrac, trenches,  name); 
	
	-- Now the main loop, which will assign the plot types.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			local rangeVal = rangesFrac:GetHeight(x,y);
			
			if (rangeVal > iMtnsBottom) then
				-- Mountains forming canyon walls
				mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
				
			elseif (rangeVal > iHillsBottom) then
				-- Hills near the canyon walls
				mtnPlots[i] = g_PLOT_TYPE_HILLS;
			
			elseif (rangeVal <= iTrenchesTop) then
				-- Trench in the canyon
				trenchPlots[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end	
end

function All_GenerateMountainsAndHills(mtnPlots, trenchPlots)
	-- Mountains and hills - pattern-specific
	print("Generating mountains and hills (everything).");
	
	-- A mountain pattern that combines all of the other mountain patterns.
	local mtnPatternFuncs = 
	{
		Tectonic_GenerateMountainsAndHills,
		FRanges_GenerateMountainsAndHills,
		Scattered_GenerateMountainsAndHills,
		Clustered_GenerateMountainsAndHills,
		Uncanny_GenerateMountainsAndHills,
		Winding_GenerateMountainsAndHills
	};
	
	local maskPct = 30; -- 40
	--print("Mountain pattern percent to include: " .. maskPct);
	
	for i, MtnPatternFunc in ipairs(mtnPatternFuncs) do
		-- Generate each mountain pattern on a separate layer of maps.
		local patternMtns     = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
		local patternTrenches = table.fill(g_PLOT_TYPE_LAND,  g_numTiles);		
		MtnPatternFunc(patternMtns, patternTrenches);
		
		-- Choose a fractal grain for filtering out pieces of the mountain pattern.
		local grain = GetMountainGrain(1) + 
			TerrainBuilder.GetRandomNumber(3, "Random mask grain");
		print("Mountain pattern mask grain: " .. grain);
		
		-- Use a fractal to mask part of the mountain pattern
		-- so that combining all patterns doesn't cover the map in mountains.
		local maskFrac = Fractal.Create(
			g_iW, g_iH, 
			grain,
			GetMountainFractalFlags(), 
			g_fracXExp, g_fracYExp);
		
		-- Include this percent of the mountain pattern.
		local iIncludeTop = GetFractalHeight(maskFrac, maskPct, "everything mountains");
		
		-- Now the main loop, which will assign the plot types.
		for x = 0, g_iW - 1, 1 do
			for y = 0, g_iH - 1, 1 do
				local iPlot = GetPlotIndexLua(x,y);
				local maskVal = maskFrac:GetHeight(x,y);
				
				if (maskVal <= iIncludeTop) then
					-- Add to the "everything" pattern's maps.
					if ((mtnPlots[iPlot]    == g_PLOT_TYPE_OCEAN) or 
						(patternMtns[iPlot] == g_PLOT_TYPE_MOUNTAIN)) then
						-- Let hills override ocean, and let mountains override hills.
						mtnPlots[iPlot]    = patternMtns[iPlot];
					end
					if (trenchPlots[iPlot] == g_PLOT_TYPE_LAND) then
						trenchPlots[iPlot] = patternTrenches[iPlot];
					end
				end
			end
		end
	end	
end

function GenerateMountainsAndHills(plotTypes)
	-- Generate a layer of mountains and hills.
	--
	-- Call this before generating extras.
	--
	-- Args:
	--   plotTypes: landmass mainland plots, not including extras

	-- Make a separate map for mountain pattern output that is
	-- agnostic of actual landmass info.
	local mtnPlots = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	
	-- track any pre-existing mountains in the mountain pattern's map.
	for i = 1, g_numTiles do
		if (plotTypes[i] == g_PLOT_TYPE_MOUNTAIN) then 
			mtnPlots[i] = g_PLOT_TYPE_MOUNTAIN;
		end
	end
	
	local trenchPlots = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
	local mtnPatternFuncs = 
	{
		Tectonic_GenerateMountainsAndHills,
		FRanges_GenerateMountainsAndHills,
		Scattered_GenerateMountainsAndHills,
		Clustered_GenerateMountainsAndHills,
		Uncanny_GenerateMountainsAndHills,
		Winding_GenerateMountainsAndHills,
		All_GenerateMountainsAndHills
	};
	local MtnPatternFunc = mtnPatternFuncs[UserInput.mountains];
	MtnPatternFunc(mtnPlots, trenchPlots);
	
	-- Set global so that we can extend mountain ranges to other parts
	-- of this script.
	ScriptData.mtnPlots        = mtnPlots;
	ScriptData.trenchPlots     = trenchPlots;
end

function CanAddLonelyMountain(plotTypes, x, y)
	-- Check adjacent plots for mountains.
	for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
		adjacentPlot = Map.GetAdjacentPlot(x, y, direction);

		if (adjacentPlot ~= nil) then
			local aX = adjacentPlot:GetX();
			local aY = adjacentPlot:GetY();
			local i = GetPlotIndexLua(aX, aY);

			if (plotTypes[i] == g_PLOT_TYPE_MOUNTAIN) then
				return false;
			end
		end
	end
	return true;
end

function AddLonelyMountains(plotTypes)
	-- Add lonely mountains to a plot array with 1-based indexing.
	local iTotalLandPlots= 0;
	local iTotalMountains = 0;

	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local i = GetPlotIndexLua(x, y);

			if plotTypes[i] ~= g_PLOT_TYPE_OCEAN then
				iTotalLandPlots = iTotalLandPlots + 1;
			end

			if plotTypes[i] == g_PLOT_TYPE_MOUNTAIN then
				iTotalMountains = iTotalMountains + 1;
			end
		end
	end

	local mtnAdjust = GetMountainAdjustments();
	local targetNumMts = Round(iTotalLandPlots * mtnAdjust/100);
	print("Target Num Mountains: " .. tostring(targetNumMts));

	local iNewMountains = targetNumMts - iTotalMountains;
	if (iNewMountains >= 0) then
		print("New Mountains ", iNewMountains);
	else
		iNewMountains = 0;
	end

	local iI = 0;
	local iMountainsSet = 0;
	while iMountainsSet < iNewMountains  and iI < iTotalLandPlots do
		local xRand = TerrainBuilder.GetRandomNumber(g_iW, "Random X");
		local yRand = TerrainBuilder.GetRandomNumber(g_iH, "Random Y");
		local index = GetPlotIndexLua(xRand, yRand);
		
		if ((plotTypes[index] ~= g_PLOT_TYPE_MOUNTAIN) and 
			(plotTypes[index] ~= g_PLOT_TYPE_OCEAN) and 
			CanAddLonelyMountain(plotTypes, xRand, yRand)) then
			-- Add a lonely mountain at this randomly-selected spot.
			iMountainsSet = iMountainsSet + 1;
			plotTypes[index] = g_PLOT_TYPE_MOUNTAIN;
		end
		iI = iI + 1;
	end
	print("Mountains Set", iMountainsSet);
end

function AddExtraHills(plotTypes)
	-- Add extra hills to a plot array with 1-based indexing.
	local iTotalLandPlots= 0;
	local iTotalHills = 0;

	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local i = GetPlotIndexLua(x, y);

			if plotTypes[i] ~= g_PLOT_TYPE_OCEAN then
				iTotalLandPlots = iTotalLandPlots + 1;
			end

			if (plotTypes[i] == g_PLOT_TYPE_HILLS) then
				iTotalHills = iTotalHills + 1;
			end
		end
	end

	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	local targetNumHills = Round(iTotalLandPlots * hillAdjust/100);
	print("Target Num Hills: " .. tostring(targetNumHills));

	local iNewHills = targetNumHills - iTotalHills;
	if (iNewHills >= 0) then
		print("New Hills ", iNewHills);
	else
		iNewHills = 0;
	end

	local iI = 0;
	local iHillsSet = 0;
	while iHillsSet < iNewHills  and iI < iTotalLandPlots do
		local xRand = TerrainBuilder.GetRandomNumber(g_iW, "Random X");
		local yRand = TerrainBuilder.GetRandomNumber(g_iH, "Random Y");
		local index = GetPlotIndexLua(xRand, yRand);
		
		if (plotTypes[index] == g_PLOT_TYPE_LAND) then
			-- Add a hill at this randomly-selected spot.
			iHillsSet = iHillsSet + 1;
			plotTypes[index] = g_PLOT_TYPE_HILLS;
		end
		iI = iI + 1;
	end
	print("Hills Set", iHillsSet);
end

function AddMountainsAndHillsToPlotTypes(plotTypes)
	-- Apply mountain and hill plots to a world's plot types.
	--
	-- Args: 
	--   plotTypes: destination map for adding mountains and hills.
	--	
	-- Mountains and hills - fractal ranges
	print("Adding mountains and hills to the world.");
	
	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	print("Mtn  height adjustment: " .. mtnAdjust);
	print("Hill height adjustment: " .. hillAdjust);
	
	-- Make a copy of the plot types before adding mountains, so that
	-- we know what to put back if we remove mountains.
	ScriptData.preMtnPlotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	for i = 1, g_numTiles do
		ScriptData.preMtnPlotTypes[i] = plotTypes[i];
	end
	
	local got_tectonic = (ScriptData.tectonicIslesMap ~= nil);
	
	-- Count # of mts, hills added
	local numMts   = 0;
	local numHills = 0;
	
	-- Apply mountain plot types to the main map.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			
			-- Check mountain pattern for mountains and hills.
			local srcPlotType = ScriptData.mtnPlots[i];
			
			if ((srcPlotType  ~= g_PLOT_TYPE_OCEAN) and
				(plotTypes[i] ~= g_PLOT_TYPE_OCEAN) and
				((got_tectonic == false) or 
				 (ScriptData.tectonicIslesMap[i] == g_PLOT_TYPE_OCEAN))) then
				-- Got a plot to add to the world.
				-- Replacing a land tile that is *not* a tectonic island.
				plotTypes[i] = srcPlotType;
				
				if (srcPlotType == g_PLOT_TYPE_MOUNTAIN) then
					numMts = numMts + 1;
				
				elseif (srcPlotType == g_PLOT_TYPE_HILLS) then
					numHills = numHills + 1;
				end
			end
		end
	end
	
	-- Note: coastal mountains may become hills during feature generation.
	print("Added " .. numMts .. " mountains and " .. numHills .. " hills.");
	
	-- Add some lonely mountains.
	-- Need to do this after populating plot types with mountains
	-- so that lonely-mountain logic can use mountain-ratio.
	print("Adding lonely mountains and hills.");
	AddLonelyMountains(plotTypes);
	AddExtraHills(plotTypes);
end
------------------------------------------------------------------------------
-- Lakes, Clusters, Peninsula Shrinking
------------------------------------------------------------------------------
function GenerateLakesFractal(water_level, lake_grain)
	-- Use a lake fractal to add water to a land-heavy map.
	-- For lakes-family landmasses with global world wrap.
	--
	-- Args:
	--   water_level: lake water level
	--   lake_grain:  lake fractal granularity
	-- Returns:
	--   plotTypes: a map of generated lakes
	local plotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
	local lakesFrac = Fractal.Create(g_iW, g_iH, lake_grain, g_iFlags, g_fracXExp, g_fracYExp)
	local lakesThreshold = GetFractalHeight(lakesFrac, water_level);
	
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = GetPlotIndexLua(x,y);
			local lakeVal = lakesFrac:GetHeight(x, y);
			if lakeVal >= lakesThreshold then
				plotTypes[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
	
	return plotTypes;
end

function GenerateLakesForClusters(inverted, lakeGrain, lakeLevelOffset)
	-- Use a lake fractal to add water to a land-heavy map.
	-- For generating clusters if lakes (hides lake-levels and lake grains).
	--
	-- Args:
	--   inverted: true iff these lakes are for inverted clusters
	--   lakeGrain: lake fractal granularity
	--   lakeLevelOffset: offset for lake fractal's height threshold
	--
	-- Returns:
	--   plotTypes: a map of generated lakes that are not yet clusters
	
	local invertableSeaLevel = UserInput.seaLevel;
	if (not inverted) then
		-- The above levels are calibrated for islands.
		-- Reverse order for lakes.
		invertableSeaLevel = 4 - invertableSeaLevel;
	end
	
	-- Map sea levels to water percent thresholds.
	local lake_levels = {85,78,70};
	local lake_level  = lake_levels[invertableSeaLevel] or 
			            lake_levels[SEALEVEL_NORMAL]    or 78;
	
	-- Any smaller and lakes might not spread out enough.
	-- Any larger and clusters might be too much like chains.
	local lake_grain = lakeGrain or 3;
	local lakeLevelOffset = lakeLevelOffset or 0;
	lake_level = lake_level + lakeLevelOffset;
	
	if (gotIceAgeFamily) then
		-- Use Ice Age sea levels, which are lower than normal sea levels.
		lake_level = lake_level + 5;
	end
	
	print("Clusters sea level: ", lake_level);
	print("Clusters grain: ", lake_grain);
	
	-- Use the general-purpose lake fractal with special inputs.
	if inverted then
		return GenerateLakesFractal(lake_level, lake_grain);
	end
	
	-- Variation of the lakes fractal to avoid islands near the map edges.
	lake_level = 100 - lake_level;
	
	local plotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
	local lakesFrac = Fractal.Create(g_iW, g_iH, lake_grain, g_iFlags, g_fracXExp, g_fracYExp)
	local lakesThreshold = GetFractalHeight(lakesFrac, lake_level);
	
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = GetPlotIndexLua(x,y);
			local lakeVal = lakesFrac:GetHeight(x, y);
			if lakeVal <= lakesThreshold then
				plotTypes[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
	return plotTypes;
end

function ShrinkPeninsulas(plotTypes, queue, curNumWaterTiles, targetNumWaterTiles)
	-- Remove land from peninsulas until there are no peninsulas left, or until sea
	-- level meets specifications.
	-- Args:
	--   plotTypes: land/water map
	--   queue: peninsulas to shrink in BFS order
	--   curNumWaterTiles: current number of water tiles
	--   targetNumWaterTiles: target number of water tiles
	-- Returns:
	--   curNumWaterTiles: new number of water tiles.
		
	-- Use a queue to search neighboring tiles in BFS order until we've
	-- covered all of the water tiles that share the same body of water.
	while ((not queue:IsEmpty()) and (curNumWaterTiles < targetNumWaterTiles)) do
	
		local coord = queue:Dequeue();
		local x, y = coord.x, coord.y;
		
		local iVisited = y * g_iW + x + 1;
		
		-- Perform a potentially-redundant peninsula check
		-- in case the tile at (x,y) is no longer a peninsula.
		if IsPeninsula(plotTypes, x, y) then
			-- Replace shrunken peninsulas with shallow water
			-- to create a maze for non-ocean units.
			--print("Removing peninsula at " .. CoordString(x,y));
			plotTypes[iVisited]             = g_PLOT_TYPE_OCEAN;
			ScriptData.coastPlots[iVisited] = g_PLOT_TYPE_LAND;
			curNumWaterTiles = curNumWaterTiles + 1;
		
			-- Randomize traversal by shuffling the order of adjacent tiles to visit.
			local shuffledDirs = GetShuffledCopyOfTable(HexDirections);
			for i, direction in ipairs(shuffledDirs) do
				local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
				
				if (adjacentPlot ~= nil) then
					-- We have an adjacent plot.
					-- Let's see if it's now a peninsula.
					local aX, aY = adjacentPlot:GetX(), adjacentPlot:GetY();
					
					if IsPeninsula(plotTypes, aX, aY) then
						-- Add to the stack of plots to visit.
						queue:Enqueue({x=aX, y=aY});
					end
				end
			end
		end
	end
	return curNumWaterTiles;
end
------------------------------------------------------------------------------
-- Extras
------------------------------------------------------------------------------
function CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
	-- Copied from Island Maker for the sole purpose of supressing
	-- obnoxious debug messages.
	
	-- This function will create the simplest form of island chain. (fTilt should be in degrees.)
	-- Data returned will be a table of LOCAL plot indices, true for land, false for water.
	local iWH = iWidth * iHeight;
	-- If dimensions are too small to operate, or the angle is not between 0 and 180 degrees, abort.
	if iWidth < 4 or iHeight < 4 or iWH < 24 or fTilt < 0 or fTilt > 180 then
		print("*** ERROR! ***"); print("Cell dimensions or Axis angle invalid!"); print("-");
		return nil
	end
	-- This function is going to execute, so set up a data table for the plots.
	local plot_data = table.fill(false, iWH);
	-- Define the center and the radii.
	local iCenterX, iCenterY = (iWidth - 1) / 2, (iHeight - 1) / 2;
	local fRadiusX, fRadiusY = iWidth / 2, iHeight / 2;
	-- Using triangular method of trigonometry. If angle > 90 degrees, swap sides and convert the angle.
	local fTilt_in_degrees = fTilt;
	if fTilt > 90 then
		fTilt_in_degrees = 180 - fTilt;
	end
	-- Convert angle to radians. (Lua math table functions operate on radians).
	local fTilt_in_radians = math.rad(fTilt_in_degrees);
	-- Determine traits of the angle.
	local is_horizontal, is_vertical, is_steep, leans_left = false, false, false, false;
	if fTilt == 0 or fTilt == 180 then
		is_horizontal = true;
	elseif fTilt == 90 then
		is_vertical = true;
	else
		if fTilt > 45 and fTilt < 135 then
			is_steep = true;
		end
		if fTilt > 90 then
			leans_left = true;
		end
	end
	-- Obtain start and end plots for the axis.
	local start_x, start_y, end_x, end_y;
	if is_horizontal then
		start_x, start_y, end_x, end_y = 0, iCenterY, iWidth - 1, iCenterY;
	elseif is_vertical then
		start_x, start_y, end_x, end_y = iCenterX, 0, iCenterX, iHeight - 1;
	else
		-- Obtain the tangent of this angle.
		local TAN = math.tan(fTilt_in_radians);
		-- Figure out which axis to use as the measurement basis for the triangle.
		-- (The one that won't let the trangle exceed the defined width and height).
		local width_viable, height_viable = false, false;
		--
		-- Check with width as primary axis.
		local width_check = fRadiusY / TAN;
		if width_check <= fRadiusX then
			width_viable = true;
		end
		-- Check with height as primary axis.
		local height_check = fRadiusX * TAN;
		if height_check <= fRadiusY then
			height_viable = true;
		end
		-- Check for error.
		if width_viable == false and height_viable == false then
			-- Neither width nor height checked out as viable? That should not be mathematically possible!
			print("!!!"); print("! ERROR ! - Trigonometric failure !"); print("!!!");
			return nil
		end
		-- Assign the coordinates.
		if width_viable then
			if leans_left == false then
				start_x, start_y, end_x, end_y = iCenterX - width_check, 0, iCenterX + width_check, iHeight - 1;
			else
				start_x, start_y, end_x, end_y = iCenterX - width_check, iHeight - 1, iCenterX + width_check, 0;
			end
		elseif height_viable then
			if leans_left == false then
				start_x, start_y, end_x, end_y = 0, iCenterY - height_check, iWidth - 1, iCenterY + height_check;
			else
				start_x, start_y, end_x, end_y = 0, iCenterY + height_check, iWidth - 1, iCenterY - height_check;
			end
		else
			print("*** ERROR *** Width and Height Checks failed! ***");
		end
	end
	
	-- Debugging
	--print("-"); print("- Traits List - Width:", iWidth, "Height:", iHeight, "Angle:", fTilt);
	--print("-"); print("Degrees:", fTilt_in_degrees, " - Radians:", fTilt_in_radians); print("-");
	--print("Start Coordinates:", start_x, start_y, " - End Coordinates:", end_x, end_y); print("-");

	local startX, startY, endX, endY, bReverseFlag, slope;
	-- Note: Incoming x/y are starting at 0/0, but we need to convert them to Lua array values that start at 1.
	if math.abs(end_y - start_y) < math.abs(end_x - start_x) then -- line is closer to horizontal
		if start_x > end_x then
			startX, startY, endX, endY = end_x + 1, end_y + 1, start_x + 1, start_y + 1; -- swap start and end
			bReverseFlag = true;
			--print("Path reversed, working from the end plot.");
		else -- don't swap
			startX, startY, endX, endY = start_x + 1, start_y + 1, end_x + 1, end_y + 1;
			bReverseFlag = false;
			--print("Path not reversed.");
		end
		local dx = endX - startX;
		local dy = endY - startY;
		if dx == 0 or dy == 0 then
			slope = 0;
		else
			slope = dy/dx;
		end
		--print("Slope: ", slope);
		local y, y_true = nil, startY;
		-- Process the Axis.
		for x = startX, endX do
			local y_int, y_frac = math.modf(y_true);
			if y_frac >= 0.5 then
				y = math.ceil(y_true);
			else
				y = math.floor(y_true);
			end
			-- Determine if this plot is to become land.
			local diceroll = TerrainBuilder.GetRandomNumber(5, "Island Making - Lua");
			if diceroll > 1 then -- Yes, turn this plot to land.
				local i = (y - 1) * iWidth + x;
				plot_data[i] = true;
			end	
			-- Adjust y for the next iteration of the loop.		
			y_true = y_true + slope;
			--print("y plus slope: ", y_true);
		end

	else -- line is closer to vertical
		if start_y > end_y then
			startX, startY, endX, endY = end_x + 1, end_y + 1, start_x + 1, start_y + 1; -- swap start and end
			bReverseFlag = true;
			--print("Path reversed, working from the end plot.");
		else -- don't swap
			startX, startY, endX, endY = start_x + 1, start_y + 1, end_x + 1, end_y + 1;
			bReverseFlag = false;
			--print("Path not reversed.");
		end
		local dx = endX - startX;
		local dy = endY - startY;
		if dx == 0 or dy == 0 then
			slope = 0;
		else
			slope = dx/dy;
		end
		--print("Slope: ", slope);
		local x, x_true = nil, startX;
		-- Process the Axis.
		for y = startY, endY do
			local x_int, x_frac = math.modf(x_true);
			if x_frac >= 0.5 then
				x = math.ceil(x_true);
			else
				x = math.floor(x_true);
			end
			-- Determine if this plot is to become land.
			local diceroll = TerrainBuilder.GetRandomNumber(5, "Island Making - Lua");
			if diceroll > 1 then -- Yes, turn this plot to land.
				local i = (y - 1) * iWidth + x;
				plot_data[i] = true;
			end	
			-- Adjust x for the next iteration of the loop.		
			x_true = x_true + slope;
			--print("x plus slope: ", x_true);
		end
	end
	
	return plot_data
end

function CreateAxisChainWithDots(iWidth, iHeight, fTilt, iInnerWidth, iInnerHeight, iNumDots)
	-- This function adds "dots" (randomly placed single plots of land) to an axis island chain.
	local plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
	-- Error handling.
	if iInnerWidth > iWidth - 2 then
		iInnerWidth = iWidth - 2;
	end
	if iInnerHeight > iHeight - 2 then
		iInnerHeight = iHeight - 2;
	end
	local westX = 1 + math.floor((iWidth - iInnerWidth) / 2);
	local southY = 1 + math.floor((iHeight - iInnerHeight) / 2);
	-- Add dots. ... Note: No collision checks. Any dots placed on existing plots are lost. This is intended.
	for loop = 1, iNumDots do
		local randomX = westX + TerrainBuilder.GetRandomNumber(iInnerWidth, "Random X coord for Dot - Lua");
		local randomY = southY + TerrainBuilder.GetRandomNumber(iInnerHeight, "Random Y coord for Dot - Lua");
		local i = (randomY - 1) * iWidth + randomX;
		plot_data[i] = true;
	end

	return plot_data
end

function CreateAxisChainWithShiftedDots(
	iWidth, iHeight, fTilt, iInnerWidth, iInnerHeight, iInnerWest, iInnerSouth, iNumDots)
	-- The dots do not necessarily go in the middle, in this function. 
	-- Use West and South to set the location of the dots.
	local plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
	-- Error handling.
	if iInnerWidth > iWidth - 2 then
		iInnerWidth = iWidth - 2;
	end
	if iInnerHeight > iHeight - 2 then
		iInnerHeight = iHeight - 2;
	end
	-- Add dots. ... Note: No collision checks. Any dots placed on existing plots are lost. This is intended.
	for loop = 1, iNumDots do
		local randomX = iInnerWest + TerrainBuilder.GetRandomNumber(iInnerWidth, "Random X coord for Dot - Lua");
		local randomY = iInnerSouth + TerrainBuilder.GetRandomNumber(iInnerHeight, "Random Y coord for Dot - Lua");
		local i = (randomY - 1) * iWidth + randomX;
		plot_data[i] = true;
	end

	return plot_data
end

function CreateAxisChainWithDoubleDots(
	iWidth, iHeight, fTilt, iInnerWidth1, iInnerHeight1, iInnerWest1, iInnerSouth1,
    iNumDots1, iInnerWidth2, iInnerHeight2, iInnerWest2, iInnerSouth2, iNumDots2)
	-- Two sets of dots, with control over size and location.
	local plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
	-- Error handling.
	if iInnerWidth1 > iWidth - 2 then
		iInnerWidth1 = iWidth - 2;
	end
	if iInnerHeight1 > iHeight - 2 then
		iInnerHeight1 = iHeight - 2;
	end
	if iInnerWidth2 > iWidth - 2 then
		iInnerWidth2 = iWidth - 2;
	end
	if iInnerHeight2 > iHeight - 2 then
		iInnerHeight2 = iHeight - 2;
	end
	-- Dots1
	for loop = 1, iNumDots1 do
		local randomX = iInnerWest1 + TerrainBuilder.GetRandomNumber(iInnerWidth1, "Random X coord for Dot - Lua");
		local randomY = iInnerSouth1 + TerrainBuilder.GetRandomNumber(iInnerHeight1, "Random Y coord for Dot - Lua");
		local i = (randomY - 1) * iWidth + randomX;
		plot_data[i] = true;
	end
	-- Dots2
	for loop = 1, iNumDots2 do
		local randomX = iInnerWest2 + TerrainBuilder.GetRandomNumber(iInnerWidth2, "Random X coord for Dot - Lua");
		local randomY = iInnerSouth2 + TerrainBuilder.GetRandomNumber(iInnerHeight2, "Random Y coord for Dot - Lua");
		local i = (randomY - 1) * iWidth + randomX;
		plot_data[i] = true;
	end

	return plot_data
end

function GenerateChains()
	-- Generate Chains of extra islands
	--
	-- Return a map of generated island chain plot types.
	
	-- Now we begin to add the island chains.
	print("Generating chains of islands/lakes.");

	-- Higher sea level => use less cells.
	local seaLevel  = UserInput.seaLevel;
	
	local landArgs = ScriptData.landInfo.extraArgs or {};
	local invertExtras = landArgs.invertExtras;
	if invertExtras then
		-- Invert sea level.
		seaLevel = 4 - seaLevel;
	end
	
	local cellTargetFracs = {0.88, 0.66, 0.44}; 
	
	local cellTargetFrac  = cellTargetFracs[seaLevel]; -- originally fixed at 0.66
	
	if (ExtrasGot.everything == true) then
		-- Got "everything" for extras.
		-- Reduce islands to make room for other types of extras.
		cellTargetFrac = cellTargetFrac / 3;
	
	elseif (ExtrasGot.tecAndChains == true) then
		-- Got "tectonic and chains" for extras.
		-- Reduce islands to make room for other extras.
		cellTargetFrac = cellTargetFrac / 2;
	end
	
	-- A cell system will be used to combine predefined land chunks with randomly generated island groups.
	-- Define the cell traits. (These need to fit correctly with the map grid width and height.)
	
	local iCellWidth = 10;
	local iCellHeight = 8;
	local iNumCellColumns = math.floor(g_iW / iCellWidth);
	local iNumCellRows = math.floor(g_iH / iCellHeight);
	local iNumTotalCells = iNumCellColumns * iNumCellRows;
	local cell_data = table.fill(false, iNumTotalCells) -- Stores data on map cells in use. All cells begin as empty.
	local iNumCellsInUse = 0;
	local iNumCellTarget = math.floor(iNumTotalCells * cellTargetFrac);
	local island_chain_PlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);

	-- Margins for centering the cell grid on the map.
	local xMargin = math.floor((g_iW - iNumCellColumns * iCellWidth) /2);
	local yMargin = math.floor((g_iH - iNumCellRows    * iCellHeight)/2);
	
	--print("Target number of cells: " .. iNumCellTarget);
	
	-- Add randomly generated island groups
	local iNumGroups = iNumCellTarget; -- Should virtually never use all the groups.
	for group = 1, iNumGroups do
		if (iNumCellsInUse >= iNumCellTarget) then -- Map has reached desired island population.
			--print("Number of Island Groups produced:", group - 1);
			break
		end
		--[[ Formation Chart
		1. Single Cell, Axis Only
		2. Double Cell, Horizontal, Axis Only
		3. Single Cell With Dots
		4. Double Cell, Horizontal, With Shifted Dots
		5. Double Cell, Vertical, Axis Only
		6. Double Cell, Vertical, With Shifted Dots
		7. Triple Cell, Vertical, With Double Dots
		8. Square of Cells 2x2 With Double Dots
		9. Rectangle 3x2 With Double Dots
		10. Rectangle 2x3 With Double Dots ]]--
		--
		-- Choose a formation
		local rate_threshold = {};
		local total_appearance_rate, iNumFormations = 0, 0;
		local appearance_rates = { -- These numbers are relative to one another. No specific target total is necessary.
			7, -- #1
			3, -- #2
			15, --#3
			8, -- #4
			3, -- #5
			6, -- #6
			4, -- #7
			6, -- #8
			4, -- #9
			3, -- #10
		};
		for i, rate in ipairs(appearance_rates) do
			total_appearance_rate = total_appearance_rate + rate;
			iNumFormations = iNumFormations + 1;
		end
		local accumulated_rate = 0;
		for index = 1, iNumFormations do
			local threshold = (appearance_rates[index] + accumulated_rate) * 10000 / total_appearance_rate;
			table.insert(rate_threshold, threshold);
			accumulated_rate = accumulated_rate + appearance_rates[index];
		end
		local formation_type;
		local diceroll = TerrainBuilder.GetRandomNumber(10000, "Choose formation type - Island Making - Lua");
		for index, threshold in ipairs(rate_threshold) do
			if diceroll <= threshold then -- Choose this formation type.
				formation_type = index;
				break
			end
		end
		-- Choose cell(s) not in use;
		local iNumAttemptsToFindOpenCells = 0;
		local found_unoccupied_cell = false;
		local anchor_cell, cell_x, cell_y, foo;
		while found_unoccupied_cell == false do
			if iNumAttemptsToFindOpenCells > 100 then 
				-- Too many attempts on this pass.
				-- Might not be any valid locations for this formation.
				formation_type = 3; -- Reset formation type.
				iNumAttemptsToFindOpenCells = 0;
			end
			local diceroll = 1 + TerrainBuilder.GetRandomNumber(iNumTotalCells, "Choosing a cell for an island group");
			if cell_data[diceroll] == false then -- Anchor cell is unoccupied.
				-- If formation type is multiple-cell, all secondary cells must also be unoccupied.
				if formation_type == 1 or formation_type == 3 then -- single cell, proceed.
					anchor_cell = diceroll;
					found_unoccupied_cell = true;
				elseif formation_type == 2 or formation_type == 4 then -- double cell, horizontal.
					-- Check to see if anchor cell is in the final column. If so, reject.
					cell_x = math.fmod(diceroll, iNumCellColumns);
					if cell_x ~= 0 then -- Anchor cell is valid, but still have to check adjacent cell.
						if cell_data[diceroll + 1] == false then -- Adjacent cell is unoccupied.
							anchor_cell = diceroll;
							found_unoccupied_cell = true;
						end
					end
				elseif formation_type == 5 or formation_type == 6 then -- double cell, vertical.
					-- Check to see if anchor cell is in the final row. If so, reject.
					cell_y, foo = math.modf(diceroll / iNumCellColumns);
					cell_y = cell_y + 1;
					if cell_y < iNumCellRows then -- Anchor cell is valid, but still have to check cell above it.
						if cell_data[diceroll + iNumCellColumns] == false then -- Adjacent cell is unoccupied.
							anchor_cell = diceroll;
							found_unoccupied_cell = true;
						end
					end
				elseif formation_type == 7 then -- triple cell, vertical.
					-- Check to see if anchor cell is in the northern two rows. If so, reject.
					cell_y, foo = math.modf(diceroll / iNumCellColumns);
					cell_y = cell_y + 1;
					if cell_y < iNumCellRows - 1 then -- Anchor cell is valid, but still have to check cells above it.
						if cell_data[diceroll + iNumCellColumns] == false then -- Cell directly above is unoccupied.
							if cell_data[diceroll + (iNumCellColumns * 2)] == false then -- Cell two rows above is unoccupied.
								anchor_cell = diceroll;
								found_unoccupied_cell = true;
							end
						end
					end
				elseif formation_type == 8 then -- square, 2x2.
					-- Check to see if anchor cell is in the final row or column. If so, reject.
					cell_x = math.fmod(diceroll, iNumCellColumns);
					if cell_x ~= 0 then
						cell_y, foo = math.modf(diceroll / iNumCellColumns);
						cell_y = cell_y + 1;
						if cell_y < iNumCellRows then -- Anchor cell is valid. Still have to check the other three cells.
							if cell_data[diceroll + iNumCellColumns] == false then
								if cell_data[diceroll + 1] == false then
									if cell_data[diceroll + iNumCellColumns + 1] == false then -- All cells are open.
										anchor_cell = diceroll;
										found_unoccupied_cell = true;
									end
								end
							end
						end
					end
				elseif formation_type == 9 then -- horizontal, 3x2.
					-- Check to see if anchor cell is too near to an edge. If so, reject.
					cell_x = math.fmod(diceroll, iNumCellColumns);
					if cell_x ~= 0 and cell_x ~= iNumCellColumns - 1 then
						cell_y, foo = math.modf(diceroll / iNumCellColumns);
						cell_y = cell_y + 1;
						if cell_y < iNumCellRows then -- Anchor cell is valid. Still have to check the other cells.
							if cell_data[diceroll + iNumCellColumns] == false then
								if cell_data[diceroll + 1] == false and cell_data[diceroll + 2] == false then
									if cell_data[diceroll + iNumCellColumns + 1] == false then
										if cell_data[diceroll + iNumCellColumns + 2] == false then -- All cells are open.
											anchor_cell = diceroll;
											found_unoccupied_cell = true;
										end
									end
								end
							end
						end
					end
				elseif formation_type == 10 then -- vertical, 2x3.
					-- Check to see if anchor cell is too near to an edge. If so, reject.
					cell_x = math.fmod(diceroll, iNumCellColumns);
					if cell_x ~= 0 then
						cell_y, foo = math.modf(diceroll / iNumCellColumns);
						cell_y = cell_y + 1;
						if cell_y < iNumCellRows - 1 then -- Anchor cell is valid. Still have to check the other cells.
							if cell_data[diceroll + iNumCellColumns] == false then
								if cell_data[diceroll + 1] == false then
									if cell_data[diceroll + iNumCellColumns + 1] == false then
										if cell_data[diceroll + (iNumCellColumns * 2)] == false then
											if cell_data[diceroll + (iNumCellColumns * 2) + 1] == false then
												-- All cells are open.
												anchor_cell = diceroll;
												found_unoccupied_cell = true;
											end
										end
									end
								end
							end
						end
					end
				end
			end
			iNumAttemptsToFindOpenCells = iNumAttemptsToFindOpenCells + 1;
		end
		-- Find Cell X and Y
		cell_x = math.fmod(anchor_cell, iNumCellColumns);
		if cell_x == 0 then
			cell_x = iNumCellColumns;
		end
		cell_y, foo = math.modf(anchor_cell / iNumCellColumns);
		cell_y = cell_y + 1;
	
		-- Create this island group.
		local iWidth, iHeight, fTilt; -- Scope the variables needed for island group creation.
		local plot_data = {};
		local x_shift, y_shift;
		if formation_type == 1 then -- single cell
			local x_shrinkage = TerrainBuilder.GetRandomNumber(4, "Cell Width adjustment - Lua");
			if x_shrinkage > 2 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 2 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth - x_shrinkage;
			iHeight = iCellHeight - y_shrinkage;
			fTilt = TerrainBuilder.GetRandomNumber(181, "Angle for island chain axis - LUA");
			plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)

		elseif formation_type == 2 then -- two cells, horizontal
			local x_shrinkage = TerrainBuilder.GetRandomNumber(8, "Cell Width adjustment - Lua");
			if x_shrinkage > 5 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 2 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth * 2 - x_shrinkage;
			iHeight = iCellHeight - y_shrinkage;
			-- Limit angles to mostly horizontal ones.
			fTilt = 145 + TerrainBuilder.GetRandomNumber(90, "Angle for island chain axis - LUA");
			if fTilt > 180 then
				fTilt = fTilt - 180;
			end
			plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
		
		elseif formation_type == 3 then -- single cell, with dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(4, "Cell Width adjustment - Lua");
			if x_shrinkage > 2 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 2 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth - x_shrinkage;
			iHeight = iCellHeight - y_shrinkage;
			fTilt = TerrainBuilder.GetRandomNumber(181, "Angle for island chain axis - LUA");
			-- Determine "dot box"
			local iInnerWidth, iInnerHeight = iWidth - 2, iHeight - 2;
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots = 4;
			if die_1 + die_2 > 1 then
				iNumDots = iNumDots + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots = iNumDots + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithDots(iWidth, iHeight, fTilt, iInnerWidth, iInnerHeight, iNumDots)

		elseif formation_type == 4 then -- two cells, horizontal, with dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(8, "Cell Width adjustment - Lua");
			if x_shrinkage > 5 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 2 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth * 2 - x_shrinkage;
			iHeight = iCellHeight - y_shrinkage;
			-- Limit angles to mostly horizontal ones.
			fTilt = 145 + TerrainBuilder.GetRandomNumber(90, "Angle for island chain axis - LUA");
			if fTilt > 180 then
				fTilt = fTilt - 180;
			end
			-- Determine "dot box"
			local iInnerWidth = math.floor(iWidth / 2);
			local iInnerHeight = iHeight - 2;
			local iInnerWest = 2 + TerrainBuilder.GetRandomNumber((iWidth - 1) - iInnerWidth, 
				"Shift for sub island group - Lua");
			local iInnerSouth = 2;
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(10, "Diceroll - Lua");
			local iNumDots = 5;
			if die_1 + die_2 > 1 then
				iNumDots = iNumDots + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots = iNumDots + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithShiftedDots(
				iWidth, 
				iHeight, 
				fTilt, 
				iInnerWidth, 
				iInnerHeight, 
				iInnerWest, 
				iInnerSouth, 
				iNumDots)
		
		elseif formation_type == 5 then -- Double Cell, Vertical, Axis Only
			local x_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Width adjustment - Lua");
			if x_shrinkage > 2 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(7, "Cell Height adjustment - Lua");
			if y_shrinkage > 4 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth - x_shrinkage;
			iHeight = iCellHeight * 2 - y_shrinkage;
			-- Limit angles to mostly vertical ones.
			fTilt = 55 + TerrainBuilder.GetRandomNumber(71, "Angle for island chain axis - LUA");
			plot_data = CreateSingleAxisIslandChain(iWidth, iHeight, fTilt)
	
		elseif formation_type == 6 then -- Double Cell, Vertical With Dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Width adjustment - Lua");
			if x_shrinkage > 2 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(7, "Cell Height adjustment - Lua");
			if y_shrinkage > 4 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth - x_shrinkage;
			iHeight = iCellHeight * 2 - y_shrinkage;
			-- Limit angles to mostly vertical ones.
			fTilt = 55 + TerrainBuilder.GetRandomNumber(71, "Angle for island chain axis - LUA");
			-- Determine "dot box"
			local iInnerWidth = iWidth - 2;
			local iInnerHeight = math.floor(iHeight / 2);
			local iInnerWest = 2;
			local iInnerSouth = 2 + TerrainBuilder.GetRandomNumber((iHeight - 1) - iInnerHeight, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(10, "Diceroll - Lua");
			local iNumDots = 5;
			if die_1 + die_2 > 1 then
				iNumDots = iNumDots + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots = iNumDots + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithShiftedDots(
				iWidth, 
				iHeight, 
				fTilt, 
				iInnerWidth, 
				iInnerHeight, 
				iInnerWest, 
				iInnerSouth, 
				iNumDots)
	
		elseif formation_type == 7 then -- Triple Cell, Vertical With Double Dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(4, "Cell Width adjustment - Lua");
			if x_shrinkage > 1 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(9, "Cell Height adjustment - Lua");
			if y_shrinkage > 5 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth - x_shrinkage;
			iHeight = iCellHeight * 3 - y_shrinkage;
			-- Limit angles to steep ones.
			fTilt = 70 + TerrainBuilder.GetRandomNumber(41, "Angle for island chain axis - LUA");
			-- Handle Dots Group 1.
			local iInnerWidth1 = iWidth - 3;
			local iInnerHeight1 = iCellHeight - 1;
			local iInnerWest1 = 2 + TerrainBuilder.GetRandomNumber(2, 
				"Shift for sub island group - Lua");
			local iInnerSouth1 = 2 + TerrainBuilder.GetRandomNumber(iCellHeight - 3, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots1 = 4;
			if die_1 + die_2 > 1 then
				iNumDots1 = iNumDots1 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots1 = iNumDots1 + die_1 + die_2;
			end
			-- Handle Dots Group 2.
			local iInnerWidth2 = iWidth - 3;
			local iInnerHeight2 = iCellHeight - 1;
			local iInnerWest2 = 2 + TerrainBuilder.GetRandomNumber(2, 
				"Shift for sub island group - Lua");
			local iInnerSouth2 = iCellHeight + 2 + TerrainBuilder.GetRandomNumber(iCellHeight - 3, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots2 = 4;
			if die_1 + die_2 > 1 then
				iNumDots2 = iNumDots2 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots2 = iNumDots2 + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithDoubleDots(
				iWidth, 
				iHeight, 
				fTilt, 
				iInnerWidth1, 
				iInnerHeight1, 
				iInnerWest1, 
				iInnerSouth1,
				iNumDots1, 
				iInnerWidth2, 
				iInnerHeight2, 
				iInnerWest2, 
				iInnerSouth2, 
				iNumDots2)
		elseif formation_type == 8 then -- Square Block 2x2 With Double Dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(6, "Cell Width adjustment - Lua");
			if x_shrinkage > 4 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 3 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth * 2 - x_shrinkage;
			iHeight = iCellHeight * 2 - y_shrinkage;
			-- Full range of angles
			fTilt = TerrainBuilder.GetRandomNumber(181, "Angle for island chain axis - LUA");
			-- Handle Dots Group 1.
			local iInnerWidth1 = iCellWidth - 2;
			local iInnerHeight1 = iCellHeight - 2;
			local iInnerWest1 = 3 + TerrainBuilder.GetRandomNumber(iCellWidth - 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth1 = 3 + TerrainBuilder.GetRandomNumber(iCellHeight - 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(6, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(10, "Diceroll - Lua");
			local iNumDots1 = 5;
			if die_1 + die_2 > 1 then
				iNumDots1 = iNumDots1 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots1 = iNumDots1 + die_1 + die_2;
			end
			-- Handle Dots Group 2.
			local iInnerWidth2 = iCellWidth - 2;
			local iInnerHeight2 = iCellHeight - 2;
			local iInnerWest2 = 3 + TerrainBuilder.GetRandomNumber(iCellWidth - 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth2 = 3 + TerrainBuilder.GetRandomNumber(iCellHeight - 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots2 = 5;
			if die_1 + die_2 > 1 then
				iNumDots2 = iNumDots2 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots2 = iNumDots2 + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithDoubleDots(
				iWidth, iHeight, 
				fTilt, 
				iInnerWidth1, iInnerHeight1, iInnerWest1, iInnerSouth1,	iNumDots1, 
				iInnerWidth2, iInnerHeight2, iInnerWest2, iInnerSouth2, iNumDots2)

		elseif formation_type == 9 then -- Horizontal Block 3x2 With Double Dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(8, "Cell Width adjustment - Lua");
			if x_shrinkage > 5 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(5, "Cell Height adjustment - Lua");
			if y_shrinkage > 3 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth * 3 - x_shrinkage;
			iHeight = iCellHeight * 2 - y_shrinkage;
			-- Limit angles to mostly horizontal ones.
			fTilt = 145 + TerrainBuilder.GetRandomNumber(90, "Angle for island chain axis - LUA");
			if fTilt > 180 then
				fTilt = fTilt - 180;
			end
			-- Handle Dots Group 1.
			local iInnerWidth1 = iCellWidth;
			local iInnerHeight1 = iCellHeight - 2;
			local iInnerWest1 = 4 + TerrainBuilder.GetRandomNumber(iCellWidth + 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth1 = 3 + TerrainBuilder.GetRandomNumber(iCellHeight - 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots1 = 9;
			if die_1 + die_2 > 1 then
				iNumDots1 = iNumDots1 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots1 = iNumDots1 + die_1 + die_2;
			end
			-- Handle Dots Group 2.
			local iInnerWidth2 = iCellWidth;
			local iInnerHeight2 = iCellHeight - 2;
			local iInnerWest2 = 4 + TerrainBuilder.GetRandomNumber(iCellWidth + 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth2 = 3 + TerrainBuilder.GetRandomNumber(iCellHeight - 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(5, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(7, "Diceroll - Lua");
			local iNumDots2 = 8;
			if die_1 + die_2 > 1 then
				iNumDots2 = iNumDots2 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots2 = iNumDots2 + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithDoubleDots(
				iWidth, iHeight, 
				fTilt, 
				iInnerWidth1, iInnerHeight1, iInnerWest1, iInnerSouth1, iNumDots1, 
				iInnerWidth2, iInnerHeight2, iInnerWest2, iInnerSouth2, iNumDots2)

		elseif formation_type == 10 then -- Vertical Block 2x3 With Double Dots
			local x_shrinkage = TerrainBuilder.GetRandomNumber(6, "Cell Width adjustment - Lua");
			if x_shrinkage > 4 then
				x_shrinkage = 0;
			end
			local y_shrinkage = TerrainBuilder.GetRandomNumber(8, "Cell Height adjustment - Lua");
			if y_shrinkage > 5 then
				y_shrinkage = 0;
			end
			x_shift, y_shift = 0, 0;
			if x_shrinkage > 0 then
				x_shift = TerrainBuilder.GetRandomNumber(x_shrinkage, "Cell Width offset - Lua");
			end
			if y_shrinkage > 0 then
				y_shift = TerrainBuilder.GetRandomNumber(y_shrinkage, "Cell Height offset - Lua");
			end
			iWidth = iCellWidth * 2 - x_shrinkage;
			iHeight = iCellHeight * 3 - y_shrinkage;
			-- Mostly vertical
			fTilt = 55 + TerrainBuilder.GetRandomNumber(71, "Angle for island chain axis - LUA");
			-- Handle Dots Group 1.
			local iInnerWidth1 = iCellWidth - 2;
			local iInnerHeight1 = iCellHeight;
			local iInnerWest1 = 3 + TerrainBuilder.GetRandomNumber(iCellWidth - 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth1 = 4 + TerrainBuilder.GetRandomNumber(iCellHeight + 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(10, "Diceroll - Lua");
			local iNumDots1 = 8;
			if die_1 + die_2 > 1 then
				iNumDots1 = iNumDots1 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots1 = iNumDots1 + die_1 + die_2;
			end
			-- Handle Dots Group 2.
			local iInnerWidth2 = iCellWidth - 2;
			local iInnerHeight2 = iCellHeight;
			local iInnerWest2 = 3 + TerrainBuilder.GetRandomNumber(iCellWidth - 2, 
				"Shift for sub island group - Lua");
			local iInnerSouth2 = 4 + TerrainBuilder.GetRandomNumber(iCellHeight + 2, 
				"Shift for sub island group - Lua");
			-- Determine number of dots
			local die_1 = TerrainBuilder.GetRandomNumber(4, "Diceroll - Lua");
			local die_2 = TerrainBuilder.GetRandomNumber(8, "Diceroll - Lua");
			local iNumDots2 = 7;
			if die_1 + die_2 > 1 then
				iNumDots2 = iNumDots2 + TerrainBuilder.GetRandomNumber(die_1 + die_2, 
					"Number of dots to add to island chain - Lua");
			else
				iNumDots2 = iNumDots2 + die_1 + die_2;
			end
			plot_data = CreateAxisChainWithDoubleDots(
				iWidth, iHeight, 
				fTilt, 
				iInnerWidth1, iInnerHeight1, iInnerWest1, iInnerSouth1, iNumDots1, 
				iInnerWidth2, iInnerHeight2, iInnerWest2, iInnerSouth2, iNumDots2)
		end

		-- Obtain land plots from the plot data
		local x_adjust = xMargin + (cell_x - 1) * iCellWidth  + x_shift;
		local y_adjust = yMargin + (cell_y - 1) * iCellHeight + y_shift;
		for y = 1, iHeight do
			for x = 1, iWidth do
				local data_index = (y - 1) * iWidth + x;
				if plot_data[data_index] == true then -- This plot is land.
					local real_x = x + x_adjust - 1;
					local real_y = y + y_adjust - 1;
					local plot_index = real_y * g_iW + real_x + 1;
					island_chain_PlotTypes[plot_index] = g_PLOT_TYPE_LAND;
				end
			end
		end
	
		-- Record cells in use
		if formation_type == 1 then -- single cell
			cell_data[anchor_cell] = true;
			iNumCellsInUse = iNumCellsInUse + 1;
		elseif formation_type == 2 then
			cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
			iNumCellsInUse = iNumCellsInUse + 2;
		elseif formation_type == 3 then
			cell_data[anchor_cell] = true;
			iNumCellsInUse = iNumCellsInUse + 1;
		elseif formation_type == 4 then
			cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
			iNumCellsInUse = iNumCellsInUse + 2;
		elseif formation_type == 5 then
			cell_data[anchor_cell], cell_data[anchor_cell + iNumCellColumns] = true, true;
			iNumCellsInUse = iNumCellsInUse + 2;
		elseif formation_type == 6 then
			cell_data[anchor_cell], cell_data[anchor_cell + iNumCellColumns] = true, true;
			iNumCellsInUse = iNumCellsInUse + 2;
		elseif formation_type == 7 then
			cell_data[anchor_cell], cell_data[anchor_cell + iNumCellColumns] = true, true;
			cell_data[anchor_cell + (iNumCellColumns * 2)] = true;
			iNumCellsInUse = iNumCellsInUse + 3;
		elseif formation_type == 8 then
			cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
			cell_data[anchor_cell + iNumCellColumns], 
			cell_data[anchor_cell + iNumCellColumns + 1] = true, true;
			iNumCellsInUse = iNumCellsInUse + 4;
		elseif formation_type == 9 then
			cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
			cell_data[anchor_cell + iNumCellColumns], 
			cell_data[anchor_cell + iNumCellColumns + 1] = true, true;
			cell_data[anchor_cell + 2], 
			cell_data[anchor_cell + iNumCellColumns + 2] = true, true;
			iNumCellsInUse = iNumCellsInUse + 6;
		elseif formation_type == 10 then
			cell_data[anchor_cell], 
			cell_data[anchor_cell + 1] = true, true;
			cell_data[anchor_cell + iNumCellColumns], 
			cell_data[anchor_cell + iNumCellColumns + 1] = true, true;
			cell_data[anchor_cell + (iNumCellColumns * 2)], 
			cell_data[anchor_cell + (iNumCellColumns * 2) + 1] = true, true;
			iNumCellsInUse = iNumCellsInUse + 6;
		end
	end
	
	return island_chain_PlotTypes;
end

function GenerateClusters(invertExtras)
	-- Generate clusters of islands
	--
	-- Return a map of generated island plot types.
	print("Generating clusters.");
		
	local worldSizeArgs = ScriptData.worldSizeInfo.clusters or {};
	
	local lakeGrain = 3;
	local lakeLevelOffset = 0;
	if (ExtrasGot.everything == true) then
		-- Got "everything" for extras.
		-- Use a lower grain to distinguish clusters from other extras.
		lakeGrain = 2;
	
	elseif (UserInput.landmass == Landmasses.INVEXTRAS) then
		-- Inverted Extras
		-- Raise sea level to increase lakes
		lakeLevelOffset = -12;
	end
	
	-- Generate a lakes fractal that doesn't have clusters yet.
	local plotTypes = GenerateLakesForClusters(invertExtras, lakeGrain, lakeLevelOffset);
	
	-- Target size for islands/lakes in a cluster.
	local targetSize = worldSizeArgs.targetSize or (LAKE_MAXNUMTILES+1);
	print("Target island/lake size: ", targetSize);
	
	-- Freshen the lakes.
	FreshenLakes(plotTypes, targetSize, false);
	
	-- We want islands, not lakes.
	-- But we started with lakes, so invert the lakes into islands.
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
			if (plotTypes[i] == g_PLOT_TYPE_OCEAN) then
				plotTypes[i] = g_PLOT_TYPE_LAND;
			else
				plotTypes[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
	
	return plotTypes;
end

function RandomSlice(rDonut)
	-- Args: 
	--    rDonut: the radius of the donut; determines mimimum slice length
	--
	-- Return [length, offset] 
	--   length: the length of the slice in radians
	--   offset: rotate the slice counter-clockwise by this much in radians.
	--     A slice with an offset of 0 begins at 6:00

	-- Enforce a minimum slice length based on donut size to avoid slices 
	-- that don't look anything like a donut.

	-- Default min length.
	local minLength = math.pi;
	
	if (rDonut >= 8) then
		minLength = TAU/3;
	end
	
	local length = RandomRadians(minLength);
	local offset = RandomRadians();
	
	--print("Slice length " .. RadString(length));
	--print("Slice offset " .. RadString(offset));
	
	return length, offset;
end

function IsInSlice(enableSlicing, theta, sliceLength)
	-- Determine whether a certain donut plot is part of the slice to include.
	--
	-- Args:
	--   enableSlicing: if false, then bypass this check and just return true
	--     so that the entire donut is in the slice.
	--   theta: angle to check
	--   sliceLength: the length of the slice in radians
	--
	-- Returns true if doWholeSlice is enabled or theta is in [0,sliceLength).

	if (enableSlicing == false) then
		-- Forcing an unsliced donut.
		return true;
	end
	
	return ((0 <= theta) and (theta < sliceLength));
end

function GenerateMiniDonut(island_plotTypes, centerX, centerY, args)
	-- Generate a single mini-donut.
	--
	-- Args
	--   island_plotTypes: add the mini-donut to this map.
	--   centerX,centerY: target location of the donut's center.
	--   args: donut args from landmass/extras config; ignored if nil
	
	-- Note: some landmasses such as Pangea may shift the mini donut 
	-- as part of landmass generation.
	--print("Generating mini-donut at " .. CoordString(centerX,centerY));
	local args = args or {};
		
	-- If the center is on an odd row then shift x to account for hex grid.
	-- When calculating Euclidian distance.
	local centerXEucl = centerX;
	if ((centerY % 2) == 1) then
		centerXEucl = centerXEucl + 0.5;
	end
	
	-- Randomize donut radius based min and max.
	local rMin = args.rMin or 2;
	local rMax = args.rMax or 3;
	local rDonut = rMin + TerrainBuilder.GetRandomNumber(rMax-rMin+1, "M-Donut radius");
	--print("Donut radius: " .. rDonut);
	
	-- Donut thicknesss range as a percentage of radius.
	local tMin = args.tMin or 1;
	local tMax = args.tMax or 100;
	tMin = math.clamp(tMin, 1,    100);
	tMax = math.clamp(tMax, tMin, 100);
	local thicknessPct = 
		tMin + TerrainBuilder.GetRandomNumber(tMax-tMin+1, "M-Donut thickness pct");
	local thickness = math.max(1, Round(rDonut*thicknessPct/100));
	--print("Donut thickness: " .. thickness);
	
	-- Use thickness to determine range for hole radius.
	-- The hole is the circle of water at the donut's center.
	-- A negative radius means no hole (filled donut).
	local rHole = rDonut - thickness;
	--print("Donut hole radius: " .. rHole);
	
	-- Donut slice boundaries.
	local sliceLength = TAU;
	local sliceOffset = 0;
	local enableSlicing = args.enableSlicing or false;
	if (enableSlicing == false) then
		--print("No slicing.");
	else
		sliceLength, sliceOffset = RandomSlice(rDonut);
	end
	
	-- Limit which plots to visit; improves performance.
	local rDonutBound = 2*rDonut;	
	local westX = centerX - rDonutBound;
	local eastX = centerX + rDonutBound;
	local southY = math.max(0,    centerY - rDonutBound);
	local northY = math.min(g_iH-1, centerY + rDonutBound);

	if (ScriptData.wrapX == false) then
		-- Regional map: don't wrap donuts in the x-direction. 
		westX  = math.max(0,    westX);
		eastX  = math.min(g_iW-1, eastX);
	end
	
	--print("Donut boundary: " .. CoordString(westX, southY) .. " to " .. CoordString(eastX, northY)); 

	-- Use a fractal to add watery imperfections to the donut.
	local baysGrain  = 5;
	if (rDonut >= 10) then
		-- Use larger bays for larger donuts.
		baysGrain = 4;
	end
	--print("Bays grain " .. baysGrain);	
	local baysHeight = args.baysHeight or 74;
	local fracFlags  = {FRAC_WRAP_X = true, FRAC_POLAR = true};
	local baysFrac   = Fractal.Create(g_iW, g_iH, baysGrain, fracFlags, -1, -1);
	local iBaysThreshold = GetFractalHeight(baysFrac, baysHeight);
	
	
	-- Loop through plots in the donut's bounding box and add land
	-- to the plots that are part of the donut.
	for x = westX, eastX do
		local plotX = x % g_iW;
		local euclX = x;
		--print("Column " .. plotX);
	
		for y = southY, northY do		
			-- Use Euclidian distance so that donuts look circular despite hex tiles.
			-- If y is an odd row then account for hex-grid tile-shift.
			if ((y % 2) == 1) then
				euclX = x + 0.5;
			else
				euclX = x;
			end
			
			local deltaX = euclX - centerXEucl;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			
			-- Use rounded Euclidian distance to improve donut symmetry.
			local d = Round(math.sqrt(deltaXSquared + deltaYSquared));
						
			-- Convert cartesian coords to theta so that we can take a 
			-- slice of the donut.
			--
			-- Offset theta to the range [0,2pi]
			local theta = math.atan2(deltaX, deltaY) + math.pi + sliceOffset;
			if (theta > TAU) then
				theta = theta - TAU;
			end

			-- Check whether to add fractal water to this tile.
			local baysVal = baysFrac:GetHeight(x, y);
			
			if ((rHole < d) and (d <= rDonut) and
			    (IsInSlice(enableSlicing, theta, sliceLength) == true) and
				(baysVal < iBaysThreshold)) then
				-- Donut land.		
				local i = y * g_iW + plotX + 1;
				
				island_plotTypes[i] = g_PLOT_TYPE_LAND;
				--print("Donut at " .. CoordString(deltaX,deltaY) .. " theta " .. theta);
				
			elseif (d <= rHole) then
				-- Donut hole.
				--local i = y * g_iW + plotX + 1;
				--ScriptData.donutFillingMap[i] = FILLING_YES;	
				--print("Filling at " .. CoordString(deltaX,deltaY) .. " theta " .. theta);
			end
		end
	end
end

function GenerateMiniDonuts(args)
	-- Generate mini-donut islands
	-- Args:
	--   args.doInverted: if true, then adjust water levels for mini-donut lakes
	--   args.baysHeight: threshold for the mini-donut bays fractal
	--   args.numDonutsPerCell: how many donuts to add to each cell in the donut grid
	--   args.numExtraDonutsMult: multiplier for the number of extra donuts to add
	--      anywhere on the map
	--   args.rMult: radius multiplier
	-- Returns a map of generated island plot types.
	print("Generating mini-donuts.");
	
	-- Args for mini-donuts.
	local args = args or {};
	
	-- Args to pass into the per-donut helper function.
	local donutArgs = {};
	
	-- Some water-level settings reverse when we have inverted extras.
	local invertableSeaLevel  = UserInput.seaLevel;
	local lakeLevel           = UserInput.lakeLevel;
	
	if args.doInverted then
		-- Flip the water levels.
		print("Inverting sea level.");
		invertableSeaLevel = 4 - invertableSeaLevel;
	end	
	
	local island_PlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);
	
	local worldSizeArgs = ScriptData.worldSizeInfo.miniDonuts or {};
	
	-- Donut integrity.
	-- higher number => more donut	
	donutArgs.baysHeight = args.baysHeight or MINIDONUT_BAYS_HEIGHT_DEFAULT;
	--print("Bays Height ", donutArgs.baysHeight);

	-- Use a cell system to distribute donuts across the map.
	-- Divide the map into a dozen cells by default.
	local numCellColumns = 4;
	local numCellRows    = 3;
		
	-- Check the aspect ratio of the grid.
	local ratio   = g_iW / g_iH; -- We've got bigger problems if H is 0.
	local epsilon = 0.1;
	
	if (ratio > (4 - epsilon)) then
		-- Got a 4:1 grid.
		print("Using 6x2 donut grid (custom 4:1 aspect ratio)");
		numCellColumns = 6;
		numCellRows    = 2;
		
	elseif (ratio > (2 - epsilon)) then
		-- Got a 2:1 grid.
		-- Use 5 columns instead of 4 so that donuts are smaller than bagels.
		print("Using 5x2 donut grid (custom 2:1 aspect ratio)");
		numCellColumns = 5;
		numCellRows    = 2;
		
	elseif (ratio < (1 + epsilon)) then
		-- Got a square
		print("Using 3x3 donut grid (custom 1:1 aspect ratio)");
		numCellColumns = 3;
		numCellRows    = 3;
	end
	
	local numTotalCells = numCellColumns * numCellRows;
	
	-- Donut radius range based on grid size, landmass, extras, and sea level.
	-- Use floating numbers here; will round when calculating radius.
	local cellWidth  = g_iW / numCellColumns;
	local cellHeight = g_iH / numCellRows;
	--print("Cell size (w,h): ",  CoordString(cellWidth, cellHeight));
	local cellLength = math.min(cellWidth, cellHeight);
	print("Cell length: " .. cellLength);
	-- Use cell size to determine the base radius range.
	local rMin = cellLength*0.25;
	local rMax = cellLength*0.4;
	print("Radius range based on cell length: ", CoordString(rMin, rMax));
	--
	local rMult = args.rMult or 1;
	rMin = math.max(1, Round(rMin * rMult));
	rMax = math.max(1, Round(rMax * rMult));
	print("Radius range with landmass & extras: ", CoordString(rMin, rMax));
	-- Offset radius range based on sea level.
	local rOffset = Round((rMax-rMin)/2);
	if (invertableSeaLevel == SEALEVEL_LOW) then
		if (rOffset > 0) then
			-- Raise min radius to enlarge donuts.
			rMin = rMin + rOffset;
		else
			rMax = rMax + 1;
		end
	elseif (invertableSeaLevel == SEALEVEL_HIGH) then
		if (rOffset > 0) then
			-- Lower max radius to shrink donuts.
			rMax = rMax - rOffset;
		else
			rMin = rMin - 1;
		end
	end
	rMax = math.max(rMin, rMax);
	print("Radius range with sea level: ", CoordString(rMin, rMax));
	donutArgs.rMin = rMin;
	donutArgs.rMax = rMax;
	
	-- Min/Max donut thickness as a percentage of radius, based on lake level.
	-- Higher lake level => higher thickness => smaller donut hole 
	--   => more land with which to generate fresh lakes.
	local tMins  = {20, 40, 60};
	local tMaxes = {40, 60, 80};
	local tMin = tMins[lakeLevel];
	local tMax = tMaxes[lakeLevel];
	print("Thickness range: ", CoordString(PercentString(tMin), PercentString(tMax)));
	donutArgs.tMin = tMin;
	donutArgs.tMax = tMax;

	-- Choose a random cell to let a donut "escape" to anywhere on the map.
	-- Makes the donut grid less obvious.
	local iEmptyCell = 1 + TerrainBuilder.GetRandomNumber(numTotalCells, "Empty mini-donut cell");
	
	-- Use a shuffled grid of donut types so that we can balance
	-- randomness with consistency between maps.
	local cellNotSliced = 0; -- Not sliced.
	local cellSliced    = 1; -- Randomly sliced.	
	local cellTypes = table.fill(cellNotSliced, numTotalCells);

	-- Percentage of sliced donut instead of unsliced donut.
	local slicedPct = 25;
	local numSlicedCells = math.clamp(0, numTotalCells, Round(numTotalCells*slicedPct/100));
	--print("Number of sliced cells: ", numSlicedCells);
	for i = 1, numSlicedCells do
		cellTypes[i] = cellSliced;
	end
	cellTypes = GetShuffledCopyOfTable(cellTypes);
		
	-- Add padding to cells to reduce overlap between donuts.
	-- Slightly less than rMax to make cell grid less obvious.
	local cellPaddingX = math.floor(math.clamp(donutArgs.rMax-1, 0, cellWidth/3));
	local cellPaddingY = math.floor(math.clamp(donutArgs.rMax-1, 0, cellHeight/3));
	--print("Cell padding: ", CoordString(cellPaddingX, cellPaddingY));

	local numDonutsPerCell = args.numDonutsPerCell or 2;
	print("Numer of donuts per cell: " .. numDonutsPerCell);
	
	-- Boundaries for the current cell.
	local iWestX  = 0;
	local iEastX  = 0;
	local iSouthY = 0;
	local iNorthY = 0;
	local iCell = 1;
	for iRow = 1, numCellRows do
		-- Advance to the next row.
		iEastX  = 0;
		iSouthY = iNorthY;
		iNorthY = math.floor(iRow * cellHeight);
	
		for iCol = 1, numCellColumns do
			-- Advance to the next column.
			iWestX = iEastX;
			iEastX = math.floor(iCol * cellWidth);
			
			for iDonutPerCell = 1, numDonutsPerCell do
			
				local donutX, donutY;
				
				if (iCell == iEmptyCell) then
					-- Empty cell: donut can be anywhere on the map.
					donutX = cellPaddingX + TerrainBuilder.GetRandomNumber(
						g_iW - 2*cellPaddingX, "Mini-Donut X (empty cell)");
					donutY = cellPaddingY + TerrainBuilder.GetRandomNumber(
						g_iH - 2*cellPaddingY, "Mini-Donut Y (empty cell)");
				else
					--print("Current cell is " .. 
					--      CoordString(iWestX, iSouthY) .. " to " .. 
					--      CoordString(iEastX, iNorthY));
				
					-- Choose a random location for the donut in the cell.
					donutX = iWestX + cellPaddingX + 
						TerrainBuilder.GetRandomNumber(
							iEastX  - iWestX - 2*cellPaddingX,  "Mini-Donut Cell X");
						
					donutY = iSouthY + cellPaddingY + 
						TerrainBuilder.GetRandomNumber(
							iNorthY - iSouthY - 2*cellPaddingY, "Mini-Donut Cell Y");
				end
				
				-- Check the cell grid to decide whether to slice this donut.
				donutArgs.enableSlicing = (cellTypes[iCell] == cellSliced);
					
				-- Generate the donut.
				GenerateMiniDonut(island_PlotTypes, donutX, donutY, donutArgs);
			end
			
			-- Advance to the next cell.
			iCell = iCell + 1;
		end
	end
		
	-- Place additional, smaller donuts anywhere on the map.
	local numExtraDonuts = worldSizeArgs.numExtraDonuts or 10;
	local numExtraDonutsMult = args.numExtraDonutsMult or 1;
	numExtraDonuts = Round(numExtraDonuts * numExtraDonutsMult);
	
	print("Placing " .. numExtraDonuts .. " additional donut(s).");
	donutArgs.rMin = 1;
	donutArgs.rMax = math.max(1,Round(donutArgs.rMax/2));
	
	for iDonut = 1, numExtraDonuts do
		local donutX = cellPaddingX + TerrainBuilder.GetRandomNumber(
			g_iW - 2*cellPaddingX, "Mini-Donut X");
		local donutY = cellPaddingY + TerrainBuilder.GetRandomNumber(
			g_iH - 2*cellPaddingY, "Mini-Donut Y");
		
		-- Randomly decide whether to slice the extra donut.
		donutArgs.enableSlicing = 
		  (TerrainBuilder.GetRandomNumber(100, "Extra donut slicing.") < slicedPct);
		
		GenerateMiniDonut(island_PlotTypes, donutX, donutY, donutArgs);
	end
	
	--print("Done generating mini-donuts.");
	return island_PlotTypes;
end

function GenerateSprinkles(inverted)
	-- Generate sprinkles of fractal extras
	-- Return a map of generated island plot types.
	print("Generating sprinkles.");
	
	local invertableSeaLevel = UserInput.seaLevel;
	if (inverted == true) then
		-- The above levels are calibrated for islands.
		-- Reverse order for lakes.
		invertableSeaLevel = 4 - invertableSeaLevel;
	end
	
	-- Map sea levels to water percent thresholds.
	local sea_levels = {75,78,81};
	local sea_level  = sea_levels[invertableSeaLevel] or 
			           sea_levels[SEALEVEL_NORMAL]    or 78;
	
	--print("sprinkles sea level: ", sea_level);
	
	local plotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
		
	-- Use high-grain fractal to produce tiny island sprinkles.
	local grain = 5;
		
	-- Generate the fractal.
	local landFrac = Fractal.Create(g_iW, g_iH, grain, g_iFlags, g_fracXExp, g_fracYExp);
	
	-- Use end-range filter to create normal-looking islands.
	local landBottom = GetFractalHeight(landFrac, sea_level);
	
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
			local landVal = landFrac:GetHeight(x, y);
			
			if (landVal >= landBottom) then
				plotTypes[i] = g_PLOT_TYPE_LAND;
			end
		end
	end
	
	return plotTypes;
end

function GenerateTectonicIslands(mainlandPlots, mtnPlots, args)
	-- Generate tectonic islands.
	-- Apply a fractal filter to the mountain pattern.
	--
	-- Args:
	--   mainlandPlots: a map of plots generated by the landmass.
	--   mtnPlots: a map of mountains or trenches generated by a mountain pattern
	--   args.invertExtras: if true, then generate islands to convert into trenches.
	--   args.tectonicFlags: flags for the tectonic islands fractal
	--   args.tectonicGrain: granularity of the tectonic islands fractal
	--   args.tectonicLandOffset: offset to adjust sea level (higher value => more land)
	--   args.tectonicSeaMultiplier: multiplier for the tectonic island fractal's sea-level
	-- Returns:
	--   plotTypes: a map of plots such that land represents tectonic islands/lakes
	print("Generating tectonic extras.");

	local plotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	
	local args = args or {};	
		
	local flags      = args.tectonicFlags  or {};
	local grain      = args.tectonicGrain  or 2;
	
	-- Add a tectonic fractal layer to govern mountains replacing water tiles.
	local tectonicFrac = Fractal.Create(
		g_iW, g_iH, 
		grain,
		flags, 
		g_fracXExp, g_fracYExp);
		
	local seaLevel = UserInput.seaLevel;
	local worldAge = UserInput.worldAge;
	local invertExtras = args.invertExtras;
	local srcPlotMatch = g_PLOT_TYPE_MOUNTAIN;
	
	if invertExtras then		
		-- Prevents overwriting mountain ranges with water.
		srcPlotMatch = g_PLOT_TYPE_OCEAN;
	end	
		
	-- Determine how much of the world's water to turn into islands.
	local flatLevel = 25;
	
	-- Higher sea level => lower percentage of the world for islands.
	local seaLevel = UP_TO_DOWN[seaLevel];
	
	local tecSeaMultiplier = args.tectonicSeaMultiplier  or 1;
	seaLevel = seaLevel * tecSeaMultiplier;
	
	flatLevel = flatLevel - (seaLevel * 5);
	
	-- Adding tectonic islands/trenches as extras
	if (ExtrasGot.everything == true) then
		-- Got "everything" for extras.
		-- Reduce islands to make room for other types of extras.
		flatLevel = 0.6 * flatLevel;
		
	elseif (ExtrasGot.tecAndChains == true) then
		-- Got "tectonic and chains" for extras.
		-- Reduce islands to make room for other extras.
		flatLevel = 0.8 * flatLevel;
	end
	
	-- Offset thresholds for certain extras-oriented landmasses.
	local landmassOffset  = args.tectonicLandOffset or 0;
	flatLevel = flatLevel * (1 + landmassOffset);
	
	-- Determine how much of the land to turn into hills and mountains.
	local mtnAdjust, hillAdjust = GetMountainAdjustments();
	
	local mtnLevel  = flatLevel * mtnAdjust/100;
	local hillLevel = flatLevel * hillAdjust/100;
	
	local iMtnBase  = 100 - mtnLevel;
	local iHillBase = iMtnBase - hillLevel;
	local iFlatBase = 100 - flatLevel;
	
	print("iMtnBase: ", iMtnBase);
	print("iHillBase: ", iHillBase);
	print("iFlatBase: ", iFlatBase);
	
	-- Thresholds at which mountains rise above the surface of the ocean.
	local name  = "tectonic islands";
	local iMtn  = GetFractalHeight(tectonicFrac, iMtnBase,  name);
	local iHill = GetFractalHeight(tectonicFrac, iHillBase, name);
	local iFlat = GetFractalHeight(tectonicFrac, iFlatBase, name);
	
	-- Count # of mts, hills, islands added
	local numMts   = 0;
	local numHills = 0;
	local numFlats = 0;
		
	-- Apply mountain plot types to the main map.
	for x = 0, g_iW - 1, 1 do
		for y = 0, g_iH - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			
			local isMatch = (mtnPlots[i] == srcPlotMatch);
			if (not isMatch) then
				-- Check adjacent plots for a match to expand tectonic islands.
				for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
					local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
					if (adjacentPlot ~= nil) then
						local iAdj = GetPlotIndexLua(adjacentPlot:GetX(), adjacentPlot:GetY());
						if (mtnPlots[iAdj] == srcPlotMatch) then
							isMatch = true;
						end
					end
				end
			end

			if (isMatch and (invertExtras or (mainlandPlots[i] == g_PLOT_TYPE_OCEAN))) then
				-- Match from the mountain pattern
				-- Avoid overwriting the mainland with tectonic islands.
				local tectonicVal = tectonicFrac:GetHeight(x,y);
			
				-- Use a fractal to decide which mountains rise above the water.
				if (tectonicVal >= iMtn) then
					-- Replace a water tile with a mountain.
					plotTypes[i] = g_PLOT_TYPE_MOUNTAIN;
					numMts = numMts + 1;
					
				elseif (tectonicVal >= iHill) then
					-- Replace a water tile with a hill.
					plotTypes[i] = g_PLOT_TYPE_HILLS;
					numHills = numHills + 1;
				
				elseif (tectonicVal >= iFlat) then
					-- Replace a water tile with flat land
					plotTypes[i] = g_PLOT_TYPE_LAND;
					numFlats = numFlats + 1;
				end
			end
		end
	end
		
	-- Higher sea level => higher threshold => less shallow water from mountains
	seaLevels = {0, 15, 30}; 
	seaLevel = seaLevels[UserInput.seaLevel];
	
	local mtnThresh = GetFractalHeight(tectonicFrac, 15 + seaLevel);
	local shallowCount = 0;
	
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do
			local i = GetPlotIndexLua(iX,iY);
			if (ScriptData.coastPlots[i] == g_PLOT_TYPE_OCEAN) then
				-- Check mountain and tectonic island maps, 
				-- decide whether to add shallow water for submerged mountain
				
				if ((plotTypes[i] == g_PLOT_TYPE_OCEAN) and 
				    (mtnPlots[i] == g_PLOT_TYPE_MOUNTAIN)) then
					-- A submerged mountain from the mountain pattern.
					
					local tectonicVal = tectonicFrac:GetHeight(iX,iY);
					if (tectonicVal >= mtnThresh) then
						-- Land in the coast map counts as coast later in map-gen.
						ScriptData.coastPlots[i] = g_PLOT_TYPE_LAND;
						shallowCount = shallowCount + 1;
					end
				end
			end
		end
	end
	
	-- Note: coastal mountains may become hills during feature generation.
	print("Tectonic tiles added: ");
	print("  Mtns:     ", numMts);
	print("  Hills:    ", numHills);
	print("  Flats:    ", numFlats);
	print("  Shallows: ", shallowCount);
	
	return plotTypes;
end

function MergeChains(destPlotTypes, srcPlotTypes)
	-- Merge chains onto a map, allowing land and possibly adjacent water 
	-- from the source to overwrite plots from the destination.
	--
	-- Do this before adding mountains and hills.
	-- 
	-- args:
	--   destPlotTypes: destination for merged extras
	--   srcPlotTypes: extras to merge
	
	--print("Merging chains.");
	local sea_thresholds = {10, 20, 30};
	local adj_thresholds = {75, 80, 85, 90, 95, 100};
	
	local sea_level = UserInput.seaLevel;
	
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local iPlot = y * g_iW + x + 1;
				
			local srcPlotType = srcPlotTypes[iPlot];
			
			if (srcPlotType ~= g_PLOT_TYPE_OCEAN) then
				-- Something to merge.
				local dice = TerrainBuilder.GetRandomNumber(100,"Chains isle exclusion");
				if (dice < sea_thresholds[sea_level]) then
					-- Occasionally add land from island chains for inversion.
					destPlotTypes[iPlot] = srcPlotType;
				end
			else
				-- Check for adjacent land.
				local numAdjacentLands = 0;
				for i, direction in ipairs(HexDirections) do
					local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
					
					if (adjacentPlot ~= nil) then
						-- We have an adjacent plot.
						-- Let's see if it's unvisited.
						local aX, aY = adjacentPlot:GetX(), adjacentPlot:GetY();
						local iCouldVisit = aY * g_iW + aX + 1;
					
						if (srcPlotTypes[iCouldVisit] ~= g_PLOT_TYPE_OCEAN) then
							-- Adjacent to land.
							numAdjacentLands = numAdjacentLands + 1;
						end
					end
				end
				
				if (numAdjacentLands > 0) then
					-- This tile is adjacent to an island chain.
					local dice = TerrainBuilder.GetRandomNumber(100,"Chains expansion");		
					if (dice < adj_thresholds[numAdjacentLands]) then
						-- Pretend that coastal water is part of the island chain.
						-- This adds water to inverted chains.
						destPlotTypes[iPlot] = g_PLOT_TYPE_LAND;
					end
				end
			end
		end
	end
	
	--print("Done merging lake chains.");
end

function MergeExtras(mergeLand, destPlotTypes, srcPlotTypes)
	-- Merge extras onto a map, allowing all land from the source to 
	-- overwrite plots from the destination.
	--
	-- Do this before adding mountains and hills.
	-- 
	-- args:
	--   mergeLand: whether to merge as land (true) or as water (false)
	--   destPlotTypes: destination for merged extras
	--   srcPlotTypes: extras to merge
	
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local iPlot = y * g_iW + x + 1;
			local srcPlotType = srcPlotTypes[iPlot];
			
			if (srcPlotType ~= g_PLOT_TYPE_OCEAN) then
				-- Something to merge.
				if (mergeLand == true) then	
					-- Merge the extra land as-is.
					destPlotTypes[iPlot] = srcPlotType;
				else
					-- Turn the extra land into a body of water.
					destPlotTypes[iPlot] = g_PLOT_TYPE_OCEAN;
				end				
			end
		end
	end
	
	--print("Done merging extras.");
end

function MergeExtrasAvoidLandmass(mergeLand, destPlotTypes, srcPlotTypes)
	-- Add extras without touching landmass land.
	-- Island landmasses use this to avoid combining islands into bigger chunks of land.
	--
	-- args:
	--   mergeLand: whether to merge land (true) or water (false)
	--   destPlotTypes: destination for merged extras
	--   srcPlotTypes: extras to merge

	print("Merging extras without touching the landmass.");
	
	if (mergeLand == false) then
		-- We're adding water, so landmass will not get bigger.
		MergeExtras(mergeLand, destPlotTypes, srcPlotTypes);
		return;
	end

	-- Filter the source map to avoid touching the destination map's land.
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local i = y * g_iW + x + 1;
			if srcPlotTypes[i] ~= g_PLOT_TYPE_OCEAN then
				if ((destPlotTypes[i] ~= g_PLOT_TYPE_OCEAN) or 
					IsAdjacentToLand(destPlotTypes, x, y)) then
					
					-- An extra-island plot is overlapping or touching 
					-- the landmass land. So erase the island plot.
					srcPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	end
	
	-- Merge the filtered source map.
	MergeExtras(mergeLand, destPlotTypes, srcPlotTypes);
end

function MergeExtrasPreserveSaltLakes(mergeLand, destPlotTypes, srcPlotTypes)
	-- Add extras without freshening lakes.
	--
	-- args:
	--   mergeLand: whether to merge land (true) or water (false)
	--   destPlotTypes: destination for merged extras
	--   srcPlotTypes: extras to merge

	print("Merging extras, but preserving salty lakes.");
	
	if (mergeLand == false) then
		-- We're adding water, so lakes will stay salty.
		MergeExtras(mergeLand, destPlotTypes, srcPlotTypes);
		return;
	end	
	
	-- The max size of a lake that could become three fresh water lakes
	-- if we added an island.
	local waterAreaThresh = 3*LAKE_MAXNUMTILES + 1;


	-- Apply island data to the main plot data.
	local numTilesAdded = 0;

	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local i = y * g_iW + x + 1;
			if srcPlotTypes[i] ~= g_PLOT_TYPE_OCEAN then
				if destPlotTypes[i] == g_PLOT_TYPE_OCEAN then
					local waterArea = GetWaterArea(destPlotTypes, x, y);
				
					-- Only add islands to sufficiently-large lakes.
					if (waterArea > waterAreaThresh) then
						destPlotTypes[i] = srcPlotTypes[i];
						numTilesAdded = numTilesAdded+1;
					end
				end
			end
		end
	end	
	
	print("Added " .. numTilesAdded .. " land tile(s) for extras.");
end

function GenerateExtras(plotTypes)
	-- Generate extra islands or lakes, depending on landmass.
	--
	-- args:
	--   plotTypes: apply extra-island data to this set of plot types
	--
	-- Return a map of extra islands for customized merging with landmass.
	print("Adding extras to the world.");
	
	-- Check whether we actually wanted extra *lakes* instead of
	-- extra islands.
	local args = ScriptData.landInfo.extraArgs or {};
	local invertExtras = args.invertExtras;
		
	-- Start with a blank map for extras.
	local extras_PlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);
		
	if (ExtrasGot.chains == true) then
		-- Add island chains to the extras map.
		MergeChains(extras_PlotTypes, GenerateChains());
	end	
	
	if (ExtrasGot.clusters == true) then
		-- Add clusters to the extras map.
		MergeExtras(true, extras_PlotTypes, GenerateClusters(invertExtras));
	end
	
	if (ExtrasGot.miniDonuts == true) then
		-- Add mini-donuts to the extras map.
		-- Radius multiplier based on landmass and extras.
		local rMult = 1;
		if (invertExtras and (ExtrasGot.everything == true)) then
			-- An extras-themed landmass with all extras
			-- Make mini-donuts smaller, but not as small as a regular landmass.
			rMult = 8/11; -- approx 0.73; divide by 1.375
			
		elseif (not invertExtras) then
			-- A landmass that doesn't need larger mini-donuts.
			-- Shrink mini-donuts to slightly more than half of base size.
			rMult = 4/7; -- approx 0.57; divide by 1.75
		end
		
		local numDonutsPerCell = 2;
		local numExtraDonutsMult = 1;
		if (ExtrasGot.everything == true) then
			-- Reduce donuts to make room for other types of extras.
			print("Reducing mini-donuts (everything extras)");
			numDonutsPerCell = 1;
			numExtraDonutsMult = 1/3;
		end
		
		local miniDonutArgs = 
		{
			doInverted         = invertExtras,
			baysHeight         = args.miniDonutBaysHeight,
			numDonutsPerCell   = numDonutsPerCell,
			numExtraDonutsMult = numExtraDonutsMult,
			rMult              = rMult
		};
		MergeExtras(true, extras_PlotTypes, GenerateMiniDonuts(miniDonutArgs));
	end
	
	if (ExtrasGot.sprinkles == true) then
		-- Add island sprinkles to the extras map.
		MergeExtras(true, extras_PlotTypes, GenerateSprinkles(invertExtras));
	end	
	
	if (ExtrasGot.tectonic == true) then
		-- Add tectonic islands to the extras map.
		local mtnPlots = ScriptData.mtnPlots;
		if invertExtras then
			-- Place islands at trenches instead of mountains.
			mtnPlots = ScriptData.trenchPlots;
		end
		
		local tectonicPlotTypes = GenerateTectonicIslands(plotTypes, mtnPlots, args);
		MergeExtras(true, extras_PlotTypes, tectonicPlotTypes);
		
		-- The mountain pattern needs this in order to avoid
		-- clobbering the tectonic islands with mountains and hills.
		ScriptData.tectonicIslesMap = tectonicPlotTypes;
	end
		
	-- Finished generating extras (1st pass).

	print("Merging extras to the landmass.");	
	
	-- Merge extras onto the mainland.
	local MergeToMainland = args.MergeToMainland or MergeExtras;
	
	if ((ExtrasGot.everything == true) and 
	    (MergeToMainland == MergeExtras)) then
		-- Everything extras adds a ton of land.
		-- Compensate by avoiding contact with the main landmass.
		print("Avoiding main landmass (everything extras).");
		MergeToMainland = MergeExtrasAvoidLandmass;
	end
	
		-- By default, use extras to generate islands (land).
	local mergeLand  = true;
	if invertExtras then
		-- Use extras to generate water instead of land.
		mergeLand  = false;
	end
	
	MergeToMainland(mergeLand, plotTypes, extras_PlotTypes);
		
	print("Done adding extras.");
end

function GenerateMtnsHillsAndExtras(plotTypes, canFreshenLakes)
	-- Add mountains, hills, and extras to the landmass.
	--
	-- Args:
	--   plotTypes: add to this map of plot types.
	--   canFreshenLakes (optional): whether to support replacing all salt water with 
	--     clusters of fresh lakes. Default is false.

	-- Generate mountain pattern.
	GenerateMountainsAndHills(plotTypes);	
	
	-- Add extras, which depends on mountain pattern.
	GenerateExtras(plotTypes);
	
	if (canFreshenLakes and UserInput.freshLakes) then
		-- Freshen lakes
		FreshenLakes(plotTypes, LAKE_MAXNUMTILES, true);
	end
	
	-- Add mountains and hills after adding all land tiles.
	AddMountainsAndHillsToPlotTypes(plotTypes);
end
-------------------------------------------------------------------------------------------
-- Plot Type overrides and helper methods
-- Need to declare these before declaring land info.
-------------------------------------------------------------------------------------------
FractalWorld = {};

function FractalWorld.Create()
	
	local data = {
		InitFractal 		= FractalWorld.InitFractal,
		GenerateCenterRift 	= FractalWorld.GenerateCenterRift,
		GeneratePlotTypes 	= FractalWorld.GeneratePlotTypes,
		
		plotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	};
	
	return data;
end	

function FractalWorld:InitFractal(args)
	local args = args or {};
	
	local continent_grain = args.continent_grain or 2;
	-- Default no rifts. Set grain to between 1 and 3 to add rifts. - Bob
	local rift_grain = args.rift_grain or -1; 
	local polar = args.polar or true;
	
	local fracFlags = {};
	
	if (polar) then
		fracFlags.FRAC_POLAR = true;
	end
	
	if(rift_grain > 0 and rift_grain < 4) then
		self.riftsFrac = Fractal.Create(
			g_iW, g_iH, rift_grain, {}, g_fracXExp, g_fracYExp);
			
		self.continentsFrac = Fractal.CreateRifts(
			g_iW, g_iH, continent_grain, fracFlags, self.riftsFrac, g_fracXExp, g_fracYExp);
	else
		self.continentsFrac = Fractal.Create(
			g_iW, g_iH, continent_grain, fracFlags, g_fracXExp, g_fracYExp);	
	end

	-- Use Brian's tectonics method to weave ridgelines in to the continental fractal.
	-- Without fractal variation, the tectonics come out too regular.
	--
	--[[ "The principle of the RidgeBuilder code is a modified Voronoi diagram. I 
	added some minor randomness and the slope might be a little tricky. It was 
	intended as a 'whole world' modifier to the fractal class. You can modify 
	the number of plates, but that is about it." ]]-- Brian Wade - May 23, 2009
	--
	local numRPlates = ScriptData.worldSizeInfo.numRPlates; -- Ridge Plates
	-- Blend a bit of ridge into the fractal.
	-- This will do things like roughen the coastlines and build inland seas. - Brian
	self.continentsFrac:BuildRidges(numRPlates, fracFlags, 1, 2);
end

function FractalWorld:GenerateCenterRift()
	-- Causes a rift to break apart and separate any landmasses overlaying the map center.
	-- Rift runs south to north ala the Atlantic Ocean.
	-- Any land plots in the first or last map columns will be lost, overwritten.
	-- This rift function is hex-dependent. It would have to be adapted to work with squares tiles.
	-- Center rift not recommended for non-oceanic worlds or with continent grains higher than 2.
	-- 
	-- First determine the rift "lean". 0 = Starts west, leans east. 1 = Starts east, leans west.
	local riftLean = TerrainBuilder.GetRandomNumber(2, "FractalWorld Center Rift Lean");
	
	-- Set up tables recording the rift line and the edge plots to each side of the rift line.
	local riftLine = {};
	local westOfRift = {};
	local eastOfRift = {};
	-- Determine minimum and maximum length of line segments for each possible direction.
	local primaryMaxLength = math.max(1, math.floor(g_iH / 8));
	local secondaryMaxLength = math.max(1, math.floor(g_iH / 11));
	local tertiaryMaxLength = math.max(1, math.floor(g_iH / 14));
	
	-- Set rift line starting plot and direction.
	local startDistanceFromCenterColumn = math.floor(g_iH / 8);
	if riftLean == 0 then
		startDistanceFromCenterColumn = -(startDistanceFromCenterColumn);
	end
	local startX = math.floor(g_iW / 2) + startDistanceFromCenterColumn;
	local startY = 0;
	local startingDirection = DirectionTypes.DIRECTION_NORTHWEST;
	if riftLean == 0 then
		startingDirection = DirectionTypes.DIRECTION_NORTHEAST;
	end
	-- Set rift X boundary.
	local riftXBoundary = math.floor(g_iW / 2) - startDistanceFromCenterColumn;
	
	-- Rift line is defined by a series of line segments traveling in one of three directions.
	-- East-leaning lines move NE primarily, NW secondarily, and E tertiary.
	-- West-leaning lines move NW primarily, NE secondarily, and W tertiary.
	-- Any E or W segments cause a wider gap on that row, requiring independent storage of 
	-- data regarding west or east of rift.
	--
	-- Key variables need to be defined here so they persist outside of the various loops 
	-- that follow. This requires that the starting plot be processed outside of those loops.
	local currentDirection = startingDirection;
	local currentX = startX;
	local currentY = startY;
	table.insert(riftLine, {currentX, currentY});
	-- Record west and east of the rift for this row.
	local rowIndex = currentY + 1;
	westOfRift[rowIndex] = currentX - 1;
	eastOfRift[rowIndex] = currentX + 1;
	-- Set this rift plot as type Ocean.
	local plotIndex = currentX + 1;
	-- Tiles crossed by the rift all turn in to water.
	self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
	
	-- Generate the rift line.
	if riftLean == 0 then -- Leans east
		while currentY < g_iH - 1 do
			-- Generate a line segment
			local nextDirection = 0;

			if currentDirection == DirectionTypes.DIRECTION_EAST then
				local segmentLength = TerrainBuilder.GetRandomNumber(tertiaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX >= riftXBoundary then
					-- Gone as far east as allowed, must turn back west.
					nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
				else
					local dice = TerrainBuilder.GetRandomNumber(3, 
						"FractalWorld Center Rift Direction");
					if dice == 1 then
						nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 do
					currentX = currentX + 1; -- Moving east, no change to Y.
					rowIndex = currentY;
					-- westOfRift[rowIndex] does not change.
					eastOfRift[rowIndex] = currentX + 1;
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end

			elseif currentDirection == DirectionTypes.DIRECTION_NORTHWEST then
				local segmentLength = TerrainBuilder.GetRandomNumber(secondaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX >= riftXBoundary then 
					-- Gone as far east as allowed, must turn back west.
					nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
				else
					local dice = TerrainBuilder.GetRandomNumber(4, 
						"FractalWorld Center Rift Direction");
					if dice == 2 then
						nextDirection = DirectionTypes.DIRECTION_EAST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 and currentY < g_iH - 1 do
					-- Identifying hex plots other than to east or west is tricky.
					-- The X coord could be one of two possibilities.
					-- Call on Map.GetAdjacentPlot to safely handle this task.
					local nextPlot = Map.GetAdjacentPlot(currentX, currentY, currentDirection);
					currentX = nextPlot:GetX();
					currentY = currentY + 1;
					rowIndex = currentY;
					westOfRift[rowIndex] = currentX - 1;
					eastOfRift[rowIndex] = currentX + 1;
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end
				
			else -- NORTHEAST
				local segmentLength = TerrainBuilder.GetRandomNumber(primaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX >= riftXBoundary then
					-- Gone as far east as allowed, must turn back west.
					nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
				else
					local dice = TerrainBuilder.GetRandomNumber(2, 
						"FractalWorld Center Rift Direction");
					if dice == 1 and currentY > g_iH * 0.28 then
						nextDirection = DirectionTypes.DIRECTION_EAST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 and currentY < g_iH - 1 do
					-- Identifying hex plots other than to east or west is tricky.
					-- The X coord could be one of two possibilities.
					-- Call on Map.GetAdjacentPlot to safely handle this task.
					local nextPlot = Map.GetAdjacentPlot(currentX, currentY, currentDirection);
					currentX = nextPlot:GetX();
					currentY = currentY + 1;
					rowIndex = currentY;
					westOfRift[rowIndex] = currentX - 1;
					eastOfRift[rowIndex] = currentX + 1;
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end
			end
			
			-- Line segment is done, set next direction.
			currentDirection = nextDirection;
		end

	else -- Leans west
		while currentY < g_iH - 1 do
			-- Generate a line segment
			local nextDirection = 0;

			if currentDirection == DirectionTypes.DIRECTION_WEST then
				local segmentLength = TerrainBuilder.GetRandomNumber(tertiaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX <= riftXBoundary then
					-- Gone as far west as allowed, must turn back east.
					nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
				else
					local dice = TerrainBuilder.GetRandomNumber(3, 
						"FractalWorld Center Rift Direction");
					if dice == 1 then
						nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 do
					currentX = currentX - 1; -- Moving west, no change to Y.
					rowIndex = currentY;
					westOfRift[rowIndex] = currentX - 1;
					-- eastOfRift[rowIndex] does not change.
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end

			elseif currentDirection == DirectionTypes.DIRECTION_NORTHEAST then
				local segmentLength = TerrainBuilder.GetRandomNumber(secondaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX <= riftXBoundary then
					-- Gone as far west as allowed, must turn back east.
					nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
				else
					local dice = TerrainBuilder.GetRandomNumber(4, 
						"FractalWorld Center Rift Direction - Lua");
					if dice == 2 then
						nextDirection = DirectionTypes.DIRECTION_WEST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHWEST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 and currentY < g_iH - 1 do
					-- Identifying hex plots other than to east or west is tricky.
					-- The X coord could be one of two possibilities.
					-- Call on Map.GetAdjacentPlot to safely handle this task.
					local nextPlot = Map.GetAdjacentPlot(currentX, currentY, currentDirection);
					currentX = nextPlot:GetX();
					currentY = currentY + 1;
					rowIndex = currentY;
					westOfRift[rowIndex] = currentX - 1;
					eastOfRift[rowIndex] = currentX + 1;
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end
				
			else -- NORTHWEST
				local segmentLength = TerrainBuilder.GetRandomNumber(primaryMaxLength + 1, 
					"FractalWorld Center Rift Segment Length");
				-- Choose next direction
				if currentX <= riftXBoundary then
					-- Gone as far west as allowed, must turn back east.
					nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
				else
					local dice = TerrainBuilder.GetRandomNumber(2, 
						"FractalWorld Center Rift Direction - Lua");
					if dice == 1 and currentY > g_iH * 0.28 then
						nextDirection = DirectionTypes.DIRECTION_WEST;
					else
						nextDirection = DirectionTypes.DIRECTION_NORTHEAST;
					end
				end
				-- Process the line segment
				local plotsToDo = segmentLength;
				while plotsToDo > 0 and currentY < g_iH - 1 do
					-- Identifying hex plots other than to east or west is tricky.
					-- The X coord could be one of two possibilities.
					-- Call on Map.GetAdjacentPlot to safely handle this task.
					local nextPlot = Map.GetAdjacentPlot(currentX, currentY, currentDirection);
					currentX = nextPlot:GetX();
					currentY = currentY + 1;
					rowIndex = currentY;
					westOfRift[rowIndex] = currentX - 1;
					eastOfRift[rowIndex] = currentX + 1;
					plotIndex = GetPlotIndexLua(currentX, currentY);
					self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
					plotsToDo = plotsToDo - 1;
				end
			end
			
			-- Line segment is done, set next direction.
			currentDirection = nextDirection;
		end
	end
	-- Process the final plot in the rift.
	westOfRift[g_iH] = currentX - 1;
	eastOfRift[g_iH] = currentX + 1;
	plotIndex = GetPlotIndexLua(currentX, g_iH - 1);
	self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;

	-- Now force the rift to widen, causing land on either side of the rift to drift apart.
	local horizontalDrift = 3;
	local verticalDrift = 2;
	--
	if riftLean == 0 then
		-- Process Western side from top down.
		for y = g_iH - 1 - verticalDrift, 0, -1 do
			local thisRowX = westOfRift[y+1];
			for x = horizontalDrift, thisRowX do
				local sourcePlotIndex = GetPlotIndexLua(x,y);
				local destPlotIndex = (y + verticalDrift) * g_iW + (x - horizontalDrift) + 1;
				self.plotTypes[destPlotIndex] = self.plotTypes[sourcePlotIndex]
			end
		end
		-- Process Eastern side from bottom up.
		for y = verticalDrift, g_iH - 1 do
			local thisRowX = eastOfRift[y+1];
			for x = thisRowX, g_iW - horizontalDrift - 1 do
				local sourcePlotIndex = GetPlotIndexLua(x,y);
				local destPlotIndex = (y - verticalDrift) * g_iW + (x + horizontalDrift) + 1;
				self.plotTypes[destPlotIndex] = self.plotTypes[sourcePlotIndex]
			end
		end
		-- Clean up remainder of tiles (by turning them all to Ocean).
		-- Clean up bottom left.
		for y = 0, verticalDrift - 1 do
			local thisRowX = westOfRift[y+1];
			for x = 0, thisRowX do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end
		-- Clean up top right.
		for y = g_iH - verticalDrift, g_iH - 1 do
			local thisRowX = eastOfRift[y+1];
			for x = thisRowX, g_iW - 1 do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end
		-- Clean up the rift.
		for y = verticalDrift, g_iH - 1 - verticalDrift do
			local westX = westOfRift[y-verticalDrift+1] - horizontalDrift + 1;
			local eastX = eastOfRift[y+verticalDrift+1] + horizontalDrift - 1;
			for x = westX, eastX do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end

	else -- riftLean = 1
		-- Process Western side from bottom up.
		for y = verticalDrift, g_iH - 1 do
			local thisRowX = westOfRift[y+1];
			for x = horizontalDrift, thisRowX do
				local sourcePlotIndex = GetPlotIndexLua(x,y);
				local destPlotIndex = (y - verticalDrift) * g_iW + (x - horizontalDrift) + 1;
				self.plotTypes[destPlotIndex] = self.plotTypes[sourcePlotIndex]
			end
		end
		-- Process Eastern side from top down.
		for y = g_iH - 1 - verticalDrift, 0, -1 do
			local thisRowX = eastOfRift[y+1];
			for x = thisRowX, g_iW - horizontalDrift - 1 do
				local sourcePlotIndex = GetPlotIndexLua(x,y);
				local destPlotIndex = (y + verticalDrift) * g_iW + (x + horizontalDrift) + 1;
				self.plotTypes[destPlotIndex] = self.plotTypes[sourcePlotIndex]
			end
		end
		-- Clean up remainder of tiles (by turning them all to Ocean).
		-- Clean up top left.
		for y = g_iH - verticalDrift, g_iH - 1 do
			local thisRowX = westOfRift[y+1];
			for x = 0, thisRowX do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end
		-- Clean up bottom right.
		for y = 0, verticalDrift - 1 do
			local thisRowX = eastOfRift[y+1];
			for x = thisRowX, g_iW - 1 do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end
		-- Clean up the rift.
		for y = verticalDrift, g_iH - 1 - verticalDrift do
			local westX = westOfRift[y+verticalDrift+1] - horizontalDrift + 1;
			local eastX = eastOfRift[y-verticalDrift+1] + horizontalDrift - 1;
			for x = westX, eastX do
				local plotIndex = GetPlotIndexLua(x,y);
				self.plotTypes[plotIndex] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
end
------------------------------------------------------------------------------
GotLakes_Fractal = {}

function GotLakes_Fractal:AddLandAndWater(water_percent)
	-- Use the continents fractal to decide land vs water for each plot.
	--
	-- Returns the total number of land tiles on the map
	local iWaterThreshold = GetFractalHeight(self.continentsFrac, water_percent);
		
	iNumTotalLandTiles = 0;
	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local i = GetPlotIndexLua(x,y);
			local val = self.continentsFrac:GetHeight(x, y);
			if(val <= iWaterThreshold) then
				self.plotTypes[i] = g_PLOT_TYPE_OCEAN;
			else
				self.plotTypes[i] = g_PLOT_TYPE_LAND;
				iNumTotalLandTiles = iNumTotalLandTiles + 1;
			end
		end
	end

	return iNumTotalLandTiles;
end

function GotLakes_Fractal:AddMtsHillsExtras()
	-- Add mountains, hills, and extra islands to the plot-types map.
	GenerateMtnsHillsAndExtras(self.plotTypes);
end

function GotLakes_Fractal:Continents_IceAge_init()
    -- Fractal init for ice age continents

    -- Ice Age: lower sea levels and use wide continents.
    local rift_dice   = TerrainBuilder.GetRandomNumber(3, "Rift Grain roll - Ice Age");
    if rift_dice == 0 then
        rift_dice = -1;
    end

    local center_dice = TerrainBuilder.GetRandomNumber(7, "Continental Grain roll - Ice Age");
    
    local args = 
    {
        continent_grain = 3,
        rift_grain      = rift_dice,
        has_center_rift = (center_dice < 3)
    };
    
    self.continentsFrac = nil;
    self:InitFractal(args);
end

function GotLakes_Fractal:Continents_Normal_init()
    -- Fractal init for continents normal
    -- Continents plot type generator may call this repeatedly.

    local grain_dice = TerrainBuilder.GetRandomNumber(7, "Continental Grain roll");
    
    if grain_dice < 4 then
        grain_dice = 2;
    else
        grain_dice = 1;
    end
    
    local rift_dice = TerrainBuilder.GetRandomNumber(3, "Rift Grain roll");
    if rift_dice < 1 then
        rift_dice = -1;
    end
    
    local args = 
    {
        continent_grain = grain_dice, 
        rift_grain = rift_dice
    };
    
    self.continentsFrac = nil;
    self:InitFractal(args);
end

function GotLakes_Fractal:Continents_GeneratePlotTypes(args)
	-- Continents landmass
  	local args = args or {};
    
    local water_percent = GetSeaLevel();
        
    local shift_plot_types = args.shift_plot_types;
	if (shift_plot_types == nil) then
		shift_plot_types = true;
	end

    local has_center_rift = args.has_center_rift;
	if (has_center_rift == nil) then
		has_center_rift = true;
	end
    
    -- Reject the continental fractal layer until the largest 
    -- landmass occupies this percent or less of the total land.
    local biggest_area_max_pct = 64;
    
    if (gotIceAgeFamily) then
        print("Applying plot type overrides (continents + ice age)");
    
        -- Change fractal initialization for ice age.
        self.continents_init =
            GotLakes_Fractal.Continents_IceAge_init;
            
        -- Remove the restriction on largest landmass size.
        biggest_area_max_pct = 100;
        
        -- Remove the center rift to allow for snaky continents.
        has_center_rift = false;
    else
        self.continents_init = 
            GotLakes_Fractal.Continents_Normal_init;
    end
    
    local biggest_area_thresh = biggest_area_max_pct * 0.01;
    
        
    -- Generate continental fractal layer and examine the largest landmass
    -- until we meet our critera.
	local done = false;
	local iAttempts = 0;
	local iWaterThreshold, biggest_area, iNumTotalLandTiles, iNumBiggestAreaTiles, iBiggestID;
	while done == false do
		local grain_dice = TerrainBuilder.GetRandomNumber(7, "Continental Grain roll");
		if grain_dice < 4 then
			grain_dice = 2;
		else
			grain_dice = 1;
		end
		local rift_dice = TerrainBuilder.GetRandomNumber(3, "Rift Grain roll");
		if rift_dice < 1 then
			rift_dice = -1;
		end
		
		self:InitFractal{continent_grain = grain_dice, rift_grain = rift_dice};
		iWaterThreshold = GetFractalHeight(self.continentsFrac, water_percent);
		local iBuffer = math.floor(g_iH/13.0);

		iNumTotalLandTiles = 0;
		for x = 0, g_iW - 1 do
			for y = iBuffer, g_iH - iBuffer - 1 do
				local i = y * g_iW + x + 1;
				local val = self.continentsFrac:GetHeight(x, y);
				local pPlot = Map.GetPlotByIndex(i-1);
				if(val >= iWaterThreshold) then
					self.plotTypes[i] = g_PLOT_TYPE_LAND;
					-- temporary setting so can calculate areas
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_DESERT);  
					iNumTotalLandTiles = iNumTotalLandTiles + 1;
				else
					self.plotTypes[i] = g_PLOT_TYPE_OCEAN;
					-- temporary setting so can calculate areas
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_OCEAN);  
				end
			end
		end

		ShiftPlotTypes(self.plotTypes);
		self:GenerateCenterRift(self.plotTypes);

		AreaBuilder.Recalculate();
		local biggest_area = Areas.FindBiggestArea(false);
		iNumBiggestAreaTiles = biggest_area:GetPlotCount();
		
		-- Now test the biggest landmass to see if it is large enough.
		if iNumBiggestAreaTiles <= iNumTotalLandTiles * biggest_area_thresh then
			done = true;
			iBiggestID = biggest_area:GetID();
		end
		iAttempts = iAttempts + 1;
	end
	
	-- Add hills, mountains, and extras which are mostly landmass-agnostic.
	self:AddMtsHillsExtras();
	
	return self.plotTypes;
end

function GotLakes_Fractal:Fractal_GeneratePlotTypes(args)
	-- Fractal landmass
	local args = args or {};
	
    local shift_plot_types = args.shift_plot_types;
	if (shift_plot_types == nil) then
		shift_plot_types = true;
	end
	
	local has_center_rift  = args.has_center_rift or false;
	
 	self:AddLandAndWater(GetSeaLevel());

	-- Add hills, mountains, and extras which are mostly landmass-agnostic.
	self:AddMtsHillsExtras();
	
	if(shift_plot_types == true) then
		ShiftPlotTypes(self.plotTypes);
		-- Center Rift warrants plot shifting to guarantee centered landmasses.
		if(has_center_rift == true) then
			self:GenerateCenterRift()
		end
	end

	return self.plotTypes;
end

function GotLakes_Fractal:Pangea_GeneratePlotTypes(args)
	-- Pangea landmass
	local args = args or {};
	
	-- The following fractal-gen args are fixed for pangea:
	--    shift_plot_types (true)
	--    has_center_rift  (false)
	
	local water_percent = GetSeaLevel();
	if (ExtrasGot.everything == true) then
		-- Pangea with everything extras: higher sea level.
		water_percent = math.min(100, water_percent + 6);

	elseif (ExtrasGot.anything == true) then
		-- Pangea with extras: slightly higher sea level
		water_percent = math.min(100, water_percent + 3);
	end

	-- Generate fractal layer and examine the largest landmass.
	-- Reject the result until the largest landmass occupies enough of the total land.
	local done = false;
	local iAttempts = 0;
	local iWaterThreshold, biggest_area, iNumBiggestAreaTiles, iBiggestID;
	while done == false do
		iAttempts = iAttempts + 1;
		print("Attempt #" .. iAttempts);

		local grain_dice = TerrainBuilder.GetRandomNumber(7, "Continental Grain roll");
		if grain_dice < 4 then
			grain_dice = 1;
		else
			grain_dice = 2;
		end
		local rift_dice = TerrainBuilder.GetRandomNumber(3, "Rift Grain roll");
		if rift_dice < 1 then
			rift_dice = -1;
		end
		
		self.continentsFrac = nil;
		self:InitFractal{continent_grain = grain_dice, rift_grain = rift_dice};
		iWaterThreshold = GetFractalHeight(self.continentsFrac, water_percent);
		
		local iNumTotalLandTiles = 0;
		for x = 0, g_iW - 1 do
			for y = 0, g_iH - 1 do
				local i = GetPlotIndexLua(x,y);
				local val = self.continentsFrac:GetHeight(x, y);
				local pPlot = Map.GetPlotByIndex(i-1);
				if(val <= iWaterThreshold) then
					self.plotTypes[i] = g_PLOT_TYPE_OCEAN;
					-- temporary setting so can calculate areas
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_OCEAN);  
				else
					self.plotTypes[i] = g_PLOT_TYPE_LAND;
					-- temporary setting so can calculate areas
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_DESERT);  
					iNumTotalLandTiles = iNumTotalLandTiles + 1;
				end
			end
		end
		
		AreaBuilder.Recalculate();
		local biggest_area = Areas.FindBiggestArea(false);
		iNumBiggestAreaTiles = biggest_area:GetPlotCount();
		
		-- Now test the biggest landmass to see if it is large enough.
		if ((iAttempts >= PANGEA_MAX_NUM_ATTEMPTS) or 
		    (iNumBiggestAreaTiles >= (iNumTotalLandTiles * PANGEA_LANDMASS_MAJORITY_MIN))) then
			done = true;
			iBiggestID = biggest_area:GetID();
			
			print("Got a sufficiently-large biggest landmass.");
		end
	end
		
	-- Because we haven't yet shifted the plot types, we will not be able to take advantage 
	-- of having water and flatland plots already set. We still have to generate all data
	-- for hills and mountains, too, then shift everything, then set plots one more time.
	self:AddMtsHillsExtras();

	ShiftPlotTypes(self.plotTypes);

	return self.plotTypes;
end
-------------------------------------------------------------------------------------------
MultilayeredFractal = {};

function MultilayeredFractal.Create()
	-- MLF constructor.

	-- Sum of all layered regions
	local wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);

	-- Create data.
	local data = 
	{
		-- member variables
		iRoundFlags		= {},
		
		-- plot arrays
		plotTypes		= {},
		wholeworldPlotTypes = wholeworldPlotTypes,		
	};
	
	setmetatable(data, {__index = MultilayeredFractal});

	return data;
end

function MultilayeredFractal:ShiftRegionPlots(iRegionWidth, iRegionHeight)
	-- Minimizes land plots along the region's edges by shifting the coordinates.
	local shift_x = self:DetermineXShift(iRegionWidth, iRegionHeight);
	local shift_y = self:DetermineYShift(iRegionWidth, iRegionHeight);
	self:ShiftRegionPlotsBy(shift_x, shift_y, iRegionWidth, iRegionHeight);
end

function MultilayeredFractal:ShiftRegionPlotsBy(xshift, yshift, iRegionWidth, iRegionHeight)
	if (xshift > 0 or yshift > 0) then
		local iWH = iRegionWidth * iRegionHeight;
		local buf = {};
		for i = 1, iWH + 1, 1 do
			buf[i] = self.plotTypes[i];
		end

		for iDestY = 0, iRegionHeight, 1 do
			for iDestX = 0, iRegionWidth, 1 do
				local iDestI = iRegionWidth * iDestY + iDestX;
				local iSourceX = (iDestX + xshift) % iRegionWidth;
				local iSourceY = (iDestY + yshift) % iRegionHeight;
				local iSourceI = iRegionWidth * iSourceY + iSourceX;
				self.plotTypes[iDestI] = buf[iSourceI]
			end
		end
	end
end

function MultilayeredFractal:DetermineXShift(iRegionWidth, iRegionHeight)
	--[[ This function will align the most water-heavy vertical portion of the region with
	its vertical edge. This is a form of centering the landmasses, but it emphasizes the
	edge not the middle. If there are columns completely empty of land, these will tend to
	be chosen as the new edge. The operation looks at a group of columns not just a single
	column, then picks the center of the most water heavy group of columns to be the new
	vertical reguin edge. ]]--

	-- First loop through the map columns and record land plots in each column.
	local land_totals = {};
	for x = 0, iRegionWidth - 1 do
		local current_column = 0;
		for y = 0, iRegionHeight - 1 do
			local i = y * iRegionWidth + x + 1;
			if (self.plotTypes[i] ~= g_PLOT_TYPE_OCEAN) then
				current_column = current_column + 1;
			end
		end
		table.insert(land_totals, current_column);
	end
	
	-- Now evaluate column groups, each record applying to the center column of the group.
	local column_groups = {};
	-- Determine the group size in relation to map width.
	local group_radius = math.max(1, math.floor(iRegionWidth / 10));
	-- Measure the groups.
	for column_index = 1, iRegionWidth do
		local current_group_total = 0;
		for current_column = column_index - group_radius, column_index + group_radius do
			local current_index = current_column % iRegionWidth;
			if current_index == 0 then -- Modulo of the last column will be zero; this repairs the issue.
				current_index = iRegionWidth;
			end
			current_group_total = current_group_total + land_totals[current_index];
		end
		table.insert(column_groups, current_group_total);
	end
	
	-- Identify the group with the least amount of land in it.
	local best_value = iRegionHeight * (2 * group_radius + 1); -- Set initial value to max possible.
	local best_group = 1; -- Set initial best group as current map edge.
	for column_index, group_land_plots in ipairs(column_groups) do
		if group_land_plots < best_value then
			best_value = group_land_plots;
			best_group = column_index;
		end
	end
	
	-- Determine X Shift
	local x_shift = best_group - 1;
	return x_shift;
end

function MultilayeredFractal:DetermineYShift(iRegionWidth, iRegionHeight)
	-- Counterpart to DetermineXShift()

	-- First loop through the map rows and record land plots in each row.
	local land_totals = {};
	for y = 0, iRegionHeight - 1 do
		local current_row = 0;
		for x = 0, iRegionWidth - 1 do
			local i = y * iRegionWidth + x + 1;
			if (self.plotTypes[i] ~= g_PLOT_TYPE_OCEAN) then
				current_row = current_row + 1;
			end
		end
		table.insert(land_totals, current_row);
	end
	
	-- Now evaluate row groups, each record applying to the center row of the group.
	local row_groups = {};
	-- Determine the group size in relation to map height.
	local group_radius = math.max(1, math.floor(iRegionHeight / 10));
	-- Measure the groups.
	for row_index = 1, iRegionHeight do
		local current_group_total = 0;
		for current_row = row_index - group_radius, row_index + group_radius do
			local current_index = current_row % iRegionHeight;
			if current_index == 0 then -- Modulo of the last row will be zero; this repairs the issue.
				current_index = iRegionHeight;
			end
			current_group_total = current_group_total + land_totals[current_index];
		end
		table.insert(row_groups, current_group_total);
	end
	
	-- Identify the group with the least amount of land in it.
	local best_value = iRegionWidth * (2 * group_radius + 1); -- Set initial value to max possible.
	local best_group = 1; -- Set initial best group as current map edge.
	for row_index, group_land_plots in ipairs(row_groups) do
		if group_land_plots < best_value then
			best_value = group_land_plots;
			best_group = row_index;
		end
	end
	
	-- Determine Y Shift
	local y_shift = best_group - 1;
	return y_shift;
end

function MultilayeredFractal:GenerateFractalLayerWithoutHills(args)
	--[[ This function is intended to be paired with ApplyTectonics. If all the hills and
	mountains plots are going to be overwritten by the tectonics results, then why waste
	calculations generating them? ]]--
	local args = args or {};
	
	-- Handle args or assign defaults.
	local iWaterPercent = args.iWaterPercent or 55;
	local iRegionWidth = args.iRegionWidth; -- Mandatory Parameter, no default
	local iRegionHeight = args.iRegionHeight; -- Mandatory Parameter, no default
	local iRegionWestX = args.iRegionWestX; -- Mandatory Parameter, no default
	local iRegionSouthY = args.iRegionSouthY; -- Mandatory Parameter, no default
	local iRegionGrain = args.iRegionGrain or 1;
	local iRegionPlotFlags = args.iRegionPlotFlags or self.iRoundFlags;
	local iRegionFracXExp = args.iRegionFracXExp or 6;
	local iRegionFracYExp = args.iRegionFracYExp or 5;
	local iRiftGrain = args.iRiftGrain or -1;
	local bShift = args.bShift or true;

	--print("Received Region Data");
	--print(iRegionWidth, iRegionHeight, iRegionWestX, iRegionSouthY, iRegionGrain);
	--print("- - -");
	
	-- Init the plot types array for this region's plot data. Redone for each new layer.
	-- Compare to self.wholeworldPlotTypes, which contains the sum of all layers.
	self.plotTypes = {};
	table.fill(self.plotTypes, g_PLOT_TYPE_OCEAN, iRegionWidth * iRegionHeight);
	
	--print("Filled regional table.");

	-- Init the land/water fractal
	local regionContinentsFrac;
	if (iRiftGrain > 0) and (iRiftGrain < 4) then
		local riftsFrac = Fractal.Create(
			iRegionWidth, iRegionHeight, iRiftGrain, {}, iRegionFracXExp, iRegionFracYExp);
		regionContinentsFrac = Fractal.CreateRifts(
			iRegionWidth, 
			iRegionHeight, 
			iRegionGrain, 
			iRegionPlotFlags, 
			riftsFrac, 
			iRegionFracXExp, 
			iRegionFracYExp);
	else
		regionContinentsFrac = Fractal.Create(
			iRegionWidth, 
			iRegionHeight, 
			iRegionGrain, 
			iRegionPlotFlags, 
			iRegionFracXExp, 
			iRegionFracYExp);	
	end
	--print("Initialized main fractal");
	
	-- Using the fractal matrices we just created, determine fractal-height values for sea level.
	local iWaterThreshold = GetFractalHeight(regionContinentsFrac, iWaterPercent);

	-- Loop through the region's plots
	for x = 0, iRegionWidth - 1, 1 do
		for y = 0, iRegionHeight - 1, 1 do
			local i = y * iRegionWidth + x + 1; -- Lua arrays start at 1.
			local val = regionContinentsFrac:GetHeight(x,y);
			if val <= iWaterThreshold then
				--do nothing
			else
				self.plotTypes[i] = g_PLOT_TYPE_LAND
			end
		end
	end
	
	--print("Generated Plot Types");
	
	if bShift then -- Shift plots to obtain a more natural shape.
		self:ShiftRegionPlots(iRegionWidth, iRegionHeight);
	end

	--print("Shifted Plots");

	-- Once the plot types for the region have been generated, they must be
	-- applied to the global plot array.
	--
	-- Default approach is to ignore water and layer the lands over one another.
	-- Land of any type in each new layer overwrites whatever had been there.
	-- If you want to layer the water, too, or some other method, then
	-- you need to replace this function with a custom version, in your script.
	--
	-- Apply the region's plots to the global plot array.
	for x = 0, iRegionWidth - 1, 1 do
		local wholeworldX = x + iRegionWestX;
		for y = 0, iRegionHeight - 1, 1 do
			local i = y * iRegionWidth + x + 1
			
			-- Check for land to exclude both ocean and nil.
			if self.plotTypes[i] == g_PLOT_TYPE_LAND then
				local wholeworldY = y + iRegionSouthY;
				local iWorld = wholeworldY * g_iW + wholeworldX + 1
				self.wholeworldPlotTypes[iWorld] = self.plotTypes[i]
			end
		end
	end
	
	--print("Applied region's plots to global plot array.");

	-- This region is done.
	return
end

function MultilayeredFractal:GenerateWaterLayer(args)
	-- This function is intended to allow adding seas to specific areas of large continents.
	--
	-- Usage: Because of how the Shift operation works, we have to treat the "water" we are
	-- trying to place in this layer as "land", until the shift (if any) has occurred. Once
	-- the shift is done, the actual layering of the plots is handled by turning any "land"
	-- plots from this layer in to water plots when applied to the whole world plot table.
	-- This is all under the hood. The only thing is that the WaterPercent in the args table
	-- does NOT apply to the water you are trying to place, but rather the dead space where
	-- no changes will occur. Put another way, you should treat this layer of water as if
	-- it were an island or continent you are trying to add, except that in actual placement
	-- it will come out as water in the end, letting you place a sea inside a larger piece 
	-- of land, or a bay that eats in to a continent from the sea. -- Sirian
	local args = args or {};
	
	-- Handle args or assign defaults.
	local iWaterPercent = args.iWaterPercent or 55;
	local iRegionWidth = args.iRegionWidth; -- Mandatory Parameter, no default
	local iRegionHeight = args.iRegionHeight; -- Mandatory Parameter, no default
	local iRegionWestX = args.iRegionWestX; -- Mandatory Parameter, no default
	local iRegionSouthY = args.iRegionSouthY; -- Mandatory Parameter, no default
	local iRegionGrain = args.iRegionGrain or 1;
	local iRegionPlotFlags = args.iRegionPlotFlags or self.iRoundFlags;
	local iRegionFracXExp = args.iRegionFracXExp or 6;
	local iRegionFracYExp = args.iRegionFracYExp or 5;
	local iRiftGrain = args.iRiftGrain or -1;
	local bShift = args.bShift or true;

	-- Init the plot types array for this region's plot data. Redone for each new layer.
	-- Compare to self.wholeworldPlotTypes, which contains the sum of all layers.
	self.plotTypes = {};
	table.fill(self.plotTypes, g_PLOT_TYPE_OCEAN, iRegionWidth * iRegionHeight);
	
	-- Init the land/water fractal
	local regionContinentsFrac;
	if (iRiftGrain > 0) and (iRiftGrain < 4) then
		local riftsFrac = Fractal.Create(
			iRegionWidth, iRegionHeight, iRiftGrain, {}, iRegionFracXExp, iRegionFracYExp);
		regionContinentsFrac = Fractal.CreateRifts(
			iRegionWidth, 
			iRegionHeight, 
			iRegionGrain, 
			iRegionPlotFlags, 
			riftsFrac, 
			iRegionFracXExp, 
			iRegionFracYExp);
	else
		regionContinentsFrac = Fractal.Create(
			iRegionWidth, 
			iRegionHeight, 
			iRegionGrain, 
			iRegionPlotFlags, 
			iRegionFracXExp, 
			iRegionFracYExp);	
	end
	
	-- Using the fractal matrices we just created, determine fractal-height values for sea level.
	local iWaterThreshold = GetFractalHeight(regionContinentsFrac, iWaterPercent);

	-- Loop through the region's plots
	for x = 0, iRegionWidth - 1, 1 do
		for y = 0, iRegionHeight - 1, 1 do
			local i = y * iRegionWidth + x + 1; -- Lua arrays start at 1.
			local val = regionContinentsFrac:GetHeight(x,y);
			if val <= iWaterThreshold then
				--do nothing
			else
				self.plotTypes[i] = g_PLOT_TYPE_LAND
			end
		end
	end
	
	if bShift then -- Shift plots to obtain a more natural shape.
		self:ShiftRegionPlots(iRegionWidth, iRegionHeight);
	end

	-- Apply the region's plots to the global plot array.
	for x = 0, iRegionWidth - 1, 1 do
		local wholeworldX = x + iRegionWestX;
		for y = 0, iRegionHeight - 1, 1 do
			local i = y * iRegionWidth + x + 1
			
			-- Check for land to exclude both ocean and nil.
			if self.plotTypes[i] == g_PLOT_TYPE_LAND then
				local wholeworldY = y + iRegionSouthY;
				local iWorld = wholeworldY * g_iW + wholeworldX + 1
				self.wholeworldPlotTypes[iWorld] = g_PLOT_TYPE_OCEAN
			end
		end
	end
	
	-- This region is done.
	return
end

function MultilayeredFractal:AddMtsHillsExtras(canFreshenLakes)
	-- Add mountains, hills, and extra islands to the plot-types map.
	--
	-- This method replaces MLF:ApplyTectonics.
	GenerateMtnsHillsAndExtras(self.wholeworldPlotTypes, canFreshenLakes);
end

function MultilayeredFractal:DoWateryPoles()
	-- Remove land from north and south poles to allow some possibility of connected oceans.
	-- Note: circumnavigation not guaranteed unless the user also selects 
	-- No Coastal Mountains and No Coastal Ice.
	if (UserInput.worldWrap == WWRAP_REGION) then
		-- Regional Map--don't worry about circumnavigation.
		return;
	end
	
	-- Ensure top and bottom rows are ocean.
	for x = 0, g_iW - 1 do
		self.wholeworldPlotTypes[x + 1]          = g_PLOT_TYPE_OCEAN;
		self.wholeworldPlotTypes[g_numTiles - x] = g_PLOT_TYPE_OCEAN;
	end
end

function MultilayeredFractal:Bagels_GeneratePlotsByRegion()
	-- Bagels	
	
	-- Fill all rows with water plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);

	-- Args to pass into the per-bagel-slice helper function.
	-- Each bagel slice is basically a large mini-donut.
	local bagelArgs = {};
	
	local worldSizeArgs = ScriptData.worldSizeInfo.bagels or {};
	
	-- Get user inputs.
	local sea_level = UserInput.seaLevel;
	
	-- Bagel integrity.
	-- Controls the frequency of bays/lakes
	local baysHeight = 80;
	
	if (gotIceAgeFamily) then
		print("Lowering sea levels (ice age)");
		baysHeight    = baysHeight    + 8;
	end
	
	-- higher number => more land for bagels
	bagelArgs.baysHeight = baysHeight;
	print("Bays Height ", bagelArgs.baysHeight);
	
	
	-- Use a cell system to distribute donuts across the map.
	-- Divide the map into half a dozen cells in 3x2 grid by default.
	local numCellColumns = 3;
	local numCellRows    = 2;
	local numEmptyCells  = 2;
	
	-- Check the aspect ratio of the grid.
	local ratio   = g_iW / g_iH; -- We've got bigger problems if H is 0.
	local epsilon = 0.1;
	
	if (ratio > (4 - epsilon)) then
		-- Got a 4:1 grid.
		print("Using 4x1 bagel grid (custom 4:1 aspect ratio)");
		numCellColumns = 4;
		numCellRows    = 1;
		numEmptyCells  = 1;
	
	elseif (ratio > (3 - epsilon)) then
		-- Got a 3:1 grid.
		print("Using 3x1 bagel grid (custom 3:1 aspect ratio)");
		numCellRows   = 1;
		numEmptyCells = 1;
		
	elseif (ratio > (2 - epsilon)) then
		-- Got a 2:1 grid.
		print("Using 4x2 bagel grid (custom 2:1 aspect ratio)");
		numCellColumns = 4;
		numEmptyCells  = 3;
		
	elseif (ratio < (1 + epsilon)) then
		-- Got a square
		print("Using 2x2 bagel grid (custom 1:1 aspect ratio)");
		numCellColumns = 2;
		numEmptyCells  = 1;
	end

	local numCells = numCellColumns * numCellRows;
	
	-- Use floating numbers here; will round when calculating cell boundaries.
	local cellWidth  = g_iW / numCellColumns;
	local cellHeight = g_iH / numCellRows;
	local cellLength = math.min(cellWidth, cellHeight);
	print("Cell size (w,h): ",  CoordString(cellWidth, cellHeight));
	
	-- Min/Max bagel radius based on cell size.
	-- A bagel radius of cellLength/2 would force the bagel to be at the
	-- center of the cell, so use something smaller for wiggle-room.
	local bagelSize = math.max(Round(cellLength*0.4), 1);
	local bagelOffsets = {1, 0, -1};
	bagelSize = bagelSize + bagelOffsets[sea_level];
	bagelArgs.rMin  = bagelSize;
	bagelArgs.rMax  = bagelSize;
	local     rMax  = bagelArgs.rMax;
	print("Radius: ", bagelSize);
	
	
	-- Min/Max bagel thickness as percentages of radius.
	bagelArgs.tMin = 50;
	bagelArgs.tMax = 75;
	print("Thickness range: ", CoordString(
		Round(bagelArgs.tMin*rMax/100), Round(bagelArgs.tMax*rMax/100)));

	
	-- Choose random cells to be empty so that there is ocean somewhere.
	local cellEmpty = 0;
	local cellBagel = 1;
	local cellTypes = table.fill(cellBagel, numCells);
	for i = 1, numEmptyCells do
		cellTypes[i] = cellEmpty;
	end
	cellTypes = GetShuffledCopyOfTable(cellTypes);
	
	
	-- Add padding to cells to reduce overlap between bagels.
	-- Slightly less than rMax to make cell grid less obvious.
	local cellPaddingX = math.floor(math.clamp(bagelArgs.rMax-1, 0, cellWidth/3));
	local cellPaddingY = math.floor(math.clamp(bagelArgs.rMax-1, 0, cellHeight/3));
	print("Cell padding: ", CoordString(cellPaddingX, cellPaddingY));

		
	-- Boundaries for the current cell.
	local iWestX  = 0;
	local iEastX  = 0;
	local iSouthY = 0;
	local iNorthY = 0;
	local iCell   = 1;
	for iRow = 1, numCellRows do
		-- Advance to the next row.
		iEastX  = 0;
		iSouthY = iNorthY;
		iNorthY = math.floor(iRow * cellHeight);
	
		for iCol = 1, numCellColumns do
			-- Advance to the next column.
			iWestX = iEastX;
			iEastX = math.floor(iCol * cellWidth);
			
			local bagelX, bagelY;
			
			if (cellTypes[iCell] == cellBagel) then
				print("Current cell is " .. CoordString(iWestX, iSouthY) .. 
					  " to " .. CoordString(iEastX, iNorthY));
			
				bagelArgs.enableSlicing = false;
			
				-- Choose a random location for the bagel in the cell.
				bagelX = iWestX + cellPaddingX + 
					TerrainBuilder.GetRandomNumber(iEastX  - iWestX - 2*cellPaddingX,  "Bagel Cell X");
					
				bagelY = iSouthY + cellPaddingY + 
					TerrainBuilder.GetRandomNumber(iNorthY - iSouthY - 2*cellPaddingY, "Bagel Cell Y");

			else
				bagelArgs.enableSlicing = true;
			
				-- Empty cell: a bagel piece could be anywhere on the map.
				bagelX = cellPaddingX + TerrainBuilder.GetRandomNumber(g_iW - 2*cellPaddingX, "Bagel Cell X");
				bagelY = cellPaddingY + TerrainBuilder.GetRandomNumber(g_iH - 2*cellPaddingY, "Bagel Cell Y");
			end
			
			-- Generate the bagel slice using the mini-donut helper function.
			GenerateMiniDonut(self.wholeworldPlotTypes, bagelX, bagelY, bagelArgs);	
			
			-- Advance to the next cell.
			iCell = iCell + 1;
		end
	end
	
	-- Make sure that bagels don't touch the poles for globe maps.
	self:DoWateryPoles();

	-- Land and water are set. Now apply mountains, hills, and extra islands.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Clusters_GeneratePlotsByRegion()
	-- Clusters	
	-- Generate a lakes fractal that doesn't have clusters yet.
	local clustersGrain    = 1;
	local lakeLevelOffset = -16;
	if (ExtrasGot.anything == true) then
		-- Got clusters with extras (possibly even more clusters).
		-- Increase grain to spread clusters a bit more evenly around the map.
		clustersGrain = 2;
	
		-- Raise the threshold to reduce clusters when there are extras.
		lakeLevelOffset = lakeLevelOffset + 8;
	end
	self.wholeworldPlotTypes = GenerateLakesForClusters(false, clustersGrain, lakeLevelOffset);
	
	-- Generate mountain pattern.
	GenerateMountainsAndHills(self.wholeworldPlotTypes);
	
	-- Add extra islands if applicable.
	local extrasPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	GenerateExtras(extrasPlotTypes);
	
	-- Merge the extras as water onto the lakes fractal.
	MergeExtras(false, self.wholeworldPlotTypes, extrasPlotTypes);
	
	-- Turn lakes and extras into clusters.
	local worldSizeArgs = ScriptData.worldSizeInfo.clusters or {};
	local targetSize = worldSizeArgs.targetSize or (LAKE_MAXNUMTILES+1);
	targetSize = targetSize * 2;
	print("Target island size: ", targetSize);
	FreshenLakes(self.wholeworldPlotTypes, targetSize, false);
	
	-- We want islands, not lakes.
	-- But we started with lakes, so invert the lakes into islands.
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = GetPlotIndexLua(x,y);
			if (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN) then
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
			else
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
	
	-- Land is set and lakes are fresh. Now apply hills and mountains.	
	AddMountainsAndHillsToPlotTypes(self.wholeworldPlotTypes);

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Donut_GeneratePlotsByRegion()
	-- Donut
						
	-- Note: fractal wrap flags do not have to match world shape.
	-- Let wrap-x be true here even if the world is flat.
	local fracFlags = {FRAC_WRAP_X = true, FRAC_POLAR = true};

	-- Get user inputs.
	
	-- Special donut filling behavior for sea level:
	-- low    -> land/water mix a.k.a. "standard"
	-- medium -> ocean
	-- high   -> ocean (overrides all other changes, including extra islands)
	local sea_level = UserInput.seaLevel;
	
	-- Special donut filling for lake level:
	-- low  -> shallow water
	-- high -> fresh lakes
	local lake_level = UserInput.lakeLevel;
	
	-- Special donut filling behavior for world age:
	-- young  -> water becomes mountains
	local world_age = UserInput.worldAge;
	
	-- Special donut filling behavior for mountain pattern:
	-- clustered highlands -> land becomes hills
	local mtn_pattern = UserInput.mountains;
	
	-- Controls the initial height and width of the donut (before adding bays/lakes)
	--
	-- Don't make this too large (> 95) or else the the landmass will intersect
	-- itself and the poles.
	local axis_multiplier = 0.55;
	
	-- Tiles within this distance to the center are part of the donut's filling.
	local filling_distance = 0.25; -- Original donut seems to be 0.25
	
	-- Tiles between this and the filling distance become mountains
	-- when the world age is young.
	local mtn_filling_distance = 0.2;
	
	-- Controls the minimum distance of bays/lakes from the inner/outer edges 
	-- of the donut
	cohesion_diff = 0.06;
	
	-- Controls the frequency of bays/lakes
	local baysHeight = 74;
	
	if (gotIceAgeFamily) then
		print("Lowering sea levels (ice age)");
		baysHeight    = baysHeight    + 8;
	end
	
	local inner_cohesion_multiplier = filling_distance + 2*cohesion_diff;
	local outer_cohesion_multiplier = axis_multiplier - cohesion_diff;
				
	-- Fill all rows with water plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	ScriptData.donutFillingMap = table.fill(FILLING_NO, g_numTiles);

	
	local centerX = g_iW / 2;
	local centerY = g_iH / 2;   
	local donutWidth = math.max(g_iW, g_iH);
	
	-- Add the donut as land plots.
	local centerS = donutWidth/2;
	local axis = centerS * axis_multiplier;
	local axisSquared = axis * axis;
	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local i = GetPlotIndexLua(x,y);
			local deltaX = x - centerX;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			local d = deltaXSquared/axisSquared + deltaYSquared/axisSquared;
			
			if ((filling_distance <= d) and (d <= 1)) then
				-- Donut land.
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
				
			elseif (d < filling_distance) then
				-- Donut filling.
				ScriptData.donutFillingMap[i] = FILLING_YES;
				
				if (sea_level == SEALEVEL_LOW) then
					-- Low sea level: turn donut filling into land, but
					-- allow some land to become water.
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
				end
			end
		end
	end
	
	-- Now add bays, fjords, inland seas, etc, but not inside the cohesion area.
	local baysGrain = 4;
	local baysFrac = Fractal.Create(g_iW, g_iH, baysGrain, fracFlags, -1, -1);
	local iBaysThreshold = GetFractalHeight(baysFrac, baysHeight);
		
	local axis = centerS * outer_cohesion_multiplier;
	local axisSquared = axis * axis;
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local deltaX = x - centerX;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			local d = deltaXSquared/axisSquared + deltaYSquared/axisSquared;
			if d > 1 then
				local i = GetPlotIndexLua(x,y);
				local baysVal = baysFrac:GetHeight(x, y);
				if baysVal >= iBaysThreshold then
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	end
	
	local axis = centerS * inner_cohesion_multiplier;
	local axisSquared = axis * axis;
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local deltaX = x - centerX;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			local d = deltaXSquared/axisSquared + deltaYSquared/axisSquared;
			if d <= 1 then
				local i = GetPlotIndexLua(x,y);
				local baysVal = baysFrac:GetHeight(x, y);
				if baysVal >= iBaysThreshold then
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
					-- Count inner cohesion water as part of the donut filling.
					ScriptData.donutFillingMap[i] = FILLING_YES;
				end
			end
		end
	end
	
	-- Land and water are set. Now apply mountains, hills, and extra islands.
	self:AddMtsHillsExtras();
	
	print("Donut: adding donut filling.");
	
	-- Override the center of the donut with sweet, sweet filling logic.
	local landFilling  = g_PLOT_TYPE_LAND;
	local waterFilling = g_PLOT_TYPE_OCEAN;
	
	if (world_age == WORLDAGE_YOUNG) then
		-- Young world: turn water into mountains
		waterFilling = g_PLOT_TYPE_MOUNTAIN;
	end
	
	if (UserInput.mountains == MtnPatterns.CLUSTERED) then
		-- Clustered highlands: turn land into hills
		landFilling = g_PLOT_TYPE_HILLS;
	end
	
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local i = GetPlotIndexLua(x,y);
			
			if (ScriptData.donutFillingMap[i] == FILLING_YES) then
				-- Got donut filling.
				if (sea_level == SEALEVEL_HIGH) then
					-- High sea level: all water.
					if ((lake_level == LAKELEVEL_LOW) and 
					    (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_LAND)) then
						-- High sea + low lake: Replace land with shallow water.
						ScriptData.coastPlots[i] = g_PLOT_TYPE_LAND;
					end
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				
				elseif (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN) then
					self.wholeworldPlotTypes[i] = waterFilling;
					
				elseif (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_LAND) then
					self.wholeworldPlotTypes[i] = landFilling;
				end
			end
		end
	end
	
	if ((sea_level ~= SEALEVEL_HIGH) and 
	    (lake_level == LAKELEVEL_LOW)) then
		-- Make the donut filling water shallow.
		for y = 0, g_iH - 1 do
			for x = 0, g_iW - 1 do
				local i = GetPlotIndexLua(x,y);
				
				if ((ScriptData.donutFillingMap[i] == FILLING_YES) and 
					(self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN)) then
					-- Got donut filling water.
					ScriptData.coastPlots[i] = g_PLOT_TYPE_LAND;
				end
			end
		end
		
	elseif (lake_level == LAKELEVEL_HIGH) then
		-- Turn the donut filling water into fresh lakes.
		for y = 0, g_iH - 1 do
			for x = 0, g_iW - 1 do
				local i = GetPlotIndexLua(x,y);
				
				if ((ScriptData.donutFillingMap[i] == FILLING_YES) and 
					(self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN)) then
					-- Got donut filling water.
					FreshenLake(self.wholeworldPlotTypes, x, y, LAKE_MAXNUMTILES);
				end
			end
		end
	end

	print("Donut: done!");
	
	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:InlandSea_GeneratePlotsByRegion()
	-- Inland Sea
	-- Use sea level input for lake size.
	-- Lake density is inversely proportional to sea level
	local lakes      = GetSeaLevel();
	local lake_grain = ScriptData.landInfo.lake_grain;
	
	
	if (UserInput.worldWrap == WWRAP_REGION) then
		-- Raise water levels to compensate for margins near map edges.
		lakes = lakes - 20;
	end
	
	if (ExtrasGot.anything == true) then
		-- Raise water levels to compensate for extra islands.
		lakes = lakes - 6;
	end
	
	
	if (UserInput.worldWrap == WWRAP_GLOBE) then
		-- Use a globe-specific lake fractal.
		self.wholeworldPlotTypes = GenerateLakesFractal(lakes, lake_grain);
	else
		-- Fill all rows with land plots.
		self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
		-- Avoid wrapping lakes around the edges.
		local fracFlags = {FRAC_POLAR = true};
		
		-- Add margins so that edges are relatively dry.
		local marginX = math.max(1,math.floor(0.05*g_iW));
		local marginY = math.max(1,math.floor(0.05*g_iH));
		
		local iWestX = marginX;
		local iEastX = g_iW - marginX;
		local iWidth = iEastX - iWestX;
		
		local iSouthY = marginY;
		local iNorthY = g_iH - marginY;
		local iHeight = iNorthY - iSouthY;
		
		local lakesFrac = Fractal.Create(iWidth, iHeight, lake_grain, fracFlags, -1, -1)
		local lakesThreshold = GetFractalHeight(lakesFrac, lakes);
		
		for y = iSouthY, iNorthY do
			for x = iWestX, iEastX do
				local val = lakesFrac:GetHeight(x, y);
				if val >= lakesThreshold then
					local i = GetPlotIndexLua(x,y);
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	
		-- Second, oval layer to increase the chance of one main body of water.
		local centerX = (g_iW / 2) - 1;
		local centerY = (g_iH / 2) - 1;
		local xAxis = centerX * 0.75;
		local yAxis = centerY * 0.5;
		local xAxisSquared = xAxis * xAxis;
		local yAxisSquared = yAxis * yAxis;
		for x = 0, g_iW - 1 do
			for y = 0, g_iH - 1 do
				local i = GetPlotIndexLua(x,y);
				local deltaX = x - centerX;
				local deltaY = y - centerY;
				local deltaXSquared = deltaX * deltaX;
				local deltaYSquared = deltaY * deltaY;
				local oval_value = deltaXSquared / xAxisSquared + deltaYSquared / yAxisSquared;
				if oval_value <= 1 then
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	end

	-- Land and water are set.
	-- Now apply hills, mountains, etc.
	self:AddMtsHillsExtras(true);
	
	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:InvertedExtras_GeneratePlotsByRegion()
	-- Inverted Extras landmass	
	-- Fill all rows with land plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
	-- Apply mountains, hills, and extra lakes.
	self:AddMtsHillsExtras(true);
	
	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:IslandPlates_GeneratePlotsByRegion()
	-- Island Plates

	-- Get user inputs.
	local fracFlags = {};
	local diffBase  = 4;
	local seaDiffs  = {-diffBase, 0, diffBase};
	local seaDiff   = seaDiffs[UserInput.seaLevel];
	
	if (gotIceAgeFamily) then
		print("Lowering sea levels (ice age)");
		seaDiff = seaDiff - diffBase;
	end

	-- Fill all rows with water plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);
		
	-- Large islands layer.
	local args = {};
	args.iWaterPercent = seaDiff + 80; -- 65;
	args.iRegionWidth = math.ceil(g_iW);
	args.iRegionHeight = math.ceil(g_iH);
	args.iRegionWestX = math.floor(0);
	args.iRegionSouthY = math.floor(0);
	args.iRegionGrain = 3;
	args.iRegionHillsGrain = 4;
	args.iRegionPlotFlags = fracFlags;
	args.iRegionFracXExp = 7;
	args.iRegionFracYExp = 6;
	self:GenerateFractalLayerWithoutHills(args);
	
	-- Bays layer
	-- Do this before adding small islands so that we don't fracture
	-- small islands or extras into tiny islands.
	local args = {};
	args.iWaterPercent = 80 - seaDiff; -- seaDiff + 90
	args.iRegionWidth = math.ceil(g_iW);
	args.iRegionHeight = math.ceil(g_iH);
	args.iRegionWestX = math.floor(0);
	args.iRegionSouthY = math.floor(0);
	args.iRegionGrain = 4;
	args.iRegionHillsGrain = 4;
	args.iRegionPlotFlags = fracFlags;
	args.iRegionFracXExp = 7;
	args.iRegionFracYExp = 6;
	args.iRiftGrain = -1;
	self:GenerateWaterLayer(args);
	
	if (ExtrasGot.anything == false) then
		-- Small islands layer for when there are no extras.
		local args = {};
		args.iWaterPercent = seaDiff + 88; -- 95;
		args.iRegionWidth = math.ceil(g_iW);
		args.iRegionHeight = math.ceil(g_iH);
		args.iRegionWestX = math.floor(0);
		args.iRegionSouthY = math.floor(0);
		args.iRegionGrain = 4;
		args.iRegionHillsGrain = 4;
		args.iRegionPlotFlags = fracFlags;
		args.iRegionFracXExp = 7;
		args.iRegionFracYExp = 6;
		self:GenerateFractalLayerWithoutHills(args);
	end
	
	-- Land and water are set. Now apply mountains, hills, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Lakes_GeneratePlotsByRegion()
	-- Lakes, Large Lakes, Seven Seas
	
	-- Use sea level input for lake size.
	-- Lake density is inversely proportional to sea level
	local lakes      = GetSeaLevel();
	local lake_grain = ScriptData.landInfo.lake_grain;
	
	local fracFlags = g_iFlags;
		
	if (ExtrasGot.anything == true) then
		-- Lower water levels to compensate for extra islands.
		lakes = lakes - 6;
	end
	
	if (UserInput.worldWrap == WWRAP_GLOBE) then
		-- Use a globe-specific lake fractal.
		self.wholeworldPlotTypes = GenerateLakesFractal(lakes, lake_grain);
	else
		-- Fill all rows with land plots.
		self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_LAND, g_numTiles);
	
		-- Avoid wrapping lakes around the edges.
		fracFlags = {FRAC_POLAR = true};
		
		local marginX = 0;
		local marginY = 0;
		
		local iWestX = marginX;
		local iEastX = g_iW - marginX;
		local iWidth = iEastX - iWestX;
		
		local iSouthY = marginY;
		local iNorthY = g_iH - marginY;
		local iHeight = iNorthY - iSouthY;
		
		local lakesFrac = Fractal.Create(iWidth, iHeight, lake_grain, fracFlags, -1, -1)
		local lakesThreshold = GetFractalHeight(lakesFrac, lakes);
		
		for y = iSouthY, iNorthY do
			for x = iWestX, iEastX do
				local val = lakesFrac:GetHeight(x, y);
				if val >= lakesThreshold then
					local i = GetPlotIndexLua(x,y);
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	end
	
	if (ScriptData.landInfo.gotLakeIslandLayers) then
		-- Island layers for Seven Seas.
		print("Generating island layers.");
		
		local diffBase  = 4;
		local seaDiffs  = {-diffBase, 0, diffBase};
		local seaDiff   = seaDiffs[UserInput.seaLevel];
		
		if (gotIceAgeFamily) then
			print("Lowering sea levels (ice age)");
			seaDiff = seaDiff - diffBase;
		end
		
		ShiftPlotTypes(self.wholeworldPlotTypes);
		
		-- Generate Medium Islands	
		local args = {};	
		args.iWaterPercent = seaDiff + 80; -- 85
		args.iRegionWidth = math.ceil(g_iW);
		args.iRegionHeight = math.ceil(g_iH);
		args.iRegionWestX = math.floor(0);
		args.iRegionSouthY = math.floor(0);
		args.iRegionGrain = 4;
		args.iRegionHillsGrain = 4;
		args.iRegionPlotFlags = fracFlags;
		args.iRegionFracXExp = 7;
		args.iRegionFracYExp = 6;
		self:GenerateFractalLayerWithoutHills(args);

		if (ExtrasGot.anything == false) then
			-- Tiny islands layer for when there are no extras.
			local args = {};
			args.iWaterPercent = seaDiff + 85; --95 + water_percent;
			args.iRegionWidth = math.ceil(g_iW);
			args.iRegionHeight = math.ceil(g_iH);
			args.iRegionWestX = math.floor(0);
			args.iRegionSouthY = math.floor(0);
			args.iRegionGrain = 4; -- 5
			args.iRegionHillsGrain = 4;
			args.iRegionPlotFlags = fracFlags;
			args.iRegionFracXExp = 7;
			args.iRegionFracYExp = 6;
			self:GenerateFractalLayerWithoutHills(args);
		end
	end

	-- Land and water are set.
	-- Now apply hills, mountains, etc.
	self:AddMtsHillsExtras(true);
	
	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:LargeIslands_GeneratePlotsByRegion()
	-- Large Islands.
	
	-- Get user inputs.
	local sea_level = UserInput.seaLevel;

	-- Get the number of civs based on map size.
	local iNumCivs = ScriptData.worldSizeInfo.numCivs or 8;
	
	-- Use Sea Level to change the target number of large islands.
	local island_multipliers = {2, 1.65, 1.3};
	local island_multiplier  = island_multipliers[sea_level]; -- used to be 1.65 always
	
	-- Use Sea Level to change the target number of occupied cells.
	--
	-- We don't need to lower this for high sea level since we'll be making less
	-- large islands anyway.
	--
	-- Raise the multiplier for low sea level so that we have a higher chance of 
	-- fitting more large islands into the map.
	local cell_multipliers   = {0.8, 0.7, 0.7};
	local cell_multiplier    = cell_multipliers[sea_level]; -- used to be 0.7 always
	
	if (gotIceAgeFamily) then
		print("Lowering water levels (ice age).");
		island_multiplier = island_multiplier + 0.35;
		cell_multiplier   = cell_multiplier + 0.1;
	end
	
	-- A cell system will be used to generate the large islands.
	-- Define the cell traits. (These need to fit correctly with the map grid width and height.)
	local iCellWidth = 5;
	local iCellHeight = 4;
	local iNumCellColumns = math.floor(g_iW / iCellWidth);
	local iNumCellRows = math.floor(g_iH / iCellHeight);
	local iNumTotalCells = iNumCellColumns * iNumCellRows;
	local cell_data = table.fill(false, iNumTotalCells) -- Stores data on map cells in use. All cells begin as empty.
	local iNumCellsInUse = 0;
	local iNumCellTarget = math.floor(iNumTotalCells * cell_multiplier);

	-- Add randomly generated island groups
	local iNumGroups = math.floor(iNumCivs * island_multiplier);
	print("-"); print("- Target number of Large Islands: ", iNumGroups); print("-");
	local cannot_find_valid_cell = false;
	for group = 1, iNumGroups do
		if iNumCellsInUse >= iNumCellTarget or cannot_find_valid_cell == true then
			-- Map has reeached desired island population.
			print("-"); print("** Cannot place all Large Islands. Actual number placed: ", group - 1); print("-");
			break
		end
		
		--print("Group ", group);
		--CheckForNilPlotTypes(self.wholeworldPlotTypes);
		
		--[[ Formation Chart
		1. Rectangle 4x2
		2. Rectangle 2x4
		3. Rectangle 3x3 ]]--
		--
		-- Choose a formation
		local rate_threshold = {};
		local total_appearance_rate, iNumFormations = 0, 0;
		local appearance_rates = { -- These numbers are relative to one another. No specific target total is necessary.
			5, -- #1
			5, -- #2
			6, -- #3
		};
		for i, rate in ipairs(appearance_rates) do
			total_appearance_rate = total_appearance_rate + rate;
			iNumFormations = iNumFormations + 1;
		end
		local accumulated_rate = 0;
		for index = 1, iNumFormations do
			local threshold = (appearance_rates[index] + accumulated_rate) * 10000 / total_appearance_rate;
			table.insert(rate_threshold, threshold);
			accumulated_rate = accumulated_rate + appearance_rates[index];
		end
		local formation_type;
		local diceroll = TerrainBuilder.GetRandomNumber(10000, "Choose formation type - Island Making - Lua");
		for index, threshold in ipairs(rate_threshold) do
			if diceroll <= threshold then -- Choose this formation type.
				formation_type = index;
				break
			end
		end
		-- Choose cell(s) not in use;
		local iNumAttemptsToFindOpenCells = 0;
		local found_unoccupied_cell = false;
		local anchor_cell, cell_x, cell_y, foo;
		while found_unoccupied_cell == false and cannot_find_valid_cell == false do
			if iNumAttemptsToFindOpenCells > 100 then -- Too many attempts on this pass. Might not be any valid locations.
				cannot_find_valid_cell = true;
			else
				local diceroll = 1 + TerrainBuilder.GetRandomNumber(iNumTotalCells, "Choosing a cell for an island group");
				if cell_data[diceroll] == false then -- Anchor cell is unoccupied.
					-- If formation type is multiple-cell, all secondary cells must also be unoccupied.
					if formation_type == 1 then -- horizontal, 4x2.
						-- Check to see if anchor cell is too near to an edge. If so, reject.
						cell_x = math.fmod(diceroll, iNumCellColumns);
						if cell_x ~= 0 and cell_x < iNumCellColumns - 2 then
							cell_y, foo = math.modf(diceroll / iNumCellColumns);
							cell_y = cell_y + 1;
							if cell_y < iNumCellRows then 
								-- Anchor cell is valid. Still have to check the other cells.
								if cell_data[diceroll + iNumCellColumns] == false then
									if cell_data[diceroll + 1] == false and cell_data[diceroll + 2] == false then
										if cell_data[diceroll + 3] == false then
											if cell_data[diceroll + iNumCellColumns + 1] == false then
												if cell_data[diceroll + iNumCellColumns + 2] == false then
													if cell_data[diceroll + iNumCellColumns + 3] == false then
														-- All cells are open.
														anchor_cell = diceroll;
														found_unoccupied_cell = true;
													end
												end
											end
										end
									end
								end
							end
						end
					elseif formation_type == 2 then -- vertical, 2x4.
						-- Check to see if anchor cell is too near to an edge. If so, reject.
						cell_x = math.fmod(diceroll, iNumCellColumns);
						if cell_x ~= 0 then
							cell_y, foo = math.modf(diceroll / iNumCellColumns);
							cell_y = cell_y + 1;
							if cell_y < iNumCellRows - 2 then
								-- Anchor cell is valid. Still have to check the other cells.
								if cell_data[diceroll + iNumCellColumns] == false then
									if cell_data[diceroll + 1] == false then
										if cell_data[diceroll + iNumCellColumns + 1] == false then
											if cell_data[diceroll + (iNumCellColumns * 2)] == false then
												if cell_data[diceroll + (iNumCellColumns * 2) + 1] == false then
													if cell_data[diceroll + (iNumCellColumns * 3)] == false then
														if cell_data[diceroll + (iNumCellColumns * 3) + 1] == false then
															-- All cells are open.
															anchor_cell = diceroll;
															found_unoccupied_cell = true;
														end
													end
												end
											end
										end
									end
								end
							end
						end
					elseif formation_type == 3 then -- square, 3x3.
						-- Check to see if anchor cell is too near to an edge. If so, reject.
						cell_x = math.fmod(diceroll, iNumCellColumns);
						if cell_x ~= 0 and cell_x < iNumCellColumns - 1 then
							cell_y, foo = math.modf(diceroll / iNumCellColumns);
							cell_y = cell_y + 1;
							if cell_y < iNumCellRows - 1 then
								-- Anchor cell is valid. Still have to check the other cells.
								if cell_data[diceroll + iNumCellColumns] == false then
									if cell_data[diceroll + 1] == false and cell_data[diceroll + 2] == false then
										if cell_data[diceroll + iNumCellColumns + 1] == false then
											if cell_data[diceroll + (iNumCellColumns * 2)] == false then
												if cell_data[diceroll + (iNumCellColumns * 2) + 1] == false then
													if cell_data[diceroll + iNumCellColumns + 2] == false then
														if cell_data[diceroll + (iNumCellColumns * 2) + 2] == false then
															-- All cells are open.
															anchor_cell = diceroll;
															found_unoccupied_cell = true;
														end
													end
												end
											end
										end
									end
								end
							end
						end
					end
				end
				iNumAttemptsToFindOpenCells = iNumAttemptsToFindOpenCells + 1;
			end
		end
	
		-- Execute remainder of process on this loop only if a valid cell was found.
		if cannot_find_valid_cell == false then

			-- Find Cell X and Y
			cell_x = math.fmod(anchor_cell, iNumCellColumns);
			if cell_x == 0 then
				cell_x = iNumCellColumns;
			end
			cell_y, foo = math.modf(anchor_cell / iNumCellColumns);
			cell_y = cell_y + 1;

			-- Create this large island.
			local iWidth, iHeight; -- Scope the variables needed for island group creation.
			local iWestX = iCellWidth * (cell_x - 1) + 1;
			local iSouthY = iCellHeight * (cell_y - 1) + 1;
			local iCohesionW, iCohesionH;
			local iCoWestX, iCoSouthY;
			local iWater, iCohesionWater = 55, 60;
			local FracXExp, FracYExp = 5, 5;
			if formation_type == 1 then -- four cells wide, two cells tall.
				iWidth = iCellWidth * 4 - 2;
				iHeight = iCellHeight * 2 - 2;
				FracXExp = 6;
				iCohesionW = math.floor(iWidth/2);
				iCohesionH = math.floor(iHeight/2);
				iCoWestX = iWestX + math.floor(iWidth/4);
				iCoSouthY = iSouthY + math.floor(iHeight/4);
			elseif formation_type == 2 then -- two cells wide, four cells tall.
				iWidth = iCellWidth * 2 - 2;
				iHeight = iCellHeight * 4 - 2;
				FracYExp = 6;
				iCohesionW = math.floor(iWidth/2);
				iCohesionH = math.floor(iHeight/2);
				iCoWestX = iWestX + math.floor(iWidth/4);
				iCoSouthY = iSouthY + math.floor(iHeight/4);
			elseif formation_type == 3 then -- three cells wide, three cells tall.
				iWidth = iCellWidth * 3 - 2;
				iHeight = iCellHeight * 3 - 2;
				iWater = 60;
				iCohesionW = math.floor(iWidth/2);
				iCohesionH = math.floor(iHeight/2);
				iCoWestX = iWestX + math.floor(iWidth/4);
				iCoSouthY = iSouthY + math.floor(iHeight/4);
			end

			-- Execute fractal layers for this Large Island.		
			local args = {};
			args.iWaterPercent = iWater;
			args.iRegionWidth = iWidth;
			args.iRegionHeight = iHeight;
			args.iRegionWestX = iWestX;
			args.iRegionSouthY = iSouthY;
			--args.iRegionGrain
			--args.iRegionHillsGrain
			args.iRegionPlotFlags = self.iRoundFlags;
			args.iRegionFracXExp = FracXExp;
			args.iRegionFracYExp = FracYExp;
			args.iRiftGrain = -1;
			--args.bShift

			self:GenerateFractalLayerWithoutHills(args)

			--print("After 1st fractal layer.");
			--CheckForNilPlotTypes(self.wholeworldPlotTypes);
			
			local args = {};
			args.iWaterPercent = iCohesionWater;
			args.iRegionWidth = iCohesionW;
			args.iRegionHeight = iCohesionH;
			args.iRegionWestX = iCoWestX;
			args.iRegionSouthY = iCoSouthY;
			--args.iRegionGrain
			--args.iRegionHillsGrain
			args.iRegionPlotFlags = self.iRoundFlags;
			args.iRegionFracXExp = FracXExp;
			args.iRegionFracYExp = FracYExp;
			args.iRiftGrain = -1;
			--args.bShift

			self:GenerateFractalLayerWithoutHills(args)
	
			-- Record cells in use
			if formation_type == 1 then
				cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
				cell_data[anchor_cell + iNumCellColumns], cell_data[anchor_cell + iNumCellColumns + 1] = true, true;
				cell_data[anchor_cell + 2], cell_data[anchor_cell + 3] = true, true;
				cell_data[anchor_cell + iNumCellColumns + 2], cell_data[anchor_cell + iNumCellColumns + 3] = true, true;
				iNumCellsInUse = iNumCellsInUse + 8;
			elseif formation_type == 2 then
				cell_data[anchor_cell], cell_data[anchor_cell + 1] = true, true;
				cell_data[anchor_cell + iNumCellColumns], cell_data[anchor_cell + iNumCellColumns + 1] = true, true;
				cell_data[anchor_cell + (iNumCellColumns * 2)], cell_data[anchor_cell + (iNumCellColumns * 2) + 1] = true, true;
				cell_data[anchor_cell + (iNumCellColumns * 3)], cell_data[anchor_cell + (iNumCellColumns * 3) + 1] = true, true;
				iNumCellsInUse = iNumCellsInUse + 8;
			elseif formation_type == 3 then
				cell_data[anchor_cell], cell_data[anchor_cell + 1], cell_data[anchor_cell + 2] = true, true, true;
				cell_data[anchor_cell + iNumCellColumns], 
				cell_data[anchor_cell + iNumCellColumns + 1], 
				cell_data[anchor_cell + iNumCellColumns + 2] = true, true, true;
				cell_data[anchor_cell + (iNumCellColumns * 2)], 
				cell_data[anchor_cell + (iNumCellColumns * 2) + 1], 
				cell_data[anchor_cell + (iNumCellColumns * 2) + 2] = true, true, true;
				iNumCellsInUse = iNumCellsInUse + 9;
			end
		end
	end

	--print("Before adding mountains, hills, extras.");
	--CheckForNilPlotTypes(self.wholeworldPlotTypes);
	
	-- Land and water are set. Now apply mountains, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Maze_GeneratePlotsByRegion()
	-- Maze
	-- Get user inputs.
	local sea_level = GetSeaLevel();

	-- Fill all rows with water plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);
	
	-- Use a fractal to create isolated clumps of land.
	local landGrain  = 3 + TerrainBuilder.GetRandomNumber(3, "Random grain")
	local landFrac   = Fractal.Create(g_iW, g_iH, landGrain, g_iFlags, -1, -1)
	local landThresh = GetFractalHeight(landFrac, sea_level);
	
	-- Use a pangea-shaped fractal to decide where to allow isolated clumps.
	local panGrain  = 1;
	local panFrac   = Fractal.Create(g_iW, g_iH, panGrain, g_iFlags, -1, -1)
	local panThresh = GetFractalHeight(panFrac, sea_level-10);
	
	for y = 0, g_iH do
		for x = 0, g_iW do
			local panVal = panFrac:GetHeight(x,y);
			if (panVal >= panThresh) then		
				local landVal = landFrac:GetHeight(x,y);
				if landVal >= landThresh then
					local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
				end
			end
		end
	end
	
	-- Use PassMaker to connect the islands with land bridges.
	local bridgeArgs = 
	{
		obstaclesName 		= "water",
		plotTypes           = self.wholeworldPlotTypes,
		InitReachPlot 		= PassMaker.Water_InitReachPlot,
		RemoveObstacle      = PassMaker.Water_RemoveObstacle,
	};
	EnsureReachabilityWithPassMaker(bridgeArgs);
	
	-- Use a bay fractal to carve bays into the land.
	local bayGrain  = 3;
	local bayFrac   = Fractal.Create(g_iW, g_iH, bayGrain, g_iFlags, -1, -1)
	local bayThresh = GetFractalHeight(bayFrac, 72);
	
	for y = 0, g_iH do
		for x = 0, g_iW do
			local bayVal = bayFrac:GetHeight(x,y);
			if (bayVal >= bayThresh) then		
				local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
			end
		end
	end
	
	-- Reunite the lands with another pass of PassMaker.
	EnsureReachabilityWithPassMaker(bridgeArgs);
	
	-- Count the number of water tiles.
	local numWaterTiles = 0;
	for y = 0, g_iH do
		for x = 0, g_iW do
			local i = y * g_iW + x + 1;
			if (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN) then
				numWaterTiles = numWaterTiles + 1;
			end
		end
	end
	local curWaterPct = Round(100.0 * (numWaterTiles / g_numTiles));
	
	local maxNumAttempts = 100;
	local iAttempt = 0;
	while ((sea_level < curWaterPct) and (iAttempt < maxNumAttempts)) do
		-- Sea level is too high.
		-- Add islands and run PassMaker to lower sea level.
		iAttempt = iAttempt + 1;
		print("Need to lower sea level by " .. (curWaterPct - sea_level) .. 
			  "% (pass #" .. iAttempt .. ")");
		
		-- Use a fractal to create isolated clumps of land.
		landGrain  = 3 + TerrainBuilder.GetRandomNumber(3, "Random grain")
		landFrac   = Fractal.Create(g_iW, g_iH, landGrain, g_iFlags, -1, -1)
		landThresh = GetFractalHeight(landFrac, sea_level);
		
		-- Use a pangea-shaped fractal to decide where to allow isolated clumps.
		panFrac   = Fractal.Create(g_iW, g_iH, panGrain, g_iFlags, -1, -1)
		panThresh = GetFractalHeight(panFrac, sea_level-10);
		
		for y = 0, g_iH do
			for x = 0, g_iW do
				local panVal = panFrac:GetHeight(x,y);
				if (panVal >= panThresh) then		
					local landVal = landFrac:GetHeight(x,y);
					if landVal >= landThresh then
						local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
						self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
					end
				end
			end
		end
		
		EnsureReachabilityWithPassMaker(bridgeArgs);
		
		-- Count the number of water tiles.
		numWaterTiles = 0;
		for y = 0, g_iH do
			for x = 0, g_iW do
				local i = y * g_iW + x + 1;
				if (self.wholeworldPlotTypes[i] == g_PLOT_TYPE_OCEAN) then
					numWaterTiles = numWaterTiles + 1;
				end
			end
		end
		curWaterPct = Round(100 * (numWaterTiles / g_numTiles));
	end
	
	if (sea_level > curWaterPct) then
		-- There is too much land.
		-- Make a shuffled copy of all peninsulas and randomly remove land.
		print("Need to raise sea level by " .. (sea_level - curWaterPct) .. "%");
		
		-- Discover initial peninsulas.
		local peninsulas = {};
		for y = 0, g_iH do
			for x = 0, g_iW do
				local i = y * g_iW + x + 1;
				if IsPeninsula(self.wholeworldPlotTypes, x, y) then
					table.insert(peninsulas, {x = x, y = y});
				end
			end
		end
		local numPeninsulas = table.maxn(peninsulas);		
		print("Found " .. numPeninsulas .. " peninsula(s).");
		
		-- Shuffle peninsulas for random traversal.
		peninsulas = GetShuffledCopyOfTable(peninsulas);
		
		-- Copy peninsulas into a queue so that we can distribute the land removal across the map
		-- (instead of doing most of the removal in one area).
		local pQueue = Queue:Create();
		for i, p in ipairs(peninsulas) do
			pQueue:Enqueue(p);
		end
		
		local targetNumWaterTiles = Round(g_numTiles * sea_level / 100);
		
		-- Recursively shrink peninsulas until sea level rises to
		-- specified level.
		numWaterTiles = ShrinkPeninsulas(
			self.wholeworldPlotTypes, pQueue, numWaterTiles, targetNumWaterTiles);
			
		local curWaterPct = Round(100 * (numWaterTiles / g_numTiles));
		print("Sea Level now at " .. curWaterPct .. "%");
	end
	
	-- Land and water are set. Now apply mountains, hills, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:MiniDonuts_GeneratePlotsByRegion()
	-- Mini Donuts landmass	
	-- Fill all rows with background plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_iW * g_iH);
	
	-- Add the landmass version of mini-donuts.	
	local numDonutsPerCell = 2;
	local rMult = 1.0;
	if (ExtrasGot.anything == true) then
		-- Got extras.
		-- Reduce donuts/cell to make room for extras.
		numDonutsPerCell = 1;
		
		if (ExtrasGot.everything == true) then
			-- Also make donuts slightly smaller.
			rMult = 0.9;
		end
	end
	
	local miniDonutArgs = 
	{ 
		numDonutsPerCell = numDonutsPerCell,
		rMult            = rMult
	};
	MergeExtras(true, self.wholeworldPlotTypes, GenerateMiniDonuts(miniDonutArgs));
	
	-- Apply mountains, hills, and extra islands.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Noodles_GeneratePlotsByRegion()
	-- Noodles (Noodley Continents)
	-- Convert sea-level into land-level for a mid-range fractal filter.
	local water_percent = GetSeaLevel();
	if (ExtrasGot.everything == true) then
		-- Pangea with everything extras: higher sea level.
		water_percent = math.min(100, water_percent + 6);

	elseif (ExtrasGot.anything == true) then
		-- Pangea with extras: slightly higher sea level
		water_percent = math.min(100, water_percent + 3);
	end
	
	-- Allow lake level to adjust the size of loops created by the landmass fractal.
	local lakeLevel  = UserInput.lakeLevel or LAKELEVEL_NORMAL;
	local bottomPcts = {5,7,9};
	local bottomPct  = bottomPcts[lakeLevel];
	
	-- Fill all rows with background plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);

	local grain = 2;
	if gotIceAgeFamily then
		-- We have enough land to raise the fractal's granularity.
		grain = 3;
	end
	
	-- Generate the fractal.
	local landFrac = Fractal.Create(g_iW, g_iH, grain, g_iFlags, g_fracXExp, g_fracYExp);
	
	-- Use an offset filter to hollow-out the insides of continents.
	local landLevel  = (100-water_percent);
	local landBottom = GetFractalHeight(landFrac, bottomPct);
	local landTop    = GetFractalHeight(landFrac, bottomPct + landLevel);
	
	for y = 0, g_iH-1 do
		for x = 0, g_iW - 1 do
			local i = y * g_iW + x + 1; -- add one because Lua arrays start at 1
			local landVal = landFrac:GetHeight(x, y);
			
			if ((landVal >= landBottom) and (landVal < landTop)) then
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
			end
		end
	end
	
	-- Make sure that continents don't touch the poles for globe maps.
	self:DoWateryPoles();
	
	-- Land and water are set. Now apply mountains, hills, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Oval_GeneratePlotsByRegion()
	-- Oval
	
	-- Note: fractal wrap flags do not have to match world shape.
	-- Let wrap-x be true here even if the world is flat.
	local fracFlags = {FRAC_WRAP_X = true, FRAC_POLAR = true};

	-- Get user inputs.
	local sea_level = UserInput.seaLevel;

	-- Controls the initial height and width of the oval (before adding bays/lakes)
	--
	-- Don't make this too large (> 95) or else the the landmass will intersect
	-- itself and the poles.
	local axis_list = {0.85, 0.79, 0.73};           -- Used to be {0.87, 0.81, 0.75}
	local axis_multiplier = axis_list[sea_level];
	
	-- Controls the minimum distance of bays/lakes from the oval's center
	--
	-- At high sea level, only the very center of the oval is guaranteed to be dry.
	local cohesion_list = {0.5, 0.3, 0.1};       -- Used to be {0.41, 0.38, 0.35}
	local cohesion_multiplier = cohesion_list[sea_level];

	-- Controls the frequency of bays/lakes
	local baysHeight_list = {86, 80, 74};  -- Used to be hard-coded as 82.
	local baysHeight = baysHeight_list[sea_level];
	local baysGrain  = 3;
	
	if (gotIceAgeFamily) then
		print("Lowering sea levels (ice age)");
		axis_multiplier     = axis_multiplier     + 0.06;
		baysHeight          = baysHeight          + 6;
	end
		
	-- Fill all rows with water plots.
	self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);

	local centerX = g_iW / 2;
	local centerY = g_iH / 2;
	local width     = centerX;
	local height    = centerY;

	if ((not ScriptData.worldSizeInfo.isCustom) and 
	    (UserInput.worldWrap == WWRAP_GLOBE) and
		(UserInput.icyPoles == ICYPOLES_CROP)) then
		-- Cropped global map.
		if (UserInput.sunlight == Sunlights.TILTED) then
			-- Tilted axis cropped.
			-- Enlarge and shift north.
			print("Cropping the oval (globe + tilted axis cropped)");
			height  = g_iH;
			centerY = g_iH;
			
		elseif (UserInput.climate == Climates.ICEAGE) then
			-- Ice age cropped.
			-- Enlarge to compensate for height-crop.
			print("Cropping the oval (globe + ice age cropped)");
			height = height * 1.5;
			
			-- Recalibrate water levels to compensate for larger oval.
			axis_multiplier     = axis_list[sea_level];
			cohesion_multiplier = 0.001;
			baysHeight          = baysHeight - 6;
			
			local baysGrains    = {3,2,1};
			baysGrain           = baysGrains[sea_level];
			
			-- Adjust civ-start strategy and AI hint to be more like a continents map.
			ScriptData.landInfo.aspDivMethod = DIVMETHOD_CONTINENTAL;
			
		elseif (UserInput.climate == Climates.SNOWBALL) then
			-- Snowball cropped.
			-- Enlarge to compensate for height-crop.
			print("Cropping the oval (globe + snowball cropped)");
			height = height * 2;
			
			-- Recalibrate water levels to compensate for larger oval.
			axis_multiplier     = axis_list[sea_level];
			cohesion_multiplier = 0.001;
			baysHeight          = baysHeight - 6;
			
			local baysGrains    = {3,2,1};
			baysGrain           = baysGrains[sea_level];
			
			-- Adjust civ-start strategy and AI hint to be more like a continents map.
			ScriptData.landInfo.aspDivMethod = DIVMETHOD_CONTINENTAL;
		end	
	end
	
	-- Add the main oval as land plots.
	local majorAxis = width  * axis_multiplier;
	local minorAxis = height * axis_multiplier;
	local majorAxisSquared = majorAxis * majorAxis;
	local minorAxisSquared = minorAxis * minorAxis;	
	for x = 0, g_iW - 1 do
		for y = 0, g_iH - 1 do
			local deltaX = x - centerX;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			local d = deltaXSquared/majorAxisSquared + deltaYSquared/minorAxisSquared;
			if d <= 1 then
				local i = y * g_iW + x + 1;
				self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
			end
		end
	end

	-- Now add bays, fjords, inland seas, etc, but not inside the cohesion area.
	local baysFrac = Fractal.Create(g_iW, g_iH, baysGrain, fracFlags, -1, -1);
	local iBaysThreshold = GetFractalHeight(baysFrac, baysHeight);
	local majorAxis = width * cohesion_multiplier;
	local minorAxis = height * cohesion_multiplier;
	local majorAxisSquared = majorAxis * majorAxis;
	local minorAxisSquared = minorAxis * minorAxis;
	for y = 0, g_iH - 1 do
		for x = 0, g_iW - 1 do
			local deltaX = x - centerX;
			local deltaY = y - centerY;
			local deltaXSquared = deltaX * deltaX;
			local deltaYSquared = deltaY * deltaY;
			local d = deltaXSquared/majorAxisSquared + deltaYSquared/minorAxisSquared;
			if d > 1 then
				local i = y * g_iW + x + 1;
				local baysVal = baysFrac:GetHeight(x, y);
				if baysVal >= iBaysThreshold then
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_OCEAN;
				end
			end
		end
	end
	
	-- Land and water are set. Now apply mountains, hills, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end

function MultilayeredFractal:Snake_GeneratePlotsByRegion()
	-- Snake Pangea		
	-- Use low-grain to create a pangea fractal.
	local grain = 1;
	
	-- Convert sea-level into land-level for a mid-range fractal filter.
	local water_percent = GetSeaLevel();
	if (ExtrasGot.everything == true) then
		-- Pangea with everything extras: higher sea level.
		water_percent = math.min(100, water_percent + 6);

	elseif (ExtrasGot.anything == true) then
		-- Pangea with extras: slightly higher sea level
		water_percent = math.min(100, water_percent + 3);
	end
	local landLevel  = (100-water_percent)/2;
	
	-- Generate fractal layer and examine the largest landmass.
	-- Reject the result until the largest landmass occupies enough of the total land.
	local done = false;
	local iAttempts = 0;
	
	while (done == false) do
		iAttempts = iAttempts + 1;
		print("Attempt #" .. iAttempts);
	
		-- Fill all rows with background plots.
		self.wholeworldPlotTypes = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
		local iNumTotalLandTiles = 0;

		-- Generate the fractal.
		local landFrac = Fractal.Create(g_iW, g_iH, grain, g_iFlags, g_fracXExp, g_fracYExp);
		
		-- Use a mid-range filter to make the pangea snaky.
		local landBottom = GetFractalHeight(landFrac, 50-landLevel);
		local landTop    = GetFractalHeight(landFrac, 50+landLevel);
		
		for y = 0, g_iH-1 do
			for x = 0, g_iW - 1 do
				local i = GetPlotIndexLua(x,y);
				local pPlot = Map.GetPlotByIndex(i-1);
				local landVal = landFrac:GetHeight(x, y);
				
				if ((landVal >= landBottom) and (landVal < landTop)) then
					-- Set terrain in global map so that we can calculate largest area.
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_DESERT); 
					self.wholeworldPlotTypes[i] = g_PLOT_TYPE_LAND;
					iNumTotalLandTiles = iNumTotalLandTiles + 1;
				else
					TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_OCEAN); 
				end
			end
		end
		
		-- Check whether the biggest landmass dominates the map.
		AreaBuilder.Recalculate();
		local biggest_area = Areas.FindBiggestArea(false);
		local iNumBiggestAreaTiles = biggest_area:GetPlotCount();
		
		-- Now test the biggest landmass to see if it is large enough.
		if ((iAttempts >= PANGEA_MAX_NUM_ATTEMPTS) or 
		    (iNumBiggestAreaTiles >= (iNumTotalLandTiles * SNAKE_LANDMASS_MAJORITY_MIN))) then
			done = true;
			print("Got a sufficiently-large biggest landmass.");
		end
	end
	
	-- Land and water are set. Now apply mountains, hills, etc.
	self:AddMtsHillsExtras();

	-- Plot Type generation completed. Return global plot array.
	return self.wholeworldPlotTypes;
end
----------------------------------------------------------------------------------
function GeneratePlotTypes()
	print("Generating Plot Types (" .. ScriptData.landInfo.name ..")");
	local plots;
	
	-- Create the appropriate fractal world for the landmass.
	local fractal_world = ScriptData.landInfo.CreateFWorld();
	
	if (ScriptData.landInfo.CreateFWorld == MultilayeredFractal.Create) then
		------------------------------
		-- MLF landmasses
		------------------------------
		fractal_world.GeneratePlotsByRegion = ScriptData.landInfo.GenPlotTypes;
		
		plots = fractal_world:GeneratePlotsByRegion();
	else
		------------------------------
		-- Fractal World landmasses
		------------------------------
		fractal_world.AddLandAndWater      = GotLakes_Fractal.AddLandAndWater;
		fractal_world.AddMtsHillsExtras    = GotLakes_Fractal.AddMtsHillsExtras;
		fractal_world.GeneratePlotTypes    = ScriptData.landInfo.GenPlotTypes;
	
        if (ScriptData.landInfo.GenPlotTypes == 
				GotLakes_Fractal.Fractal_GeneratePlotTypes) then
			---------------------------
			-- Archipelago
			-- Fractal
			-- Small Continents
			-- Tiny Islands
			--------------------------- 	
			fractal_world:InitFractal(ScriptData.landInfo.fractalInitArgs);
		end
		
		-- Generate plots for a non-MLF fractal world.
		plots = fractal_world:GeneratePlotTypes(ScriptData.landInfo.fractalGenArgs);
	end
	
	-- Connect all water tiles, if applicable.
	-- Although this doesn't yet guarantee connected saltwater seas yet,
	-- this will probably do most of the work, unless a volcano or impassable
	-- wonder happens to get in the way. Also, this avoids having to remove
	-- land features or add water features, since features don't exist yet.
	ConnectOceans(plots);
	
	--CheckForNilPlotTypes(plots);
	return plots;
end
----------------------------------------------------------------------------------
-- Coasts and coastal mountains.
----------------------------------------------------------------------------------
function GenerateCoasts(plotTypes, terrainTypes)
	print("Setting coasts and oceans...");
		
	local shallowWater = g_TERRAIN_TYPE_COAST;
	local deepWater    = g_TERRAIN_TYPE_OCEAN;
		
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do
			local index = GetPlotIndexLua(iX,iY);
			if (plotTypes[index] == g_PLOT_TYPE_OCEAN) then
				if (IsAdjacentToLand(plotTypes, iX, iY)) then
					terrainTypes[index] = shallowWater;
				else
					terrainTypes[index] = deepWater;
				end
			
			-- Initialize all land as grass
			elseif (plotTypes[index] == g_PLOT_TYPE_MOUNTAIN) then
			    terrainTypes[index] = g_TERRAIN_TYPE_GRASS_MOUNTAIN;
				
			elseif (plotTypes[index] == g_PLOT_TYPE_HILLS) then
				terrainTypes[index] = g_TERRAIN_TYPE_GRASS_HILLS;
				
			elseif (plotTypes[index] == g_PLOT_TYPE_LAND) then
				terrainTypes[index] = g_TERRAIN_TYPE_GRASS;
			
			else
				print("Unexpected plot type at " .. 
				CoordString(iX, iY) .. ": " .. NonNilStr(plotTypes[index]));
			end
		end
	end
	
	print("Expanding coasts");
	for iI = 0, 2 do
		local shallowWaterPlots = {};
		for iX = 0, g_iW - 1 do
			for iY = 0, g_iH - 1 do
				local index = GetPlotIndexLua(iX,iY);
				if (terrainTypes[index] == deepWater) then
					-- Chance for each eligible plot to become an expansion is 1 / iExpansionDiceroll.
					-- Default is two passes at 1/4 chance per eligible plot on each pass.
					if (IsAdjacentToShallowWater(terrainTypes, iX, iY) and 
						TerrainBuilder.GetRandomNumber(4, "add shallows") == 0) then
						table.insert(shallowWaterPlots, index);
					end
				end
			end
		end
		for i, index in ipairs(shallowWaterPlots) do
			terrainTypes[index] = shallowWater;
		end
	end
	
	-- Add coasts from the global coast map.
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do
			local index = GetPlotIndexLua(iX,iY);
			if ((plotTypes[index] == g_PLOT_TYPE_OCEAN) and 
			    (ScriptData.coastPlots[index] == g_PLOT_TYPE_LAND)) then
				terrainTypes[index] = shallowWater;
			end
		end
	end
end

function RemoveCoastalMountains(plotTypes, terrainTypes)
	local mountainsTransformed = 0;
	
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do
			local index = GetPlotIndexLua(iX, iY);

			if plotTypes[index] == g_PLOT_TYPE_MOUNTAIN then
				if IsAdjacentToShallowWater(terrainTypes, iX, iY) then
                    -- Replace mountains with hills.
					plotTypes[index] = g_PLOT_TYPE_HILLS;
                    terrainTypes[index] = g_TERRAIN_TYPE_GRASS_HILLS;
					mountainsTransformed = mountainsTransformed + 1;
					--print(CoordString(iX, iY));
				end
			end
		end
	end

	AreaBuilder.Recalculate();
	
	print("Coastal mountains removed: ", mountainsTransformed);
	return plotTypes;
end
----------------------------------------------------------------------------------
-- Lakes and Rivers - overrides and helper methods
----------------------------------------------------------------------------------
function CanHavePostLandmassLake(plot)
	-- Return true iff the plot is a valid candidate for a post-landmass lake.
	
	-- Avoid plots that are already water because adding a lake to that would have no effect.
	-- Avoid mountains because mountains might be surrounded by other mountains.
    -- Avoid adjacent mountains if we're not supposed to have coastal mountains.
	-- Avoid coastal land lest coastal water creeps into the landmass.
	-- Avoid rivers so that we don't cut through the middle of a river.
	-- Don't worry about natural wonders--we didn't add those yet.
	return (plot and not (-- Avoid NPE
		    plot:IsWater() or 
		    plot:IsMountain() or 
			plot:IsCoastalLand() or
		    IsAdjacentToRiver(plot:GetX(),plot:GetY()) or
            ((UserInput.noCoastMts == true) and 
				IsAdjacentToMountain(plot:GetX(),plot:GetY())) ));
end

function AddMoreLake(plot, lakePlots)
	-- Maybe expand a post-landmass lake plot into a multi-plot lake.
	-- Args: 
	--   plot: lake-plot from which to expand
	--   lakePlots: accumulator of plots to turn into water
	local largeLake = 0;
	for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
		local adjacentPlot = Map.GetAdjacentPlot(plot:GetX(), plot:GetY(), direction);
		
		if CanHavePostLandmassLake(adjacentPlot) then
			local r = TerrainBuilder.GetRandomNumber(4 + largeLake, "Lake expansion");
			if r < 3 then
				--print("Expanding lake at " .. CoordString(adjacentPlot:GetX(),adjacentPlot:GetY()));
				-- Add to lake plots; don't turn land into water yet because that
				-- might prevent expansion to other adjacent plots.
				table.insert(lakePlots, adjacentPlot);
				largeLake = largeLake + 1;
			end		
		end
	end
end

function AddPostLandmassLake(plot, lakePlotRand)
	-- Turn this tile and maybe some adjacent tiles into a lake.
	-- Args: 
	--   plot: where to start adding a lake. 
	--     This plot must pass the CanHavePostLandmassLake() test.
	--   lakePlotRand: non-zero denominator for the chance of adding a lake
	--     i.e., the chance of adding a lake is 1/lakePlotRand.
	-- Returns: the number of lake tiles added to the map.
	local lakeDice = TerrainBuilder.GetRandomNumber(lakePlotRand, "fresh Lakes");
	if (lakeDice ~= 0) then
		return 0;
	end
	
	local numLakeTilesAdded = 0;
	
	-- Make a list of plots to turn into water so that we can add
	-- more lakes without confusing neighboring tiles with 
	-- "coastal land".
	local lakePlots = {plot};
		
	-- Try to expand the lake into adjacent tiles.
	AddMoreLake(plot, lakePlots);
	
	-- Turn lake plots into water.
	for i,lakePlot in ipairs(lakePlots) do 
		numLakeTilesAdded = numLakeTilesAdded + 1;
		TerrainBuilder.SetTerrainType(lakePlot, g_TERRAIN_TYPE_COAST);
	end
	return numLakeTilesAdded;
end

function GetLakePlotRand()
	-- Get the chance of spawning a freshwater lake.
	
	local lakePlotRand = GlobalParameters.LAKE_PLOT_RANDOM  or 40;
	
	-- Allow the user to raise/lower water-tables for lakes.
	local lakeLevel = UserInput.lakeLevel or LAKELEVEL_NORMAL;
	
	-- More fresh water => smaller lake dice => higher frequency of random lakes.
	--
	-- Use larger dice than the base game because we're adding lakes before rivers,
	-- which means that there are more eligible tiles for lakes.
	local lakeMults = {3.0, 1.5, 0.75};
	local lakeMult = lakeMults[lakeLevel] or 1.5;
	
	return lakePlotRand * lakeMult;
end

function AddLakes()
	-- Add some fresh-water lakes.
	print("Adding lakes.");
	
	-- Double the lake-plot dice 
	-- because we add lakes twice.
	local lakePlotRand = GetLakePlotRand();
	
	-- Turn the dice into a natural number.
	lakePlotRand = math.max(1,Round(lakePlotRand));
	
	print("Chance of lake plot: 1/" .. lakePlotRand);
	
	local numLakeTilesAdded  = 0;
	local numLakesAdded      = 0;
	local numLargeLakesAdded = 0;

	for i = 0, (g_iW * g_iH) - 1, 1 do
		plot = Map.GetPlotByIndex(i);
		
		if CanHavePostLandmassLake(plot) then 
			-- This plot has lake potential.
			-- Roll dice to decide whether to make this plot a lake tile.
			local numNewLakeTilesAdded = AddPostLandmassLake(plot, lakePlotRand);
			
			numLakeTilesAdded = numLakeTilesAdded + numNewLakeTilesAdded;
			
			if (numNewLakeTilesAdded > 0) then
				numLakesAdded = numLakesAdded + 1;
			end
			if (numNewLakeTilesAdded > 3) then
				numLargeLakesAdded = numLargeLakesAdded + 1;
			end
		end
	end
	
	-- this is a minimalist update because lakes have been added
	if numLakeTilesAdded > 0 then
		print("Lake tiles added:  " .. numLakeTilesAdded)
		print("Total Lakes added: " .. numLakesAdded)
		print("Large Lakes added: " .. numLargeLakesAdded)
		AreaBuilder.Recalculate();
	end
end

DefaultRiverPattern = 
{
	-- Debug name.
	name = "unknown",
	
	-- Toggle randomizing the river pattern for each river.
	isRandom = false,

	-- Toggle rivers creating branches (multi-recursion).
	allowBranch = true,
	
	-- Toggle Y-shaped merges with other rivers.
	allowYMerge = ENABLE_RIVER_MERGE;

	
	-- Toggle rivers flowing into fresh lakes.
	allowLakeMouths = true,
	
	-- Toggle generating lakes when generating inland rivers.
	allowCreateLakes = true,

	-- Chance of extending a river in both directions at each segment.
	-- Higher values lead to high-fanout rivers, and require a shorter 
	-- min-length in order to avoid covering the entire map.
	branchPct = 20,
	
	-- Chance of trying the fallback direction if the first-choice is fruitless.
	-- Higher values result in snaky rivers. Setting to 0 effectively disables this.
	fallbackPct = 20,
	
	-- Don't try as hard to extend any river that has grown to at least 
	-- this many river segments.
	--
	-- This has no effect on simple or branchy rivers.
	softMaxLength = 1, -- dummy value
	
	-- Stop extending the river after it reaches this length.
	hardMaxLength = 1, -- dummy value
	
	-- Affect of exceeding softMaxLength on river recursion chances.
	-- Lower number in [0,1] range results in more drastic reduction.
	longRiverFactor = 0.25,
	
	-- Chance of starting a river at a qualifying spot.
	-- Use this for responsiveness to user input.
	startPct = 1, -- dummy value
	
	-- A river must create at least this many segments in order to prevent
	-- other rivers from starting near its starting spot.
	--
	-- Any river smaller than this is considered "small" and will allow
	-- other rivers to start at a closer distance.
	smallRiverLength = 1, -- dummy value
};

function CreateRiverPattern_Simple(args)
	-- Create the Simple Rivers pattern.
	local args = args or {};
	args.name             = "simple";
	args.allowBranch      = true;  -- allow multiple sources
	args.allowYMerge      = false; -- enforce one mouth
	args.allowLakeMouths  = false;
	args.allowCreateLakes = false;
	args.softMaxLength    = args.softMaxLength * 2;
	args.hardMaxLength    = math.huge;
	args.branchPct        = 6;
	args.fallbackPct      = 0;
		
	if ((gotLakesFamily and UserInput.freshLakes and (not UserInput.connectSeas)) or
	    (UserInput.landmass == Landmasses.INVEXTRAS)) then
		-- A lakes family landmass with all fresh lakes,
		-- or the Inverted Extras landmass.
		-- Allow starting at fresh lakes because much of the water is fresh.
		args.name            = "simple - allow lake mouths";
		args.allowLakeMouths = true;
		
	elseif (UserInput.landmass == Landmasses.INLANDSEA) then
		-- Inland sea rivers
		-- Allow y-merge, but not branching.
		args.name        = "simple - inland sea";
		args.allowBranch = false; -- force one source
		args.allowYMerge = ENABLE_RIVER_MERGE;  -- allow multiple mouths
		args.branchPct   = 0;
	end
	
	-- Apply simple river overrides to the default pattern.
	return GetConfigInfo(DefaultRiverPattern, args);
end

function CreateRiverPattern_Detailed(args)
	-- Create the Detailed Rivers pattern.
	local args = args or {};
	args.name = "detailed";
	
	-- Apply arg overrides to the default pattern.
	return GetConfigInfo(DefaultRiverPattern, args);
end

function CreateRiverPattern_Branchy(args)
	-- Create the Branchy Rivers pattern.
	local args = args or {};
	args.name          = "branchy";
	args.hardMaxLength = 0.75 * args.softMaxLength;
	args.branchPct     = 90;
	args.fallbackPct   = 10;
	args.startPct      = args.startPct + 20;
	
	-- Apply arg overrides to the default pattern.
	return GetConfigInfo(DefaultRiverPattern, args);
end

function CreateRiverPattern_Snaky(args)
	-- Create the Snaky Rivers pattern.
	local args = args or {};
	args.name            = "snaky";
	args.allowYMerge     = false;
	args.hardMaxLength   = args.hardMaxLength + args.smallRiverLength;
	args.longRiverFactor = 0.1;
	args.branchPct       = 10;
	args.fallbackPct     = 100;
	-- Apply arg overrides to the default pattern.
	return GetConfigInfo(DefaultRiverPattern, args);
end

function CreateRiverPattern_Everything(args)
	-- Create the Everything Rivers pattern.
	local args = args or {};
	args.name     = "everything";
	args.isRandom = true;
	
	-- Apply arg overrides to the default pattern.
	return GetConfigInfo(DefaultRiverPattern, args);
end

RiverGenerator = {};

function RiverGenerator.Create()
	-- Constructor.
	-- Reuse this instance for both coastsal and inland river generation.
	--
	-- This generator creates all rivers by starting at the mouth
	-- and tracing backwards to the source.

	-- Allow user to increase/decrease the number of river tiles.
	local waterLevel = UserInput.riverLevel or RIVERLEVEL_NORMAL;
	
	-- More fresh water => higher chance of river starting at a valid location => more rivers
	local startPcts = {25, 35, 55};
	local startPct  = startPcts[waterLevel];
	
	local lakePlotRand = GetLakePlotRand();
	
	if (UserInput.landmass == Landmasses.INLANDSEA) then
		-- Increase rivers to compensate for few bodies of water
		print("Increasing rivers and lakes (inland sea)");
		lakePlotRand = lakePlotRand / 8;
		startPct     = startPct + 15;
	
	elseif ((UserInput.landmass == Landmasses.INVEXTRAS) and (not ExtrasGot.anything)) then
		-- Increase rivers to compensate for world that only has post-landmass lakes.
		print("Increasing rivers and lakes (inverted extras + no extras)");
		lakePlotRand = lakePlotRand / 8;
		startPct     = startPct + 40;
	end
	
	-- Turn the dice into a natural number.
	lakePlotRand = math.max(1,Round(lakePlotRand));
	
	-- Calculate bounds for river length.
	
	-- Allow user input to affect river bounds.
	local waterLengthMults = {1,2,3};
	local waterLengthMult  = waterLengthMults[waterLevel];
	
	-- Base Game uses Map.GetMapSize(), 
	-- which is inconsistent when there are custom map sizes.
	--
	-- Incrementing by 1/2 map size index seems to result in better 
	-- consistency across sizes.
	local smallRiverLength = 2 + Round(ScriptData.worldSizeInfo.index/2);
	print("Small River length: " .. smallRiverLength);
	
	-- Example [soft, hard] lengths for detailed rivers: 
	-- => sparse:   [8,  12]
	-- => standard: [12, 16]
	-- => abundant: [16, 20]
	local softMaxLength = (waterLengthMult + 1) * smallRiverLength;
	local hardMaxLength = softMaxLength + smallRiverLength;
		
	-- River pattern settings.
	local patternArgs = 
	{	
		-- Don't try as hard to extend any river that has grown to at least 
		-- this many river segments.
		--
		-- This has no effect on simple or branchy rivers.
		softMaxLength = softMaxLength,
		
		-- Stop extending the river after it reaches this length.
		hardMaxLength = hardMaxLength,
		
		-- Chance of starting a river at a qualifying spot.
		-- Use this for responsiveness to user input.
		startPct = startPct,
		
		-- A river must create at least this many segments in order to prevent
		-- other rivers from starting near its starting spot.
		--
		-- Any river smaller than this is considered "small" and will allow
		-- other rivers to start at a closer distance.
		smallRiverLength = smallRiverLength
	};
	
	print("Chance of river-start lake plot: 1/" .. lakePlotRand);
	
	local patterns = 
	{
		CreateRiverPattern_Simple(    GetConfigInfo(DefaultRiverPattern, patternArgs)),
		CreateRiverPattern_Detailed(  GetConfigInfo(DefaultRiverPattern, patternArgs)),
		CreateRiverPattern_Branchy(   GetConfigInfo(DefaultRiverPattern, patternArgs)),
		CreateRiverPattern_Snaky(     GetConfigInfo(DefaultRiverPattern, patternArgs)),
		CreateRiverPattern_Everything(GetConfigInfo(DefaultRiverPattern, patternArgs))
	};
	local pattern = patterns[UserInput.rivers];
		
	local stats = 
	{
		-- Number of rivers started.
		numRivers = 0,
		
		-- Number of lake tiles created for forward rivers.
		numLakeTiles = 0,
		
		-- Number of river segments added to the map.
		numSegments = 0,
	};
	
	-- Create data.
	local data = 
	{
		-- Helper functions
		AssignIDToLake           = RiverGenerator.AssignIDToLake,
		AssignIDToRiver          = RiverGenerator.AssignIDToRiver,
		ChooseNextFlowDir        = RiverGenerator.ChooseNextFlowDir,
		ChoosePattern            = RiverGenerator.ChoosePattern,
		GetIntersectInfo         = RiverGenerator.GetIntersectInfo,
		GetOppositeFlowDirection = RiverGenerator.GetOppositeFlowDirection,
		GetPlotElevation         = RiverGenerator.GetPlotElevation,
		GetRiverElevationAtPlot  = RiverGenerator.GetRiverElevationAtPlot,
		GetRiverIDs              = RiverGenerator.GetRiverIDs,
		GetRiverSegment          = RiverGenerator.GetRiverSegment,
		IsAdjacentRiver          = RiverGenerator.IsAdjacentRiver,
		IsCloseToAnotherStart    = RiverGenerator.IsCloseToAnotherStart,
		MergeRivers              = RiverGenerator.MergeRivers,
		PrintStats               = RiverGenerator.PrintStats,
		Reset                    = RiverGenerator.Reset,
		RiverPrint               = RiverGenerator.RiverPrint,
		SetRiver                 = RiverGenerator.SetRiver,
		Validate                 = RiverGenerator.Validate,
		ValidateTraverse         = RiverGenerator.ValidateTraverse,
		WouldFlowBetweenDryPlots = RiverGenerator.WouldFlowBetweenDryPlots,
		
		-- Top-Level functions
		AddCoastalRivers         = RiverGenerator.AddCoastalRivers,
		AddInlandRivers          = RiverGenerator.AddInlandRivers,
	
		-- River Propagation
		StartRiver               = RiverGenerator.StartRiver,
		DoRiver                  = RiverGenerator.DoRiver,
		DoNextRiver              = RiverGenerator.DoNextRiver,
	
		-- Pattern-specific settings
		patterns = patterns,
		pattern  = pattern,
		
		-- Instrumentation.
		stats = stats,
	
		-- Keep track of places where we randomly decided not to start a river.
		-- So that we don't repeatedly roll dice for the same spot.
		skippedStartPlots = {},
		
		-- Keep track of starting locations for small rivers (mouths for reverse-
		-- river-gen) so that we can properly space them out.
		smallStartPlots = {},
		
		-- Keep track of river starting locations (mouths for reverse-river-gen) 
		-- so that we can properly space them out.
		normalStartPlots = {},
		
		-- Assign unique IDs to rivers so that we can allow certain kinds of merges
		-- but not self-merges.
		nextRiverID = 0,
		
		-- Two maps of river plots for precise river-intersection detection
		--   S:  Which river is touching each plot's S  corner
		--   SE: Which river is touching each plot's SE corner
		riverPlots_S  = table.fill(-1, g_numTiles),	
		riverPlots_SE = table.fill(-1, g_numTiles),

		-- Assign IDs to the water plots of lakes as rivers flow into them
		-- so that no river flows both into and out of the same lake.
		lakeIDMap = table.fill(-1, g_numTiles),
		
		-- The chance of spawning a river-start lake.
		lakePlotRand = lakePlotRand
	};
		
	return data;
end

function RiverGenerator:AssignIDToLake(lakePlot, id)
	-- Assign a unique lake ID to all plots in a lake.
	if (not (lakePlot and lakePlot:IsLake())) then
		return;
	end
		
	-- Use a stack to search neighboring tiles in DFS order until we've
	-- assigned a lake ID to all water tiles in the lake.
	local stack = Stack:Create();
	local count = 0;
	local iVisited = GetPlotIndexLua(lakePlot:GetX(), lakePlot:GetY());
	
	stack:Push({x=lakePlot:GetX(), y=lakePlot:GetY()});
	self.lakeIDMap[iVisited] = id;
	
	while (not stack:IsEmpty()) do
	
		local coord = stack:Pop();
		local x, y = coord.x, coord.y;
		
		-- Increase the water count.
		count = count + 1;
		
		for i, direction in ipairs(HexDirections) do
			local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
			
			if (adjacentPlot and adjacentPlot:IsLake()) then
				-- We have an adjacent plot.
				-- Let's see if it's unvisited water.
				local aX, aY = adjacentPlot:GetX(), adjacentPlot:GetY();
				local iCouldVisit = GetPlotIndexLua(aX, aY);
			
				if (self.lakeIDMap[iCouldVisit] < 0) then
					-- Add to the stack of plots to visit.
					stack:Push({x=aX, y=aY});
					self.lakeIDMap[iCouldVisit] = id;
				end
			end
		end
	end

	self:RiverPrint("Assigned ID#" .. id .. " to lake of size " .. count);
end

function RiverGenerator:AssignIDToRiver(riverSegment)
	-- Assign an ID to a river and/or starting lake.
	-- 
	-- If the river starts from a lake, then the river and lake must
	-- have matching IDs to avoid the same river flowing both two 
	-- and from a lake.
	--
	-- Use lake ID if the river starting next to an already-ID'ed lake.
	--
	-- If the lake doesn't yet have an ID, assign a new ID to both 
	-- the lake and the river.
	--
	-- If the river is starting from salt water, just assign a new ID
	-- to the river.
	--
	-- Args: riverSegment: the river's first segment, i.e. the mouth
	-- Returns: the ID assigned to the river.
	
	local id = -1;
	local plot = riverSegment.lakeIDPlot;
	if (plot and plot:IsLake()) then
		-- Plot is starting at a lake.
		local plotIndex = GetPlotIndexLua(plot:GetX(), plot:GetY());
		local lakeID = self.lakeIDMap[plotIndex];
		
		if (lakeID < 0) then
			-- Lake with no ID.
			-- Use a new river ID and assign it to the lake.
			id = self.nextRiverID;
			self.nextRiverID = self.nextRiverID + 1;
			self:AssignIDToLake(plot, id);
		else
			-- Lake already has an ID.
			-- Use that for river ID.
			id = lakeID;
		end
	else
		-- Starting at a salty coast.
		-- Just use a new river ID.
		id = self.nextRiverID;
		self.nextRiverID = self.nextRiverID + 1;
	end
	return id;
end

function RiverGenerator:ChooseNextFlowDir(riverSegment, originalFlowDir)
	-- Decide which direction to take for the next segment of reverse-river gen.
	--
	-- Args: 
	--   riverSegment: current river segment; must have a next plot
	--   originalFlowDir: the river's original flow direction;
    --     use this to bias the river against extending back 
	--     towards the sea.	
	-- 
	-- Returns
	--   flowDir: the recommended flow direction; not necessarily a viable direction,
	--     but the best direction for this river segment.
	--   fallbackDir: the other flow direction to use as a fallback.
	local nextPlot = riverSegment.nextPlot;
	
	local directionIndex = 1 + TerrainBuilder.GetRandomNumber (2, "River Direction");

	local nextDirs = riverSegment.nextDirs;
	local flowDirA = nextDirs[1];
	local flowDirB = nextDirs[2];
	
	local flowDirAStr = FlowDirStr(flowDirA);
	local flowDirBStr = FlowDirStr(flowDirB);
	
	local riverInfoA = self:GetRiverSegment(nextPlot, flowDirA);
	local riverInfoB = self:GetRiverSegment(nextPlot, flowDirB);
		
	-- Check whether we have two directions to choose from.
	if (not (riverInfoB and riverInfoB.riverPlot)) then
		-- Direction B is no good.
		--
		-- We didn't check direction A, but even if A is not
		-- good, we still have to choose a direction, so just 
		-- go with direction A.
		self:RiverPrint("Choosing flowDir " .. flowDirAStr .. 
						" because " .. flowDirBStr .. " is no good.");
		return flowDirA, flowDirB;
	
	elseif (not (riverInfoA and riverInfoA.riverPlot)) then
		-- Direction A is no good, so just go with direction B.
		self:RiverPrint("Choosing flowDir " .. flowDirBStr .. 
						" because " .. flowDirAStr .. " is no good.");
		return flowDirB, flowDirA;
	end
	
	-- We have two directions, so compare elevation info.
	local valueA = self:GetRiverElevationAtPlot(riverInfoA.sourcePlot) +
		self:GetRiverElevationAtPlot(riverInfoA.riverPlot) +
		self:GetRiverElevationAtPlot(riverInfoA.otherSidePlot);

	local valueB = self:GetRiverElevationAtPlot(riverInfoB.sourcePlot) +
		self:GetRiverElevationAtPlot(riverInfoB.riverPlot) +
		self:GetRiverElevationAtPlot(riverInfoB.otherSidePlot);
	
	-- If we're flowing back towards the sea then we're going downhill,
	-- so slash elevation.
	local backwardsDir = self:GetOppositeFlowDirection(originalFlowDir);
	if (flowDirA == backwardsDir) then
		valueA = valueA / 4;
	
	elseif (flowDirB == backwardsDir) then
		valueB = valueB / 4;
	end
	
	-- Pick whichever flow direction leads to higher elevation,
	-- since we're generating the river in reverse.	
	if (valueA == valueB) then
		-- It's a tie, so randomly choose a direction.
		local flowDirIndex = 1 + TerrainBuilder.GetRandomNumber(2, "River Direction");
		return nextDirs[flowDirIndex], nextDirs[3-flowDirIndex];	
		
	elseif (valueB > valueA) then
		return flowDirB, flowDirA;
	end
	return flowDirA, flowDirB;
end

function RiverGenerator:ChoosePattern()
	-- Choose a river pattern for a potential river to start.
	if (self.pattern.isRandom) then
		-- Choose a random river pattern (not including the "everything" pattern).
		local randSize = (#self.patterns)-1;
		local riverDice = 1 + TerrainBuilder.GetRandomNumber(randSize, "Random river pattern");
		return self.patterns[riverDice];
	end
	
	-- Choose the user-specified non-random river pattern.
	return self.pattern;
end

function RiverGenerator:GetIntersectInfo(riverSegment, pattern)
	-- Analyze neighboring rivers to determine the type of intersection,
	-- of rivers if any, that would occur if a river existed at a
	-- certain segment.
	--
	-- Args: 
	--   riverSegment (must be non-nil): which river segment to check for 
	--     intersections
	--   pattern: the river pattern - affects which intersections are allowed
	--   
	-- Returns:
	--   isValid: true iff the intersection type is allowed
	--   isMerge: true iff the intersection would combine two different rivers
	--   typeStr: describes the type of interesction
	if (riverSegment.riverExists) then
		-- The river segment already exists. Complete overlap would occur.
		return false, false, "overlap";
		
	elseif ((riverSegment.riverPlot  == nil) or
		    (riverSegment.nextPlot   == nil) or 
	        (riverSegment.mouthPlot  == nil) or 
			(riverSegment.sourcePlot == nil)) then
		-- The river is either along or off the edge of the map.
		return true, false, "map edge";
	end
		
	-- Check river ID at each end of the segment.
	local mouthID, sourceID = self:GetRiverIDs(riverSegment);
	
	if (not (mouthID or sourceID)) then
		-- Unable to get river ID info.
		return false, false, "map edge (no river IDs)";
		
	elseif ((mouthID < 0) and (sourceID < 0)) then
		-- No rivers touching this segment.
		return true, false, "none";
			
	elseif (mouthID == sourceID) then
		-- River would intersect with itself.
		return false, true, "self";
	end
	
	-- The intersection is a merge if both ends already touch a river.
	local intersectIsMerge = (mouthID >= 0) and (sourceID >= 0);
		
	-- Mouth and Source are either different rivers, or one side
	-- doesn't exist yet.
	--
	-- Need to look at neighboring rivers to differentiate 
	-- various types of merges.
	local sourceRiverInfoA = 
		self:GetRiverSegment(riverSegment.nextPlot, riverSegment.nextDirs[1]);
		
	local sourceRiverInfoB = 
		self:GetRiverSegment(riverSegment.nextPlot, riverSegment.nextDirs[2]);
	
	-- Get info for the same river segment except in the opposite direction
	-- so that we can check which river segments are touching this 
	-- segment's mouth.
	local backwardsInfo = self:GetRiverSegment(
		riverSegment.nextPlot, self:GetOppositeFlowDirection(riverSegment.flowDir));
	
	local mouthRiverInfoA = nil;
	local mouthRiverInfoB = nil;
	
	if (backwardsInfo) then
		mouthRiverInfoA = self:GetRiverSegment(
			backwardsInfo.nextPlot, backwardsInfo.nextDirs[1]);
		
		mouthRiverInfoB = self:GetRiverSegment(
			backwardsInfo.nextPlot, backwardsInfo.nextDirs[2]);
	end
	
	local gotSourceA = sourceRiverInfoA and sourceRiverInfoA.riverExists;
	local gotSourceB = sourceRiverInfoB and sourceRiverInfoB.riverExists;
	local gotMouthA  = mouthRiverInfoA  and mouthRiverInfoA.riverExists;
	local gotMouthB  = mouthRiverInfoB  and mouthRiverInfoB.riverExists;
	
	local gotBothSource = gotSourceA and gotSourceB;
	local gotBothMouth  = gotMouthA  and gotMouthB;
	
	if (gotBothSource and gotBothMouth) then
		-- All four neighboring river segments exist.
		-- River would form an X-shaped merge
		return false, true, "inner x-merge";
		
	elseif (gotBothSource or gotBothMouth) then
		-- Either source or mouth branches off into two river segments.
		
		-- Need to further-analyze the side that has both 
		-- in order to detect the tip of an X-merge.
		local riverInfoA = sourceRiverInfoA;
		local riverInfoB = sourceRiverInfoB;
		if gotBothMouth then
			riverInfoA = mouthRiverInfoA;
			riverInfoB = mouthRiverInfoB;
		end
		
		local riverInfoAA = self:GetRiverSegment(
			riverInfoA.nextPlot, riverInfoA.nextDirs[1]);
		
		local riverInfoAB = self:GetRiverSegment(
			riverInfoA.nextPlot, riverInfoA.nextDirs[2]);
		
		local gotAA = riverInfoAA and riverInfoAA.riverExists;
		local gotAB = riverInfoAB and riverInfoAB.riverExists;
		
		if (gotAA and gotAB) then
			-- The last leg of an X-shaped merge would form.
			return false, intersectIsMerge, "outer x-merge-a";
		end
		
		local riverInfoBA = self:GetRiverSegment(
			riverInfoB.nextPlot, riverInfoB.nextDirs[1]);
		
		local riverInfoBB = self:GetRiverSegment(
			riverInfoB.nextPlot, riverInfoB.nextDirs[2]);
		
		local gotBA = riverInfoBA and riverInfoBA.riverExists;
		local gotBB = riverInfoBB and riverInfoBB.riverExists;
		
		if (gotBA and gotBB) then
			-- The last leg of an X-shaped merge would form.
			return false, intersectIsMerge, "outer x-merge-b";
		end
		
		if (intersectIsMerge == false) then
			-- An unclaimed vertex on one end two segments touching the other.
			-- And we've ruled-out the x-merge.
			-- So this segment would create a new branch off of another river.
			return pattern.allowBranch, false, "branch";
		end
		
		-- Both ends of the merge-side of the river have
		-- at most one river touching them each, so we've got
		-- a Y-shaped merge, which is OK.
		return pattern.allowYMerge, true, "y-merge"; 
	end
	
	if (intersectIsMerge == false) then
		-- An unclaimed vertex on one end one segment touching the other.
		-- Just a normal extension to a river.
		return true, false, "extension";
	end

	-- Both source and mouth is just one river segment.
	-- Merging rivers like this could form weird loops that 
	-- result in rivers with two mouths but no source.
	-- So don't allow this type of merge.
	return false, true, "end-to-end";
end

function RiverGenerator:GetOppositeFlowDirection(dir)
	local numTypes = FlowDirectionTypes.NUM_FLOWDIRECTION_TYPES;
	return ((dir + 3) % numTypes);
end

function RiverGenerator:GetPlotElevation(plot)

	if (plot:IsMountain()) then
		-- Mountains may be taller, but we don't want 
		-- rivers to hug them too much.
		-- Need a way to escape from mountain ranges.
		return 2;
	elseif (plot:IsHills()) then
		return 3;
	elseif (not plot:IsWater()) then
		return 2;
	else
		return 1;
	end
end

function RiverGenerator:GetRiverElevationAtPlot(plot)
	-- Custom method for reverse river propagation
	if (not plot) then
		-- Treat a map edge as a tall mountain.
		return 1000;
	end
	
	local sum = self:GetPlotElevation(plot) * 20;
	
	if IsAdjacentToSaltWater(plot:GetX(), plot:GetY()) then
		-- Saltwater coast is basically sea-level.
		-- We want the river to flow away from the sea,
		-- but possibly towards lakes.
		sum = sum - 1000;
	end

	-- Don't worry about cliffs or natural wonders. They don't exist yet.

	-- Factor neighboring plots into plot elevation.
	for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
		local adjacentPlot = Map.GetAdjacentPlot(plot:GetX(), plot:GetY(), direction);
		if (adjacentPlot) then
			sum = sum + self:GetPlotElevation(adjacentPlot);
		else
			sum = sum + 100;  -- Treat map edges as tall mountains.
		end
	end

	sum = sum + TerrainBuilder.GetRandomNumber(10, "River Rand");
	return sum;
end

function RiverGenerator:GetRiverIDs(riverSegment)
    -- Get river ID info for each end of a river segment.
	-- Args: riverSegment: which river segment to look-up.
	-- Returns:
	--   mouthID: which river, if any, would touch the mouth
	--   sourceID: which river, if any, would touch the source
	if (riverSegment == nil) then
		return nil, nil;
	end
	
	local mouthID  = nil;
	local sourceID = nil;
	
	local mouthPlot  = riverSegment.mouthIDPlot;
	if (mouthPlot) then
		local mouthIndex = GetPlotIndexLua(mouthPlot:GetX(), mouthPlot:GetY());
		mouthID = riverSegment.mouthIDMap[mouthIndex];
	end
	
	local sourcePlot  = riverSegment.sourceIDPlot;
	if (sourcePlot) then
		local sourceIndex = GetPlotIndexLua(sourcePlot:GetX(), sourcePlot:GetY());
		sourceID = riverSegment.sourceIDMap[sourceIndex];
	end
	
	return mouthID, sourceID;
end

function RiverGenerator:GetRiverSegment(targetPlot, flowDirection)
    -- Get all the direction-specific info about extending a river backwards 
    -- to flow in towards a target plot in a certain direction.
    -- Args:
    --   targetPlot: the S or SE plot corner where the next river segment would end
    --   flowDirection: the direction that the river would take to get to the
    --     target plot's SE edge. Must not be nil or "no direction"
    -- Returns:
    -- {
	--   targetPlot: the passed-in target plot
	--   flowDir: the passed-in flow direction
    --   nextPlot (can be nil): the next target plot for river propagation
	--   nextDirs: the directions that the river can take on the next plot.
    --   riverPlot (can be nil): where to place the river
    --   otherSidePlot (can be nil): shares the river edge with riverPlot
    --   sourcePlot (can be nil): where the new river would flow from
    --   mouthPlot (can be nil): where the new river would flow to
	--   sourceIDPlot (can be nil): which plot to use for getting the source-end's river ID
	--   mouthIDPlot (can be nil): which plot to use for getting the mouth-end's river ID
	--   lakeIDPlot (can be nil): which plot to use for getting the segment's lake ID
	--   mouthIDMap: which river ID map to use for the mouth (S or SE)
	--   sourceIDMap: which river ID map to use for the source (S or SE)
    --   riverExists: true iff riverPlot is non-nil and already has the river 
	--      that SetRiver would set.
    --   SetRiver: the direction-specific function to place the river on the plot;
    --      matches the signature of TerrainBuilder.Set__OfRiver() methods.
    -- }

    if (targetPlot == nil) then
        --self:RiverPrint("GetReverseRiverSegment: requires a non-nil target plot.");
        return nil;
    end
    
    local flowDirection = flowDirection or FlowDirectionTypes.NO_FLOWDIRECTION;
    if (flowDirection == FlowDirectionTypes.NO_FLOWDIRECTION) then
        self:RiverPrint("GetReverseRiverSegment: requires a meaninful flow direction.");
        return nil;
    end
    
	-- River propagation info
    local nextPlot = targetPlot;
	local nextDirs;
	
	-- Plots surrounding the river
	local riverPlot = targetPlot;
    local otherSidePlot;
    local sourcePlot;
    local mouthPlot;
	
	-- River intersection info
	local mouthIDMap;  -- Which map the mouth lives in (S or SE)
	local sourceIDMap; -- Which map the source lives in (S or SE)
	
	-- River state
    local riverExists = false;
    local SetRiver;

    -- Direction-specific logic:
    --   N and NW: riverPlot == nextPlot
    --   S and SE: riverPlot == targetPlot
    --   NE and SW: targetPlot == riverPlot == nextPlot
    if (flowDirection == FlowDirectionTypes.FLOWDIRECTION_NORTH) then
       
		nextPlot = Map.GetAdjacentPlot(
            targetPlot:GetX(), targetPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
        
		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_NORTHWEST,
			FlowDirectionTypes.FLOWDIRECTION_NORTHEAST
		};
		
        riverPlot = nextPlot;
		mouthPlot = targetPlot;
		
		mouthIDMap  = self.riverPlots_S;
		sourceIDMap = self.riverPlots_SE;
        
        if (riverPlot ~= nil) then
            otherSidePlot = Map.GetAdjacentPlot(
                riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_EAST);
            
            sourcePlot = Map.GetAdjacentPlot(
                riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
				
            riverExists    = riverPlot:IsWOfRiver();
			SetRiver = TerrainBuilder.SetWOfRiver;
        end
			
	elseif (flowDirection == FlowDirectionTypes.FLOWDIRECTION_NORTHEAST) then
		
		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_NORTH,
			FlowDirectionTypes.FLOWDIRECTION_SOUTHEAST
		};
		
		otherSidePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);

		sourcePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
            
        mouthPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_EAST);

		mouthIDMap  = self.riverPlots_SE;
		sourceIDMap = self.riverPlots_S;
			
        riverExists    = riverPlot:IsNWOfRiver();
		SetRiver = TerrainBuilder.SetNWOfRiver;
		
	elseif (flowDirection == FlowDirectionTypes.FLOWDIRECTION_SOUTHEAST) then
		
        nextPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_WEST);
			
		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_SOUTH,
			FlowDirectionTypes.FLOWDIRECTION_NORTHEAST
		};
        
		otherSidePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
            
        sourcePlot = nextPlot;
        
        mouthPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);

		mouthIDMap  = self.riverPlots_S;
		sourceIDMap = self.riverPlots_SE;
			
        riverExists    = riverPlot:IsNEOfRiver();
		SetRiver = TerrainBuilder.SetNEOfRiver;
		
	elseif (flowDirection == FlowDirectionTypes.FLOWDIRECTION_SOUTH) then
		
        nextPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
        
		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_SOUTHWEST,
			FlowDirectionTypes.FLOWDIRECTION_SOUTHEAST
		};
		
		otherSidePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_EAST);
            
        sourcePlot = nextPlot;
        
        mouthPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);

		mouthIDMap  = self.riverPlots_SE;
		sourceIDMap = self.riverPlots_S;
			
        riverExists    = riverPlot:IsWOfRiver();
		SetRiver = TerrainBuilder.SetWOfRiver;
		
	elseif (flowDirection == FlowDirectionTypes.FLOWDIRECTION_SOUTHWEST) then

		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_SOUTH,
			FlowDirectionTypes.FLOWDIRECTION_NORTHWEST
		};
	
		otherSidePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
            
		sourcePlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_EAST);
            
        mouthPlot = Map.GetAdjacentPlot(
            riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
        
		mouthIDMap  = self.riverPlots_S;
		sourceIDMap = self.riverPlots_SE;
		
        riverExists    = riverPlot:IsNWOfRiver();
		SetRiver = TerrainBuilder.SetNWOfRiver;

	elseif (flowDirection == FlowDirectionTypes.FLOWDIRECTION_NORTHWEST) then
		
		nextPlot = Map.GetAdjacentPlot(
            targetPlot:GetX(), targetPlot:GetY(), DirectionTypes.DIRECTION_EAST);
        
		nextDirs = 
		{
			FlowDirectionTypes.FLOWDIRECTION_NORTH,
			FlowDirectionTypes.FLOWDIRECTION_SOUTHWEST
		};
		
        riverPlot = nextPlot;
        mouthPlot = targetPlot;
		
		mouthIDMap  = self.riverPlots_SE;
		sourceIDMap = self.riverPlots_S;
        
        if (riverPlot ~= nil) then
            otherSidePlot = Map.GetAdjacentPlot(
                riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
                
            sourcePlot = Map.GetAdjacentPlot(
                riverPlot:GetX(), riverPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
				
			riverExists    = riverPlot:IsNEOfRiver();
			SetRiver = TerrainBuilder.SetNEOfRiver;
		end        
	end
    
    return {
				targetPlot    = targetPlot,
				flowDir       = flowDirection,
				nextPlot      = nextPlot,
				nextDirs      = nextDirs,
                riverPlot     = riverPlot, 
                otherSidePlot = otherSidePlot, 
                sourcePlot    = sourcePlot,
                mouthPlot     = mouthPlot,
				sourceIDPlot  = nextPlot,
				mouthIDPlot   = targetPlot,
				lakeIDPlot    = mouthPlot,
				mouthIDMap    = mouthIDMap,
				sourceIDMap   = sourceIDMap,
                riverExists   = riverExists,
                SetRiver      = SetRiver
           };
end

function RiverGenerator:IsAdjacentRiver(riverSegment)
	-- Got enough river info to analyze neighboring river segments.
	local mouthID, sourceID = self:GetRiverIDs(riverSegment);
	return (((mouthID ~= nil) and (mouthID >= 0)) or
		    ((sourceID ~= nil) and (sourceID >= 0)));
end

function RiverGenerator:IsCloseToAnotherStart(pStartPlot)
	local iPlotIndex = pStartPlot:GetIndex();

	-- Distance threshold for skipped starts.
	local iNotAllowedAsCloseAs = 2;
	for i, riverPlotIndex in ipairs(self.skippedStartPlots) do
		if (Map.GetPlotDistance(iPlotIndex, riverPlotIndex) <= iNotAllowedAsCloseAs) then
		    return true;
		end
	end
	
	-- Distance threshold for small rivers.
	iNotAllowedAsCloseAs = 2;
	for i, riverPlotIndex in ipairs(self.smallStartPlots) do
		if (Map.GetPlotDistance(iPlotIndex, riverPlotIndex) <= iNotAllowedAsCloseAs) then
		    return true;
		end
	end

	-- Distance threshold for sufficiently-long rivers.
	iNotAllowedAsCloseAs = 4;
	for i, riverPlotIndex in ipairs(self.normalStartPlots) do
		if (Map.GetPlotDistance(iPlotIndex, riverPlotIndex) <= iNotAllowedAsCloseAs) then
		    return true;
		end
	end
	
	-- Also avoid map edges.
	return IsCloseToMapEdge(pStartPlot:GetX(), pStartPlot:GetY(), 1);
end

function RiverGenerator:MergeRivers(riverA, riverB)
	-- Merge two rivers into a single river system.
	-- Args: the ids of the rivers to merge.
	-- Returns: the id of the merged river.
	if ((riverA == nil) or 
		(riverB == nil) or 
		(riverA < 0) or 
		(riverB < 0)) then
		-- Programmer error.
		self:RiverPrint("MergeRivers: attempt to merge " .. 
			NonNilStr(riverA) .. " with " .. NonNilStr(riverB));
		return;
	end
	
	for y = 0, g_iH - 1, 1 do
		for x = 0, g_iW - 1, 1 do
			local i = GetPlotIndexLua(x,y);
			
			-- Replace all instances of riverA with riverB.
			if (self.riverPlots_S[i] == riverA) then
				self.riverPlots_S[i] = riverB;
			end
			if (self.riverPlots_SE[i] == riverA) then
				self.riverPlots_SE[i] = riverB;
			end
			if (self.lakeIDMap[i] == riverA) then
				self.lakeIDMap[i] = riverB;
			end
		end
	end
	self:RiverPrint("Merged river #" .. riverA .. " into river #" .. riverB);
	return riverB;
end

function RiverGenerator:PrintStats()
	print("Created " .. self.stats.numRivers .. " rivers and " .. 
		                self.stats.numSegments .. " river segments.");
						
	print("Created " .. self.stats.numLakeTiles .. " river-start lake plots.");
						
	print("River start-plot breakdown: " .. 
		tostring(table.maxn(self.skippedStartPlots)) .. " skipped, " ..
		tostring(table.maxn(self.smallStartPlots)) .. " small, " ..
		tostring(table.maxn(self.normalStartPlots)) .. " normal");
end

function RiverGenerator:Reset()
	-- Reset state. Call this before adding rivers.

	-- Ignore starts from previous rivers.
	self.skippedStartPlots = {};
	self.smallStartPlots   = {};
	self.normalStartPlots  = {};

	-- Reset stats.
	self.stats.numLakeTiles = 0;
	self.stats.numRivers    = 0;
	self.stats.numSegments  = 0;
end

function RiverGenerator:RiverPrint(str)
	-- Master-switch wrapper to enable/disable printing river debug messages to console.
	-- Because RiverGenerator has a lot of debug messages.
	if ENABLE_RIVER_DEBUG then
		print(NonNilStr(str));
	end
end

function RiverGenerator:SetRiver(riverSegment, riverID)
    -- Make the river at the river segment exist on the map.
	-- Also update river ID maps.
	-- Args: 
	--   riverSegment: which river segment to set.
	--   riverID: the ID of the river to which this segment belongs.
	if (not (riverSegment and riverSegment.riverPlot)) then
		-- Unable to set the river.
		self:RiverPrint("Attempt to extend river #" .. NonNilStr(riverID) .. 
						" at a non-existent river segment.");
		return;
	end
	
	-- Add the river to the global map.
	if ScriptData.gotGatheringStorm then
		-- Gathering Storm changed the signature of SetRiver().
		riverSegment.SetRiver(riverSegment.riverPlot, true, riverSegment.flowDir, riverID);
	else
		riverSegment.SetRiver(riverSegment.riverPlot, true, riverSegment.flowDir);	
	end
	
	-- Update river ID maps.
	local mouthPlot  = riverSegment.mouthIDPlot;
	if (mouthPlot) then
		local mouthIndex = GetPlotIndexLua(mouthPlot:GetX(), mouthPlot:GetY());
		riverSegment.mouthIDMap[mouthIndex] = riverID;
	end
	
	local sourcePlot  = riverSegment.sourceIDPlot;
	if (sourcePlot) then
		local sourceIndex = GetPlotIndexLua(sourcePlot:GetX(), sourcePlot:GetY());
		riverSegment.sourceIDMap[sourceIndex] = riverID;
	end
	
	-- Update stats.
	self.stats.numSegments = self.stats.numSegments + 1;
end

function RiverGenerator:Validate()
	-- Validate rivers on the map.
	-- In particular, detect cycles.
	self:RiverPrint("Validating rivers.");

	-- Map hex directions to river-detection methods.
	local IsRiverFunctions = {
		[DIRECTION_NE] = function(plot) 
			local plotNE = Map.GetAdjacentPlot(plot:GetX(), plot:GetY(), DIRECTION_NE);
			return plotNE and plotNE:IsNEOfRiver(); 
		end,
		
		[DIRECTION_E] = function(plot) 
			return plot:IsWOfRiver();
		end,
		
		[DIRECTION_SE] = function(plot) 
			return plot:IsNWOfRiver();
		end,
		
		[DIRECTION_SW] = function(plot) 
			return plot:IsNEOfRiver();
		end,
		
		[DIRECTION_W] = function(plot) 
			local plotW  = Map.GetAdjacentPlot(plot:GetX(), plot:GetY(), DIRECTION_W);
			return plotW and plotW:IsWOfRiver();
		end,
		
		[DIRECTION_NW] = function(plot) 
			local plotNW = Map.GetAdjacentPlot(plot:GetX(), plot:GetY(), DIRECTION_NW);
			return plotNW and plotNW:IsNWOfRiver();
		end	
	};
	
	local visitedMap = table.fill(0, g_numTiles);
	local valid = true;
	
	for x = 0, g_iW - 1, 1 do
		-- Traverse along the bottom edge of the map
		-- in order to support rivers touching the map edge.
		valid = valid and self:ValidateTraverse(IsRiverFunctions, visitedMap, x, 0);
	end
	
	if (not ScriptData.wrapY) then
		-- No y-wrap, so traverse starting at top edge too.
		for x = 0, g_iW - 1, 1 do
			-- Traverse along the bottom edge of the map
			-- in order to support rivers touching the map edge.
			valid = valid and self:ValidateTraverse(IsRiverFunctions, visitedMap, x, g_iH-1);
		end
	end
	
	if (not ScriptData.wrapX) then
		-- No x-wrap, so traverse starting at left and right edges too.
		for y = 0, g_iH - 1, 1 do
			-- Traverse along the bottom edge of the map
			-- in order to bypass rivers touching the map edge.
			valid = valid and self:ValidateTraverse(IsRiverFunctions, visitedMap, 0,      y);
			valid = valid and self:ValidateTraverse(IsRiverFunctions, visitedMap, g_iW-1, y);
		end
	end
	
	if (not valid) then
		self:RiverPrint("Rivers are invalid.");
		return;
	end
	
	-- Check for unvisited plots.
	local numUnvisited = 0;
	for y = 0, g_iH - 1, 1 do
		for x = 0, g_iW - 1, 1 do
			local i = GetPlotIndexLua(x, y);
			
			if (visitedMap[i] == 0) then
				self:RiverPrint("River cycle detected! Unable to reach " .. CoordString(x,y));
				numUnvisited = numUnvisited + 1;
			end
		end
	end
	if (numUnvisited == 0) then
		self:RiverPrint("Rivers are OK.");
	else	
		self:RiverPrint("Rivers have at least one cycle. Unable to reach " .. numUnvisited .. " tile(s)");
	end
end

function RiverGenerator:ValidateTraverse(IsRiverFunctions, visitedMap, startX, startY)
	-- Recursive helper method for river validation.
	-- Use a stack to visit the map in DFS order.
	--
	-- Args:
	--   IsRiverFunctions: a mapping of directions to river-existence test functions
	--   visitedMap: a map of visited flags for each plot
	--   startX, startY: where to begin traversal
	--
	-- Returns: true iff traversal was valid (false if something unexpected occurred).
	local stack = Stack:Create();
	stack:Push({x=startX, y=startY});
	
	local iVisited = GetPlotIndexLua(startX, startY);
	visitedMap[iVisited] = 1;
	
	while (not stack:IsEmpty()) do
		local coord = stack:Pop();
		local x, y = coord.x, coord.y;
		
		local plot = Map.GetPlot(x,y);
		
		for i, direction in ipairs(HexDirections) do
			local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
			
			local IsRiverFunc = IsRiverFunctions[direction];
						
			if (adjacentPlot and (not IsRiverFunc(plot))) then
				-- We have an adjacent plot that is not across a river.
				-- Let's see if it's unvisited.
				local aX, aY = adjacentPlot:GetX(), adjacentPlot:GetY();
				local iCouldVisit = GetPlotIndexLua(aX, aY);
			
				if (visitedMap[iCouldVisit] == 0) then
					-- Add to the stack of plots to traverse.
					stack:Push({x=aX, y=aY});
					visitedMap[iCouldVisit] = 1;
				end
			elseif ((not adjacentPlot) and 
					((direction == DIRECTION_E) or 
					 (direction == DIRECTION_SE) or 
				     (direction == DIRECTION_SW)) and 
					IsRiverFunc(plot)) then
				self:RiverPrint("Detected a river that runs along the map edge at " .. 
					CoordString(x,y));
				return false;
			end
		end
	end
	return true;
end

function RiverGenerator:WouldFlowBetweenDryPlots(riverSegment)
	-- Return true iff the river at riverSegment would flow 
	-- between two non-nil, non-water plots.
	--
	-- Does not check whether the river actually exists on the map.
	return riverSegment and (riverSegment.riverPlot ~= nil) and (riverSegment.otherSidePlot ~= nil) and not
		((riverSegment.riverPlot:IsWater()) or (riverSegment.otherSidePlot:IsWater()));
end

function RiverGenerator:AddCoastalRivers()
	-- Add rivers to salt-water coasts.
	print("Adding coastal rivers (" .. self.pattern.name .. ")");
	
	self:Reset();
	
    -- Don't worry about natural wonders because they don't exist yet.
    -- Don't worry about coastal land because water-tile checks are direction-specific.
	for i = 0, (g_iW * g_iH) - 1, 1 do
		local plot = Map.GetPlotByIndex(i);
        
        -- Don't start too close to another river's starting spot.
        if (not self:IsCloseToAnotherStart(plot)) then
            -- Consider all meaningful flow directions.
			-- Shuffle the directions for each plot to avoid directional bias.
			local flowDirs = GetShuffledCopyOfTable(FlowDirections);
            for i, flowDirection in ipairs(flowDirs) do
				-- Get the pattern for this potential river.
				local pattern = self:ChoosePattern();
			
				-- Get reverse-river propagation info.
				local riverSegment = self:GetRiverSegment(plot, flowDirection);
				
				local mouthPlot     = riverSegment.mouthPlot;
				local sourcePlot    = riverSegment.sourcePlot;
				
				-- Initial river flow:
					-- Avoid nearby rivers.
					-- Avoid map edges.
					-- Avoid water on either side of river.
					-- Avoid flowing directly from a water source.
					-- Check mouth for water, but mouth must be salty unless we allow lake-starts.
				if ((not self:IsAdjacentRiver(riverSegment)) and 
					(riverSegment.riverExists == false) and 
					(mouthPlot ~= nil) and (sourcePlot ~= nil) and
				    self:WouldFlowBetweenDryPlots(riverSegment) and 
					mouthPlot:IsWater() and 
					((not mouthPlot:IsLake()) or pattern.allowLakeMouths) and
					(not sourcePlot:IsWater())) then
					
					self:StartRiver(riverSegment, pattern, false);
					break;
				end
			end
        end
	end
	
	self:PrintStats();
end

function RiverGenerator:AddInlandRivers()
	-- Add rivers to areas that are far from the sea.
	print("Adding inland Rivers (" .. self.pattern.name .. ")");
	
	self:Reset();
	
	local plotsPerRiverEdge = GlobalParameters.RIVER_PLOTS_PER_EDGE or 12;
		
	local passConditions = {
		function(plot)
			return (plot:IsHills() or plot:IsMountain());
		end,
		
		function(plot)
			return (not plot:IsCoastalLand());
		end,
		
		function(plot)
			local area = plot:GetArea();
			return (plot:IsHills() or plot:IsMountain()) and 
			       (area:GetRiverEdgeCount() < ((area:GetPlotCount() / plotsPerRiverEdge) + 1));
		end,
		
		function(plot)
			local area = plot:GetArea();
			return (area:GetRiverEdgeCount() < (area:GetPlotCount() / plotsPerRiverEdge) + 1);
		end
	}
	
	-- Don't worry about natural wonders--they don't exist yet.
	for i = 0, (g_iW * g_iH) - 1, 1 do
		local plot = Map.GetPlotByIndex(i);
		
		-- Don't start too close to another river's starting spot.
		if (not self:IsCloseToAnotherStart(plot)) then
		
			-- Scan the map multiple times to find and eliminate dry spots.		
			for iPass, passCondition in ipairs(passConditions) do
			
				-- Consider all meaningful flow directions.
				-- Shuffle the directions for each plot to avoid directional bias.
				local flowDirs = GetShuffledCopyOfTable(FlowDirections);
				for i, flowDirection in ipairs(flowDirs) do
					-- Get the pattern for this potential river.
					local pattern = self:ChoosePattern();
				
					-- Get river propagation info.
					local riverSegment = self:GetRiverSegment(plot, flowDirection);
					
					local mouthPlot     = riverSegment.mouthPlot;
					local sourcePlot    = riverSegment.sourcePlot;
										
					-- Initial river flow:
					-- Avoid nearby rivers.
					-- Avoid map edges.
					-- Avoid water on either side of river.
					-- Avoid flowing directly from a water source.
					-- Check mouth for water, but mouth must be salty unless we allow lake-starts.
					if ((not self:IsAdjacentRiver(riverSegment)) and 
					    (riverSegment.riverExists == false) and 
						(mouthPlot ~= nil) and (sourcePlot ~= nil) and
						self:WouldFlowBetweenDryPlots(riverSegment) and 
						(not sourcePlot:IsWater()) and 
						((not mouthPlot:IsLake()) or pattern.allowLakeMouths) and
						passCondition(sourcePlot)) then
						-- So far, so good.
						-- However, Civ6 in-game graphics require all rivers to flow
						-- into a water tile. So check whether the mouth plot is water.
						if (mouthPlot:IsWater() or CanHavePostLandmassLake(mouthPlot)) then
							-- Mouth plot either is water or can become water.
							local createLake = not mouthPlot:IsWater();
							self:StartRiver(riverSegment, pattern, createLake);
						end
						break;
					end
				end
			end
		end
	end
	
	self:PrintStats();
end

function RiverGenerator:StartRiver(riverSegment, pattern, createLake)
	-- Maybe start a river.
	if ((createLake == true) and (pattern.allowCreateLakes == false)) then
		-- lake-creation disabled. We can't start a river here.
		return;
	end

	-- Roll dice to decide whether to start a river.
	local targetPlotIndex = riverSegment.targetPlot:GetIndex();
	
	local dice = TerrainBuilder.GetRandomNumber(100, "River recursion");
	if (dice >= pattern.startPct) then
		-- Record the canceled start plot 
		-- to avoid trying the plot in another direction.
		-- Allows us to tune the number of river starts.
		table.insert(self.skippedStartPlots, targetPlotIndex);
		return;
	end
	
	if (createLake == true) then
		-- Create a lake as a source for the river.
		local numLakeTilesAdded = AddPostLandmassLake(riverSegment.mouthPlot, self.lakePlotRand);
		if (numLakeTilesAdded == 0) then
			-- Did not create a lake here.
			return;
		end
		self.stats.numLakeTiles = self.stats.numLakeTiles + numLakeTilesAdded;		
	end

	-- Get the ID of the river's start.
	local riverID = self:AssignIDToRiver(riverSegment);
	
    -- Add the first plot's river.
	self:SetRiver(riverSegment, riverID);
	
	-- Update stats.
	self.stats.numRivers = self.stats.numRivers + 1;
	
	-- Look at elevation to decide which way to go.	
	local nextDir, fallbackDir = self:ChooseNextFlowDir(riverSegment, riverSegment.flowDir);
	
    -- Recursively draw the rest of the river.
    local newLength = self:DoRiver(
		riverSegment.nextPlot,
		nextDir, 
		riverSegment.flowDir, 
		1,
		riverID,
		pattern,
		false);
		
	if (newLength == 1) then
		-- The river didn't grow in that direction.
		-- Try the other direction.
		newLength = self:DoRiver(
			riverSegment.nextPlot,
			fallbackDir,
			riverSegment.flowDir, 
			1, 
			riverID,
			pattern,
			false);
	end
	
	if (newLength >= pattern.smallRiverLength) then
		-- Record the start plot to space-out start plots.
		-- Only do this for sufficiently-long rivers to avoid unnecessary gaps.
		table.insert(self.normalStartPlots, targetPlotIndex);
	else
		table.insert(self.smallStartPlots, targetPlotIndex);
	end
end

function RiverGenerator:DoRiver(
    startPlot, 
	thisFlowDirection, 
	originalFlowDirection, 
	curLength, 
	riverID,
	pattern,
	isBranch)
    -- Generate a river recursively from mouth to source.
    -- Args:
    --   startPlot: the plot at whose SE edge the river is ENDING
    --   thisFlowDirection: the direction the river would flow TOWARDS the start plot's SE edge
    --   originalFlowDirection: the direction in which the mouth of the river is facing
    --   curLength: the number of river segments that we have placed so far
    --   riverID: a unique ID to distinguish this river from other rivers
	--   pattern: the river pattern with which to generate this river
	--   isBranch: indicates whether we have recursively branched off of an existing river
	-- Returns:
	--   newLength: the new length of the river
	--   isMerge: true iff the river just merged with another river
	--   riverID: the new river ID
        
    local originalFlowDirStr = FlowDirStr(originalFlowDirection);
    local thisFlowDirStr     = FlowDirStr(thisFlowDirection);

	self:RiverPrint ("Extending " .. originalFlowDirStr .. " " .. pattern.name .. 
		   " river #" .. tostring(riverID) .. 
           " of length " .. tostring(curLength) .. 
		   " to flow " .. thisFlowDirStr ..
           " towards " .. CoordString(startPlot:GetX(), startPlot:GetY()));

	local newLength = curLength;
		   
	-- startPlot = the plot at whose SE edge the river is ENDING 
    -- (because we're going in reverse).
    --
    -- The next variables are relative to the river placed in this iteration:
    -- riverPlot: the plot that places the new river
    -- otherSidePlot: the plot across the new river from riverPlot
    -- sourcePlot: the plot that new the river flows from
    -- nextPlot: the plot at whose SE edge the new river ends
    local riverSegment = self:GetRiverSegment(startPlot, thisFlowDirection);
    if (not riverSegment) then
        self:RiverPrint("Stopping river; unable to get propagation info.");
        return newLength, false, riverID;
    end
	
	if (riverSegment.riverExists or (not self:WouldFlowBetweenDryPlots(riverSegment))) then
		-- River touches the map edge or a body of water.
        -- Stop recursion.
		self:RiverPrint("Stopping river from flowing " .. thisFlowDirStr .. ".");
		return newLength, false, riverID;
	end
    
    local riverPlot  = riverSegment.riverPlot;
    local sourcePlot = riverSegment.sourcePlot;
    if IsSaltWater(sourcePlot) then
        -- Don't let the river start at salt water.
        -- Stop recursion.
        self:RiverPrint("Stopping river from flowing " .. thisFlowDirStr .. " from salt water.");
        return newLength, false, riverID;
		
    elseif (sourcePlot and sourcePlot:IsLake()) then
		-- Don't let the river start and end at the same lake.
		local sourceLakeID = self.lakeIDMap[sourcePlot:GetY()*g_iW + sourcePlot:GetX() + 1];
		if (riverID == sourceLakeID) then
			self:RiverPrint("Stopping river from flowing " .. thisFlowDirStr .. 
							" from an originating lake.");
			return newLength, false, riverID;
		end
	end
	
	local intersectIsValid, intersectIsMerge, intersectStr = 
		self:GetIntersectInfo(riverSegment, pattern);
	if (not intersectIsValid) then
		-- Intersection type not allowed.
		-- Stop recursion.
		self:RiverPrint("Stopping river to prevent a " .. thisFlowDirStr .. " " .. 
						intersectStr .. " intersection.");
        return newLength, false, riverID;
	end
	
	if (isBranch and intersectIsMerge) then
		-- Intersection type not allowed after a branch.
		-- Stop recursion.
		self:RiverPrint("Stopping river to prevent post-branch " .. intersectStr .. 
						" intersection.");
        return newLength, false, riverID;
	end
    
	local mouthID, sourceID = self:GetRiverIDs(riverSegment);
	self:SetRiver(riverSegment, riverID);
	newLength = newLength + 1;
              
   	local nextPlot = riverSegment.nextPlot; 
	
	-- Check whether we need to stop the river.
	-- Check for merges first in case we need to merge river IDs.
	if (intersectIsMerge) then
        -- The river has intersected another river. We are done.
        self:RiverPrint("Found a river source (another river).");

		-- Merge rivers.
		riverID = self:MergeRivers(riverID, sourceID);
        return newLength, true, riverID;
		
    elseif (sourcePlot ~= nil) and sourcePlot:IsLake() then
        -- The river is now flowing from a lake. We are done.
        self:RiverPrint("Found a river source (fresh water).");
		
		local sourceLakeID = self.lakeIDMap[sourcePlot:GetY()*g_iW + sourcePlot:GetX() + 1];
		
		if (sourceLakeID < 0) then
			-- No other river has touched this lake.
			-- Tag the lake with the river ID.
			self:AssignIDToLake(sourcePlot, riverID);
			return newLength, false, riverID;
		else
			-- The lake is part of another river system. Merge rivers.
			riverID = self:MergeRivers(riverID, sourceLakeID);
			return newLength, true, riverID;
		end
	
    elseif ((nextPlot == nil) or (sourcePlot == nil)) then
        -- The river is now flowing from off the map / towards the edge of the map. We are done.
        self:RiverPrint("Found a river source (map edge).");
        return newLength, false, riverID;
		
    elseif (sourcePlot:IsMountain() and (newLength > pattern.softMaxLength)) then
        -- The river is now flowing from a mountain. We are done.
        self:RiverPrint("Found a river source (mountain).");
        return newLength, false, riverID;
    end
		
    -- Storing X,Y positions as locals to prevent redundant function calls.
	local nextPlotX = nextPlot:GetX();
	local nextPlotY = nextPlot:GetY();
    
	-- Choose the next flow direction.
	local bestFlowDir, fallbackFlowDir = 
		self:ChooseNextFlowDir(riverSegment, originalFlowDirection);
			
	-- Recursively generate river.
	return self:DoNextRiver(
		fallbackFlowDir,
		nextPlot, 
		bestFlowDir, 
		originalFlowDirection, 
		newLength, 
		riverID,
		pattern);
end

function RiverGenerator:DoNextRiver(
	fallbackFlowDir,
	nextPlot, 
	bestFlowDir, 
	originalFlowDirection, 
	curLength, 
	riverID,
	pattern)
	-- Extend the river recursively, and maybe also try the secondary direction,
	-- either as a fallback or as a branch.
	--
    -- Args:
	--   prevLength: the previous length of the river, for deciding whether to do fall-back.
	--   fallbackFlowDir: the secondary flow direction for falling-back or branching.
	--   nextPlot: the next plot for river propagation
    --   bestFlowDir: the 1st choioce of flow direction for river propagation
    --   originalFlowDirection: the direction in which the start of the river is facing
    --   curLength: the number of river segments that we have placed so far
    --   riverID: a unique ID to distinguish this river from other rivers
	--   pattern: the pattern with which to generate this river
	-- Returns:
	--   returnedLength: the length of the river after propagation has finished
	--   isMerge: true iff the river just merged with another river
	--   riverID: the new river ID
	
	if (curLength >= pattern.hardMaxLength) then
		-- River is at max length. 
		-- This allows the user to control the number of river segments.
		return curLength, false, riverID;
	end
	
	local isBranch = false;
	
	-- Recursive call in the 1st direction.
	local returnedLength, isMerge, returnedRiverID = self:DoRiver(
		nextPlot, 
		bestFlowDir, 
		originalFlowDirection, 
		curLength, 
		riverID,
		pattern,
		isBranch);
	
	-- By default, don't branch.
	-- Don't branch right before a merge.
	local fallbackDice = TerrainBuilder.GetRandomNumber(100, "River Fallback/Branch Recursion");
	local percentChance = 0;
	
	if (returnedLength == curLength) then
		-- The "best" flow direction didn't help.
		-- So maybe try the fallback direction.
		percentChance = pattern.fallbackPct;
	
	elseif (isMerge == false) then
		-- We didn't just merge with another river, so we can branch.
		isBranch = true;
		
		-- Randomly decide whether to create a branch.
		percentChance = pattern.branchPct;
	end
	
	if (curLength >= pattern.softMaxLength) then
		-- Reduce chances for longer rivers.
		-- Use current length to bias branches towards the start of propagation.
		percentChance = percentChance * pattern.longRiverFactor;
	end

	local branchLength = 0;
	if (fallbackDice < percentChance) then
		if isBranch then
			self:RiverPrint("River #" .. returnedRiverID .. " creating branch.");
		else
			self:RiverPrint("River #" .. returnedRiverID .. " trying the other direction.");
		end
			
		branchLength, isMerge, returnedRiverID = self:DoRiver(
			nextPlot, 
			fallbackFlowDir, 
			originalFlowDirection, 
			curLength, 
			returnedRiverID,
			pattern,
			isBranch);
	end
	return math.max(returnedLength, branchLength), false, returnedRiverID;
end

function AddLakesAndRivers()
	print("Generating lakes and rivers.");
	
	-- Add lakes.
	AddLakes();
	
	-- Set-up the river generator.
	local riverGen = RiverGenerator.Create();
	
	-- Trace rivers mouth-to-source from salt water.
	riverGen:AddCoastalRivers();
	
	-- Fill remaining dry spots in the map with rivers.
	riverGen:AddInlandRivers();
	
	if ENABLE_RIVER_DEBUG then
		-- Validate rivers. Useful for debugging.
		riverGen:Validate();
	end
	
	-- Redo areas after adding inland river-start lakes.
	AreaBuilder.Recalculate();
end
------------------------------------------------------------------------------
-- Latitude Lookup
-- Need to declare these before declaring climate info.
------------------------------------------------------------------------------
function DefaultGlobe_GetLatitudeAtPlot(iX, iY)
	-- Default latitude for globe maps.
	-- Returns a latitude value between 0.0 (hot equator) and 1.0 (uncropped cold poles).
	local lat = math.abs((g_iH / 2) - iY) / (g_iH / 2);
	return lat * ScriptData.sunlightInfo.latMult[UserInput.climate];
end

function DefaultRegion_GetLatitudeAtPlot(iX, iY)
	-- Default latitude for region maps.
	return ScriptData.climateInfo.regionLat[UserInput.icyPoles];
end

function TiltedAxisGlobe_GetLatitudeAtPlot(iX, iY)
	-- Custom lat for Cropped Tilted Axis Globe.
	-- Use a scale of 0 (southern hot side) to 1 (uncropped northern cold side).
	local lat = iY / g_iH;
	return lat * ScriptData.sunlightInfo.latMult[UserInput.climate];
end

function TiltedAxisRegion_GetLatitudeAtPlot(iX, iY)
	-- Custom lat for Tilted Axis Region.
	-- Distance from this point to the pole which faces the sun.
	-- Use Euclidian distance so that the pole is circular-ish (give or take
	-- a column). This was good enough for donut, so why not use it here too!
	local hotPoleDist = Distance(iX, iY, 
		ScriptData.terrainInfo.hotPoleX, ScriptData.terrainInfo.hotPoleY);
	
	return Interpolate(hotPoleDist, 
		ScriptData.terrainInfo.minR,         
		ScriptData.terrainInfo.maxR,
		ScriptData.climateInfo.tiltedLatMin[UserInput.icyPoles], 
		ScriptData.climateInfo.tiltedLatMax[UserInput.icyPoles]);
end

function TwoSunsGlobe_GetLatitudeAtPlot(iX, iY)
	-- Custom lat for Two Suns Globe.
	-- Flip the scale so that the equator is cold.
	local lat = 1 - math.abs((g_iH / 2) - iY) / (g_iH / 2);
	return lat * ScriptData.sunlightInfo.latMult[UserInput.climate];
end

function TwoSunsRegion_GetLatitudeAtPlot(iX, iY)
	-- Custom lat for Two Suns Region.	
	-- Distance from this point to the nearest sun-facing pole.
	-- Use Euclidian distance so that the pole is circular-ish (give or take
	-- a column). This was good enough for donut, so why not use it here too!
	local hotPoleDist = math.min(
		Distance(iX, iY, 
			ScriptData.terrainInfo.southPoleX, 
			ScriptData.terrainInfo.southPoleY),
		Distance(iX, iY, 
			ScriptData.terrainInfo.northPoleX, 
			ScriptData.terrainInfo.northPoleY));
			
	local latMult = ScriptData.sunlightInfo.latMult[UserInput.climate];
	--local latMultPadding = latMult * 0.1;
	
	return Interpolate(hotPoleDist, 
		ScriptData.terrainInfo.minR,
		ScriptData.terrainInfo.maxR,
		0, ---1 * latMultPadding,
		latMult); --latMult + latMultPadding);
end

function GL_GetLatitudeAtPlot(iX, iY)
	-- Latitude for Got Lakes - no variation fractal required.
	local latitudeFcn = ScriptData.sunlightInfo.GetLatitudeAtPlot[UserInput.worldWrap];
	return latitudeFcn(iX, iY);
end

function GetLatitudeAtPlot(variationFrac, iX, iY)
	-- Override MapUtilities to use Got Lakes latitude.
	return GL_GetLatitudeAtPlot(iX, iY);
end
----------------------------------------------------------------------------------
-- Terrain
----------------------------------------------------------------------------------
function GenerateTerrain()
	print("Generating Terrain (" .. 
		   ScriptData.climateInfo.name .. " + " ..
		   ScriptData.biomeInfo.name .. " + " .. 
		   ScriptData.sunlightInfo.name .. ")");
	
	-- Create the terrain generator using args from climate and biome info.
	local terraingen = GotLakes_TerrainGenerator.Create(
		ScriptData.climateInfo,
		ScriptData.biomeInfo,
		ScriptData.sunlightInfo,
		ScriptData.donutFillingMap,
		CreateClimateFractal,
		GL_GetLatitudeAtPlot);
	
	if (UserInput.worldWrap == WWRAP_REGION) then
		-- Additional step for climates that need region init.
		ScriptData.terrainInfo = terraingen:InitRegion(
			ENABLE_TILTEDREGION_RANDOM_POLES,
			TILTEDREGION_DEFAULT_POLE_RDIST,
			TILTEDREGION_DEFAULT_POLE_THETA);
	end
	
	-- Generate terrain.
	terraingen:GenerateTerrain();	
end
------------------------------------------------------------------------------
-- Continental boundaries and volcanoes (GS only)
-- These methods happen after stamping continents onto the world.
------------------------------------------------------------------------------
function CountContinentBoundaryPlots()
	local iContinentBoundaryPlots = 0;

	for i = 0, g_numTiles - 1, 1 do
		pPlot = Map.GetPlotByIndex(i);
		if (Map.FindSecondContinent(pPlot, 3)) then
			iContinentBoundaryPlots = iContinentBoundaryPlots + 1;
		end
	end
	return iContinentBoundaryPlots;
end

function AddVolcanicTerrain(iContinentBoundaryPlots)
	print("Adding volcanoes.");
	local aLonelyMountainIndices:table = {};
	local iVolcanoesPlaced = 0;

	-- Compute target number of volcanoes
	local iTotalLandPlots = 0;
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do
			if (MapGetPlotType(iX, iY) ~= g_PLOT_TYPE_OCEAN) then
				iTotalLandPlots = iTotalLandPlots + 1;
			end
		end
	end
	local world_age = UserInput.worldAge;
	local divisors = {3, 5, 6};  -- iDivisor should be 3 for new, 6 for old
	local iDivisor = divisors[world_age] or 5;
	local iDesiredVolcanoes = iTotalLandPlots / (iDivisor * 25); -- iDivisor * 50
	print ("Desired Volcanoes: " .. iDesiredVolcanoes);

	-- Donut + Tectonic Extras = volcanic filling.
	local gotVolcanoFilling = 
		((UserInput.landmass == Landmasses.DONUT) and 
		 (UserInput.extras   == ExtraIslesLakes.TECTONIC));

	-- 2/3rds of Earth's volcanoes are near continent boundaries
	print ("Continent Boundary Plots: " .. iContinentBoundaryPlots);
	local iDesiredNearBoundaries = iDesiredVolcanoes * 2 / 3;

	if (iDesiredNearBoundaries > 0) then
		local iBoundaryPlotsPerVolcano = iContinentBoundaryPlots / iDesiredNearBoundaries;

		-- Not more than 1 per 16 tiles
		if (iBoundaryPlotsPerVolcano < 16) then
			iBoundaryPlotsPerVolcano = 16;
		end
		print ("Boundary Plots Per Volcano: " .. iBoundaryPlotsPerVolcano);

		for iX = 0, g_iW - 1 do
			for iY = 0, g_iH - 1 do
				local index = (iY * g_iW) + iX;
				local plotType = MapGetPlotType(iX, iY);
				-- Don't add volcanoes to water tiles.
				-- If No Coastal Mountains is enabled then avoid coastal volcanoes.
				-- Avoid map edges to prevent walls of volcanoes cutting off corners.
				-- Don't add volcanoes to plots that are surrounded by impassable terrain.
				if (not ((plotType == g_PLOT_TYPE_OCEAN) or 
					     (((UserInput.noCoastMts == true) and IsAdjacentToWater(iX, iY))) or
					     (IsCloseToMapEdge(iX, iY, 1)) or
						 (CountAdjacentPassable(iX, iY) == 0) )) then
					-- Maybe add a volcano here...
					local plot = Map.GetPlot(iX, iY);
					local bVolcanoHere = false;
					
					if (gotVolcanoFilling and 
						(ScriptData.donutFillingMap[index+1] == FILLING_YES) and
						(not IsAdjacentToVolcano(iX, iY))) then
						-- Volcano donut filling!
						bVolcanoHere = true;
					
					elseif (Map.FindSecondContinent(plot, 1)) then
						if (TerrainBuilder.GetRandomNumber(iBoundaryPlotsPerVolcano *.7, 
							"Volcano on boundary") == 1) then
							bVolcanoHere = true;
						end
					elseif(Map.FindSecondContinent(plot, 2)) then
						if (TerrainBuilder.GetRandomNumber(iBoundaryPlotsPerVolcano, 
						    "Volcano 1 from boundary") == 1) then
							bVolcanoHere = true;
						end
					elseif(Map.FindSecondContinent(plot, 3)) then
						if (TerrainBuilder.GetRandomNumber(iBoundaryPlotsPerVolcano * 1.5, 
						    "Volcano 2 from boundary") == 1) then
							bVolcanoHere = true;
						end

					elseif (plotType == g_PLOT_TYPE_MOUNTAIN) then
						if (not IsAdjacentToMountain(iX, iY)) then
							table.insert(aLonelyMountainIndices, index);
						end
					end

					if bVolcanoHere then
						MapSetPlotType(iX, iY, g_PLOT_TYPE_MOUNTAIN);
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_VOLCANO);
						--print ("Volcano Placed at " .. CoordString(iX, iY));
						iVolcanoesPlaced = iVolcanoesPlaced + 1;
					end
				end
			end
		end
		print ("Continent Edge Volcanoes Placed: " .. iVolcanoesPlaced);
	end

	if ((iDesiredVolcanoes - iVolcanoesPlaced) > 0 and #aLonelyMountainIndices > 0) then
		local iChance = #aLonelyMountainIndices / iDesiredVolcanoes;
		aShuffledIndices =  GetShuffledCopyOfTable(aLonelyMountainIndices);
		for i, index in ipairs(aShuffledIndices) do
			local plot = Map.GetPlotByIndex(index);
			TerrainBuilder.SetFeatureType(plot, g_FEATURE_VOLCANO);
			--print ("Volcano Placed at " .. CoordStringPlot(plot));
			iVolcanoesPlaced = iVolcanoesPlaced + 1;
			if (iVolcanoesPlaced >= iDesiredVolcanoes) then
				break
			end
		end
	end

	-- Recalc areas because volcanoes are impassable.
	AreaBuilder.Recalculate();
	print ("Total Volcanoes Placed: " .. iVolcanoesPlaced);
end
------------------------------------------------------------------------------
-- Feature-Gen overrides and helper methods
-- Need to declare these before declaring climate info.
------------------------------------------------------------------------------
GotLakes_FeatureGenerator = {};

function GotLakes_FeatureGenerator.Create(
	landArgs, biodivArgs, climateArgs, biomeArgs, sunlightArgs)
	-- Feature-Gen constructor.
	
	local freshWater  = UserInput.riverLevel;
	local temperature = UserInput.temperature;
	local rainfall    = UserInput.rainfall;
	local worldWrap   = UserInput.worldWrap;
	local biodiv      = UserInput.biodiv;
	local climate     = UserInput.climate;
	local sunlight    = UserInput.sunlight;
	local icyPoles    = UserInput.icyPoles;
		
	local polarIceNumRows = landArgs.polarIceNumRows;
	if ((climate == Climates.GREENHOUSE) or 
	    (climate == Climates.SANDSTORM) or
	    (icyPoles == ICYPOLES_CROP)) then
		-- Poles cropped, or climate too hot for ice.
		polarIceNumRows = 0;
	end
		
	-- Set feature traits.
	-- Jungles
	local junglePct      = biomeArgs.junglePct;
	local junglePctShift = biomeArgs.junglePctShift;
	
	-- Reefs
	local reefPct = 7; -- 8% is too much
	if (ScriptData.wrapX == false) then
		print("Reducing reefs (region).");
		reefPct = 1;
	end
	
	-- Oases.
	local oasisPct    = biomeArgs.oasisPct;    -- originally 6; r&f 1
	local oasisChange = biomeArgs.oasisChange; -- originally a scale factor of 1.5
	
	-- Forests
	local forestPct    = biomeArgs.forestPct;
	local forestChange = biomeArgs.forestChange;

	-- Marsh
	local marshPct    = biomeArgs.marshPct;
	local marshChange = biomeArgs.marshChange;
	
	-- Ice
	local icePct    = sunlightArgs.icePct[climate];
	local iceChange = 10;
	
	-- How much to adjust latitudes based on temperature.
	local jungleLatChange  = 0.1;	
	local reefMaxLatChange = 0.1;
	local forestLatChange  = 0.1;
	local marshLatChange   = 0.1;
	local iceLatChange     = 0.1;

	-- Latitude interpolation ranges: 0 = hottest, 1 = uncropped coldest.
	local jungleMinLat  = sunlightArgs.jungleMinLat[climate];
	local jungleMaxLat  = sunlightArgs.jungleMaxLat[climate];
	local reefMaxLat    = sunlightArgs.reefMaxLat[climate];
	local forestHMinLat = sunlightArgs.forestHMinLat[climate]; 
	local forestHMaxLat = sunlightArgs.forestHMaxLat[climate];
	local forestCMinLat = sunlightArgs.forestCMinLat[climate];
	local forestCMaxLat = sunlightArgs.forestCMaxLat[climate];
	local iceMinLat     = sunlightArgs.iceMinLat[climate];
	local iceMaxLat     = sunlightArgs.iceMaxLat[climate];
	
	local jungleMaxLatDiff = biomeArgs.jungleMaxLatDiff;
	jungleMaxLat = jungleMaxLat + jungleMaxLatDiff;
	
	local forestCMaxLatDiff = biomeArgs.forestCMaxLatDiff;
	forestCMaxLat = forestCMaxLat + forestCMaxLatDiff;
	
	local marshMinLat = forestHMaxLat - 0.05; -- 0.25;
	local marshMaxLat = forestCMinLat + 0.2;  -- 0.8;
	
	if (icyPoles == ICYPOLES_CROP) then
		-- Reduce all ice fractals for cropped poles.
		local cropMult = 0.5;
		icePct = Round(cropMult * icePct);
		iceChange  = Round(cropMult * iceChange);
	end
	
	-- Compute change multiplier based on temperature.
	local tempMult  = DOWN_TO_UP[temperature];
	
	-- Warmer climate => wider band of jungles.
	jungleMinLat = jungleMinLat + (tempMult * jungleLatChange);
	jungleMaxLat = jungleMaxLat + (tempMult * jungleLatChange);
	
	-- Warmer climate => wider band of reefs.
	reefMaxLat = reefMaxLat + (tempMult * reefMaxLatChange);
	
	-- Warmer climate => trees stretching closer to the poles
	forestHMinLat = forestHMinLat + (tempMult * forestLatChange);
	forestHMaxLat = forestHMaxLat + (tempMult * forestLatChange);
	forestCMinLat = forestCMinLat + (tempMult * forestLatChange);
	forestCMaxLat = forestCMaxLat + (tempMult * forestLatChange);
	
	-- Warmer climate => marsh extending closer to the poles.
	marshMinLat = marshMinLat + (tempMult * marshLatChange);
	marshMaxLat = marshMaxLat + (tempMult * marshLatChange);
	
	-- Warmer climate => less ice
	icePct = icePct - (tempMult * iceChange);
	iceMinLat  = iceMinLat  + (tempMult * iceLatChange);
	iceMaxLat  = iceMaxLat  + (tempMult * iceLatChange);
	
	-- Use rainfall to control forests, jungles, and marsh.
	local rainMult = DOWN_TO_UP[rainfall];
	
	junglePct = junglePct + (rainMult * junglePctShift);
	forestPct = forestPct + (rainMult * forestChange);
	marshPct  = marshPct  + (rainMult * marshChange);
	
	-- More fresh water (rivers) => more oases.
	-- This is a balance tweak--more rivers means less deserts on which to spawn oases.
	local waterMult = DOWN_TO_UP[freshWater];	
	oasisPct = oasisPct + (waterMult * oasisChange);

	local addIceAtPlotFcn;
	if (#sunlightArgs.AddIceAtPlot > 0) then
		-- Non-standard sunlight.
		addIceAtPlotFcn = sunlightArgs.AddIceAtPlot[worldWrap];
	else
		-- Standard sunlight, so let climate decide how to add ice.
		addIceAtPlotFcn = climateArgs.AddIceAtPlot[worldWrap];
	end

	-- create instance data
	local instance = 
	{
		-- methods
		InitFractals		= GotLakes_FeatureGenerator.InitFractals,
		InitIcePhases		= GotLakes_FeatureGenerator.InitIcePhases,
		GetIcePhase         = GotLakes_FeatureGenerator.GetIcePhase,
		FractalIceAtPlot    = GotLakes_FeatureGenerator.FractalIceAtPlot,
		PolarRowsIceAtPlot  = GotLakes_FeatureGenerator.PolarRowsIceAtPlot,
		WhiteNoiseIceAtPlot = GotLakes_FeatureGenerator.WhiteNoiseIceAtPlot,
		AddFeatures			= GotLakes_FeatureGenerator.AddFeatures,
		AddOasisAtPlot		= GotLakes_FeatureGenerator.Default_AddOasisAtPlot,
		AddIceAtPlot		= addIceAtPlotFcn;
		AddMarshAtPlot		= GotLakes_FeatureGenerator.Default_AddMarshAtPlot,
		AddJunglesAtPlot	= GotLakes_FeatureGenerator.Default_AddJunglesAtPlot,
		AddForestsAtPlot	= GotLakes_FeatureGenerator.Default_AddForestsAtPlot,
		AddReefAtPlot       = GotLakes_FeatureGenerator.Default_AddReefAtPlot,
		AddFeaturesFromContinents 
							= GotLakes_FeatureGenerator.AddFeaturesFromContinents,
			
		-- members
		polarIceNumRows = polarIceNumRows,
		
		junglePct = junglePct,
		forestPct = forestPct,
		marshPct  = marshPct,
		oasisPct  = oasisPct,
		icePct    = icePct,
		reefPct   = reefPct,
	
		bForestsOnTundra = biodivArgs.tundraForest and (UserInput.noTForests == false),
		bOasesOnDesert   = biodivArgs.desertOasis  and (UserInput.noDOases   == false),
		
		bJunglesOnGrass  = biodivArgs.grassJungle  and (UserInput.noGJungles == false),
		bPlainsOnMarsh   = biodivArgs.plainsMarsh  and (UserInput.noPMarsh   == false),
		
		bJunglesOnDesert = biodivArgs.desertJungle and (UserInput.noDJungles == false),
		bForestsOnSnow   = biodivArgs.snowForest   and (UserInput.noSForests == false),
	
		bForestsOnDesert = biodivArgs.desertForest and (UserInput.noDForests == false),
		bOasesOnSnow     = biodivArgs.snowOasis    and (UserInput.noSOases   == false),
			
		jungleMinLat  = jungleMinLat,
		jungleMaxLat  = jungleMaxLat,
		forestHMinLat = forestHMinLat,
		forestHMaxLat = forestHMaxLat,
		forestCMinLat = forestCMinLat,
		forestCMaxLat = forestCMaxLat,
		marshMinLat   = marshMinLat,
		marshMaxLat   = marshMaxLat,
		reefMaxLat    = reefMaxLat,
		iceMinLat     = iceMinLat,
		iceMaxLat     = iceMaxLat,	
		
		fissureCount = 0,
	};
	--PrintContentsOfTable(instance);

	-- initialize instance data
	instance:InitFractals();
	instance:InitIcePhases();
	
	return instance;
end

function GotLakes_FeatureGenerator:InitFractals()
	-- Initialize fractals
	self.jungles = CreateClimateFractal("jungles");
	self.forests = CreateClimateFractal("forests");
	self.marsh   = CreateClimateFractal("marsh");
	self.ice     = CreateClimateFractal("ice");
	
	-- Threshold for max density of fractal ice.
	-- Does not affect white-noise ice.
	self.iceBottomPct = 100 - self.icePct;
	
	-- Threshold for non-interpolated ice.
	self.iceLevel = GetFractalHeight(self.ice, self.iceBottomPct);
	
	-- Reduce frequency of oases on snow.
	self.oasisSnowPct = self.oasisPct / 4;
end

function GotLakes_FeatureGenerator:InitIcePhases()
	if (not ScriptData.gotGatheringStorm) then
		-- GS is disabled, so stub-out ice phases.
		self.iceNumPhases = 0;
		return;
	end
	-- Initialize logic for determining meltability of each ice tile.
	print("Initializing ice phases.");
	
	-- Map sea level to ice-loss phase.
	local phases = {};
	local numPhases = 0;
	for row in GameInfo.RandomEvents() do
		if (row.EffectOperatorType == "SEA_LEVEL") then
			local kPhaseDetails = {};
			kPhaseDetails.randomEventEnum = row.Index;
			
			-- Ice loss as percentage lost during phase
			kPhaseDetails.iceLoss = row.IceLoss;
			
			table.insert(phases, kPhaseDetails);
			numPhases = numPhases + 1;
		end
	end
	self.icePhases = phases;
	self.iceNumPhases = numPhases;
end

function GotLakes_FeatureGenerator:GetIcePhase(iceLoss)
	-- Map ice loss from [0,100] to appropriate ice phase # or -1 for permanent ice.
	if (self.iceNumPhases <= 0) then
		return -1;
	end
	
	local minPhase = nil;
	local minIceLoss = 101;
	
	-- Look for the phase with lowest ice loss that is still > param iceLoss
	for i, phase in ipairs(self.icePhases) do
		if ((phase.iceLoss >= iceLoss) and (phase.iceLoss < minIceLoss)) then
			minPhase = phase;
			minIceLoss = phase.iceLoss;
		end
	end
	
	if (not minPhase) then
		-- Permanent ice.
		return -1;
	end
	return minPhase.randomEventEnum;
end

function GotLakes_FeatureGenerator:FractalIceAtPlot(plot, iX, iY, lat)
	-- Fractal ice with linear latitude interpolation.
	local iceLevel = GetFractalHeight(self.ice, Interpolate(lat, 
		self.iceMinLat, self.iceMaxLat, 
		100, self.iceBottomPct));
		
	if (self.ice:GetHeight(iX, iY) <= iceLevel) then
		-- no ice.
		return false, 0;
	end
	
	-- Map latitude to ice loss such that higher lat => higher phase required to melt ice.
	local iceLoss = Interpolate(lat, self.iceMinLat, self.iceMaxLat, 0, 100);
	return true, self:GetIcePhase(iceLoss);
end

function GotLakes_FeatureGenerator:PolarRowsIceAtPlot(plot, iX, iY, lat)
	-- Add ice to the top/bottom rows of the map.
	if ((iY < self.polarIceNumRows) or (iY >= g_iH - self.polarIceNumRows)) then
		-- Got polar ice.
		-- Not enough latitude diff here to bother with interpolation, 
		-- so randomize melting of top/bottom rows of ice.
		local iceLoss = TerrainBuilder.GetRandomNumber(100, "White Noise Ice Loss");
		return true, self:GetIcePhase(iceLoss);
	end
	
	return false, 0;
end

function GotLakes_FeatureGenerator:WhiteNoiseIceAtPlot(plot, iX, iY, lat, maxPct)
	-- Interpolated white noise is good enough for maps that don't have much ice.
	local maxPct = maxPct or 100;
	local rand = TerrainBuilder.GetRandomNumber(100, "White Noise Ice");
	local iceLevel = Interpolate(lat, 
		self.iceMinLat, self.iceMaxLat, 
		100, 100 - maxPct,
		Square);
	if (rand <= iceLevel) then
		return false, 0;
	end
		
	-- Map latitude to ice loss such that higher lat => higher phase required to melt ice.
	local iceLoss = Interpolate(lat, self.iceMinLat, self.iceMaxLat, 0, 100);
	return true, self:GetIcePhase(iceLoss);
end

function GotLakes_FeatureGenerator:AddFeatures()
	-- Default behavior for adding features.
	self.iNumLandPlots = 0;
		
	local latMin = math.huge;
	local latMax = 0.0;
	
	local maxNumReefs = math.huge;
	local numReefs = 0;
	
	if (ScriptData.wrapX == false) then
		-- For some reason, region maps crash if there are too many reefs.
		-- Standard size max is 27 on my machine.
		maxNumReefs = Round(g_numTiles / 250); -- Roughly 17 for standard-size maps
		print("Max number of reefs: " .. maxNumReefs);
	end
	
	if ScriptData.gotGatheringStorm then
		-- First let's add Floodplains
		print("Adding GS floodplains.");
		-- GotLakes rivers are created mouth-first.
		-- However, this flag might be more concerned about 
		-- whether rivers merge toward the mouth (start inland, multiple sources per mouth) or
		-- whether rivers merge toward the source (start at mouth, multiple mouths per source).
		-- ...but GL rivers can do both!
		local bRiversStartInland = false;
		--	not ((UserInput.rivers == RiverPatterns.SIMPLE) and 
		--	     (UserInput.landmass == Landmasses.INLANDSEA));
		-- Floodplain min/max sizes seem to have no effect 
		-- on number of floodplains tiles added to the map.
		local iMinFloodplainSize = 4;
		local iMaxFloodplainSize = 10;
		TerrainBuilder.GenerateFloodplains(
			bRiversStartInland, iMinFloodplainSize, iMaxFloodplainSize);
	end
	
	-- Main loop, adds features to all plots as appropriate
	for y = 0, g_iH - 1, 1 do
		for x = 0, g_iW - 1, 1 do
			local plot = Map.GetPlot(x,y);
			
			if (plot ~= nil) then
				local lat = GL_GetLatitudeAtPlot(x, y);

				if ((UserInput.worldWrap == WORLDWRAP_GLOBE) and 
				    (gotIceAgeFamily == true)) then
					-- Global ice age climate -- squish latitude bands.
					--lat = lat * 0.6;
				end
				
				latMin = math.min(latMin, lat);
				latMax = math.max(latMax, lat);
				
				if plot:IsWater() then	
					-- Water feature
					-- TerrainBuilder.CanHaveFeature() doesn't allow ice in lakes, 
					-- so skip that check because we're OK with frozen lakes.
					--
					-- Avoid rivers.
					-- Avoid coast if no-coastal-ice option is enabled.
					local addedIce = false;
					if ((not IsAdjacentToRiver(x, y)) and
						((UserInput.noCoastIce == false) or 
						 (not IsAdjacentToLandPlot(x, y))) ) then
						-- Maybe add ice.
						local addedIce, icePhase = self:AddIceAtPlot(plot, x, y, lat);
						if addedIce then
							TerrainBuilder.SetFeatureType(plot, g_FEATURE_ICE);
							if ScriptData.gotGatheringStorm then
								-- GS: also set ice phase.
								TerrainBuilder.AddIce(plot:GetIndex(), icePhase);
							end
						end
					end
					if (g_FEATURE_REEF and 
						(UserInput.noReefs == false) and 
						(addedIce == false) and 
						(numReefs < maxNumReefs)) then
						-- Maybe add a reef.
						if (self:AddReefAtPlot(plot, x, y, lat)) then
							-- Added a reef.
							TerrainBuilder.SetFeatureType(plot, g_FEATURE_REEF);
							numReefs = numReefs + 1;
						end
					end
				else
					--[
					-- Land feature
					self.iNumLandPlots = self.iNumLandPlots + 1;
					if (plot:GetFeatureType() ~= g_FEATURE_NONE) then
						-- Skip land plots that already have features.
					
					elseif ((not ScriptData.gotGatheringStorm) and 
					    (TerrainBuilder.CanHaveFeature(plot, g_FEATURE_FLOODPLAINS))) then
						-- Classic floodplains.
						-- All desert plots along river are set to flood plains.
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_FLOODPLAINS);
						
					elseif (self:AddOasisAtPlot(plot, x, y, lat)) then
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_OASIS);
						-- Added an oasis.
						--
						-- GS base game tries to prevent oases next to geothermal fissures,
						-- but I simply don't care if that happens.
						
					elseif (self:AddMarshAtPlot(plot, x, y, lat)) then
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_MARSH)
						-- Added marsh
						if ((not self.bPlainsOnMarsh) and 
							IsBaseTerrainType(g_TERRAIN_TYPE_PLAINS, plot:GetTerrainType())) then
							-- Convert plains under marsh into grass 
							SetBaseTerrain(plot, g_TERRAIN_TYPE_GRASS);
						end
					
					elseif (self:AddJunglesAtPlot(plot, x, y, lat)) then
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_JUNGLE);
						-- Added jungle.
						if ((not self.bJunglesOnGrass) and 
						    IsBaseTerrainType(g_TERRAIN_TYPE_GRASS, plot:GetTerrainType())) then
							-- Convert grass under jungle into plains 
							SetBaseTerrain(plot, g_TERRAIN_TYPE_PLAINS);
						end
						
					elseif (self:AddForestsAtPlot(plot, x, y, lat)) then
						TerrainBuilder.SetFeatureType(plot, g_FEATURE_FOREST);
						-- Added forest.
					end
					--]]
				end
			else
				print("Nil plot at " .. CoordString(x,y));
			end
		end
	end
	
	print("Number of reefs: " .. numReefs);
	
	latMin = Round(latMin*100)/100;
	latMax = Round(latMax*100)/100;
	print("Feature latitude range: " .. CoordString(latMin, latMax));	
end

function GotLakes_FeatureGenerator:Default_AddOasisAtPlot(plot, iX, iY, lat)
	local terrainType = plot:GetTerrainType();		
	if (not ((self.bOasesOnDesert and (terrainType == g_TERRAIN_TYPE_DESERT)) or
			 (self.bOasesOnSnow   and (terrainType == g_TERRAIN_TYPE_SNOW  )) )) then
		return false;
	end
	if IsAdjacentToOasis(iX, iY) then
		return false;
	end
	
	local dice = TerrainBuilder.GetRandomNumber(100, "Add Oasis Lua");
	
	if (terrainType == g_TERRAIN_TYPE_SNOW) then
		return dice <= self.oasisSnowPct;
	end
	return (dice <= self.oasisPct);
end

function GotLakes_FeatureGenerator:Default_AddMarshAtPlot(plot, iX, iY, lat)
	-- Allow marsh on either flat grassland or flat plains.
	local terrainType = plot:GetTerrainType();	
	if (not ((terrainType == g_TERRAIN_TYPE_PLAINS) or 
			 (terrainType == g_TERRAIN_TYPE_GRASS))) then
		return false;
	end
	
	-- Chance of marsh, depending on latitude.
	local marshVal = self.marsh:GetHeight(iX, iY);
	local marshPctWidth = Interpolate(lat, 
		self.marshMinLat, self.marshMaxLat, 
		(self.marshPct)/4, 0,
		math.sqrt);

	-- Split marsh fractal into two semi-snaky bands.
	return (((marshVal >= GetFractalHeight(self.marsh, 25-marshPctWidth))  and 
			 (marshVal <  GetFractalHeight(self.marsh, 25+marshPctWidth))) or
			((marshVal >= GetFractalHeight(self.marsh, 75-marshPctWidth))  and 
			 (marshVal <  GetFractalHeight(self.marsh, 75+marshPctWidth))));
end

function GotLakes_FeatureGenerator:Default_AddJunglesAtPlot(plot, iX, iY, lat)
	-- Allow jungles on plains, grassland, and maybe even desert.
	local terrainType = plot:GetTerrainType();
	if (not ((self.bJunglesOnDesert and 
			 ((terrainType == g_TERRAIN_TYPE_DESERT) or 
			  (terrainType == g_TERRAIN_TYPE_DESERT_HILLS))) or 
			  TerrainBuilder.CanHaveFeature(plot, g_FEATURE_JUNGLE))) then
		return false;
	end
	
	-- Chance of jungle, depending on latitude.
	local jungleOffset = Interpolate(lat, 
		self.jungleMinLat, self.jungleMaxLat, 
		self.junglePct/2, 0,
		math.sqrt);
	local jungleBottom = GetFractalHeight(self.jungles, 50 - jungleOffset);
	local jungleTop    = GetFractalHeight(self.jungles, 50 + jungleOffset);
	
	local jungleVal = self.jungles:GetHeight(iX, iY);
	return ((jungleVal >= jungleBottom) and (jungleVal < jungleTop));
end

function GotLakes_FeatureGenerator:Default_AddForestsAtPlot(plot, iX, iY, lat)
	-- Allow forests adjacent to fresh lakes.
	local terrainType = plot:GetTerrainType();		
	if (not ((terrainType == g_TERRAIN_TYPE_PLAINS) or 
		     (terrainType == g_TERRAIN_TYPE_PLAINS_HILLS) or
			 (terrainType == g_TERRAIN_TYPE_GRASS) or 
		     (terrainType == g_TERRAIN_TYPE_GRASS_HILLS) or
			 (self.bForestsOnTundra and 
			  ((terrainType == g_TERRAIN_TYPE_TUNDRA) or 
		       (terrainType == g_TERRAIN_TYPE_TUNDRA_HILLS))) or
			 (self.bForestsOnDesert and 
			  ((terrainType == g_TERRAIN_TYPE_DESERT) or 
		       (terrainType == g_TERRAIN_TYPE_DESERT_HILLS))) or
			 (self.bForestsOnSnow and 
			  ((terrainType == g_TERRAIN_TYPE_SNOW) or 
			   (terrainType == g_TERRAIN_TYPE_SNOW_HILLS))) )) then
		return false;
	end
	
	-- Chance of forest, depending on latitude.
	local forestVal = self.forests:GetHeight(iX, iY);
	local pctWidth = (self.forestPct)/4;
	
	if (lat <= self.forestHMaxLat) then
		-- Hot forest interpolation: fade towards the equator.
		pctWidth = Interpolate(lat, 
			self.forestHMinLat, self.forestHMaxLat, 
			0, pctWidth,
			math.sqrt);
			
	elseif (lat >= self.forestCMinLat) then
		-- Cold forest interpolation: fade towards the pole.
		pctWidth = Interpolate(lat, 
			self.forestCMinLat, self.forestCMaxLat, 
			pctWidth, 0,
			math.sqrt);
	end
	
	local pctWidthHalf = pctWidth/2;
	
	-- Use multiple ranges to create a mixture of large and small forest clumps.
	return ((forestVal >=  GetFractalHeight(self.forests, 100-(2*pctWidth))) or
		    ((forestVal >= GetFractalHeight(self.forests, 12.5-pctWidthHalf)) and
		     (forestVal <  GetFractalHeight(self.forests, 12.5+pctWidthHalf))) or
		    ((forestVal >= GetFractalHeight(self.forests, 37.5-pctWidthHalf)) and
		     (forestVal <  GetFractalHeight(self.forests, 37.5+pctWidthHalf))));
end

function GotLakes_FeatureGenerator:Default_AddReefAtPlot(plot, iX, iY, lat)
	-- Reef Check. 
	-- First see if we can place it here.
	if ((lat < self.reefMaxLat) and 
	    TerrainBuilder.CanHaveFeature(plot, g_FEATURE_REEF)) then
		-- Roll dice for a chance at a reef.
		local dice = TerrainBuilder.GetRandomNumber(100, "Add Reef Lua");
		if (dice <= self.reefPct) then
			return true;
		end
	end
	return false;
end

function GotLakes_FeatureGenerator:Globe_AddIceAtPlot(plot, iX, iY, lat)
	-- Default ice for a globe map.
	-- Assuming we only have at most two rows at each vertical edge
	-- of the map, just use white noise for scarce ice tiles.
	local gotIce, icePhase = self:PolarRowsIceAtPlot(plot, iX, iY, lat);
	if gotIce then
		return true, icePhase;
	end
	return self:WhiteNoiseIceAtPlot(plot, iX, iY, lat);
end

function GotLakes_FeatureGenerator:IceAgeGlobe_AddIceAtPlot(plot, iX, iY, lat)
	-- Ice Age globe.
	-- Top or bottom N rows of the map ==> frozen
	-- Overlap white noise with a fractal pattern.
	local gotIce, icePhase = self:PolarRowsIceAtPlot(plot, iX, iY, lat);
	if gotIce then
		return true, icePhase;
	end
	gotIce, icePhase = self:WhiteNoiseIceAtPlot(plot, iX, iY, lat);
	if gotIce then
		return true, icePhase;
	end
	return self:FractalIceAtPlot(plot, iX, iY, lat);
end

function GotLakes_FeatureGenerator:IceAgeRegion_AddIceAtPlot(plot, iX, iY, lat)
	-- Ice Age region.
	if (UserInput.landmass == Landmasses.DONUT) then
		-- Donut landmass.
		local i = GetPlotIndexLua(iX, iY);
		if (ScriptData.donutFillingMap[i] == FILLING_YES) then
			-- Turn all donut filling water into ice.			
			local iceLoss = TerrainBuilder.GetRandomNumber(100, "White Noise Ice Loss");
			return true, self:GetIcePhase(iceLoss);
		end
	end
	-- Use a non-interpolated fractal to cover the whole map with blobs of ice.
	if (self.ice:GetHeight(iX, iY) < self.iceLevel) then
		return false, 0;
	end
	
	local iceLoss = TerrainBuilder.GetRandomNumber(100, "White Noise Ice Loss");
	return true, self:GetIcePhase(iceLoss);
end

function GotLakes_FeatureGenerator:Region_AddIceAtPlot(plot, iX, iY, lat)
	-- Region maps have no ice by default.
	return false, 0;
end

function GotLakes_FeatureGenerator:TiltedAxisGlobe_AddIceAtPlot(plot, iX, iY, lat)
	-- Tilted Axis Globe
	local iceNumRows = ScriptData.landInfo.polarIceNumRows;
	if (iY >= g_iH - iceNumRows) then
		-- Top rows for cropped climate => frozen
		local iceLoss = 100; -- Permanent ice for tilted axis full
		if (UserInput.icyPoles == ICYPOLES_CROP) then
			-- Random ice melt for tilted axis cropped.
			iceLoss = TerrainBuilder.GetRandomNumber(100, "White Noise Ice Loss");
		end
		return true, self:GetIcePhase(iceLoss);
	end
	-- Don't bother with ice on the bottom rows,
	-- since the south pole is hot.
	
	-- Overlap white noise with a fractal pattern.
	local gotIce, icePhase = self:WhiteNoiseIceAtPlot(plot, iX, iY, lat);
	if gotIce then
		return true, icePhase;
	end	
	return self:FractalIceAtPlot(plot, iX, iY, lat);
end

function GotLakes_FeatureGenerator:TiltedAxisRegion_AddIceAtPlot(plot, iX, iY, lat)
	-- Tilted Axis region: overlap white noise with a fractal pattern.
	-- Reduce white noise so that the dark side is not completely covered in ice.
	local gotIce, icePhase = self:WhiteNoiseIceAtPlot(plot, iX, iY, lat, 50);
	if gotIce then
		return true, icePhase;
	end
	return self:FractalIceAtPlot(plot, iX, iY, lat);
end

function GotLakes_FeatureGenerator:TwoSuns_AddIceAtPlot(plot, iX, iY, lat)
	-- Two Suns: overlap white noise with a fractal pattern.
	local gotIce, icePhase = self:WhiteNoiseIceAtPlot(plot, iX, iY, lat);
	if gotIce then
		return true, icePhase;
	end
	return self:FractalIceAtPlot(plot, iX, iY, lat);	
end

function GotLakes_FeatureGenerator:AddFeaturesFromContinents()
	print("Adding geothermal fissures.");
	local aPossibleFissureIndices:table = {};

	local gotSoilFilling = 
		((UserInput.landmass == Landmasses.DONUT) and 
		 (ExtrasGot.tectonic == true) and
		 (UserInput.biodiv   == Biodivs.VERYHIGH));

	for y = 0, g_iH - 1, 1 do
		for x = 0, g_iW - 1, 1 do
			local i = y * g_iW + x;
			local plot = Map.GetPlot(x,y);
			if(plot ~= nil) then
				local featureType = plot:GetFeatureType();

				if(plot:IsImpassable() or featureType ~= g_FEATURE_NONE) then
					--No Feature
				elseif (gotSoilFilling and 
					    (ScriptData.donutFillingMap[i+1] == FILLING_YES) and
						TerrainBuilder.CanHaveFeature(plot, g_FEATURE_VOLCANIC_SOIL)) then
					-- Volcanic soil donut filling!
					TerrainBuilder.SetFeatureType(plot, g_FEATURE_VOLCANIC_SOIL);		
						
				elseif (TerrainBuilder.CanHaveFeature(plot, g_FEATURE_GEOTHERMAL_FISSURE) and
					Map.FindSecondContinent(plot, 3)) then
					table.insert(aPossibleFissureIndices, i);
				end
			end
		end
	end

	-- Place fissures near continent divides
	local iDesiredFissures = self.iNumLandPlots / 100; -- /200
	if (iDesiredFissures > 0 and #aPossibleFissureIndices > 0) then
		aShuffledIndices =  GetShuffledCopyOfTable(aPossibleFissureIndices);
		for i, index in ipairs(aShuffledIndices) do
			local pPlot = Map.GetPlotByIndex(index);
			TerrainBuilder.SetFeatureType(pPlot, g_FEATURE_GEOTHERMAL_FISSURE);
			self.fissureCount = self.fissureCount + 1;
			--print ("Fissure Placed at " .. CoordString(pPlot:GetX(), pPlot:GetY()));
			if (self.fissureCount >= iDesiredFissures) then
				break
			end
		end
	end

	-- Still have fissures to place?  Add them anywhere
	if (iDesiredFissures > self.fissureCount) then
		local aFullMapFissureIndices:table = {};
		for y = 0, g_iH - 1, 1 do
			for x = 0, g_iW - 1, 1 do
				local i = y * g_iW + x;
				local plot = Map.GetPlotByIndex(i);
				if(plot ~= nil) then
					local featureType = plot:GetFeatureType();

					if(plot:IsImpassable() or featureType ~= g_FEATURE_NONE) then
						--No Feature
					else
						if (TerrainBuilder.CanHaveFeature(plot, 
								g_FEATURE_GEOTHERMAL_FISSURE)) then
							if (not Map.FindSecondContinent(plot, 3)) then
								table.insert(aFullMapFissureIndices, i);
							end
						end
					end
				end
			end
		end
		if (#aFullMapFissureIndices > 0) then
			aShuffledIndices =  GetShuffledCopyOfTable(aFullMapFissureIndices);
			for i, index in ipairs(aShuffledIndices) do
				local pPlot = Map.GetPlotByIndex(index);
				TerrainBuilder.SetFeatureType(pPlot, g_FEATURE_GEOTHERMAL_FISSURE);
				self.fissureCount = self.fissureCount + 1;
				--print ("Full-Map Fissure Placed at " .. CoordString(pPlot:GetX(), pPlot:GetY()));
				if (self.fissureCount >= iDesiredFissures) then
					break
				end
			end
		end
	end
	print("Number of Fissures: ", self.fissureCount)
end

function GenerateFeatures()
	print("Generating Features (" .. 
		   ScriptData.landInfo.name .. " + " ..
		   ScriptData.climateInfo.name .. " + " ..
		   ScriptData.biomeInfo.name .. " + " .. 
		   ScriptData.sunlightInfo.name .. ")");
	
	-- Create the feature generator.
	local featuregen = GotLakes_FeatureGenerator.Create(
		ScriptData.landInfo,
		ScriptData.biodivInfo,
		ScriptData.climateInfo,
		ScriptData.biomeInfo,
		ScriptData.sunlightInfo);
	
	featuregen:AddFeatures();
	return featuregen;
end
------------------------------------------------------------------------------
-- Natural Wonder Generator overrides
-- Improved edge-case handling
------------------------------------------------------------------------------
function CustomGetMultiTileFeaturePlotList(pPlot, eFeatureType, aPlots)
	-- Override to improve stability.
	
	-- First check this plot itself
	if ((pPlot == nil) or (not TerrainBuilder.CanHaveFeature(pPlot, eFeatureType, true))) then
		return false;
	else
		table.insert(aPlots, pPlot:GetIndex());
	end

	-- Which type of custom placement is it?
	local customPlacement = GameInfo.Features[eFeatureType].CustomPlacement;

	-- 2 tiles inland, east-west facing camera
	if (customPlacement == "PLACEMENT_TORRES_DEL_PAINE" or
	    customPlacement == "PLACEMENT_YOSEMITE") then

		-- Assume first tile is the western one, check the one to the east
		local pAdjacentPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_EAST);
		if (pAdjacentPlot ~= nil and TerrainBuilder.CanHaveFeature(pAdjacentPlot, eFeatureType, true) == true) then
			table.insert(aPlots, pAdjacentPlot:GetIndex());
			return true;
		end

	-- 2 tiles on coast, roughly facing camera
	elseif (customPlacement == "PLACEMENT_CLIFFS_DOVER") then
		local pNEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
		local pWPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_WEST);
		local pSWPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
		local pSEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
		local pEPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_EAST);

		-- W and SW are water, see if SE works
		local pSecondPlot;
		if (pWPlot ~= nil and 
		    pSWPlot ~= nil and 
			pWPlot:IsWater() and pWPlot:IsLake() == false and 
			pSWPlot:IsWater() and pWPlot:IsLake() == false) then
			pSecondPlot = pSEPlot;

		-- SW and SE are water, see if E works
		elseif (pSWPlot ~= nil and 
				pSEPlot ~= nil and 
				pSWPlot:IsWater() and pSWPlot:IsLake() == false and 
				pSEPlot:IsWater() and pSEPlot:IsLake() == false) then
			pSecondPlot = pEPlot;

		-- SE and E are water, see if NE works
		-- <<MOD: pSEPlot, not pSWPlot for nil-check>>
		elseif (pSEPlot ~= nil and 
				pEPlot ~= nil  and 
				pSEPlot:IsWater() and pSEPlot:IsLake() == false and 
				pEPlot:IsWater() and pEPlot:IsLake() == false) then
			pSecondPlot = pNEPlot;
		else
			return false;
		end

		if (pSecondPlot ~= nil and TerrainBuilder.CanHaveFeature(pSecondPlot, eFeatureType, true)) then
			table.insert(aPlots, pSecondPlot:GetIndex());
			return true;
		end

	-- 2 tiles, one on coastal land and one in water, try to face camera if possible
	elseif (customPlacement == "PLACEMENT_GIANTS_CAUSEWAY") then

		-- Assume first tile a land tile without hills, check around it in a preferred order for water
		if (pPlot:IsWater() or pPlot:IsHills()) then
			return false;
		end

		local pSWPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
		if (pSWPlot ~= nil and pSWPlot:IsWater() and pSWPlot:IsLake() == false) then
			table.insert(aPlots, pSWPlot:GetIndex());
			return true;
		end

		local pSEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
		if (pSEPlot ~= nil and pSEPlot:IsWater() and pSEPlot:IsLake() == false) then
			table.insert(aPlots, pSEPlot:GetIndex());
			return true;
		end

		local pWPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_WEST);
		if (pWPlot ~= nil and pWPlot:IsWater() and pWPlot:IsLake() == false) then
			table.insert(aPlots, pWPlot:GetIndex());
			return true;
		end

		local pEPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_EAST);
		if (pEPlot ~= nil and pEPlot:IsWater() and pEPlot:IsLake() == false) then
			table.insert(aPlots, pEPlot:GetIndex());
			return true;
		end

		local pNWPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_NORTHWEST);
		if (pNWPlot ~= nil and pNWPlot:IsWater() and pNWPlot:IsLake() == false) then
			table.insert(aPlots, pNWPlot:GetIndex());
			return true;
		end

		local pNEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
		if (pNEPlot ~= nil and pNEPlot:IsWater() and pNEPlot:IsLake() == false) then
			table.insert(aPlots, pNEPlot:GetIndex());
			return true;
		end
		
	-- 4 tiles (triangle plus a tail)
	elseif (customPlacement == "PLACEMENT_RORAIMA") then

		-- This one does require three in a row, so let's find that first
		for i = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
			local pFirstPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), i);
			if (pFirstPlot ~= nil and TerrainBuilder.CanHaveFeature(pFirstPlot, eFeatureType, true)) then
				local pSecondPlot = Map.GetAdjacentPlot(pFirstPlot:GetX(), pFirstPlot:GetY(), i);
				if (pSecondPlot ~= nil and TerrainBuilder.CanHaveFeature(pSecondPlot, eFeatureType, true)) then
					local iNewDir = i - 1;
					if iNewDir == -1 then
						iNewDir = 5;
					end
					local pThirdPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), iNewDir);
					if (pThirdPlot ~= nil and TerrainBuilder.CanHaveFeature(pThirdPlot, eFeatureType, true)) then
						table.insert(aPlots, pFirstPlot:GetIndex());
						table.insert(aPlots, pSecondPlot:GetIndex());
						table.insert(aPlots, pThirdPlot:GetIndex());
						return true;
					end
				end
			end
		end

	-- 3 tiles in a straight line
	elseif (customPlacement == "PLACEMENT_ZHANGYE_DANXIA") then

		for i = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
			local pFirstPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), i);
			if (pFirstPlot ~= nil and TerrainBuilder.CanHaveFeature(pFirstPlot, eFeatureType, true)) then
				local pSecondPlot = Map.GetAdjacentPlot(pFirstPlot:GetX(), pFirstPlot:GetY(), i);
				if (pSecondPlot ~= nil and TerrainBuilder.CanHaveFeature(pSecondPlot, eFeatureType, true)) then
					table.insert(aPlots, pFirstPlot:GetIndex());
					table.insert(aPlots, pSecondPlot:GetIndex());
					return true;
				end
			end
		end

	-- 3 tiles in triangle coast on front edge, land behind (with any rotation)
	elseif (customPlacement == "PLACEMENT_PIOPIOTAHI") then

		local pWPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_WEST);
		local pNWPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_NORTHWEST);
		local pNEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
		local pEPlot  = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_EAST);
		local pSEPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
		local pSWPlot = Map.GetAdjacentPlot(pPlot:GetX(), pPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
		
		-- all 6 hexes around must be land
		if (pNWPlot == nil or pNEPlot == nil or pWPlot== nil or 
			pSWPlot== nil  or pSEPlot == nil or pEPlot== nil or 
			pNWPlot:IsWater() or pNEPlot:IsWater() or pWPlot:IsWater() or 
			pSWPlot:IsWater() or pSEPlot:IsWater() or pEPlot:IsWater()) then
			return false;
		else
			-- find two adjacent plots that can both serve for this NW
			local bWValid  = TerrainBuilder.CanHaveFeature(pWPlot, eFeatureType, true);
			local bNWValid = TerrainBuilder.CanHaveFeature(pNWPlot, eFeatureType, true);
			local bNEValid = TerrainBuilder.CanHaveFeature(pNEPlot, eFeatureType, true);
			local bEValid  = TerrainBuilder.CanHaveFeature(pEPlot, eFeatureType, true);
			local bSEValid = TerrainBuilder.CanHaveFeature(pSEPlot, eFeatureType, true);
			local bSWValid = TerrainBuilder.CanHaveFeature(pSWPlot, eFeatureType, true);

			if (bSEValid ~= nil and bSWValid ~= nil and bSEValid == true and bSWValid == true ) then
				pWaterCheck1 = Map.GetAdjacentPlot(pSEPlot:GetX(), pSEPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
				pWaterCheck2 = Map.GetAdjacentPlot(pSWPlot:GetX(), pSWPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);
				pWaterCheck3 = Map.GetAdjacentPlot(pSWPlot:GetX(), pSWPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
				--- mod <<<
				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				--- mod >>>
				if (pWaterCheck1:IsWater() == false or 
					pWaterCheck2:IsWater() == false or 
					pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pSEPlot:GetIndex());
					table.insert(aPlots, pSWPlot:GetIndex());
					return true;
				end
			end
			
			if (bEValid  ~= nil and bSEValid ~= nil and bEValid  == true and bSEValid == true ) then
				pWaterCheck1 = Map.GetAdjacentPlot(pEPlot:GetX(), pEPlot:GetY(), DirectionTypes.DIRECTION_EAST);
				pWaterCheck2 = Map.GetAdjacentPlot(pSEPlot:GetX(), pSEPlot:GetY(), DirectionTypes.DIRECTION_EAST);
				pWaterCheck3 = Map.GetAdjacentPlot(pSEPlot:GetX(), pSEPlot:GetY(), DirectionTypes.DIRECTION_SOUTHEAST);

				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				
				if (pWaterCheck1:IsWater() == false or pWaterCheck2:IsWater() == false or pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pEPlot:GetIndex());
					table.insert(aPlots, pSEPlot:GetIndex());
					return true;
				end
			end
			
			if (bSWValid  ~= nil and bWValid ~= nil and bSWValid  == true and bWValid == true ) then
				pWaterCheck1 = Map.GetAdjacentPlot(pSWPlot:GetX(), pSWPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
				pWaterCheck2 = Map.GetAdjacentPlot(pWPlot:GetX(), pWPlot:GetY(), DirectionTypes.DIRECTION_SOUTHWEST);
				pWaterCheck3 = Map.GetAdjacentPlot(pWPlot:GetX(), pWPlot:GetY(), DirectionTypes.DIRECTION_WEST);
				
				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				
				if (pWaterCheck1:IsWater() == false or pWaterCheck2:IsWater() == false or pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pSWPlot:GetIndex());
					table.insert(aPlots, pWPlot:GetIndex());
					return true;
				end
			end

			if (bWValid  ~= nil and bNWValid ~= nil and bWValid  == true and bNWValid == true ) then	
				pWaterCheck1 = Map.GetAdjacentPlot(pWPlot:GetX(), pWPlot:GetY(), DirectionTypes.DIRECTION_WEST);
				pWaterCheck2 = Map.GetAdjacentPlot(pNWPlot:GetX(), pNWPlot:GetY(), DirectionTypes.DIRECTION_WEST);
				pWaterCheck3 = Map.GetAdjacentPlot(pNWPlot:GetX(), pNWPlot:GetY(), DirectionTypes.DIRECTION_NORTHWEST);
				
				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				
				if (pWaterCheck1:IsWater() == false or pWaterCheck2:IsWater() == false or pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pWPlot:GetIndex());
					table.insert(aPlots, pNWPlot:GetIndex());
					return true;
				end
			end
			
			if (bNEValid  ~= nil and bEValid ~= nil and bNEValid  == true and bEValid == true ) then	
				pWaterCheck1 = Map.GetAdjacentPlot(pNEPlot:GetX(), pNEPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
				pWaterCheck2 = Map.GetAdjacentPlot(pEPlot:GetX(), pEPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
				pWaterCheck3 = Map.GetAdjacentPlot(pEPlot:GetX(), pEPlot:GetY(), DirectionTypes.DIRECTION_EAST);
				
				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				
				if (pWaterCheck1:IsWater() == false or pWaterCheck2:IsWater() == false or pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pNEPlot:GetIndex());
					table.insert(aPlots, pEPlot:GetIndex());
					return true;
				end
			end

			if (bNWValid  ~= nil and bNEValid ~= nil and bNWValid  == true and bNEValid == true ) then
				pWaterCheck1 = Map.GetAdjacentPlot(pNWPlot:GetX(), pNWPlot:GetY(), DirectionTypes.DIRECTION_NORTHWEST);
				pWaterCheck2 = Map.GetAdjacentPlot(pNEPlot:GetX(), pNEPlot:GetY(), DirectionTypes.DIRECTION_NORTHWEST);
				pWaterCheck3 = Map.GetAdjacentPlot(pNEPlot:GetX(), pNEPlot:GetY(), DirectionTypes.DIRECTION_NORTHEAST);
				
				if ((pWaterCheck1 == nil) or (pWaterCheck2 == nil) or (pWaterCheck3 == nil)) then
					-- Off the edge of the map. This prevents NPE.
					return false;
				end
				
				if (pWaterCheck1:IsWater() == false or pWaterCheck2:IsWater() == false or pWaterCheck3:IsWater() == false) then
					return false;
				else
					table.insert(aPlots, pNWPlot:GetIndex());
					table.insert(aPlots, pNEPlot:GetIndex());
					return true;
				end
			end
		end
	end

	return false;
end

function ResetTerrain(iPlot)
	-- No-op - don't let NW generator mess with terrain.
end

function ResetNaturalWonderTerrain(pPlot)
	-- Call this after running PassMaker on natural wonders.
	local iTerrain = pPlot:GetTerrainType();
	if(iTerrain == g_TERRAIN_TYPE_SNOW_HILLS  or 
	   iTerrain == g_TERRAIN_TYPE_SNOW_MOUNTAIN) then
		TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_SNOW);
		
	elseif(iTerrain == g_TERRAIN_TYPE_DESERT_HILLS  or 
	       iTerrain == g_TERRAIN_TYPE_DESERT_MOUNTAIN) then
		TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_DESERT);
		
	elseif(iTerrain == g_TERRAIN_TYPE_PLAINS_HILLS  or 
	       iTerrain == g_TERRAIN_TYPE_PLAINS_MOUNTAIN) then
		TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_PLAINS);
		
	elseif(iTerrain == g_TERRAIN_TYPE_GRASS_HILLS  or 
	       iTerrain == g_TERRAIN_TYPE_GRASS_MOUNTAIN) then
		TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_GRASS);
		
	elseif(iTerrain == g_TERRAIN_TYPE_TUNDRA_HILLS  or 
	       iTerrain == g_TERRAIN_TYPE_TUNDRA_MOUNTAIN) then
		TerrainBuilder.SetTerrainType(pPlot, g_TERRAIN_TYPE_TUNDRA);
	end
end

function GenerateNaturalWonders()
	print("Adding natural wonders");
	local wonderArgs = 
	{
		numberToPlace = GameInfo.Maps[Map.GetMapSize()].NumNaturalWonders,
	};
	NaturalWonderGenerator.Create(wonderArgs);
		
	-- Recalculate land areas and check for chokepoints 
	-- before adding cliffs.
	AreaBuilder.Recalculate();
end
------------------------------------------------------------------------------
-- Cliffs
------------------------------------------------------------------------------
function SetCliff(iX, iY)
	local pPlot = Map.GetPlot(iX,iY);

	for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
		local adjacentPlot = Map.GetAdjacentPlot(iX, iY, direction);
		if (adjacentPlot ~= nil) then
			if (adjacentPlot:IsWater() == true) then
				if(direction == DirectionTypes.DIRECTION_NORTHEAST) then
					TerrainBuilder.SetNEOfCliff(adjacentPlot, true);
				elseif(direction == DirectionTypes.DIRECTION_EAST) then
					TerrainBuilder.SetWOfCliff(pPlot, true); 
				elseif(direction == DirectionTypes.DIRECTION_SOUTHEAST) then
					TerrainBuilder.SetNWOfCliff(pPlot, true); 
				elseif(direction == DirectionTypes.DIRECTION_SOUTHWEST) then
					TerrainBuilder.SetNEOfCliff(pPlot, true); 
				elseif(direction == DirectionTypes.DIRECTION_WEST) then
					TerrainBuilder.SetWOfCliff(adjacentPlot, true); 
				elseif(direction == DirectionTypes.DIRECTION_NORTHWEST) then
					TerrainBuilder.SetNWOfCliff(adjacentPlot, true); 
				end
			end
		end
	end
end

function AddCliffs()
	print("Adding cliffs");
	for iX = 0, g_iW - 1 do
		for iY = 0, g_iH - 1 do	
		
			if (MapGetPlotType(iX,iY) == g_PLOT_TYPE_HILLS and 
				-- Allow cliffs next to lakes or coasts
				IsAdjacentToWater(iX, iY) == true and 
				IsAdjacentToIce(iX, iY)   == false and
				IsAdjacentToRiver(iX, iY) == false) then
				
				local plot = Map.GetPlot(iX, iY);
				local area = plot:GetArea();
				
				-- Don't worry about areas not having flat coast.
				-- Mountain reachability will break cliffs if necessary.
				-- Also, Lakes maps might not have any coast, but just fresh lakes.
				if (area:GetPlotCount() > 1) then
					SetCliff(iX, iY);
				end
			end
		end
	end
end
------------------------------------------------------------------------------
-- Resource Generator overrides
-- Need to declare these before declaring land and climate info.
------------------------------------------------------------------------------
function PlotCanHaveResource(plot, resourceIndex)
	-- A simple test for land resource placement.
	-- Much easier than overriding terrain-resource mappings.
    --
    -- Args:
    --   plot: plot to check
    --   resourceIndex: which resource to validate
    -- Returns: true iff the plot is allowed to have the resource.

    if (UserInput.scraLux == false) then
        -- Scrambled luxuries disabled. Use the default check.
        return ResourceBuilder.CanHaveResource(plot, resourceIndex);
    end
    -- Else use a simple set of rules to decide where the resource can go.
    
	if (plot:IsWater() or plot:IsMountain()) then
		-- Avoid certain plots.
		return false;
	end
	
	local terrainType = plot:GetTerrainType();
	
	if ((terrainType == g_TERRAIN_TYPE_SNOW) or 
		(terrainType == g_TERRAIN_TYPE_SNOW_HILLS)) then
		-- Avoid snow.
		return false;
	end
	
	local featureType = plot:GetFeatureType();
	
	if ((featureType == g_FEATURE_NONE) or
	    (featureType == g_FEATURE_FLOODPLAINS) or
	    (featureType == g_FEATURE_JUNGLE) or
	    (featureType == g_FEATURE_FOREST) or
	    (featureType == g_FEATURE_MARSH)) then
		-- Allow only these features.
		-- Avoid ice and oasis.
		-- Avoid natural wonders, which are special feature types.
		return true;
	end

	return false;
end

function ResourceGenerator:__ValidLuxuryPlots(eContinent)
	-- Custom logic to allow more luxuries on non-normal climates.
	-- go through each plot on the continent and put the luxuries	
	local iSize = #self.aLuxuryType;
	local iBaseScore = 1;
	self.iTotalValidPlots = 0;
	
	local avoidIce = ScriptData.climateInfo.resourcesAvoidIce;

	plots = Map.GetContinentPlots(eContinent);
	for i, plot in ipairs(plots) do
	
		local bCanHaveSomeResource = false;
		local pPlot = Map.GetPlotByIndex(plot);

		if(pPlot~=nil and pPlot:IsWater() == false) then
		
			-- See which resources can appear here
			for iI = 1, iSize do
				local bIce = false;

				if(IsAdjacentToIce(pPlot:GetX(), pPlot:GetY()) == true) then
					bIce = avoidIce;
				end
				
				-- Relax constraints on resource placement.
				if (PlotCanHaveResource(pPlot, self.eResourceType[self.aLuxuryType[iI]]) and (bIce == false)) then
					row = {};
					row.MapIndex = plot;
					row.Score = iBaseScore;

					table.insert (self.aaPossibleLuxLocs[self.aLuxuryType[iI]], row);
					bCanHaveSomeResource = true;
				end
			end


			if (bCanHaveSomeResource == true) then
				self.iTotalValidPlots = self.iTotalValidPlots + 1;
			end
		end
		-- Compute how many of each resource to place
	end

	self.iOccurencesPerFrequency = self.iTargetPercentage / 100 * #plots * self.iLuxuryPercentage / 100 / self.iLuxuriesPerRegion;
end

function ResourceGenerator:__ScoreLuxuryPlots(iResourceIndex, eContinent)
	-- Custom logic to allow more luxuries on non-normal climates.
	-- Clear all earlier entries (some might not be valid if resources have been placed
	for k, v in pairs(self.aaPossibleLuxLocs[iResourceIndex]) do
		self.aaPossibleLuxLocs[iResourceIndex][k] = nil;
	end
	
	local avoidIce = ScriptData.climateInfo.resourcesAvoidIce;

	plots = Map.GetContinentPlots(eContinent);
	for i, plot in ipairs(plots) do
		local pPlot = Map.GetPlotByIndex(plot);
		local bIce = false;
		
		if(IsAdjacentToIce(pPlot:GetX(), pPlot:GetY()) == true) then
			bIce = avoidIce;
		end

		-- Relax constraints on resource placement.
		if (PlotCanHaveResource(pPlot, self.eResourceType[iResourceIndex]) and bIce == false) then
			row = {};
			row.MapIndex = plot;
			row.Score = 500;
			row.Score = row.Score / ((ResourceBuilder.GetAdjacentResourceCount(pPlot) + 1) * 3.75);
			row.Score = row.Score + TerrainBuilder.GetRandomNumber(100, "Resource Placement Score Adjust");
			
			if(ResourceBuilder.GetAdjacentResourceCount(pPlot) <= 1 or #self.aaPossibleLuxLocs == 0) then
					table.insert (self.aaPossibleLuxLocs[iResourceIndex], row);
			end
		end
	end
end

function GenerateResources()
	print("Generating resources (" .. 
		ScriptData.landInfo.name .. " + " .. 
		ScriptData.climateInfo.name .. ").");

	local resourceArgs = 
	{
		resources    = UserInput.resources,
		START_CONFIG = UserInput.start
	};
	local resGen = ResourceGenerator.Create(resourceArgs);
end
------------------------------------------------------------------------------
-- Custom start positioner to handle civ starts on a variety of maps.
--
-- Based on AssignStartingPlots from Civ 5.
------------------------------------------------------------------------------
GotLakes_ASP = {}

function GotLakes_ASP.Create(numCivs)
	-- There are two methods of dividing the map into regions.
	-- Biggest Landmass and Continents. Default method is Continents.
	--
	-- Standard start plot finding uses a regional division method, then
	-- assigns one civ per region. Regions with lowest average fertility
	-- get their assignment first, to avoid the poor getting poorer.
	--
	-- Main data table ("self dot" table).
	--	
	local numCivs = numCivs or PlayerManager.GetAliveMajorsCount();
	
	local findStarts = 
	{
		-- Core Process member methods
		__Init = GotLakes_ASP.__Init,
		ApplyHexAdjustment = GotLakes_ASP.ApplyHexAdjustment,
		GenerateRegions = GotLakes_ASP.GenerateRegions,
		ChooseLocations = GotLakes_ASP.ChooseLocations,
		
		-- Generate Regions member methods
		MeasureStartPlacementFertilityOfPlot = 
			GotLakes_ASP.MeasureStartPlacementFertilityOfPlot,
		MeasureStartPlacementFertilityOfLandmass = 
			GotLakes_ASP.MeasureStartPlacementFertilityOfLandmass,
		RemoveDeadRows = GotLakes_ASP.RemoveDeadRows,
		DivideIntoRegions = GotLakes_ASP.DivideIntoRegions,
		ChopIntoThreeRegions = GotLakes_ASP.ChopIntoThreeRegions,
		ChopIntoTwoRegions = GotLakes_ASP.ChopIntoTwoRegions,

		-- Choose Locations member methods
		MeasureTerrainInRegions = GotLakes_ASP.MeasureTerrainInRegions,
		PlaceImpactAndRipples = GotLakes_ASP.PlaceImpactAndRipples,
		MeasureSinglePlot = GotLakes_ASP.MeasureSinglePlot,
		EvaluateCandidatePlot = GotLakes_ASP.EvaluateCandidatePlot,
		IterateThroughCandidatePlotList = GotLakes_ASP.IterateThroughCandidatePlotList,
		FindStart = GotLakes_ASP.FindStart,
		
		-- Civ start position variables
		-- Stores x and y coordinates (and "score") of starting plots for civs, 
		-- indexed by region number
		startingPlots = {},		
		iNumCivs = numCivs,		-- Number of land civs at game start
		-- Stores table of NextToSaltWater plots to reduce redundant calculations
		plotDataIsCoastal = {},		
		-- Stores table of TwoAwayFromSaltWater plots to reduce redundant calculations
		plotDataIsNextToCoast = {},
		regionData = {},				-- Stores data returned from regional division algorithm
		regionTerrainCounts = {},		-- Stores counts of terrain elements for all regions
		-- Stores "impact and ripple" data of start points as each is placed
		distanceData = table.fill(0, g_numTiles), 
		
		-- Positioner defaults. 
		-- These are the controls for the "Center Bias" placement method for civ starts.
		centerBias = 34, -- % of radius from region center to examine first
		middleBias = 67, -- % of radius from region center to check second

		-- Hex Adjustment tables. These tables direct plot by plot scans in a radius 
		-- around a center hex, starting to Northeast, moving clockwise.
		firstRingYIsEven = {{0, 1}, {1, 0}, {0, -1}, {-1, -1}, {-1, 0}, {-1, 1}},
		secondRingYIsEven = {
		{1, 2}, {1, 1}, {2, 0}, {1, -1}, {1, -2}, {0, -2},
		{-1, -2}, {-2, -1}, {-2, 0}, {-2, 1}, {-1, 2}, {0, 2}
		},
		thirdRingYIsEven = {
		{1, 3}, {2, 2}, {2, 1}, {3, 0}, {2, -1}, {2, -2},
		{1, -3}, {0, -3}, {-1, -3}, {-2, -3}, {-2, -2}, {-3, -1},
		{-3, 0}, {-3, 1}, {-2, 2}, {-2, 3}, {-1, 3}, {0, 3}
		},
		firstRingYIsOdd = {{1, 1}, {1, 0}, {1, -1}, {0, -1}, {-1, 0}, {0, 1}},
		secondRingYIsOdd = {		
		{1, 2}, {2, 1}, {2, 0}, {2, -1}, {1, -2}, {0, -2},
		{-1, -2}, {-1, -1}, {-2, 0}, {-1, 1}, {-1, 2}, {0, 2}
		},
		thirdRingYIsOdd = {		
		{2, 3}, {2, 2}, {3, 1}, {3, 0}, {3, -1}, {2, -2},
		{2, -3}, {1, -3}, {0, -3}, {-1, -3}, {-2, -2}, {-2, -1},
		{-3, 0}, {-2, 1}, {-2, 2}, {-1, 3}, {0, 3}, {1, 3}
		},
	}
	
	findStarts:__Init()
	
	return findStarts
end

function GotLakes_ASP:__Init()
	-- Set up data tables that record whether a plot is coastal land and whether a plot is 
	-- adjacent to coastal land.
	self.plotDataIsCoastal, self.plotDataIsNextToCoast = GenerateNextToCoastalLandDataTables();
end

function GotLakes_ASP:ApplyHexAdjustment(x, y, plot_adjustments)
	-- Used this bit of code so many times, I had to make it a function.
	local adjusted_x, adjusted_y;
	if ScriptData.wrapX == true then
		adjusted_x = (x + plot_adjustments[1]) % g_iW;
	else
		adjusted_x = x + plot_adjustments[1];
	end
	if ScriptData.wrapY == true then
		adjusted_y = (y + plot_adjustments[2]) % g_iH;
	else
		adjusted_y = y + plot_adjustments[2];
	end
	return adjusted_x, adjusted_y;
end
------------------------------------------------------------------------------
-- Start of functions tied to GenerateRegions()
------------------------------------------------------------------------------
function GotLakes_ASP:MeasureStartPlacementFertilityOfPlot(x, y)
	-- Fertility of plots is used to divide continents or areas into Regions.
	-- Regions are used to assign starting plots and place some resources.
	-- Usage: x, y are plot coords, with 0,0 in SW. The check is a boolean.
	--
	-- We want players who start in temperate terrain to have the least room to expand.
	local plot = Map.GetPlot(x, y);
	
	if (not IsPassableLand(plot)) then
		-- Not a valid location for a city.
		return 0;
	end

	-- Start at 3 so that the lowest possible measured fertility is 0.
	local plotFertility = 3;
	
	local terrainType = plot:GetTerrainType();
	local featureType = plot:GetFeatureType();
	
	if plot:IsNaturalWonder() then
		-- Treat passable-land natural wonders as fertile.
		plotFertility = plotFertility + 5;
	end
	
	if IsAdjacentToMountain(x, y) then
		-- Mountains add useful adjacency bonuses to land plots.
		plotFertility = plotFertility + 1;
	end
	
	local numAdjacentVolcanoes = CountAdjacentVolcanoes(x,y);
	if (numAdjacentVolcanoes == 1) then
		-- Volcanoes are even more useful than regular mountains...
		plotFertility = plotFertility + 1;
		
	elseif (numAdjacentVolcanoes > 1) then
		-- However, multiple adjacent volcanoes is probably too hazardous.
		plotFertility = plotFertility - 1;
	end

	if plot:IsRiver() then
		-- River: fresh water access and watermill-capable.
		plotFertility = plotFertility + 2;
		
	elseif IsAdjacentToNonIceLake(x,y) then
		-- Access to fresh water improves housing for land plots.
		plotFertility = plotFertility + 1;
	end

	-- At this point, the plot is land/hills.
	if plot:IsHills() then
		-- Hills add production, which is a bonus for most terrains.
		plotFertility = plotFertility + 1;
	end
	
	if IsBaseTerrainType(g_TERRAIN_TYPE_GRASS, terrainType) then
		-- Grassland: 2 for flat, 3 for hills.
		plotFertility = plotFertility + 2;
		
	elseif IsBaseTerrainType(g_TERRAIN_TYPE_PLAINS, terrainType) then
		-- Plains: 3 for flat, 2 for hills.
		plotFertility = plotFertility + 3;
		if plot:IsHills() then
			-- Cancel out hills bonus.
			plotFertility = plotFertility - 2;
		end
		
	elseif (IsBaseTerrainType(g_TERRAIN_TYPE_TUNDRA, terrainType)) then
		-- Tundra: bad, but not as bad as snow/desert.
		plotFertility = plotFertility - 1;
		
	elseif (IsBaseTerrainType(g_TERRAIN_TYPE_SNOW, terrainType) or 
	        IsBaseTerrainType(g_TERRAIN_TYPE_DESERT, terrainType)) then
		-- Featureless flat snow/desert is barren, 
		-- but don't rule out the possibility of starting here.
		plotFertility = plotFertility - 2;
	end

	if featureType == g_FEATURE_FOREST then
		plotFertility = plotFertility + 1;
		
	elseif featureType == g_FEATURE_JUNGLE then
		plotFertility = plotFertility + 1;
		
	elseif featureType == g_FEATURE_MARSH then
		plotFertility = plotFertility + 1;
		
	elseif (featureType == g_FEATURE_OASIS) then
		plotFertility = plotFertility + 5;
	
	elseif (featureType == g_FEATURE_FLOOD_PLAINS) then 
		plotFertility = plotFertility + 5;
		
	elseif (g_FEATURE_FLOODPLAINS_GRASSLAND and 
			(featureType == g_FEATURE_FLOODPLAINS_GRASSLAND)) then
		plotFertility = plotFertility + 5;

	elseif (g_FEATURE_FLOODPLAINS_PLAINS and    
			(featureType == g_FEATURE_FLOODPLAINS_PLAINS)) then
		plotFertility = plotFertility + 5;
		
	elseif (g_FEATURE_GEOTHERMAL_FISSURE and 
	        (featureType == g_FEATURE_GEOTHERMAL_FISSURE)) then
		plotFertility = plotFertility + 1;
	end
	
	if plot:IsCoastalLand() then
		plotFertility = plotFertility + 1;
	end

	return plotFertility;
end

function GotLakes_ASP:MeasureStartPlacementFertilityOfLandmass(
	iAreaID, iWestX, iEastX, iSouthY, iNorthY, wrapsX, wrapsY)
	-- This function is designed to provide initial data for regional division recursion.
	-- Loop through plots in this landmass and measure Fertility Rating.
	-- Results will include a data table of all plots within the rectangle that includes 
	-- the entirety of this landmass.
	--
	-- This function will account for any wrapping around the world this landmass may do.
	--
	-- Args:
	--   iAreaID: area ID of the landmass to measure
	--   iWestX, iEastX, iSouthY, iNorthY: bounding box of the landmass
	--   wrapsX: whether the landmass wraps across the east/west edge of the map
	--   wrapsY: whether the landmass wraps across the north/south edge of the map
	-- Returns:
	--   areaFertilityTable: a list of plot fertilities (one value for each plot in the 
	--     bounding box).
	--   areaFertilityCount: landmass fertility as the sum of all plot fertilities.
	--   plotCount: number of plots in the rectangle
	--   areaPlotCount: number of plots that are part of the landmass
	
	-- These coordinates will be used in case of wrapping landmass, 
	-- extending the landmass "off the map", in to imaginary space 
	-- to process it. Modulo math will correct the coordinates for 
	-- accessing the plot data array.
	local xEnd, yEnd; 
	
	if wrapsX then
		xEnd = iEastX + g_iW;
	else
		xEnd = iEastX;
	end
	if wrapsY then
		yEnd = iNorthY + g_iH;
	else
		yEnd = iNorthY;
	end
	--
	--print("Measuring start placement fertility for regional division.");
	
	local areaFertilityTable = {};
	local areaFertilityCount = 0;
	local plotCount     = 0; -- total plots in rectangle
	local areaPlotCount = 0; -- total plots with matching area ID
	-- When generating a plot data table incrementally, 
	-- process Y first so that plots go row by row.
	for yLoop = iSouthY, yEnd do
		for xLoop = iWestX, xEnd do
			plotCount = plotCount + 1;
			local x = xLoop % g_iW;
			local y = yLoop % g_iH;
			local plot = Map.GetPlot(x, y);
			local thisPlotsArea =plot:GetArea():GetID();
			if thisPlotsArea ~= iAreaID then
				-- This plot is not a member of the landmass, set value to 0
				table.insert(areaFertilityTable, 0);
			else -- This plot is a member, process it.
				local plotFertility = self:MeasureStartPlacementFertilityOfPlot(x, y);
				table.insert(areaFertilityTable, plotFertility);
				areaPlotCount      = areaPlotCount      + 1;
				areaFertilityCount = areaFertilityCount + plotFertility;
			end
		end
	end
	
	-- Note: The table accounts for world wrap, so make sure to translate its index correctly.
	-- Plots in the table run from the southwest corner along the bottom row, 
	-- then upward row by row, per normal plot data indexing.
	return areaFertilityTable, areaFertilityCount, plotCount, areaPlotCount;
end

function GotLakes_ASP:RemoveDeadRows(fertility_table, iWestX, iSouthY, iWidth, iHeight)
	-- Any outside rows in the fertility table of a just-divided region that 
	-- contains all zeroes can be safely removed.
	-- This will improve the accuracy of operations involving any applicable region.
	local adjusted_table = {};
	local adjusted_WestX;
	local adjusted_SouthY
	local adjusted_Width
	local adjusted_Height;
	
	-- Check for rows to remove on the bottom.
	local adjustSouth = 0;
	for y = 0, iHeight - 1 do
		local bKeepThisRow = false;
		for x = 0, iWidth - 1 do
			local i = y * iWidth + x + 1;
			if fertility_table[i] ~= 0 then
				bKeepThisRow = true;
				break
			end
		end
		if bKeepThisRow == true then
			break
		else
			adjustSouth = adjustSouth + 1;
		end
	end

	-- Check for rows to remove on the top.
	local adjustNorth = 0;
	for y = iHeight - 1, 0, -1 do
		local bKeepThisRow = false;
		for x = 0, iWidth - 1 do
			local i = y * iWidth + x + 1;
			if fertility_table[i] ~= 0 then
				bKeepThisRow = true;
				break
			end
		end
		if bKeepThisRow == true then
			break
		else
			adjustNorth = adjustNorth + 1;
		end
	end

	-- Check for columns to remove on the left.
	local adjustWest = 0;
	for x = 0, iWidth - 1 do
		local bKeepThisColumn = false;
		for y = 0, iHeight - 1 do
			local i = y * iWidth + x + 1;
			if fertility_table[i] ~= 0 then
				bKeepThisColumn = true;
				break
			end
		end
		if bKeepThisColumn == true then
			break
		else
			adjustWest = adjustWest + 1;
		end
	end

	-- Check for columns to remove on the right.
	local adjustEast = 0;
	for x = iWidth - 1, 0, -1 do
		local bKeepThisColumn = false;
		for y = 0, iHeight - 1 do
			local i = y * iWidth + x + 1;
			if fertility_table[i] ~= 0 then
				bKeepThisColumn = true;
				break
			end
		end
		if bKeepThisColumn == true then
			break
		else
			adjustEast = adjustEast + 1;
		end
	end

	if adjustSouth > 0 or adjustNorth > 0 or adjustWest > 0 or adjustEast > 0 then
		-- Truncate this region to remove dead rows.
		adjusted_WestX = (iWestX + adjustWest) % g_iW;
		adjusted_SouthY = (iSouthY + adjustSouth) % g_iH;
		adjusted_Width = (iWidth - adjustWest) - adjustEast;
		adjusted_Height = (iHeight - adjustSouth) - adjustNorth;
		-- Reconstruct fertility table. This must be done row by row, so process Y coord first.
		for y = 0, adjusted_Height - 1 do
			for x = 0, adjusted_Width - 1 do
				local i = (y + adjustSouth) * iWidth + (x + adjustWest) + 1;
				local plotFert = fertility_table[i];
				table.insert(adjusted_table, plotFert);
			end
		end
		--[[
		print("-");
		print("Removed Dead Rows, West: ", adjustWest, " East: ", adjustEast);
		print("Removed Dead Rows, South: ", adjustSouth, " North: ", adjustNorth);
		print("-");
		print("Incoming values: ", iWestX, iSouthY, iWidth, iHeight);
		print("Outgoing values: ", adjusted_WestX, adjusted_SouthY, adjusted_Width, adjusted_Height);
		print("-");
		local incoming_index = table.maxn(fertility_table);
		local outgoing_index = table.maxn(adjusted_table);
		print("Size of incoming fertility table: ", incoming_index);
		print("Size of outgoing fertility table: ", outgoing_index);
		--]]
		return adjusted_table, adjusted_WestX, adjusted_SouthY, adjusted_Width, adjusted_Height;
	
	else -- Region not adjusted, return original values unaltered.
		return fertility_table, iWestX, iSouthY, iWidth, iHeight;
	end
end

function GotLakes_ASP:DivideIntoRegions(iNumDivisions, fertility_table, rectangle_data_table)
	-- This is a recursive algorithm. (Original concept and implementation by Ed Beach).
	--
	-- Fertility table is a plot data array including data for all plots to be processed here.
	-- The fertility table is obtained as part of the MeasureFertility functions, or via 
	-- division during the recursion.
	--
	-- Rectangle table includes seven data fields:
	-- westX, southY, width, height, AreaID, fertilityCount, plotCount
	--
	-- If AreaID is -1, it means the rectangle contains fertility data from all plots 
	-- regardless of their AreaIDs. The plotCount is an absolute count of plots within the 
	-- rectangle, without regard to AreaID membership. This is going to purposely reduce 
	-- average fertility per plot for Order-of-Assignment priority. Rectangles with a lot 
	-- of non-member plots will tend to be misshapen and need to be on the favorable side 
	-- of minDistance elements.
	
	-- If this rectangle is not to be divided, break recursion and record the data.
	if (iNumDivisions <= 1) then -- This area is to be defined as a Region.
		-- Expand rectangle table to include an eighth field for average fertility per plot.
		-- fertilityCount/plotCount
		local fAverageFertility = rectangle_data_table[6] / rectangle_data_table[7];
		table.insert(rectangle_data_table, fAverageFertility);
		-- Insert this record in to the instance data for start placement regions for this game.
		-- (This is the crux of the entire regional definition process, 
		-- determining an actual region.)
		table.insert(self.regionData, rectangle_data_table);
		--[[
		local iNumberOfThisRegion = table.maxn(self.regionData);
		print("-");
		print("---------------------------------------------");
		print("Defined location of Start Region #", iNumberOfThisRegion);
		print("---------------------------------------------");
		print("-");
		--]]
		return;
	end
	
	-- Divide this rectangle into iNumDivisions worth of subdivisions, then send each
	-- subdivision back through this function in a recursive loop.
	--print("DivideIntoRegions: Need " .. iNumDivisions .. " regions.");
		
	local firstSubdivisions = 0;
	local laterSubdivisions = 0;
	
	-- See if region is taller or wider.
	local iWidth  = Round(rectangle_data_table[3]);
	local iHeight = Round(rectangle_data_table[4]);
	local bTaller = false;
	if iHeight > iWidth then
		bTaller = true;
	end

	if ((iNumDivisions % 2) == 0) then
		-- Even number of divisions, so divide evenly in half.	
		firstSubdivisions = iNumDivisions / 2;
		laterSubdivisions = firstSubdivisions;
		--print("DivideIntoRegions: even split => 2 x " .. firstSubdivisions);
		
		-- Undershoot by design, to compensate for inevitable overshoot. 
		-- Gets the actual result closer to target.
		chopPercent = 49.5;
		
	elseif ((iNumDivisions % 3) == 0) then
		-- Multiple of 3, so divide evenly into thirds.
		local iSubdivisions = iNumDivisions / 3;
		--print("DivideIntoRegions: even split => 3 x " .. iSubdivisions);

		local results = self:ChopIntoThreeRegions(fertility_table, rectangle_data_table, bTaller);
		local first_section_fertility_table = results[1];
		local first_section_data_table = results[2];
		local second_section_fertility_table = results[3];
		local second_section_data_table = results[4];
		local third_section_fertility_table = results[5];
		local third_section_data_table = results[6];
		
		self:DivideIntoRegions(
			iSubdivisions, first_section_fertility_table, first_section_data_table)
		self:DivideIntoRegions(
			iSubdivisions, second_section_fertility_table, second_section_data_table)
		self:DivideIntoRegions(
			iSubdivisions, third_section_fertility_table, third_section_data_table)
		return;
		
	else
		-- Not divisible by 2 or 3, so do an uneven split into two regions.
		firstSubdivisions = math.floor(iNumDivisions/2);
		laterSubdivisions = firstSubdivisions + 1;

		--print("DivideIntoRegions: uneven split => " .. firstSubdivisions .. " + " .. laterSubdivisions);
		
		-- These chopPercents are all set to undershoot slightly, 
		-- averaging out the actual result closer to target.
		chopPercent = 98 * (firstSubdivisions / iNumDivisions);
	end
	
	-- Chop into two pieces, either evenly or unevenly.
	local results = self:ChopIntoTwoRegions(
		fertility_table, rectangle_data_table, bTaller, chopPercent);
	local first_section_fertility_table = results[1];
	local first_section_data_table = results[2];
	local second_section_fertility_table = results[3];
	local second_section_data_table = results[4];
	
	self:DivideIntoRegions(
		firstSubdivisions, first_section_fertility_table, first_section_data_table)
	self:DivideIntoRegions(
		laterSubdivisions, second_section_fertility_table, second_section_data_table)
end

function GotLakes_ASP:ChopIntoThreeRegions(fertility_table, rectangle_data_table, bTaller)
	--print("-"); print("ChopIntoThree called.");
	-- Performs the mechanics of dividing a region into three roughly equal fertility subregions.
	local results = {};

	-- Chop off the first third.
	-- Undershoot by a bit, tends to make the actual result closer to accurate.
	local initial_results = self:ChopIntoTwoRegions(fertility_table, rectangle_data_table, bTaller, 33);
	-- add first subdivision to results
	local temptable = initial_results[1];
	table.insert(results, temptable); 

	--[[ Activate table printouts for debug purposes only, then deactivate when done. ]]--
	--print("Data returned to ChopIntoThree from ChopIntoTwo.");
	--PrintContentsOfTable(temptable)

	local temptable = initial_results[2];
	table.insert(results, temptable);

	--PrintContentsOfTable(temptable)

	-- Prepare the remainder for further processing.
	local second_section_fertility_table = initial_results[3]; 

	--PrintContentsOfTable(second_section_fertility_table)

	local second_section_data_table = initial_results[4];

	--PrintContentsOfTable(second_section_data_table)
	--print("End of this instance, ChopIntoThree tables.");

	-- See if this piece is taller or wider. (Ed's original implementation skipped this step).
	local bTallerForRemainder = false;
	local width = second_section_data_table[3];
	local height = second_section_data_table[4];
	if height > width then
		bTallerForRemainder = true;
	end

	-- Chop the bigger piece in half.
	-- Undershoot just a little.
	local interim_results = self:ChopIntoTwoRegions(
		second_section_fertility_table, second_section_data_table, bTallerForRemainder, 48.5);
	table.insert(results, interim_results[1]); 
	table.insert(results, interim_results[2]); 
	table.insert(results, interim_results[3]); 
	table.insert(results, interim_results[4]); 

	--[[ Returns a table of six entries, each of which is a nested table.
	1: fertility_table of first subdivision
	2: rectangle_data_table of first subdivision.
	3: fertility_table of second subdivision
	4: rectangle_data_table of second subdivision.
	5: fertility_table of third subdivision
	6: rectangle_data_table of third subdivision.  ]]--
	return results
end

function GotLakes_ASP:ChopIntoTwoRegions(
	fertility_table, rectangle_data_table, bTaller, chopPercent)
	-- Performs the mechanics of dividing a region into two subregions.
	--
	-- Fertility table is a plot data array including data for all plots to be processed here.
	-- This data already factors any need for processing AreaID.
	--
	-- Rectangle table includes seven data fields:
	-- westX, southY, width, height, AreaID, fertilityCount, plotCount
	--print("-"); print("ChopIntoTwo called.");

	--[[ Log dump of incoming table data. Activate for debug only.
	print("Data tables passed to ChopIntoTwoRegions.");
	PrintContentsOfTable(fertility_table)
	PrintContentsOfTable(rectangle_data_table)
	print("End of this instance, ChopIntoTwoRegions tables.");
	--]]--

	-- Read the incoming data table.
	local iWestX      = Round(rectangle_data_table[1]);
	local iSouthY     = Round(rectangle_data_table[2]);
	local iRectWidth  = Round(rectangle_data_table[3]);
	local iRectHeight = Round(rectangle_data_table[4]);
	local iAreaID = rectangle_data_table[5];
	local iTargetFertility = rectangle_data_table[6] * chopPercent / 100;
	
	-- Now divide the region.
	--
	-- West and South edges remain the same for first region.
	local firstRegionWestX = iWestX;
	local firstRegionSouthY = iSouthY;
	-- scope variables that get decided conditionally.
	local firstRegionWidth, firstRegionHeight;
	local secondRegionWestX, secondRegionSouthY, secondRegionWidth, secondRegionHeight;
	local iFirstRegionFertility = 0;
	local iSecondRegionFertility = 0;
	local region_one_fertility = {};
	local region_two_fertility = {};

	if (bTaller) then -- We will divide horizontally, resulting in first region on bottom, second on top.
		--
		-- Width for both will remain the same as the parent rectangle.
		firstRegionWidth = iRectWidth;
		secondRegionWestX = iWestX;
		secondRegionWidth = iRectWidth;

		-- Measure one row at a time, moving up from bottom, until we have exceeded the target fertility.
		local reachedTargetRow = false;
		local rectY = 0;
		while reachedTargetRow == false do
			-- Process the next row in line.
			for rectX = 0, iRectWidth - 1 do
				local fertIndex = rectY * iRectWidth + rectX + 1;
				local plotFertility = fertility_table[fertIndex] or 0;
				-- Add this plot's fertility to the region total so far.
				iFirstRegionFertility = iFirstRegionFertility + plotFertility;
				-- Record this plot in a new fertility table. (Needed for further subdivisions).
				-- Note, building this plot data table incrementally, so it must go row by row.
				table.insert(region_one_fertility, plotFertility);
			end
			if iFirstRegionFertility >= iTargetFertility then
				-- This row has completed the region.
				firstRegionHeight = rectY + 1;
				secondRegionSouthY = (iSouthY + rectY + 1) % g_iH;
				secondRegionHeight = iRectHeight - firstRegionHeight;
				reachedTargetRow = true;
				break
			else
				rectY = rectY + 1;
			end
		end
		
		-- Debug printout of division location.
		--print("Dividing along horizontal line between rows: ", secondRegionSouthY - 1, "-", secondRegionSouthY);
		
		-- Create the fertility table for the second region, the one on top.
		-- Data must be added row by row, to keep the table index behavior consistent.
		for rectY = firstRegionHeight, iRectHeight - 1 do
			for rectX = 0, iRectWidth - 1 do
				local fertIndex = rectY * iRectWidth + rectX + 1;
				local plotFertility = fertility_table[fertIndex] or 0;
				-- Add this plot's fertility to the region total so far.
				iSecondRegionFertility = iSecondRegionFertility + plotFertility;
				-- Record this plot in a new fertility table. (Needed for further subdivisions).
				-- Note, building this plot data table incrementally, so it must go row by row.
				table.insert(region_two_fertility, plotFertility);
			end
		end
				
	else -- We will divide vertically, resulting in first region on left, second on right.
		--
		-- Height for both will remain the same as the parent rectangle.
		firstRegionHeight = iRectHeight;
		secondRegionSouthY = iSouthY;
		secondRegionHeight = iRectHeight;
		
		--[[ First region's new fertility table will be a little tricky. We don't know how many 
		     table entries it will need beforehand, and we cannot add the entries sequentially
		     when the data is being generated column by column, yet the table index needs to 
		     proceed row by row. So we will have to make a second pass.  ]]--

		-- Measure one column at a time, moving left to right, until we have exceeded the target fertility.
		local reachedTargetColumn = false;
		local rectX = 0;
		while reachedTargetColumn == false do
			-- Process the next column in line.
			for rectY = 0, iRectHeight - 1 do
				local fertIndex = rectY * iRectWidth + rectX + 1;
				local plotFertility = fertility_table[fertIndex] or 0;
				-- Add this plot's fertility to the region total so far.
				iFirstRegionFertility = iFirstRegionFertility + plotFertility;
				-- No table record here, handle later row by row.
			end
			if iFirstRegionFertility >= iTargetFertility then
				-- This column has completed the region.
				firstRegionWidth = rectX + 1;
				secondRegionWestX = (iWestX + rectX + 1) % g_iW;
				secondRegionWidth = iRectWidth - firstRegionWidth;
				reachedTargetColumn = true;
				break
			else
				rectX = rectX + 1;
			end
		end

		-- Debug printout of division location.
		--print("Dividing along vertical line between columns: ", secondRegionWestX - 1, "-", secondRegionWestX);

		-- Create the fertility table for the second region, the one on the right.
		-- Data must be added row by row, to keep the table index behavior consistent.
		for rectY = 0, iRectHeight - 1 do
			for rectX = firstRegionWidth, iRectWidth - 1 do
				local fertIndex = rectY * iRectWidth + rectX + 1;
				local plotFertility = fertility_table[fertIndex];
				-- Add this plot's fertility to the region total so far.
				iSecondRegionFertility = iSecondRegionFertility + plotFertility;
				-- Record this plot in a new fertility table. (Needed for further subdivisions).
				-- Note, building this plot data table incrementally, so it must go row by row.
				table.insert(region_two_fertility, plotFertility);
			end
		end
		-- Now create the fertility table for the first region.
		for rectY = 0, iRectHeight - 1 do
			for rectX = 0, firstRegionWidth - 1 do
				local fertIndex = rectY * iRectWidth + rectX + 1;
				local plotFertility = fertility_table[fertIndex];
				table.insert(region_one_fertility, plotFertility);
			end
		end
	end
	
	-- Now check the newly divided regions for dead rows (all zero values) along
	-- the edges and remove any found.
	--
	-- First region
	local FRFertT, FRWX, FRSY, FRWid, FRHei;
	FRFertT, FRWX, FRSY, FRWid, FRHei = self:RemoveDeadRows(region_one_fertility,
		firstRegionWestX, firstRegionSouthY, firstRegionWidth, firstRegionHeight);
	--
	-- Second region
	local SRFertT, SRWX, SRSY, SRWid, SRHei;
	SRFertT, SRWX, SRSY, SRWid, SRHei = self:RemoveDeadRows(region_two_fertility,
		secondRegionWestX, secondRegionSouthY, secondRegionWidth, secondRegionHeight);
	--
	
	-- Generate the data tables that record the location of the new subdivisions.
	local firstPlots = FRWid * FRHei;
	local secondPlots = SRWid * SRHei;
	local region_one_data = {FRWX, FRSY, FRWid, FRHei, iAreaID, iFirstRegionFertility, firstPlots};
	local region_two_data = {SRWX, SRSY, SRWid, SRHei, iAreaID, iSecondRegionFertility, secondPlots};
	-- Generate the final data.
	local outcome = {FRFertT, region_one_data, SRFertT, region_two_data};
	return outcome
end

function GotLakes_ASP:GenerateRegions(startMinY, startMaxY)
	print("GotLakes ASP: Dividing the map into Regions");
	-- This function stores its data in the instance (self) data table.
	--
	-- The "Three Methods" of regional division:
	-- 1. Biggest Landmass: All civs start on the biggest landmass.
	-- 2. Continental: Civs are assigned to continents. Any continents with more than one civ 
	--                 are divided.
	-- 3. Rectangular: Civs start within a given rectangle that spans the whole map, without 
	--                 regard to landmass sizes. This method is primarily applied to Archipelago 
	--                 and other maps with lots of tiny islands.

	-- Determine number of civilizations present in this game.
	print("Generating regions for " .. self.iNumCivs .. " civ(s).");

	-- NOTE: these dimensions need to be whole numbers 
	-- or else indexing failures can occur.
	local minX = 0;
	local maxX = g_iW - 1;
	
	-- Y bounds: initially as percent of height for avoiding starts near the poles.
	local minY = startMinY or 0;
	local maxY = startMaxY or 100;
	
	-- Convert percentages into plot lengths.
	minY = Round(minY * 0.01 * g_iH);
	maxY = Round(maxY * 0.01 * g_iH);
	
	minY = math.clamp(minY, 0,    g_iH-1);
	maxY = math.clamp(maxY, minY, g_iH-1);
	
	self.minX = minX;
	self.minY = minY;
	self.maxX = maxX;
	self.maxY = maxY;
	
	if ScriptData.landInfo.aspDivMethod == DIVMETHOD_BIGGESTLAND then -- Biggest Landmass
		print("Division Method: biggest landmass");
		-- Identify the biggest landmass.
		local biggest_area = Areas.FindBiggestArea(False);
		local iAreaID = biggest_area:GetID();
		-- We'll need all eight data fields returned in the results table from the boundary finder:
		local landmass_data = ObtainLandmassBoundaries(iAreaID, minX, minY, maxX, maxY);
		local iWestX = landmass_data[1];
		local iSouthY = landmass_data[2];
		local iEastX = landmass_data[3];
		local iNorthY = landmass_data[4];
		local iWidth = landmass_data[5];
		local iHeight = landmass_data[6];
		local wrapsX = landmass_data[7];
		local wrapsY = landmass_data[8];
		
		-- Obtain "Start Placement Fertility" of the landmass. (This measurement is customized 
		-- for start placement). This call returns a table recording fertility of all plots 
		-- within a rectangle that contains the landmass, with a zero value for any plots not 
		-- part of the landmass -- plus a fertility sum and plot count.
		local fert_table, fertCount, plotCount = 
			self:MeasureStartPlacementFertilityOfLandmass(
				iAreaID, iWestX, iEastX, iSouthY, iNorthY, wrapsX, wrapsY);
		-- Now divide this landmass in to regions, one per civ.
		-- The regional divider requires three arguments:
		-- 1. Number of divisions. (For "Biggest Landmass" this means number of civs in the game).
		-- 2. Fertility table. (This was obtained from the last call.)
		-- 3. Rectangle table. This table includes seven data fields:
		-- westX, southY, width, height, AreaID, fertilityCount, plotCount
		-- This is why we got the fertCount and plotCount from the fertility function.
		--
		-- Assemble the Rectangle data table:
		local rect_table = {iWestX, iSouthY, iWidth, iHeight, iAreaID, fertCount, plotCount};
		-- The data from this call is processed in to self.regionData during the process.
		self:DivideIntoRegions(self.iNumCivs, fert_table, rect_table)
		-- The regions have been defined.
	
	else -- Continental.
		print("Division Method: continental");
		-- Loop through all plots on the map, measuring fertility of each land 
		-- plot, identifying its AreaID, building a list of landmass AreaIDs, and
		-- tallying the Start Placement Fertility for each landmass.

		-- region_data: [WestX, EastX, SouthY, NorthY, 
		-- numLandPlotsinRegion, numCoastalPlotsinRegion,
		-- numOceanPlotsinRegion, iRegionNetYield, 
		-- iNumLandAreas, iNumPlotsinRegion]
		local best_areas = {};
		local globalFertilityOfLands = {};

		-- Obtain info on all landmasses for comparision purposes.
		local iGlobalFertilityOfLands = 0;
		local iNumLandPlots = 0;
		local iNumLandAreas = 0;
		local land_area_IDs = {};
		local land_area_plots = {};
		local land_area_fert = {};
		-- Cycle through all plots in the bounding box, checking their Start Placement Fertility 
		-- and AreaID.
		for x = minX, maxX do
			for y = minY, maxY do
				local i = y * g_iW + x + 1;
				local plot = Map.GetPlot(x, y);
				if not plot:IsWater() then -- Land plot, process it.
					iNumLandPlots = iNumLandPlots + 1;
					local iArea = plot:GetArea():GetID();
					local plotFertility = self:MeasureStartPlacementFertilityOfPlot(x, y);
					iGlobalFertilityOfLands = iGlobalFertilityOfLands + plotFertility;
					-- This plot is the first detected in its AreaID.
					if TestMembership(land_area_IDs, iArea) == false then 
						iNumLandAreas = iNumLandAreas + 1;
						table.insert(land_area_IDs, iArea);
						land_area_plots[iArea] = 1;
						land_area_fert[iArea] = plotFertility;
					else -- This AreaID already known.
						land_area_plots[iArea] = land_area_plots[iArea] + 1;
						land_area_fert[iArea] = land_area_fert[iArea] + plotFertility;
					end
				end
			end
		end
				
		-- Sort areas, achieving a list of AreaIDs with best areas first.
		--
		-- Fertility data in land_area_fert is stored with areaID index keys.
		-- Need to generate a version of this table with indices of 1 to n, where n is number of 
		-- land areas.
		local interim_table = {};
		for loop_index, data_entry in pairs(land_area_fert) do
			table.insert(interim_table, data_entry);
		end
		
		-- Sort the fertility values stored in the interim table. Sort order in Lua is lowest to 
		-- highest.
		table.sort(interim_table);

		--[[
		for AreaID, fert in ipairs(interim_table) do
			print("Interim Table ID " .. AreaID .. " has fertility of " .. fert);
		end
		print("* * * * * * * * * *");
		--]]

		-- If less players than landmasses, we will ignore the extra landmasses.
		local iNumRelevantLandAreas = math.min(iNumLandAreas, self.iNumCivs);
		-- Now re-match the AreaID numbers with their corresponding fertility values
		-- by comparing the original fertility table with the sorted interim table.
		-- During this comparison, best_areas will be constructed from sorted AreaIDs, richest 
		-- stored first.
		local best_areas = {};
		-- Currently, the best yields are at the end of the interim table. We need to step 
		-- backward from there.
		local end_of_interim_table = table.maxn(interim_table);
		-- We may not need all entries in the table. Process only iNumRelevantLandAreas worth of 
		-- table entries.
		local fertility_value_list = {};
		local fertility_value_tie = false;
		for tableConstructionLoop = end_of_interim_table, 
			(end_of_interim_table - iNumRelevantLandAreas + 1), -1 do
			if TestMembership(
				fertility_value_list, interim_table[tableConstructionLoop]) == true then
				fertility_value_tie = true;
				--print("*** WARNING: Fertility Value Tie exists! ***");
			else
				table.insert(fertility_value_list, interim_table[tableConstructionLoop]);
			end
		end

		-- No ties, so no need of special handling for ties.
		if fertility_value_tie == false then 
			for areaTestLoop = end_of_interim_table, 
				(end_of_interim_table - iNumRelevantLandAreas + 1), -1 do
				for loop_index, AreaID in ipairs(land_area_IDs) do
					if interim_table[areaTestLoop] == 
						land_area_fert[land_area_IDs[loop_index]] then
						table.insert(best_areas, AreaID);
						break
					end
				end
			end
		else 
			-- Ties exist! Special handling required to protect against a 
			-- shortfall in the number of defined regions.
			local iNumUniqueFertValues = table.maxn(fertility_value_list);
			for fertLoop = 1, iNumUniqueFertValues do
				for AreaID, fert in pairs(land_area_fert) do
					if fert == fertility_value_list[fertLoop] then
						-- Add ties only if there is room!
						local best_areas_length = table.maxn(best_areas);
						if best_areas_length < iNumRelevantLandAreas then
							table.insert(best_areas, AreaID);
						else
							break
						end
					end
				end
			end
		end
				
		--[[ Debug printout
		print("-"); print("--- Continental Division, Initial Readout ---"); print("-");
		print("- Global Fertility:", iGlobalFertilityOfLands);
		print("- Total Land Plots:", iNumLandPlots);
		print("- Total Areas:", iNumLandAreas);
		print("- Relevant Areas:", iNumRelevantLandAreas); print("-");
		--
		print("* * * * * * * * * *");
		for area_loop, AreaID in ipairs(best_areas) do
			print("Area ID " .. AreaID .. " has fertility of " .. land_area_fert[AreaID]);
		end
		print("* * * * * * * * * *");
		--]]

		-- Assign continents to receive start plots. Record number of civs assigned to each 
		-- landmass.
		-- Use a padding multiplier to add slight bias towards civs on separate continents
		-- over civs sharing a continent.
		local civPaddingMult = 1.05;
		local inhabitedAreaIDs = {};
		-- Indexed in synch with best_areas. Use same index to match values from each table.
		local numberOfCivsPerArea = table.fill(0, iNumRelevantLandAreas); 
		for civToAssign = 1, self.iNumCivs do
			local bestRemainingArea;
			local bestRemainingFertility = 0;
			local bestAreaTableIndex;
			-- Loop through areas, find the one with the best remaining fertility (civs added 
			-- to a landmass reduces its fertility rating for subsequent civs).
			--
			--print("- - Searching landmasses in order to place Civ #", civToAssign);
			for area_loop, AreaID in ipairs(best_areas) do
				local thisLandmassCurrentFertility = 
					land_area_fert[AreaID] / 
					(1 + (civPaddingMult * numberOfCivsPerArea[area_loop]));
				if thisLandmassCurrentFertility > bestRemainingFertility then
					bestRemainingArea = AreaID;
					bestRemainingFertility = thisLandmassCurrentFertility;
					bestAreaTableIndex = area_loop;
					--
				end
			end
			-- Record results for this pass. (A landmass has been assigned to receive 
			-- one more start point than it previously had).
			numberOfCivsPerArea[bestAreaTableIndex] = numberOfCivsPerArea[bestAreaTableIndex] + 1;
			if TestMembership(inhabitedAreaIDs, bestRemainingArea) == false then
				table.insert(inhabitedAreaIDs, bestRemainingArea);
			end
		end
		
		--[[
		print("*** Number of Civs per Landmass - Table Readout ***");
		PrintContentsOfTable(numberOfCivsPerArea)
		--]]
			
		-- Loop through the list of inhabited landmasses, dividing each landmass into regions.
		-- Note that it is OK to divide a continent with one civ on it: this will assign the 
		-- whole of the landmass to a single region, and is the easiest method of recording 
		-- such a region.
		local iNumInhabitedLandmasses = table.maxn(inhabitedAreaIDs);
		for loop, currentLandmassID in ipairs(inhabitedAreaIDs) do
			-- Obtain the boundaries of and data for this landmass.
			local landmass_data = 
				ObtainLandmassBoundaries(currentLandmassID, minX, minY, maxX, maxY);
			local iWestX = landmass_data[1];
			local iSouthY = landmass_data[2];
			local iEastX = landmass_data[3];
			local iNorthY = landmass_data[4];
			local iWidth = landmass_data[5];
			local iHeight = landmass_data[6];
			local wrapsX = landmass_data[7];
			local wrapsY = landmass_data[8];
			-- Obtain "Start Placement Fertility" of the current landmass. (Necessary to do this
			-- again because the fert_table can't be built prior to finding boundaries, and we had
			-- to ID the proper landmasses via fertility to be able to figure out their boundaries.
			local fert_table, fertCount, plotCount, areaPlotCount = 
				self:MeasureStartPlacementFertilityOfLandmass(
					currentLandmassID, iWestX, iEastX, iSouthY, iNorthY, wrapsX, wrapsY);
			-- Assemble the rectangle data for this landmass.
			local rect_table = 
			{
				iWestX, iSouthY, iWidth, iHeight, currentLandmassID, fertCount, plotCount
			};
			-- Divide this landmass in to number of regions equal to civs assigned here.
			iNumCivsOnThisLandmass = numberOfCivsPerArea[loop];
			if iNumCivsOnThisLandmass > 0 then -- valid number of civs.
			
				--[ Debug printout for regional division inputs.
				local fertPerPlot = Round(fertCount/math.max(1,areaPlotCount));
				local plotsPerCiv = Round(areaPlotCount/iNumCivsOnThisLandmass);
				local fertPerCiv  = Round(fertCount/iNumCivsOnThisLandmass);
				print("Region #" .. loop .. " => Area #" .. currentLandmassID);
				print("  Relevant Plots: " .. areaPlotCount);
				print("  Relevant Civs:  " .. iNumCivsOnThisLandmass);
				print("  Plots/Civ:      " .. plotsPerCiv);
				print("  Fertility:      " .. fertCount);
				print("  Fertility/Plot: " .. fertPerPlot);
				print("  Fertility/Civ:  " .. fertPerCiv);
				--]]
			
				self:DivideIntoRegions(iNumCivsOnThisLandmass, fert_table, rect_table)
			else
				print("Invalid number of civs assigned to a landmass: ", iNumCivsOnThisLandmass);
			end
		end
		--
		-- The regions have been defined.
	end
	
	--[[ Printout is for debugging only. Deactivate otherwise.
	local tempRegionData = self.regionData;
	for i, data in ipairs(tempRegionData) do
		print("-");
		print("Data for Start Region #", i);
		print("WestX:  ", data[1]);
		print("SouthY: ", data[2]);
		print("Width:  ", data[3]);
		print("Height: ", data[4]);
		print("AreaID: ", data[5]);
		print("Fertility:", data[6]);
		print("Plots:  ", data[7]);
		print("Fert/Plot:", data[8]);
		print("-");
	end
	--]]
end
------------------------------------------------------------------------------
-- Start of functions tied to ChooseLocations()
------------------------------------------------------------------------------
function FindClosestPlot(outer_eligible_list, iWidth, iHeight, iWestX, iSouthY)
	-- Helper method to encapsulate some confusing logic.
	local closestPlot;
	local closestDistance = math.max(g_iW, g_iH);
	local bullseyeX = iWestX + (iWidth / 2);
	if bullseyeX < iWestX then -- wrapped around: un-wrap it for test purposes.
		bullseyeX = bullseyeX + g_iW;
	end
	local bullseyeY = iSouthY + (iHeight / 2);
	if bullseyeY < iSouthY then -- wrapped around: un-wrap it for test purposes.
		bullseyeY = bullseyeY + g_iH;
	end
	if (math.floor(bullseyeY) % 2 == 1) then -- Y coord is odd, add .5 to X coord for hex-shift.
		bullseyeX = bullseyeX + 0.5;
	end
	
	for loop, plotIndex in ipairs(outer_eligible_list) do
		local fx = (plotIndex - 1) % g_iW;
		local fy = math.floor((plotIndex - fx - 1) / g_iW);
		local adjusted_x = fx;
		local adjusted_y = fy;
		if (math.floor(fy) % 2 == 1) then -- Y coord is odd, add .5 to X coord for hex-shift.
			adjusted_x = fx + 0.5;
		end
		
		if fx < iWestX then -- wrapped around: un-wrap it for test purposes.
			adjusted_x = adjusted_x + g_iW;
		end
		if fy < iSouthY then -- wrapped around: un-wrap it for test purposes.
			adjusted_y = fy + g_iH;
		end
		local fDistance = math.sqrt( (adjusted_x - bullseyeX)^2 + (adjusted_y - bullseyeY)^2 );
		if fDistance < closestDistance then -- Found new "closer" plot.
			closestPlot = plotIndex;
			closestDistance = fDistance;
		end
	end
	-- Assign the closest eligible plot as the start point.
	local x = (closestPlot - 1) % g_iW;
	local y = math.floor((closestPlot - x - 1) / g_iW);

	return x, y, closestPlot;
end

function FindPassableForceStart(iWidth, iHeight, iWestX, iSouthY)
	-- Search a region for a start plot that is passable i.e. not a mountain.
	-- Only do this when there are no fallback plots. We're looking for something
	-- better than the bottom-left corner of the region.
	--
	-- Args:
	--   iWidth: width of the region
	--   iHeight: height of the region
	--   iWestX: west edge of the region
	--   iSouthY: bottom edge of the region
	--
	-- Returns: x, y location of the plot
	
	-- Add some randomness to the start location of the scan.
	local iStartX = TerrainBuilder.GetRandomNumber(iWidth,  "X for passable-start search.");
	local iStartY = TerrainBuilder.GetRandomNumber(iHeight, "Y for passable-start search.");
	
	for region_y = 0, iHeight - 1 do -- When handling global plot indices, process Y first.
		for region_x = 0, iWidth - 1 do
		
			local x = ( ((region_x + iStartX) % iWidth)  + iWestX)  % g_iW;
			local y = ( ((region_y + iStartY) % iHeight) + iSouthY) % g_iH;
			local plotIndex = y * g_iW + x + 1;
			local plot = Map.GetPlot(x, y);
			if IsPassableLand(plot) then
				-- Check if plot can host a city.
				print("Found a passable force-start plot at " .. CoordString(x,y));
				return x, y;
			end
		end
	end
	
	print("An entire civ start region at " .. 
		CoordString(iWestX, iSouthY) .. " with dimensions " .. 
		CoordString(iWidth, iHeight) .. " is impassable!");
		
	local hackPlot = Map.GetPlot(iWestX, iSouthY);	
	TerrainBuilder.SetTerrainType(hackPlot, g_TERRAIN_TYPE_GRASS);
	TerrainBuilder.SetFeatureType(hackPlot, g_FEATURE_NONE);	
		
	return iWestX, iSouthY;
end

function GetBiggestPassableLandArea(minX, minY, maxX, maxY)
	-- Determine the largest number of passable land tiles that are reachable
	-- from a plot within the specified rectangle. Ignore all plots outside 
	-- of the rectangle
	--
	-- Args:
	--  minX, minY, maxX, maxY: ignore plots that are beyond this bounding rectangle.
	--
	-- Returns: the largest number of passable land tiles reachable from a plot
	-- within the bounding box, not including any land tiles outside of the bounding
	-- box.
	
	-- Memoize the visitation table to avoid redundant plot counts.
	local visited = table.fill(0, g_numTiles);
		
	local maxNumPlots = 0;
	
	for x = minX, maxX do
		for y = minY, maxY - 1 do
			maxNumPlots = math.max(maxNumPlots, GetPassableLandArea(
				Map.GetPlot(x,y), g_numTiles, minX, minY, maxX, maxY, visited));
		end
	end
	return maxNumPlots;
end

function GetPassableLandArea(
	plot, searchLimitNumTiles, minX, minY, maxX, maxY, plotsVisited)
	-- Count the number of passable land tiles reachable from the specified plot.
	-- Stop searching if we've reached the "big enough" threshold.
	--
	-- Args:
	--  plot: starting plot
	--  searchLimitNumTiles: stop traversing after reaching this many tiles.
	--  minX, minY, maxX, maxY: ignore plots that are beyond this bounding rectangle.
	--  plotsVisited: (optional) map of visited plots
	--
	-- Returns: the number of passable land tiles reachable from the specified
	--          plot, or zero if the plot itself is already-visited or not passable land.
	local visited = plotsVisited or table.fill(0, g_numTiles);
	
	local iX = plot:GetX();
	local iY = plot:GetY();
	local iVisited = iY * g_iW + iX + 1; -- add one because Lua arrays start at 1

	if ((searchLimitNumTiles == nil) or 
	    (IsPassableLand(plot) == false) or 
		(visited[iVisited] ~= 0)) then
		-- Non-passable or already-visited starting plot.
		return 0;
	end
	
	-- Use a stack to search neighboring tiles in DFS order until we've
	-- covered all of the tiles that share the same passable-land area.
	local stack = Stack:Create();
	local count = 0;
	
	stack:Push({x=iX, y=iY});
	visited[iVisited] = 1;
	
	while ((not stack:IsEmpty()) and (count < searchLimitNumTiles)) do
	
		local coord = stack:Pop();
		local x, y = coord.x, coord.y;
		
		-- Increase the tile count.
		count = count + 1;
		
		for i, direction in ipairs(HexDirections) do
			local adjacentPlot = Map.GetAdjacentPlot(x, y, direction);
			
			if (adjacentPlot ~= nil) then
				-- We have an adjacent plot.
				-- Let's see if it's unvisited passable land.
				local aX, aY = adjacentPlot:GetX(), adjacentPlot:GetY();
				local iCouldVisit = aY * g_iW + aX + 1;
			
				if ((IsPassableLand(adjacentPlot) == true) and 
					(visited[iCouldVisit] == 0) and 
					(aX >= minX) and (aX <= maxX) and 
					(aY >= minY) and (aY <= maxY)) then
					-- Add to the stack of plots to visit.
					stack:Push({x=aX, y=aY});
					visited[iCouldVisit] = 1;
				end
			end
		end
	end

	return count;
end

function IsFarFromNaturalWonder(plot)
	-- Returns false if the player can start because there is a natural wonder too close.

	-- If Start position config equals legendary then you can start near Natural wonders
	if(UserInput.start == START_LEGEND) then
		return true;
	end

	local iMaxNW = GlobalParameters.START_DISTANCE_MAJOR_NATURAL_WONDER or 4;

	local plotX = plot:GetX();
	local plotY = plot:GetY();
	for dx = -iMaxNW, iMaxNW do
		for dy = -iMaxNW,iMaxNW do
			local otherPlot = Map.GetPlotXY(plotX, plotY, dx, dy, iMaxNW);
			if(otherPlot and otherPlot:IsNaturalWonder()) then
				return false;
			end
		end
	end 

	return true;
end

function GotLakes_ASP:MeasureTerrainInRegions()
	-- This function stores its data in the instance (self) data table.
	for region_loop, region_data_table in ipairs(self.regionData) do
		local iWestX = region_data_table[1];
		local iSouthY = region_data_table[2];
		local iWidth = region_data_table[3];
		local iHeight = region_data_table[4];
		local iAreaID = region_data_table[5];
		
		local totalPlots, areaPlots = 0, 0;
		local waterCount, flatlandsCount, hillsCount, peaksCount = 0, 0, 0, 0;
		local lakeCount, coastCount, oceanCount, iceCount = 0, 0, 0, 0;
		local grassCount, plainsCount, desertCount = 0, 0, 0; -- counts flatlands only!
		local tundraCount, snowCount = 0, 0;                  -- counts flatlands only!
		local forestCount, jungleCount, marshCount, riverCount = 0, 0, 0, 0;
		local floodplainCount, oasisCount, reefCount = 0, 0, 0;
		local coastalLandCount, nextToCoastCount = 0, 0;

		-- Iterate through the region's plots, getting plotType, terrainType, 
		-- featureType and river status.
		for region_loop_y = 0, iHeight - 1 do
			for region_loop_x = 0, iWidth - 1 do
				totalPlots = totalPlots + 1;
				local x = (region_loop_x + iWestX) % g_iW;
				local y = (region_loop_y + iSouthY) % g_iH;
				local plot = Map.GetPlot(x, y);
				local area_of_plot = plot:GetArea():GetID();
				-- get plot info
				local terrainType = plot:GetTerrainType()
				local featureType = plot:GetFeatureType()
				
				-- Mountain and Ocean plot types get their own AreaIDs, 
				-- but we are going to measure them anyway.
				if plot:IsMountain() then
					-- and that's it for Mountain plots. No other stats.
					peaksCount = peaksCount + 1; 
				elseif plot:IsWater() then
					waterCount = waterCount + 1;
					if terrainType == g_TERRAIN_TYPE_COAST then
						if plot:IsLake() then
							lakeCount = lakeCount + 1;
						else
							coastCount = coastCount + 1;
						end
					else
						oceanCount = oceanCount + 1;
					end
					if featureType == g_FEATURE_ICE then
						iceCount = iceCount + 1;
					elseif g_FEATURE_REEF and (featureType == g_FEATURE_REEF) then
						reefCount = reefCount + 1;
					end

				else
					-- Hills and Flatlands, check plot for region membership. 
					-- Only process this plot if it is a member.
					if (area_of_plot == iAreaID) or (iAreaID == -1) then
						areaPlots = areaPlots + 1;

						-- set up coastalLand and nextToCoast index
						local i = g_iW * y + x + 1;
			
						-- Record plot data
						if plot:IsHills() then
							hillsCount = hillsCount + 1;

							if self.plotDataIsCoastal[i] then
								coastalLandCount = coastalLandCount + 1;
							elseif self.plotDataIsNextToCoast[i] then
								nextToCoastCount = nextToCoastCount + 1;
							end

							if plot:IsRiver() then
								riverCount = riverCount + 1;
							end

							-- Feature check checking for all types, in case features 
							-- are not obeying standard allowances.
							if featureType == g_FEATURE_FOREST then
								forestCount = forestCount + 1;
							elseif featureType == g_FEATURE_JUNGLE then
								jungleCount = jungleCount + 1;
							elseif featureType == g_FEATURE_MARSH then
								marshCount = marshCount + 1;
							elseif featureType == g_FEATURE_FLOODPLAIN then
								floodplainCount = floodplainCount + 1;
							elseif featureType == g_FEATURE_OASIS then
								oasisCount = oasisCount + 1;
							end
								
						else -- Flatlands plot
							flatlandsCount = flatlandsCount + 1;
	
							if self.plotDataIsCoastal[i] then
								coastalLandCount = coastalLandCount + 1;
							elseif self.plotDataIsNextToCoast[i] then
								nextToCoastCount = nextToCoastCount + 1;
							end

							if plot:IsRiver() then
								riverCount = riverCount + 1;
							end
				
							if IsBaseTerrainType(g_TERRAIN_TYPE_GRASS, terrainType) then
								grassCount = grassCount + 1;
							elseif IsBaseTerrainType(g_TERRAIN_TYPE_PLAINS, terrainType) then
								plainsCount = plainsCount + 1;
							elseif IsBaseTerrainType(g_TERRAIN_TYPE_DESERT, terrainType) then
								desertCount = desertCount + 1;
							elseif IsBaseTerrainType(g_TERRAIN_TYPE_TUNDRA, terrainType) then
								tundraCount = tundraCount + 1;
							elseif IsBaseTerrainType(g_TERRAIN_TYPE_SNOW, terrainType) then
								snowCount = snowCount + 1;
							end
				
							-- Feature check checking for all types, in case features 
							-- are not obeying standard allowances.
							if featureType == g_FEATURE_FOREST then
								forestCount = forestCount + 1;
							elseif featureType == g_FEATURE_JUNGLE then
								jungleCount = jungleCount + 1;
							elseif featureType == g_FEATURE_MARSH then
								marshCount = marshCount + 1;
							elseif featureType == g_FEATURE_FLOODPLAIN then
								floodplainCount = floodplainCount + 1;
							elseif featureType == g_FEATURE_OASIS then
								oasisCount = oasisCount + 1;
							end
						end
					end
				end
			end
		end
			
		-- Assemble in to an array the recorded data for this region: 24 variables.
		local regionCounts = {
			totalPlots, areaPlots,
			waterCount, flatlandsCount, hillsCount, peaksCount,
			lakeCount, coastCount, oceanCount, iceCount,
			grassCount, plainsCount, desertCount, tundraCount, snowCount,
			forestCount, jungleCount, marshCount, riverCount, 
			floodplainCount, oasisCount, reefCount,
			coastalLandCount, nextToCoastCount
			}
		--[[ Table Key:
		
		1) totalPlots
		2) areaPlots                 13) desertCount
		3) waterCount                14) tundraCount
		4) flatlandsCount            15) snowCount
		5) hillsCount                16) forestCount
		6) peaksCount                17) jungleCount
		7) lakeCount                 18) marshCount
		8) coastCount                19) riverCount
		9) oceanCount                20) floodplainCount
		10) iceCount                 21) oasisCount
		11) grassCount               22) coastalLandCount
		12) plainsCount              23) nextToCoastCount   ]]--
			
		-- Add array to the data table.
		table.insert(self.regionTerrainCounts, regionCounts);
	end
end

function GotLakes_ASP:PlaceImpactAndRipples(x, y)
	-- To establish a bias of 9, we Impact the overlay and Ripple outward 8 times.
	-- Value of 0 in a plot means no influence from existing Impacts in that plot.
	-- Value of 99 means an Impact occurred in that plot and it IS a start point.
	-- Values > 0 and < 99 are "ripples", meaning that plot is near a start point.
	local wrapX = ScriptData.wrapX;
	local wrapY = ScriptData.wrapY;
	local impact_value = 99;
	local ripple_values = {97, 95, 92, 89, 69, 57, 24, 15};
	local odd = self.firstRingYIsOdd;
	local even = self.firstRingYIsEven;
	local nextX, nextY, plot_adjustments;
	-- Now the main data layer, for start points themselves, and the City State data layer.
	-- Place Impact!
	local impactPlotIndex = y * g_iW + x + 1;
	self.distanceData[impactPlotIndex] = impact_value;
	-- Place Ripples
	for ripple_radius, ripple_value in ipairs(ripple_values) do
		-- Moving clockwise around the ring, the first direction to travel will be Northeast.
		-- This matches the direction-based data in the odd and even tables. Each
		-- subsequent change in direction will correctly match with these tables, too.
		--
		-- Locate the plot within this ripple ring that is due West of the Impact Plot.
		local currentX = x - ripple_radius;
		local currentY = y;
		-- Now loop through the six directions, moving ripple_radius number of times
		-- per direction. At each plot in the ring, add the ripple_value for that ring 
		-- to the plot's entry in the distance data table.
		for direction_index = 1, 6 do
			for plot_to_handle = 1, ripple_radius do
				-- Must account for hex factor.
			 	if currentY / 2 > math.floor(currentY / 2) then -- Current Y is odd. Use odd table.
					plot_adjustments = odd[direction_index];
				else -- Current Y is even. Use plot adjustments from even table.
					plot_adjustments = even[direction_index];
				end
				-- Identify the next plot in the ring.
				nextX = currentX + plot_adjustments[1];
				nextY = currentY + plot_adjustments[2];
				-- Make sure the plot exists
				if wrapX == false and (nextX < 0 or nextX >= g_iW) then -- X is out of bounds.
					-- Do not add ripple data to this plot.
				elseif wrapY == false and (nextY < 0 or nextY >= g_iH) then -- Y is out of bounds.
					-- Do not add ripple data to this plot.
				else -- Plot is in bounds, process it.
					-- Handle any world wrap.
					local realX = nextX;
					local realY = nextY;
					if wrapX == true then
						realX = realX % g_iW;
					end
					if wrapY == true then
						realY = realY % g_iH;
					end
					-- Record ripple data for this plot.
					local ringPlotIndex = realY * g_iW + realX + 1;
					if self.distanceData[ringPlotIndex] > 0 then -- This plot is already in range of at least one other civ!
						-- First choose the greater of the two, existing value or current ripple.
						local stronger_value = math.max(self.distanceData[ringPlotIndex], ripple_value);
						-- Now increase it by 1.2x to reflect that multiple civs are in range of this plot.
						local overlap_value = math.min(97, math.floor(stronger_value * 1.2));
						self.distanceData[ringPlotIndex] = overlap_value;
					else
						self.distanceData[ringPlotIndex] = ripple_value;
					end
				end
				currentX, currentY = nextX, nextY;
			end
		end
	end
end

function GotLakes_ASP:MeasureSinglePlot(x, y)
	-- Note that "food" and "prod" not strictly about tile yield
	-- Also account for potential for improvement.
	--
	-- Returns:
	--   isFood: if the plot is a source of food
	--   isProd: if the plot is a source of production
	--   goodness: number of nice-to-have points.
	--   isJunk: if the plot is barren/unworkable
	local plot = Map.GetPlot(x, y);
	local plotIsHills = plot:IsHills();
	local terrainType = plot:GetTerrainType();
	local featureType = plot:GetFeatureType();
	local isFood = false;
	local isProd = false;
	local goodness = 0;
	local isJunk = false;
		
	if plot:IsMountain() then
		-- Wonder mountains and volcanoes are good. Regular unreachable mountains are junk.
		if (plot:IsNaturalWonder() or IsVolcano(plot)) then
			goodness = goodness + 1;
		end
		
		isJunk = (goodness <= 0) and (not IsAdjacentToPassableLand(plot));
		return isFood, isProd, goodness, isJunk;
		
	elseif plot:IsWater() then
		if featureType == g_FEATURE_ICE then
			-- Ice is barren and impassble, so junk.
			isJunk = true;
		elseif (featureType ~= g_FEATURE_NONE) then
			-- Got a non-ice feature, which could be a natural wonder.
			goodness = goodness + 1;
			if g_FEATURE_REEF and (featureType == g_FEATURE_REEF) then
				isFood = true;
				isProd = true;
			end
		elseif plot:IsLake() then
			-- Lakes themselves are not good, but adjacent land might be good.
			isFood = true;
		elseif terrainType == g_TERRAIN_TYPE_COAST then
			isFood = true;
		else
			-- Ocean tiles are neither good nor junk.
		end
		return isFood, isProd, goodness, isJunk;
	end
	-- At this point, the plot is either land or hills.

	-- Hills add production to all land terrain.
	isProd = plotIsHills;
	
	if (featureType ~= g_FEATURE_NONE) then
		-- Got a feature, which could be a natural wonder.
		-- All land features are good regardless of terrain.
		goodness = goodness + 1;
		if featureType == g_FEATURE_JUNGLE then
			isFood = true;
		elseif featureType == g_FEATURE_FOREST then
			isProd = true;
		elseif featureType == g_FEATURE_OASIS then
			isFood = true;
		elseif featureType == g_FEATURE_FLOOD_PLAINS then
			isFood = true;	
		elseif g_FEATURE_FLOODPLAINS_GRASSLAND and 
			   (featureType == g_FEATURE_FLOODPLAINS_GRASSLAND) then
			isFood = true;	
				
		elseif g_FEATURE_FLOODPLAINS_PLAINS and    
			   (featureType == g_FEATURE_FLOODPLAINS_PLAINS) then
			isFood = true;
			
		elseif g_FEATURE_GEOTHERMAL_FISSURE and 
			   (featureType == g_FEATURE_GEOTHERMAL_FISSURE) then
			-- Neither food nor prod; +1 goodness is enough
		
		elseif featureType == g_FEATURE_MARSH then
			isFood = true;
		end
	end
	
	if IsBaseTerrainType(g_TERRAIN_TYPE_DESERT, terrainType) then
		-- Desert is junk if featureless.
		isJunk = (featureType == g_FEATURE_NONE);
		
	elseif IsBaseTerrainType(g_TERRAIN_TYPE_SNOW, terrainType) then
		-- Snow is junk unless it's a snow-asis.
		isJunk = (featureType ~= g_FEATURE_OASIS);

	elseif IsBaseTerrainType(g_TERRAIN_TYPE_TUNDRA, terrainType) then
		-- Tundra by itself is not junk, but not good either.
		-- Not farmable, so not enough food to count as a food source.

	elseif IsBaseTerrainType(g_TERRAIN_TYPE_PLAINS, terrainType) then
		-- Plains are always prod, but also food if flat.
		isFood = isFood or (not plotIsHills);
		isProd = true;
		goodness = goodness + 2;

	elseif IsBaseTerrainType(g_TERRAIN_TYPE_GRASS, terrainType) then
		-- Grass is always food (also prod if hills).
		isFood = true;
		goodness = goodness + 2;
	end
	
	if (not isJunk) then
		-- Additional checks for non-junk land/hill tiles.
		if IsAdjacentToMountain(x, y) then
			goodness = goodness + 1;
			
			local numAdjacentVolcanoes = CountAdjacentVolcanoes(x,y);
			if (numAdjacentVolcanoes == 1) then
				-- Volcanoes are even more useful than regular mountains...
				goodness = goodness + 1;
				
			elseif (numAdjacentVolcanoes > 1) then
				-- However, multiple adjacent volcanoes is probably too hazardous.
				goodness = goodness - 1;
			end
		end
		
		-- Let mountain goodness stack with fresh-water goodness.
		if plot:IsRiver() then
			-- Rivers offer fresh water and allow water mill.
			goodness = goodness + 2;
			
		elseif IsAdjacentToNonIceLake(x,y) then
			-- Lakes offer fresh water, but no water mill
			goodness = goodness + 1;
		end
	end

	return isFood, isProd, goodness, isJunk;
end

function GotLakes_ASP:EvaluateCandidatePlot(plotIndex)
	local goodSoFar = true;
	local reason = "I dunno...";
	local x = (plotIndex - 1) % g_iW;
	local y = math.floor((plotIndex - x - 1) / g_iW);
	local plot = Map.GetPlot(x, y);
	local isEvenY = true;
	if ((y % 2) == 1) then
		isEvenY = false;
	end
	local wrapX = ScriptData.wrapX;
	local wrapY = ScriptData.wrapY;
	local distance_bias = self.distanceData[plotIndex];
	local foodTotal, prodTotal, goodTotal, junkTotal = 0, 0, 0, 0;
	local plotScore = 0;
	local search_table = {};
	local junkMult = 4;
	
	-- Evaluate the plot itself.
	local isFood, isProd, goodness, isJunk = self:MeasureSinglePlot(x, y);
	if isJunk then
		-- The plot itself is junk.
		plotScore = -60;
		goodSoFar = false;
		reason = "junk plot";
	else
		-- Amplify goodness of the plot itself.
		plotScore = plotScore + (13 * goodness);
	end
		
	-- Evaluate First Ring
	if isEvenY then
		search_table = self.firstRingYIsEven;
	else
		search_table = self.firstRingYIsOdd;
	end

	for loop, plot_adjustments in ipairs(search_table) do
		local searchX, searchY;
		if wrapX then
			searchX = (x + plot_adjustments[1]) % g_iW;
		else
			searchX = x + plot_adjustments[1];
		end
		if wrapY then
			searchY = (y + plot_adjustments[2]) % g_iH;
		else
			searchY = y + plot_adjustments[2];
		end
		--
		if searchX < 0 or searchX >= g_iW or searchY < 0 or searchY >= g_iH then
			-- This plot does not exist. It's off the map edge.
			junkTotal = junkTotal + 1;
		else
			local isFood, isProd, goodness, isJunk = 
				self:MeasureSinglePlot(searchX, searchY)
			if isJunk then
				junkTotal = junkTotal + 1;
			end
			if isFood then
				foodTotal = foodTotal + 1;
			end
			if isProd then
				prodTotal = prodTotal + 1;
			end
			goodTotal = goodTotal + goodness;
		end
	end

	-- Set up the "score" for this candidate. Inner ring results weigh the heaviest.
	local weightedFoodInner = {0, 8, 14, 19, 22, 24, 25};
	local foodResultInner = weightedFoodInner[foodTotal + 1];
	local weightedProdInner = {0, 10, 16, 20, 20, 12, 0};
	local prodResultInner = weightedProdInner[prodTotal + 1];
	local goodResultInner = goodTotal * 2;
	local innerRingScore = 
		foodResultInner + prodResultInner + goodResultInner - (junkTotal * junkMult);
	
	-- Evaluate Second Ring
	if isEvenY then
		search_table = self.secondRingYIsEven;
	else
		search_table = self.secondRingYIsOdd;
	end

	for loop, plot_adjustments in ipairs(search_table) do
		local searchX, searchY;
		if wrapX then
			searchX = (x + plot_adjustments[1]) % g_iW;
		else
			searchX = x + plot_adjustments[1];
		end
		if wrapY then
			searchY = (y + plot_adjustments[2]) % g_iH;
		else
			searchY = y + plot_adjustments[2];
		end
		if searchX < 0 or searchX >= g_iW or searchY < 0 or searchY >= g_iH then
			-- This plot does not exist. It's off the map edge.
			junkTotal = junkTotal + 1;
		else
			local isFood, isProd, goodness, isJunk = 
				self:MeasureSinglePlot(searchX, searchY)
			if isJunk then
				junkTotal = junkTotal + 1;
			end
			if isFood then
				foodTotal = foodTotal + 1;
			end
			if isProd then
				prodTotal = prodTotal + 1;
			end
			goodTotal = goodTotal + goodness;
		end
	end
	
	-- Update up the "score" for this candidate. Middle ring results weigh significantly.
	-- 35 for any further values.
	local weightedFoodMiddle = {0, 2, 5, 10, 20, 25, 28, 30, 32, 34, 35};
	local foodResultMiddle = 35;
	if foodTotal < 10 then
		foodResultMiddle = weightedFoodMiddle[foodTotal + 1];
	end
	local weightedProdMiddle = {0, 10, 20, 25, 30, 35}; -- 35 for any further values.
	local effectiveProdTotal = prodTotal;
	if foodTotal * 2 < prodTotal then
		effectiveProdTotal = math.ceil(foodTotal / 2);
	end
	local prodResultMiddle = 35;
	if effectiveProdTotal < 5 then
		prodResultMiddle = weightedProdMiddle[effectiveProdTotal + 1];
	end
	local goodResultMiddle = goodTotal * 2;
	local middleRingScore = 
		foodResultMiddle + 
		prodResultMiddle + 
		goodResultMiddle - 
		(junkTotal * junkMult);
	
	-- Evaluate Third Ring
	if isEvenY then
		search_table = self.thirdRingYIsEven;
	else
		search_table = self.thirdRingYIsOdd;
	end

	for loop, plot_adjustments in ipairs(search_table) do
		local searchX, searchY;
		if wrapX then
			searchX = (x + plot_adjustments[1]) % g_iW;
		else
			searchX = x + plot_adjustments[1];
		end
		if wrapY then
			searchY = (y + plot_adjustments[2]) % g_iH;
		else
			searchY = y + plot_adjustments[2];
		end
		if searchX < 0 or searchX >= g_iW or searchY < 0 or searchY >= g_iH then
			-- This plot does not exist. It's off the map edge.
			junkTotal = junkTotal + 1;
		else
			local isFood, isProd, goodness, isJunk = 
				self:MeasureSinglePlot(searchX, searchY)
			if isJunk then
				junkTotal = junkTotal + 1;
			end
			if isFood then
				foodTotal = foodTotal + 1;
			end
			if isProd then
				prodTotal = prodTotal + 1;
			end
			goodTotal = goodTotal + goodness;
		end
	end

	-- Tally the final "score" for this candidate.
	local outerRingScore = foodTotal + prodTotal + goodTotal - (junkTotal * (junkMult-1));
	local finalScore = plotScore + innerRingScore + middleRingScore + outerRingScore;

	-- Check Impact and Ripple data to see if candidate is near an already-placed start point.
	if distance_bias > 0 then
		-- This candidate is near an already placed start. This invalidates its 
		-- eligibility for first-pass placement; but it may still qualify as a 
		-- fallback site, so we will reduce its Score according to the bias factor.
		goodSoFar = false;
		reason = "other civ nearby";
		finalScore = finalScore - math.floor(finalScore * distance_bias / 100);
	end
	
	-- Get the size in tiles of the land-chunk that owns this plot.
	-- This can be less than plot:GetArea():GetPlotCount() 
	-- due to mountains making other tiles unreachable by land.
	local plotAreaNumTiles = GetPassableLandArea(
		plot, self.majorStartMinLandSize, self.minX, self.minY, self.maxX, self.maxY);
	
	if (plotAreaNumTiles < self.majorStartMinLandSize) then
		-- This island is less than a small fraction of the biggest land-chunk's size.
		--print("Downgrading tiny-island plot at " .. CoordString(plot:GetX(),plot:GetY()) ..
		--	" which can only reach " .. plotAreaNumTiles .. " tile(s).");
		finalScore = finalScore - 40;	
	end
	
	-- Avoid plots that have no access to fresh water.
	if ((not plot:IsWater()) and 
	    (not plot:IsMountain()) and
		(not plot:IsRiver()) and
		(not IsAdjacentToNonIceLake(x,y))) then
		--print("Downgrading non-fresh plot at " .. CoordString(plot:GetX(),plot:GetY()));
		goodSoFar = false;
		reason = "no fresh water besides ice";
		finalScore = finalScore - 40;	
	end
	
	if (not IsFarFromNaturalWonder(plot)) then
		-- The plot is too close to a natural wonder.
		-- Downgrade to discourage starting too close to the wonder.
		finalScore = finalScore - 80;
	end

	--[[ Debug
	print(".");
	print("Plot:", x, y, " Food:", foodTotal, "Prod: ", prodTotal, "Good:", goodTotal, "Junk:", 
	       junkTotal, "Score:", finalScore);
	print("Plot:", x, y, " Coastal:", self.plotDataIsCoastal[plotIndex], "Distance Bias:", distance_bias);
	--]]
	
	return finalScore, goodSoFar, reason;
end

function GotLakes_ASP:IterateThroughCandidatePlotList(plot_list)
	-- Iterates through a list of candidate plots.
	-- Each plot is identified by its global plot index.
	-- This function assumes all candidate plots can have a city built on them.
	-- Any plots not allowed to have a city should be weeded out when building the candidate list.
	local found_eligible = false;
	local bestPlotScore = -5000;
	local bestPlotIndex;
	local found_fallback = false;
	local bestFallbackScore = -5000;
	local bestFallbackIndex = -1;
	local bestFallbackReason = "";
	-- Process list of candidate plots.
	for loop, plotIndex in ipairs(plot_list) do
		local score, meets_minimums, fallbackReason = self:EvaluateCandidatePlot(plotIndex);
		-- Test current plot against best known plot.
		if meets_minimums == true then
			found_eligible = true;
			if score > bestPlotScore then
				bestPlotScore = score;
				bestPlotIndex = plotIndex;
			end
		else
			if ((not found_fallback) or (score > bestFallbackScore)) then
				found_fallback = true;
				bestFallbackScore = score;
				bestFallbackIndex = plotIndex;
				bestFallbackReason = fallbackReason;
			end
		end
	end
	local election_results = 
	{	
		found_eligible,     -- bool
		bestPlotScore,      -- int
		bestPlotIndex,      -- int
		found_fallback,     -- bool
		bestFallbackScore,  -- int
		bestFallbackIndex,  -- int
		bestFallbackReason  -- string
	};
	return election_results
end

function GotLakes_ASP:FindStart(region_number)
	-- This function attempts to choose a start position for a single region.
	-- This function returns two boolean flags, indicating the success level of the operation.
	local bSuccessFlag = false; -- Returns true when a start is placed, false when process fails.
	-- Returns true if this region had no eligible starts and one was forced to occur.
	local bForcedPlacementFlag = false; 
	
	-- Obtain data needed to process this region.
	
	local region_data_table = self.regionData[region_number];
	local iWestX = region_data_table[1];
	local iSouthY = region_data_table[2];
	local iWidth = region_data_table[3];
	local iHeight = region_data_table[4];
	local iAreaID = region_data_table[5];
	local iMembershipEastX = iWestX + iWidth - 1;
	local iMembershipNorthY = iSouthY + iHeight - 1;
	--
	-- Done setting up region data.
	-- Set up contingency.
	local fallback_plots = {};
	
	print("Looking for start between " .. CoordString(iWestX, iSouthY) .. 
		  " and " .. CoordString(iWestX+iWidth-1, iSouthY+iHeight-1) .. 
		  " with region size " .. CoordString(iWidth, iHeight));
	
	-- Establish scope of center bias.
	local fCenterWidth = (self.centerBias / 100) * iWidth;
	local iNonCenterWidth = math.floor((iWidth - fCenterWidth) / 2)
	local iCenterWidth = iWidth - (iNonCenterWidth * 2);
	-- Modulo math to synch coordinate to actual map in case of world wrap.
	local iCenterWestX = (iWestX + iNonCenterWidth) % g_iW;
	-- "Test" values ignore world wrap for easier membership testing.
	local iCenterTestWestX = (iWestX + iNonCenterWidth);
	local iCenterTestEastX = (iCenterWestX + iCenterWidth - 1);

	local fCenterHeight = (self.centerBias / 100) * iHeight;
	local iNonCenterHeight = math.floor((iHeight - fCenterHeight) / 2)
	local iCenterHeight = iHeight - (iNonCenterHeight * 2);
	local iCenterSouthY = (iSouthY + iNonCenterHeight) % g_iH;
	local iCenterTestSouthY = (iSouthY + iNonCenterHeight);
	local iCenterTestNorthY = (iCenterTestSouthY + iCenterHeight - 1);

	-- Establish scope of "middle donut", outside the center but inside the outer.
	local fMiddleWidth = (self.middleBias / 100) * iWidth;
	local iOuterWidth = math.floor((iWidth - fMiddleWidth) / 2)
	local iMiddleWidth = iWidth - (iOuterWidth * 2);
	local iMiddleWestX = (iWestX + iOuterWidth) % g_iW;
	local iMiddleTestWestX = (iWestX + iOuterWidth);
	local iMiddleTestEastX = (iMiddleTestWestX + iMiddleWidth - 1);

	local fMiddleHeight = (self.middleBias / 100) * iHeight;
	local iOuterHeight = math.floor((iHeight - fMiddleHeight) / 2)
	local iMiddleHeight = iHeight - (iOuterHeight * 2);
	local iMiddleSouthY = (iSouthY + iOuterHeight) % g_iH;
	local iMiddleTestSouthY = (iSouthY + iOuterHeight);
	local iMiddleTestNorthY = (iMiddleTestSouthY + iMiddleHeight - 1); 

	-- Assemble candidates lists.
	local iNumCenter        = 0;
	local center_river      = {};
	local center_coastal    = {};
	local center_inland_dry = {};
	local iNumMiddle        = 0;
	local middle_river      = {};
	local middle_coastal    = {};
	local middle_inland_dry = {};
	local outer_plots       = {};
	
	-- Identify candidate plots.
	for region_y = 0, iHeight - 1 do -- When handling global plot indices, process Y first.
		for region_x = 0, iWidth - 1 do
			-- Actual coords, adjusted for world wrap, if any.
			local x = (region_x + iWestX) % g_iW; 
			local y = (region_y + iSouthY) % g_iH; --
			local plotIndex = y * g_iW + x + 1;
			local plot = Map.GetPlot(x, y);
			
			if IsPassableLand(plot) then 
				-- Could host a city.
				local area_of_plot = plot:GetArea():GetID();
				if area_of_plot == iAreaID or iAreaID == -1 then
					-- This plot is a member, so it goes on at least one candidate list.
					--
					-- Test whether plot is in center bias, middle donut, or outer donut.
					--
					-- "Test" coords, ignoring any world wrap and
					-- reaching in to virtual space if necessary.
					local test_x = region_x + iWestX; 
					local test_y = region_y + iSouthY;
					if (test_x >= iCenterTestWestX and test_x <= iCenterTestEastX) and 
					   (test_y >= iCenterTestSouthY and test_y <= iCenterTestNorthY) then
						-- Center Bias.
						iNumCenter = iNumCenter + 1;
						if plot:IsRiver() then
							table.insert(center_river, plotIndex);
						elseif plot:IsFreshWater() or 
							   self.plotDataIsCoastal[plotIndex] == true then
							table.insert(center_coastal, plotIndex);
						else
							table.insert(center_inland_dry, plotIndex);
						end
					elseif (test_x >= iMiddleTestWestX and test_x <= iMiddleTestEastX) and 
						   (test_y >= iMiddleTestSouthY and test_y <= iMiddleTestNorthY) then
						iNumMiddle = iNumMiddle + 1;
						if plot:IsRiver() then
							table.insert(middle_river, plotIndex);
						elseif plot:IsFreshWater() or 
							   self.plotDataIsCoastal[plotIndex] == true then
							table.insert(middle_coastal, plotIndex);
						else
							table.insert(middle_inland_dry, plotIndex);
						end
					else
						table.insert(outer_plots, plotIndex);
					end
				end
			end
		end
	end

	-- Check how many plots landed on each list.
	local iNumCenterRiver     = table.maxn(center_river);
	local iNumCenterCoastLake = table.maxn(center_coastal);
	local iNumCenterInlandDry = table.maxn(center_inland_dry);
	local iNumMiddleRiver     = table.maxn(middle_river);
	local iNumMiddleCoastLake = table.maxn(middle_coastal);
	local iNumMiddleInlandDry = table.maxn(middle_inland_dry);
	local iNumOuter           = table.maxn(outer_plots);
	
	-- Process lists of candidate plots.
	if iNumCenter + iNumMiddle > 0 then
		local candidate_lists = {};
		if iNumCenterRiver > 0 then -- Process center bias river plots.
			table.insert(candidate_lists, center_river);
		end
		if iNumMiddleRiver > 0 then -- Process middle donut river plots.
			table.insert(candidate_lists, middle_river);
		end
		if iNumCenterCoastLake > 0 then -- Process center bias lake or coastal plots.
			table.insert(candidate_lists, center_coastal);
		end
		if iNumMiddleCoastLake > 0 then -- Process middle donut lake or coastal plots.
			table.insert(candidate_lists, middle_coastal);
		end
		if iNumCenterInlandDry > 0 then -- Process center bias inland dry plots.
			table.insert(candidate_lists, center_inland_dry);
		end
		if iNumMiddleInlandDry > 0 then -- Process middle donut inland dry plots.
			table.insert(candidate_lists, middle_inland_dry);
		end
		--
		for loop, plot_list in ipairs(candidate_lists) do 
			-- Up to six plot lists, processed by priority.
			local election_returns = self:IterateThroughCandidatePlotList(plot_list)
			-- If any candidates are eligible, choose one.
			local found_eligible = election_returns[1];
			if found_eligible then
				local bestPlotScore = election_returns[2]; 
				local bestPlotIndex = election_returns[3];
				local x = (bestPlotIndex - 1) % g_iW;
				local y = math.floor((bestPlotIndex - x - 1) / g_iW);
				self.startingPlots[region_number] = {x, y, bestPlotScore, "OK"};
				self:PlaceImpactAndRipples(x, y)
				return true, false
			end
			-- If none eligible, check for fallback plot.
			local found_fallback = election_returns[4];
			if found_fallback then
				local bestFallbackScore = election_returns[5];
				local bestFallbackIndex = election_returns[6];
				local bestFallbackReason = election_returns[7];
				local x = (bestFallbackIndex - 1) % g_iW;
				local y = math.floor((bestFallbackIndex - x - 1) / g_iW);
				table.insert(fallback_plots, {x, y, bestFallbackScore, bestFallbackReason});
			end
		end
	end
	-- Reaching this point means no eligible sites in center bias or middle donut subregions!
	
	-- Process candidates from Outer subregion, if any.
	if iNumOuter > 0 then	
		local outer_eligible_list = {};
		local found_eligible = false;
		local found_fallback = false;
		local bestFallbackScore = -5000;
		local bestFallbackIndex = -1;
		local bestFallbackReason = "";
		-- Process list of candidate plots.
		for loop, plotIndex in ipairs(outer_plots) do
			local score, meets_minimums, fallbackReason = self:EvaluateCandidatePlot(plotIndex)
			-- Test current plot against best known plot.
			if meets_minimums == true then
				found_eligible = true;
				table.insert(outer_eligible_list, plotIndex);
			else
				if ((not found_fallback) or (score > bestFallbackScore)) then
					found_fallback = true;
					bestFallbackScore = score;
					bestFallbackIndex = plotIndex;
					bestFallbackReason = fallbackReason;
				end
			end
		end
		if found_eligible then 
			-- Iterate through eligible plots and choose the one 
			-- closest to the center of the region.
			local x, y, closestPlot = FindClosestPlot(
				outer_eligible_list, iWidth, iHeight, iWestX, iSouthY);
			-- Re-get plot score for inclusion in start plot data.
			local score = self:EvaluateCandidatePlot(closestPlot);
			-- Assign this plot as the start for this region.
			self.startingPlots[region_number] = {x, y, score, "OK"};
			self:PlaceImpactAndRipples(x, y)
			return true, false
		end
		-- Add the fallback plot (best scored plot) from the Outer region to the fallback list.
		if found_fallback then
			local x = (bestFallbackIndex - 1) % g_iW;
			local y = math.floor((bestFallbackIndex - x - 1) / g_iW);
			table.insert(fallback_plots, {x, y, bestFallbackScore, bestFallbackReason});
		end
	end
	-- Reaching here means no plot in the entire region met the minimum standards for selection.
	
	-- The fallback plot contains the best-scored plots from each test area in this region.
	-- We will compare all the fallback plots and choose the best to be the start plot.
	local iNumFallbacks = table.maxn(fallback_plots);
	if iNumFallbacks > 0 then
		local gotFallback = false;
		local best_fallback_score = -50000;
		local best_fallback_x;
		local best_fallback_y;
		local best_fallback_reason = "";
		for loop, plotData in ipairs(fallback_plots) do
			local score = plotData[3];
			if score > best_fallback_score then
				gotFallback = true;
				best_fallback_score = score;
				best_fallback_x = plotData[1];
				best_fallback_y = plotData[2];
				best_fallback_reason = plotData[4];
			end
		end
        
        if gotFallback then
            -- Assign the start for this region.
            self.startingPlots[region_number] = 
			{
				best_fallback_x, 
				best_fallback_y, 
				best_fallback_score,
				"Fallback - " .. best_fallback_reason
			};
            self:PlaceImpactAndRipples(best_fallback_x, best_fallback_y)
            bSuccessFlag = true;
        else
            -- We didn't have any *good* fallbacks.
            iNumFallbacks = 0;
        end
	end
    
    -- Check num fallbacks again in case we had crappy fallbacks.
    if (iNumFallbacks == 0) then
		-- This region cannot have a start and something has gone way wrong.
		
		-- Look for a passable (non-mountain, etc) tile to avoid breaking mountain pattern 
		-- reachability.
		local plotX, plotY = FindPassableForceStart(iWidth, iHeight, iWestX, iSouthY);
		bSuccessFlag = true;
		bForcedPlacementFlag = true;
		self.startingPlots[region_number] = {plotX, plotY, 0, "Forced"};
		self:PlaceImpactAndRipples(plotX, plotY)
	end

	return bSuccessFlag, bForcedPlacementFlag
end

function GotLakes_ASP:ChooseLocations()
	print("Got Lakes ASP: Choosing Start Locations for Civilizations");
	
	-- Get the size in tiles of the biggest chunk of land.
	-- Remember this size when checking for tiny islands.
	local biggestAreaNumTiles = 
		GetBiggestPassableLandArea(self.minX, self.minY, self.maxX, self.maxY);
	print("Biggest land chunk has " .. biggestAreaNumTiles .. " tile(s).");
	
	local minLandSizeMultiplier = ASP_STARTAREA_RATIO;
	
	if (UserInput.Mountains == MtnPatterns.WINDING) then
		print("Reverting to default starting land-size threshold (winding canyons)");
		minLandSizeMultiplier = 0.25;
	end
	
	-- Minimum number of land tiles immediately reachable from the candidate plot.
	-- Any less than this and the candidate becomes a fallback
	-- to avoid starting on tiny islands, mountain-blocked peninsulas, etc.
	self.majorStartMinLandSize = 
		math.clamp(Round(biggestAreaNumTiles * minLandSizeMultiplier), 1, 100);
	
	print("Looking for land chunks that have at least " .. 
			self.majorStartMinLandSize .. " tile(s).");
	
	-- Measure terrain/plot/feature in regions.
	self:MeasureTerrainInRegions()

	-- Set up list of regions (to be processed in this order).
	--
	-- First, make a list of all average fertility values...
	local regionAssignList = {};
	local averageFertilityListUnsorted = {};
	local averageFertilityListSorted = {}; 
	-- Have to make this a separate table, not merely a pointer to the first table.
	for i, region_data in ipairs(self.regionData) do
		local thisRegionAvgFert = region_data[8];
		table.insert(averageFertilityListUnsorted, {i, thisRegionAvgFert});
		table.insert(averageFertilityListSorted, thisRegionAvgFert);
	end
	-- Now sort the copy low to high.
	table.sort(averageFertilityListSorted);
	-- Finally, match each sorted fertilty value to the matching unsorted region number 
	-- and record in sequence.
	local iNumRegions = table.maxn(averageFertilityListSorted);
	for region_order = 1, iNumRegions do
		for loop, data_pair in ipairs(averageFertilityListUnsorted) do
			local unsorted_fert = data_pair[2];
			if averageFertilityListSorted[region_order] == unsorted_fert then
				local unsorted_reg_num = data_pair[1];
				table.insert(regionAssignList, unsorted_reg_num);
				-- HAVE TO remove the entry from the table in rare case of ties on fert 
				-- value. Or it will just match this value for a second time, then crash 
				-- when the region it was tied with ends up with nil data.
				table.remove(averageFertilityListUnsorted, loop);
				break
			end
		end
	end

	-- main loop
	for assignIndex = 1, iNumRegions do
		local currentRegionNumber = regionAssignList[assignIndex];
		local bSuccessFlag = false;
		local bForcedPlacementFlag = false;
		
		-- Turn region boundaries/dimensions into whole numbers 
		-- so that coordinates are also whole numbers.
		local region_data_table = self.regionData[currentRegionNumber];
		region_data_table[1] = Round(region_data_table[1]);
		region_data_table[2] = Round(region_data_table[2]);
		region_data_table[3] = Round(region_data_table[3]);
		region_data_table[4] = Round(region_data_table[4]);
		
		-- Filter by area ID since we assigned each civ a continent or part of a continent.
		bSuccessFlag, bForcedPlacementFlag = self:FindStart(currentRegionNumber);
		
		--[[ Printout for debug only.
		print("- - -");
		print("Start Plot for Region #", currentRegionNumber, " was successful: ", bSuccessFlag);
		print("Start Plot for Region #", currentRegionNumber, " was forced: ", bForcedPlacementFlag);
		]]--		
	end
	--

	--[ Printout of start plots. Debug use only.
	print("-");
	print("--- Table of results, GotLakes_ASP ---");
	for loop, startData in ipairs(self.startingPlots) do
		print("-");
		print("Start #" .. loop .. " is at ", CoordString(startData[1], startData[2]), 
			  " with Fertility", startData[3], startData[4]);
	end
	print("-");
	print("--- Table of results, GotLakes_ASP ---");
	print("-");
	--]]
end
------------------------------------------------------------------------------
-- Overrides for the system that determines civ starting plots.
------------------------------------------------------------------------------
function AssignStartingPlots:__InitStartingData()
	-- Override for improved stability.
	
	if(self.uiMinMajorCivFertility <= 0) then
		self.uiMinMajorCivFertility = 5;
	end

	if(self.uiMinMinorCivFertility <= 0) then
		self.uiMinMinorCivFertility = 5;
	end

	-- Find Default Number of players.
	-- Used for luxury spacing and major/minor civ-start buffers.
	MapSizeTypes = {};
	for row in GameInfo.Maps() do
		MapSizeTypes[row.RowId] = row.DefaultPlayers;
	end
	local sizekey = Map.GetMapSize() + 1;
	local iDefaultNumberPlayers = MapSizeTypes[sizekey] or ScriptData.worldSizeInfo.numCivs;
	self.iDefaultNumberMajor = iDefaultNumberPlayers;
	self.iDefaultNumberMinor = math.floor(iDefaultNumberPlayers * 1.5);
		
	-- See if there are any civs starting out in the water
	local numMajorCivsTotal = PlayerManager.GetAliveMajorsCount();
	local totalCivsList     = PlayerManager.GetAliveMajorIDs();
	self.iNumMajorCivs      = 0; -- Number of civs that start on land.
	self.iNumWaterMajorCivs = 0;
	self.majorList          = {}; -- Civs that start on land.
	self.waterMajorList     = {};
	
	if ScriptData.gotGatheringStorm then
		-- Gathering Storm has civs that start in water.
		-- NumMajorCivs == number of civs that start on land.
		-- Do we have enough water on this map for the number of water civs specified?
		local TILES_NEEDED_FOR_WATER_START = 8;
		if (self.waterMap == true) then
			TILES_NEEDED_FOR_WATER_START = 1;
		end
		local iCandidateWaterTiles = 
			StartPositioner.GetTotalOceanStartCandidates(self.waterMap);
		if (iCandidateWaterTiles < 
			(TILES_NEEDED_FOR_WATER_START * self.iNumWaterMajorCivs)) then
			-- Not enough water, so have all civs start on land.
			print("Not enough water for water starts--everyone must start on land!");
			self.iNumMajorCivs = numMajorCivsTotal;
			self.majorList     = totalCivsList;
		else
			for i = 1, numMajorCivsTotal do
				local majorCiv = totalCivsList[i];
				local leaderType = PlayerConfigurations[majorCiv]:GetLeaderTypeName();
				if ((not self.startAllOnLand) and
					GameInfo.Leaders_XP2[leaderType] ~= nil and 
					GameInfo.Leaders_XP2[leaderType].OceanStart == true) then
					print ("Found a civ that starts on water.");
					table.insert(self.waterMajorList, majorCiv);
					self.iNumWaterMajorCivs = self.iNumWaterMajorCivs + 1;
				else
					table.insert(self.majorList, majorCiv);
					self.iNumMajorCivs = self.iNumMajorCivs + 1;
				end
			end
		end
	else
		-- Prior to GS, all major civs start on land.
		self.iNumMajorCivs = numMajorCivsTotal;
		self.majorList     = totalCivsList;
	end
	
	self.iNumMinorCivs = PlayerManager.GetAliveMinorsCount();

	-- Use Custom start positioner to find land starts for all civs.
	-- Water civs can use a land start as a fallback in case water start fails.
	local asp = GotLakes_ASP.Create(numMajorCivsTotal);
	asp:GenerateRegions(self.uiStartMinY, self.uiStartMaxY);
	asp:ChooseLocations();
	
	local startPlots = asp.startingPlots;
	local iMajorCivStartLocs = table.maxn(startPlots);
	if (iMajorCivStartLocs < numMajorCivsTotal) then
		-- Not enough spots for the major civs. Just bail out.
		print("ERROR: not enough starting spots for " .. numMajorCivsTotal .. " major civs!");
		return;
	end
	
	-- Export results from our custom start positioner to Civ 6 ASP
	-- for land civs only.
	self.majorStartPlots = {};
	for i = 1, self.iNumMajorCivs do
		local startData = asp.startingPlots[i];
		local plot = Map.GetPlot(startData[1], startData[2]);
		table.insert(self.majorStartPlots, plot);
		table.insert(self.majorCopy, plot);
	end
	
	-- Run Civ 6's start positioner for city states.
	-- Magical black box to assign a region for each major and minor civ.
	local aMajorStartPlotIndices = {};
	StartPositioner.DivideMapIntoMajorRegions(
		self.iNumMajorCivs,
		self.uiMinMajorCivFertility, 
		self.uiMinMinorCivFertility,
		self.startLargestLandmassOnly);
	
	if (ScriptData.gotGatheringStorm and (self.iNumWaterMajorCivs > 0)) then
		-- Place the ocean civs
		local iWaterCivs = StartPositioner.PlaceOceanStartCivs(
			self.waterMap, self.iNumWaterMajorCivs, aMajorStartPlotIndices);
		for i = 1, iWaterCivs do
			local waterPlayer = Players[self.waterMajorList[i]];
			-- Indices start at 0 here
			local iStartIndex = StartPositioner.GetOceanStartTile(i - 1);  
			local pStartPlot = Map.GetPlotByIndex(iStartIndex);
			waterPlayer:SetStartingPlot(pStartPlot);
			print("Water Start #" .. i .. ": " .. 
				  CoordString(pStartPlot:GetX(),pStartPlot:GetY()));
		end
		if (iWaterCivs < self.iNumWaterMajorCivs) then
			local numFailedCivs = self.iNumWaterMajorCivs - iWaterCivs;
			print("Failed to place " .. numFailedCivs .. 
				  " civ(s) in water. Starting civs on land instead.");
			
			-- Revert to land plots for failed civs. -483108917 duel map 1 kupe
			-- Must do this before doing start bias.
			for i = 1, numFailedCivs do
				local startData = asp.startingPlots[i + self.iNumMajorCivs];
				local plot = Map.GetPlot(startData[1], startData[2]);
				table.insert(self.majorStartPlots, plot);
				table.insert(self.majorCopy, plot);
				
				table.insert(self.majorList, self.waterMajorList[1]);
				table.remove(self.waterMajorList, 1);
				
			end
			self.iNumMajorCivs      = self.iNumMajorCivs      + numFailedCivs;
			self.iNumWaterMajorCivs = self.iNumWaterMajorCivs - numFailedCivs;
		end
	end
	
	--Begin Start Bias for major
	if (self.noStartBiases or 
		(GameInfo.StartBiasResources() == nil and 
		 GameInfo.StartBiasFeatures() == nil and 
		 GameInfo.StartBiasTerrains() == nil and 
		 GameInfo.StartBiasRivers() == nil)) then
		self.playerStarts = {};
		for i = 1, self.iNumMajorCivs do
			local playerStart = {}
			for j, plot in ipairs(self.majorStartPlots) do
				playerStart[j] = plot;
			end
			self.playerStarts[i] = playerStart;
		end

		for j, playerIndex in ipairs(self.majorList) do
			local hasPlot = false;
			local index = playerIndex + 1;

			if(index > 0 and self:__ArraySize(self.playerStarts, index) > 1) then
				for k, v in pairs(self.playerStarts[index]) do
					if(v~= nil and hasPlot == false) then
						hasPlot = true;
						--Call Removal
						self:__StartBiasPlotRemoval(v, false, index);
					end
				end
			end
		end
	else
		self:__InitStartBias(false);
	end
	
	if(UserInput.start == START_BALANCED) then
		print("Tuning resources for balanced starts.");
		self:__AddResourcesBalanced();
		
	elseif (UserInput.start == START_LEGEND) then
		print("Tuning resources for legendary starts.");
		self:__AddResourcesLegendary();
	end
	
	for i = 1, self.iNumMajorCivs do
		local player = Players[self.majorList[i]]
		
		if(player == nil) then
			print("Major start #" .. i .. " FAILED");
		else
			local hasPlot = false;
			for k, v in pairs(self.playerStarts[i]) do
				if(v~= nil and hasPlot == false) then
					hasPlot = true;
					player:SetStartingPlot(v);
					table.insert(aMajorStartPlotIndices, v:GetIndex());
					print("Major Start #" .. i .. ": " .. CoordString(v:GetX(),v:GetY()));
				end
			end
		end
	end

	--Place the minor start plots in an array
	self.minorStartPlots = {};
	StartPositioner.DivideMapIntoMinorRegions(self.iNumMinorCivs);
	local iMinorCivStartLocs = StartPositioner.GetNumMinorCivStarts();
	local i = 0;
	local valid = 0;
	while i <= iMinorCivStartLocs - 1 and valid < self.iNumMinorCivs do
		plots = StartPositioner.GetMinorCivStartPlots(i);
		local startPlot = self:__SetStartMinor(plots);
		info = StartPositioner.GetMinorCivStartInfo(i);
		if(startPlot ~= nil) then
			table.insert(self.minorStartPlots, startPlot);
			valid = valid + 1;
		end
		
		i = i + 1;
	end

	for k, plot in ipairs(self.minorStartPlots) do
		table.insert(self.minorCopy, plot);
	end

	--Begin Start Bias for minor
	self.minorList = PlayerManager.GetAliveMinorIDs();
	
	if (self.noStartBiases or 
		(GameInfo.StartBiasResources() == nil and 
		 GameInfo.StartBiasFeatures() == nil and 
		 GameInfo.StartBiasTerrains() == nil and 
		 GameInfo.StartBiasRivers() == nil)) then
		self.playerStarts = {};
		for i = 1, self.iNumMinorCivs do
			local playerStart = {}
			for j, plot in ipairs(self.minorStartPlots) do
				playerStart[j] = plot;
			end
			self.playerStarts[self.iNumMajorCivs + i] = playerStart
		end

		for j, playerIndex in ipairs(self.minorList) do
			local hasPlot = false;
			local index = playerIndex + 1;

			if(index > 0 and self:__ArraySize(self.playerStarts, index) > 1) then
				for k, v in pairs(self.playerStarts[index]) do
					if(v~= nil and hasPlot == false) then
						hasPlot = true;
						--Call Removal
						self:__StartBiasPlotRemoval(v, true, index);
					end
				end
			end
		end
	else
		self:__InitStartBias(true);
	end

	for i = 1, self.iNumMinorCivs do
		local player = Players[self.minorList[i]]
		
		if(player == nil) then
			print("Minor start #" .. i .. " FAILED");
		else
			local hasPlot = false;
			for k, v in pairs(self.playerStarts[i + self.iNumMajorCivs]) do
				if(v~= nil and hasPlot == false) then
					hasPlot = true;
					player:SetStartingPlot(v);
					print("Minor Start #" .. i .. ": " .. CoordString(v:GetX(),v:GetY()));
				end
			end
		end
	end
end

function AssignStartingPlots:__GetValidAdjacent(plot, minor)
	-- Override to be more permissive w.r.t. challenging terrain.

	local maxH = 0;
	local minH = 0;
	if(minor == 0) then
		maxH = math.ceil(g_iH * self.uiStartMaxY / 100);
		minH = math.ceil(g_iH * self.uiStartMinY / 100);
	end

	if((plot:GetY() <= minH) or 
	   (plot:GetY() > (g_iH - maxH)) or 
	   (maxH == 0 and minH == 0)) then
		return false;
	end

	-- Allow some barren tiles next to the start, because a suboptimal start is
	-- better than no start at all, especially on a map with challenging terrain.
	return true;
end
------------------------------------------------------------------------------
function DetermineStartingPlots()

	print("Creating start plot database (" .. 
		ScriptData.landInfo.name .. " + " .. 
		ScriptData.climateInfo.name .. ").");

	-- Map options and order of precedence (highest to lowest):
	-- 1) Other mods
	-- 2) Climate options
	-- 3) Landmass options
	
	-- Use both land and climate info to calculate fertility thresholds.
	local majorCivFert = math.max(1,Round(
		ScriptData.landInfo.aspMinMajorFert * 
		ScriptData.climateInfo.aspMinFertMult));
		
	local minorCivFert = math.max(1,Round( 
		ScriptData.landInfo.aspMinMinorFert * 
		ScriptData.climateInfo.aspMinFertMult));
	
	-- Ignore the bottom START_MIN_Y % and the top START_MAX_Y % 
	-- of the grid height when placing major civs.
	local startMinY = 0;
	local startMaxY = 100;
	local divMethod = ScriptData.landInfo.aspDivMethod;
	
	if ((UserInput.mountains == MtnPatterns.WINDING) or
		(UserInput.mountains == MtnPatterns.ALL)) then
		-- Heavy mountain patterns can divide a largest landmass into smaller areas,
		-- So use a division method that expects smaller areas
		print("Forcing continental regional div method (heavy mtn pattern + largest landmass)");
		ScriptData.landInfo.aspDivMethod = DIVMETHOD_CONTINENTAL;
	end
	 
	if (UserInput.worldWrap == WWRAP_GLOBE) then
		-- Avoid starts near the poles.
		local climate = UserInput.climate;
		startMinY = ScriptData.sunlightInfo.aspStartMinY[climate];
		startMaxY = ScriptData.sunlightInfo.aspStartMaxY[climate];
		
		if ((UserInput.icyPoles == ICYPOLES_FULL) and 
		    ((UserInput.sunlight == Sunlights.TILTED) or gotIceAgeFamily)) then
			-- Override division method to continental
			-- in case cropping splits/shrinks the largest landmass.
			print("Forcing continental regional div method " ..
			      "(globe wrap + ice age full or tilted axis full)");
			ScriptData.landInfo.aspDivMethod = DIVMETHOD_CONTINENTAL;
		end
	end
	
	if (UserInput.connectSeas) then
		print("Forcing continental regional div method (connected seas)");
		ScriptData.landInfo.aspDivMethod = DIVMETHOD_CONTINENTAL;
	end
	
	-- Create the AssignStartingPlots database.
	-- Even though we might override an init method, use the 
	-- inherited constructor in case there are other 
	-- ASP-overriding mods.
	local args = 
	{
		MIN_MAJOR_CIV_FERTILITY = majorCivFert,
		MIN_MINOR_CIV_FERTILITY = minorCivFert,
		MIN_BARBARIAN_FERTILITY = 1,
		START_MIN_Y             = startMinY,
		START_MAX_Y             = startMaxY,
		LAND                    = ScriptData.landInfo.aspLandMap,
		WATER                   = ScriptData.landInfo.aspWaterMap,
		START_CONFIG            = UserInput.start,
	};
	local asp = AssignStartingPlots.Create(args);
end
------------------------------------------------------------------------------
-- Map Configuration
------------------------------------------------------------------------------
------------------------------------------------------------------------------
-- Climate configs
------------------------------------------------------------------------------
ClimateInfo = 
{
	default = 
	{
		name = "standard climate",
		
		biodiv = Biodivs.STANDARD,
		
		-- Fixed latitude for standard-sunlight regions.
		-- Indices are {ICYPOLES_CROP, ICYPOLES_FULL}
		regionLat = {0.2, 0.3},
		
		-- Min regional lat < 0 to add thickness to hot pole.
		-- lower when uncropped to compensate for extended dark side.
		-- Indices are {ICYPOLES_CROP, ICYPOLES_FULL}
		tiltedLatMin = {0, -0.05}, 
		
		-- Max regional lat: increase this to make dark side thicker.
		-- For uncropped, allow plenty of room for dark-side interpolation.
		-- Indices are {ICYPOLES_CROP, ICYPOLES_FULL}
		tiltedLatMax = {0.7, 1.0},
		
		-- Ice generator for standard sunlight
		-- Indices are {WWRAP_GLOBE, WWRAP_REGION}
		AddIceAtPlot = 
		{
			GotLakes_FeatureGenerator.Globe_AddIceAtPlot, 
			GotLakes_FeatureGenerator.Region_AddIceAtPlot
		},
		
		-- Resource generation
		-- Cold climates can override this flag to allow resources next to ice.
		resourcesAvoidIce = true,
		
		-- Start plot database
		-- Major/Minor civ fertility multiplier.
		-- Reduce for less-fertile maps.
		aspMinFertMult = 1.0,
	},
	
	snowball = 
	{
		name = "snowball",
		
		biodiv = Biodivs.VERYHIGH,
	
		-- Vary region lat based on icy-poles
		-- to distinguish "ice age cropped" from "ice age full".
		regionLat = {0.23, 0.38},
		
		tiltedLatMin = {0.0, 0.25}, 
		tiltedLatMax = {0.5, 0.75},
		
		AddIceAtPlot = 
		{
			GotLakes_FeatureGenerator.IceAgeGlobe_AddIceAtPlot, 
			GotLakes_FeatureGenerator.IceAgeRegion_AddIceAtPlot
		},
		
		resourcesAvoidIce = false,
		
		aspMinFertMult = 0.01,
	},
	
	iceAge = 
	{
		name = "ice age",
	
		biodiv = Biodivs.HIGH,
	
		-- Vary region lat based on icy-poles
		-- to distinguish "ice age cropped" from "ice age full".
		regionLat = {0.27, 0.4},
		
		tiltedLatMin = {-0.05, -0.1}, 
		tiltedLatMax = {0.55,  1.0},
		
		AddIceAtPlot = 
		{
			GotLakes_FeatureGenerator.IceAgeGlobe_AddIceAtPlot, 
			GotLakes_FeatureGenerator.IceAgeRegion_AddIceAtPlot
		},
		
		resourcesAvoidIce = false,
		
		aspMinFertMult = 0.5,
	},
	
	greenhouse = 
	{
		name = "greenhouse",
	
		biodiv = Biodivs.HIGH,
	
		-- Shift region lat towards poles to allow adjustment of desert/jungle
		regionLat = {0.3, 0.35},
		
		tiltedLatMin = {0,   0}, 
		tiltedLatMax = {0.7, 0.9},
		
		aspMinFertMult = 0.8,
	},
	
	sandstorm = 
	{
		name = "sandstorm",
		
		biodiv = Biodivs.VERYHIGH,
			
		-- Shift region lat towards poles to allow adjustment of desert/jungle
		regionLat = {0.45, 0.55},
		
		tiltedLatMin = {0,   0}, 
		tiltedLatMax = {0.9, 1.0},
		
		aspMinFertMult = 0.6,
	},
};
------------------------------------------------------------------------------
-- Biome configs
------------------------------------------------------------------------------
BiomeInfo = 
{
	default = 
	{
		name = "standard biome",
		
		-- Percentage of fertile terrain that is plains (all else is grassland).
		plainsPct = 50,
		
		-- Offset percentage of land that is desert
		-- to make room for biome-specific terrain.
		desertPctOffset = 0,
		
		-- Max jungle as a percentage of applicable tiles.
		junglePct = 40,
		
		-- How much to offset jungle based on rainfall.
		junglePctShift = 8,
		
		-- How much to decrease min lat and increase max lat for jungles.
		jungleMaxLatDiff = 0.0,
		
		-- Percentage of flat desert land that is oases.
		oasisPct = 20,
		
		-- How much to offset oases based on river level
		-- as a counter-balance to higher river level reducing oases.
		oasisChange = 10,
		
		-- Percentage of land that is forests.
		forestPct = 40,
		
		-- How much to offset forests based on rainfall.
		forestChange = 8,
		
		-- How much to decrease min lats and increase max lat for forests.
		forestCMaxLatDiff = 0.0,
		
		-- Percentage of land that is marsh
		marshPct = 20,
		
		-- How much to offset marsh based on rainfall.
		marshChange = 5,
	},
	
	arborea = 
	{
		name = "arborea",
		
		-- Make room for terrain that supports forests.
		desertPctOffset = -30,
		
		-- Increase all kinds of trees.
		junglePct = 85,
		forestPct = 80,
		
		-- Expand tree latitudes.
		jungleMaxLatDiff  = 0.1,
		forestCMaxLatDiff = 0.2,
	},
	
	prairie = 
	{
		name = "prairie",
		
		plainsPct = 60,
		
		-- Less desert, more grass/plains.
		desertPctOffset = -20,
		
		-- Fewer trees for more open terrain.
		junglePct = 15,
		forestPct = 15,
		
		-- Less marsh, more featureless terrain.
		marshPct = 10,
		marshChange  = 3,
	},
	
	wetland = 
	{
		name = "wetland",
		
		plainsPct = 40,
		
		-- Slightly less desert, since some desert will become oases.
		desertPctOffset = -10,
		
		-- Slightly increase trees in case the map doesn't have marsh.
		junglePct = 60,
		forestPct = 60,
		
		-- Make deserts wetter with more oases.
		oasisPct = 60,
		oasisChange  = 20,
		
		-- Greatly increase marsh.
		marshPct = 60,
		marshChange  = 15,
	}
};
------------------------------------------------------------------------------
-- Sunlight configs
------------------------------------------------------------------------------
SunlightInfo = 
{
	default = 
	{
		name = "standard sunlight",
		
		-- Latitude multiplier for cropped globes.
		-- Indices are Climates {SNOWBALL, ICEAGE, STANDARD, GREENHOUSE, SANDSTORM}
		latMult = {0.5, 2/3, 0.9, 0.9, 0.9},
	
		-- Latitude lookup
		-- Indices are {WWRAP_GLOBE, WWRAP_REGION}
		GetLatitudeAtPlot = {DefaultGlobe_GetLatitudeAtPlot, DefaultRegion_GetLatitudeAtPlot},
		
		-- Latitude ranges
		-- Indices are Climates {SNOWBALL, ICEAGE, STANDARD, GREENHOUSE, SANDSTORM}
		-- Latitude below which all land is desert.
		desertMinLat = {-0.25, -0.14, 0.1, 0.2, 0.5},
		
		-- Latitude above which no land is desert.
		desertMaxLat = {-0.2, -0.67, 0.45, 0.5, 0.8},
		
		-- Latitude below which no land is tundra.
		tundraMinLat = {-0.15, 0.16, 0.55, 0.8, 1.3},
		
		-- Latitude above which all non-river land is either tundra or snow.
		tundraNonRiverMaxLat = {0.0, 0.33, 0.75, 0.9, 1.4},
		
		-- Latitude above which all land is either tundra or snow.
		-- This used to be (tundraNonRiverMax + snowMax)/2
		tundraMaxLat = {0.0, 0.47, 0.825, 1.0, 1.5},
		
		-- Latitude below which no land is snow.
		snowMinLat = {0.0, 0.27, 0.75, 1.1, 1.6},
		
		-- Latitude above which all land is snow.
		snowMaxLat = {0.5, 0.67, 0.9, 1.5, 2.0},
		
		-- Latitude below which all land is jungle.
		jungleMinLat = {-2.0, -0.14, 0.2, 0.35, 0.5},
		
		-- Latitude above which no land is jungle.
		-- 0.34 -- 0.32 was slightly too low
		jungleMaxLat = {-1.0, -0.07, 0.4, 0.6, 0.9},
		
		-- Latitude above which no water is non-wonder reef.
		-- base game is 0.7
		reefMaxLat = {-1.0, -0.07, 0.54, 0.6, 0.8},
		
		-- Latitude below which no land is forest.
		-- By default, start forests at negative lat to increase jungle/forest overlap
		forestHMinLat = {-2.0, -0.07, -0.1, 0.3, 0.4},
		
		-- Max latitude for forests fading towards the equator.
		-- Indices are Climates {SNOWBALL, ICEAGE, STANDARD, GREENHOUSE, SANDSTORM}
		forestHMaxLat = {-1.0, 0.33, 0.3, 0.45, 0.7},
		
		-- Min latitude for forests fading towards icy poles.
		forestCMinLat = {0.0, 0.53, 0.6, 0.7, 0.8},
		
		-- Max latitude for forests fading towards icy poles.
		forestCMaxLat = {0.9, 0.9, 0.9, 1.0, 1.1},
		
		-- Min latitude for ice interpolation
		iceMinLat = {-0.5, 0.18, 0.6, 0.8, 1.5},
		
		-- Max latitude for ice interpolation
		iceMaxLat = {1.0, 1.0, 1.0, 1.5, 2.0},
		
		-- Terrain generation
		-- Base percentage of extreme-hot region that is desert.
		desertBasePct = {0, 50, 50, 50, 75},
		
		-- Hook for initializing sunlight-specific regional latitude ranges.
		TInitRegion = GotLakes_TerrainGenerator.Default_InitRegion,
		
		-- Whether to allow climate-biome combos to adjust the base desert percentage.
		enableDesertPctShift = true,
		
		-- Percentage of the cold pole that is snow, if applicable.
		coldPolePct = {100, 100, 100, 100, 100},
		
		-- Iterpolation function for desert / hot-pole fractal.
		-- Default to sqrt so that desert terrain has a subtle creep from from the equator.
		desertInterpFcn = math.sqrt,
		
		-- Interpolation function for transition from fertile to tundra
		-- Default to square so that frozen terrain has a subtle creep from the N/S map edges.
		tundraInterpFcn = Square,
		
		-- Iterpolation function for transition from tundra to snow
		-- Default to square so that frozen terrain has a subtle creep from the N/S map edges.
		snowInterpFcn = Square,
		
		-- Feature Generation
		-- Ice generator
		-- Indices are {WWRAP_GLOBE, WWRAP_REGION}
		-- Use the globe function as a place-holder to use climate function as a fallback.
		AddIceAtPlot = {},
		
		-- Max ice as a fractal percentile.
		-- Indices are Climates {SNOWBALL, ICEAGE, STANDARD, GREENHOUSE, SANDSTORM}
		icePct = {80, 25, 25, 25, 25},
		
		-- Start plot database
		-- Min/Max start latitude as percent of height
		-- Indices are climates {SNOWBALL, ICEAGE, STANDARD, GREENHOUSE, SANDSTORM}
		aspStartMinY = {33, 25,  5,  5,  5},
		aspStartMaxY = {67, 75, 95, 95, 95},
	},
	
	tilted = 
	{
		name = "tilted axis",
		
		-- Extend the uncropped tilted scale to 2 to freeze the northern hemisphere
		-- and to allow for snow/ice interpolation.
		latMult = {0.33, 0.5, 0.67, 0.75, 0.9},
		
		GetLatitudeAtPlot = 
			{TiltedAxisGlobe_GetLatitudeAtPlot, TiltedAxisRegion_GetLatitudeAtPlot},
		
		TInitRegion = GotLakes_TerrainGenerator.TiltedAxis_InitRegion,
				
		desertMinLat         = {-2.0, 0.0,  0.0,  0.1,  0.2},
		desertMaxLat         = {-1.5, 0.25, 0.33, 0.5,  0.75},
		tundraMinLat         = {0.1,  0.28, 0.45, 0.8,  1.5},
		tundraNonRiverMaxLat = {0.2,  0.4,  0.67, 0.9,  1.6},
		tundraMaxLat         = {0.25, 0.45, 0.78, 1.0,  1.7},
		snowMinLat           = {0.2,  0.4,  0.67, 1.6,  1.6},
		snowMaxLat           = {0.8,  0.9,  0.95, 2.0,  2.0},
		jungleMinLat          = {-2.0, 0.1,  0.15, 0.3,  0.5},
		jungleMaxLat          = {-1.0, 0.25, 0.3,  0.6,  0.9},
		forestHMinLat         = {0,    0,    0.1,  0.25, 0.5},
		forestHMaxLat         = {0.23, 0.23, 0.4,  0.5,  0.65},
		forestCMinLat         = {0.4,  0.4,  0.6,  0.65, 0.75},
		forestCMaxLat         = {0.9,  0.9,  1.0,  1.0,  1.0},
		iceMinLat             = {-0.5, 0.28, 0.65, 0.8,  1.5},
		iceMaxLat             = {1.0,  1.0,  1.0,  2.0,  2.0},
		
		
		desertBasePct = {0, 85, 85, 85, 85},
		
		enableDesertPctShift = false,
		
		coldPolePct = {100, 75, 75, 75, 75},
		
		-- Square makes the desert transition suddenly,
		-- making the tilted axis latitude bands more obvious.
		desertInterpFcn = Square,
		
		-- sqrt makes the snow appear suddenly,
		-- with tundra gradually fading into snow.
		snowInterpFcn = math.sqrt,
		
		AddIceAtPlot = 
		{
			GotLakes_FeatureGenerator.TiltedAxisGlobe_AddIceAtPlot, 
			GotLakes_FeatureGenerator.TiltedAxisRegion_AddIceAtPlot
		},
		
		icePct = {95, 50, 50, 50, 50},
		
		-- Avoid the barren wasteland.
		aspStartMinY = { 5,  5, 20, 40, 50},
		aspStartMaxY = {40, 50, 65, 90, 95},
	},
	
	twoSuns = 
	{
		name = "two suns",
		
		latMult = {0.5, 2/3, 0.85, 0.9, 0.9},
		
		GetLatitudeAtPlot = 
			{TwoSunsGlobe_GetLatitudeAtPlot, TwoSunsRegion_GetLatitudeAtPlot},
		
		TInitRegion = GotLakes_TerrainGenerator.TwoSuns_InitRegion,
				
		desertMinLat         = {-2.0, 0,    0,    0.1,  0.2},
		desertMaxLat         = {-1.5, 0.2,  0.4,  0.5,  0.8},
		tundraMinLat         = {0.1,  0.38, 0.6,  0.9,  1.5},
		tundraNonRiverMaxLat = {0.25, 0.6,  1.2,  1.5,  1.6},
		tundraMaxLat         = {0.3,  0.8,  1.3,  1.6,  1.7},
		snowMinLat           = {0.25, 0.67, 0.85, 1.6,  1.6},
		snowMaxLat           = {0.95, 1.0,  1.6,  2.0,  2.0},
		jungleMinLat          = {-2.0, 0,    0.2,  0.3,  0.5},
		jungleMaxLat          = {-1.0, 0.2,  0.45, 0.6,  0.9},	
		forestHMinLat         = {0,    0,    0.2,  0.25, 0.5},
		forestHMaxLat         = {0.23, 0.4,  0.45, 0.5,  0.65},
		forestCMinLat         = {0.4,  0.5,  0.8,  0.8,  0.9},
		forestCMaxLat         = {1.0,  1.1,  1.1,  1.1,  1.2},
		iceMinLat             = {-0.5, 0.45, 0.65, 0.8,  1.5},
		iceMaxLat             = {0.8,  1.0,  1.2,  2.0,  2.0},
		
		desertBasePct = {0, 90, 90, 90, 90},
		
		enableDesertPctShift = false,
		
		coldPolePct = {100, 90, 90, 90, 90},
		
		-- Square works better for polar bands,
		-- and in this case the poles are hot desert.
		desertInterpFcn = Square,
		
		-- sqrt works better for equatorial bands,
		-- and in this case the equator is tundra and snow.
		tundraInterpFcn = math.sqrt,
		snowInterpFcn   = math.sqrt,
		
		AddIceAtPlot = 
		{
			GotLakes_FeatureGenerator.TwoSuns_AddIceAtPlot, 
			GotLakes_FeatureGenerator.TwoSuns_AddIceAtPlot
		},
		
		icePct = {95, 25, 25, 25, 0},
		
		-- Avoid hot desert at the poles.
		aspStartMinY = { 5,  5,  5,  5,  5},
		aspStartMaxY = {95, 95, 95, 95, 95},
	},
}
------------------------------------------------------------------------------
-- Landmass configs
------------------------------------------------------------------------------
LandInfo = 
{
	default = 
	{
		name        = "unknown land",
		id          = 0,
				
		-- Method to create a fractal world for plot generation.
		-- By default, use FractalWorld.Create().
		CreateFWorld = FractalWorld.Create,
		GenPlotTypes = GotLakes_Fractal.Fractal_GeneratePlotTypes,
		
		-- Args for plot type generation
		fractalInitArgs = {},
		fractalGenArgs  = {},
		extraArgs       = {},
        
		-- Lake grain and sea levels {low, normal, high}
		lake_grain  = 3,
        seas_iceage = {61,66,70},
        seas_normal = {67,72,76},
		
		-- Whether to add layers of islands to a large lakes map.
		-- Differentiates large Lakes from Seven Seas.
		gotLakeIslandLayers = false,
				
		-- Feature Generation
		-- How many rows of ice to add to the top and bottom of a global map.
		polarIceNumRows = 1,
		
		-- Starting Plot Database
		aspLandMap  = false, -- true for land-heavy maps
		aspWaterMap = false, -- true for water-heavy maps
		
		-- Major/Minor civ fertility thresholds; 
		-- directly proportional to land/water ratio, 
		-- so raise values for land-heavy maps.
		aspMinMajorFert = 150,
		aspMinMinorFert = 50, 
		
		-- Regional division method for civ starts.
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	archipelago = 
	{
		name        = "Archipelago",
		id          = Landmasses.ARCHIPELAGO,
		
		fractalInitArgs = {continent_grain = 4},
		
		extraArgs = 
		{
			-- Don't let extra islands merge with landmass islands.
			MergeToMainland = MergeExtrasAvoidLandmass, 
			tectonicGrain   = 4,
		},
				
		aspWaterMap     = true,
		aspMinMajorFert = 75,
		aspMinMinorFert = 5, 
		
		aspDivMethod   = DIVMETHOD_CONTINENTAL,
	},
	
	bagels = 
	{
		name         = "Bagels",
		id           = Landmasses.BAGELS,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Bagels_GeneratePlotsByRegion,
		
		aspDivMethod    = DIVMETHOD_CONTINENTAL,
	},
	
	clusters = 
	{
		name        = "Clusters",
		id          = Landmasses.CLUSTERS,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Clusters_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extra islands merge with landmass islands.
			MergeToMainland = MergeExtrasAvoidLandmass, 		
		},
        
        seas_iceage = {62,67,74},
        seas_normal = {73,78,82},
				
		aspWaterMap     = true,
		aspMinMajorFert = 75,
		aspMinMinorFert = 5,
		
		aspDivMethod = DIVMETHOD_CONTINENTAL,
	},
	
	continents = 
	{
		name         = "Continents",
		id           = Landmasses.CONTINENTS,
		
		GenPlotTypes = GotLakes_Fractal.Continents_GeneratePlotTypes,
        
        seas_iceage  = {59,64,70},
        seas_normal  = {67,72,76},
		
		aspDivMethod    = DIVMETHOD_CONTINENTAL,
	},
	
	donut = 
	{
		name        = "Donut",
		id          = Landmasses.DONUT,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Donut_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			tectonicFlags  = {FRAC_POLAR = true}, -- keep tectonic islands away from map edges.
			tectonicGrain  = 3,
		}, 
				
		aspWaterMap  = true,	
		aspDivMethod = DIVMETHOD_BIGGESTLAND,
	},
	
	fractal = 
	{
		name        = "Fractal",
		id          = Landmasses.FRACTAL,
		
		fractalInitArgs = 
		{
			rift_grain      = -1, 
			has_center_rift = false, 
			polar           = true,
		},
		
		fractalGenArgs = {has_center_rift = false},
		
		extraArgs = {tectonicFlags = {FRAC_POLAR = true}}, -- keep tectonic islands away from map edges	
		
        seas_iceage = {57,64,72},
        seas_normal = {65,72,78},
        
		aspMinMajorFert = 175,
		aspMinMinorFert = 50, 
		
		aspDivMethod   = DIVMETHOD_CONTINENTAL,
	},
	
	inlandSea = 
	{
		name        = "Inland Sea",
		id          = Landmasses.INLANDSEA,
		
		CreateFWorld    = MultilayeredFractal.Create,
		GenPlotTypes    = MultilayeredFractal.InlandSea_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extras freshen lakes
			MergeToMainland   = MergeExtrasPreserveSaltLakes, 
			tectonicFlags  	  = {FRAC_POLAR = true}, -- keep tectonic islands close to the lake
			tectonicGrain     = 4,
		},
		
		-- For this landmass, sea level affects lake grains and lake threshold.
		-- Higher grain size meams smaller lakes
		-- Higher threshold means less water overall.
		lake_grain  = 1,
		seas_iceage = {88,78,68},
		seas_normal = {82,72,62},
				
		polarIceNumRows = 0,
		
		aspLandMap      = true,
		aspMinMajorFert = 200,
		aspMinMinorFert = 50, 
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	invertedExtras = 
	{
		name        = "Inverted Extras",
		id          = Landmasses.INVEXTRAS,
		
		CreateFWorld    = MultilayeredFractal.Create,
		GenPlotTypes    = MultilayeredFractal.InvertedExtras_GeneratePlotsByRegion,
		
		-- Make extras form water instead of land.
		extraArgs = 
		{
			invertExtras          = true,
			tectonicGrain 		  = 4,
			tectonicLandOffset    = 1,
			tectonicSeaMultiplier = 2,
		},
				
		polarIceNumRows = 0,
		
		aspLandMap      = true,
		aspMinMajorFert = 200,
		aspMinMinorFert = 50, 		
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	islandPlates = 
	{
		name        = "Island Plates",
		id          = Landmasses.ISLEPLATES,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.IslandPlates_GeneratePlotsByRegion,		
					
		extraArgs = 
		{
			-- Don't let extra islands merge with landmass islands.
			MergeToMainland = MergeExtrasAvoidLandmass, 
			tectonicGrain   = 3,		
		},
				
		aspWaterMap     = true,
		aspMinMajorFert = 85,
		aspMinMinorFert = 5, 
		
		aspDivMethod    = DIVMETHOD_CONTINENTAL,
	},
	
	lakes = 
	{
		name        = "Lakes",
		id          = Landmasses.LAKES,

		CreateFWorld    = MultilayeredFractal.Create,
		GenPlotTypes    = MultilayeredFractal.Lakes_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extras freshen lakes
			MergeToMainland = MergeExtrasPreserveSaltLakes, 
			tectonicGrain   = 5,
		},
		
		-- For this landmass, sea level affects lake threshold.
		-- Higher threshold means less water overall.
		-- Note: any lower than 82 results in significant salt-water lakes, which
		-- the plot type function will have to freshen by adding land tiles.
		lake_grain  = 4,
		seas_iceage = {90,82,74},
		seas_normal = {86,78,70}, -- Used to be {93, 90, 85} 
				
		polarIceNumRows = 0,
		
		aspLandMap      = true,
		aspMinMajorFert = 300,
		aspMinMinorFert = 50, 		
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	largeIslands = 
	{
		name        = "Large Islands",
		id          = Landmasses.LRGISLES,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.LargeIslands_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extra islands merge with landmass islands.
			MergeToMainland = MergeExtrasAvoidLandmass, 
			tectonicGrain = 3,		
		},
				
		aspWaterMap     = true,
		aspMinMajorFert = 85,
		aspMinMinorFert = 5, 
		
		aspDivMethod    = DIVMETHOD_CONTINENTAL,
	},
	
	largeLakes = 
	{
		name        = "Large Lakes",
		id          = Landmasses.LRGLAKES,
		
		CreateFWorld    = MultilayeredFractal.Create,
		GenPlotTypes    = MultilayeredFractal.Lakes_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extras freshen lakes
			MergeToMainland   = MergeExtrasPreserveSaltLakes, 
			tectonicGrain     = 5,		
		},
		
		-- For this landmass, sea level affects lake grains and lake threshold.
		-- Higher threshold means less water overall.
		lake_grain  = 3, -- grain of 2 at high sea level looks like inland sea
		seas_iceage = {90,84,76},
		seas_normal = {84,76,68},
		
		polarIceNumRows = 0,
		
		aspLandMap      = true,
		aspMinMajorFert = 300,
		aspMinMinorFert = 50, 		
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	maze = 
	{
		name         = "Maze",
		id           = Landmasses.MAZE,
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Maze_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			tectonicFlags  = {FRAC_POLAR = true}, -- keep tectonic islands away from map edges.
			tectonicGrain  = 1,			
		},
		
		--seas_iceage = {55,60,67},
        --seas_normal = {63,68,73},
		
		aspWaterMap       = true,
		aspMinMajorFert   = 75,
		aspMinMinorFert   = 5, 
		
		-- This pangea can easily splinter into separate areas, 
		-- so use "continental" regions for starting plots.
		aspDivMethod    = DIVMETHOD_CONTINENTAL,
	},
	
	miniDonuts = 
	{
		name        = "Mini Donuts",
		id          = Landmasses.MINIDONUTS,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.MiniDonuts_GeneratePlotsByRegion,
		
		extraArgs = 
		{
			-- Don't let extra islands merge with landmass islands.
			MergeToMainland = MergeExtrasAvoidLandmass, 
			tectonicGrain   = 3,
		},
				
		aspMinMajorFert = 85,
		aspMinMinorFert = 5,
		
		aspDivMethod = DIVMETHOD_CONTINENTAL,
	},
	
	noodles = 
	{
		name = "Noodles",
		id   = Landmasses.NOODLES,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Noodles_GeneratePlotsByRegion,
		
        seas_iceage  = {63,68,72},
        seas_normal  = {67,72,76},
		
		aspDivMethod = DIVMETHOD_CONTINENTAL,
	},	
	
	oval = 
	{
		name         = "Oval",
		id           = Landmasses.OVAL,
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Oval_GeneratePlotsByRegion,

		extraArgs    = 
		{
			tectonicFlags = {FRAC_POLAR = true}, -- keep tectonic islands away from map edges.
			tectonicGrain = 2, -- landmass is so big that we need 2-grain to notice islands	
		},
		
		aspMinMajorFert = 200,
		aspMinMinorFert = 50, 			
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	pangea = 
	{
		name         = "Pangea",
		id           = Landmasses.PANGEA,
		GenPlotTypes = GotLakes_Fractal.Pangea_GeneratePlotTypes,
		
		extraArgs = 
		{
			tectonicFlags  = {FRAC_POLAR = true}, -- keep tectonic islands away from map edges.
			tectonicGrain  = 1,			
		},
		
		seas_iceage = {55,60,67},
        seas_normal = {63,68,73},
				
		aspMinMajorFert = 300,
		aspMinMinorFert = 50, 		
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},
	
	sevenSeas = 
	{
		name        = "Seven Seas",
		id          = Landmasses.SEVENSEAS,
		
		CreateFWorld    = MultilayeredFractal.Create,
		GenPlotTypes    = MultilayeredFractal.Lakes_GeneratePlotsByRegion,
		
		-- Enlarge extras.
		extraArgs = 
		{
			tectonicGrain         = 4,
			tectonicLandOffset    = 1,
			tectonicSeaMultiplier = 2,
		},
		
		-- For this landmass, sea level affects lake grains and lake threshold.
		-- Higher threshold means less water overall.
		lake_grain  = 3,
		seas_iceage = {62,56,50},
		seas_normal = {56,50,44},
		
		-- Add islands similar to island plates.
		gotLakeIslandLayers = true,
		
		polarIceNumRows = 0,
		
		aspLandMap      = true,
		aspMinMajorFert = 300,
		aspMinMinorFert = 50, 		
		aspDivMethod    = DIVMETHOD_BIGGESTLAND,
	},	
	
	smallContinents = 
	{
		name        = "Small Continents",
		id          = Landmasses.SMALLCONTS,

		fractalInitArgs = {continent_grain = 3},
		
		extraArgs = 
		{
			tectonicGrain = 3,
		},
        
        seas_iceage = {60,65,72},
        seas_normal = {69,75,80},
				
		aspMinMajorFert = 125,
		aspMinMinorFert = 40, 
		
		aspDivMethod = DIVMETHOD_CONTINENTAL,
	},
	
	snake = 
	{
		name        = "Snake",
		id          = Landmasses.SNAKE,
		
		CreateFWorld = MultilayeredFractal.Create,
		GenPlotTypes = MultilayeredFractal.Snake_GeneratePlotsByRegion,
					
		aspMinMajorFert = 75,
		aspMinMinorFert = 5,
		
		-- This pangea can splinter into separate areas, 
		-- so use "continental" regions for starting plots.
		aspDivMethod = DIVMETHOD_CONTINENTAL,
	},
};
------------------------------------------------------------------------------
-- Helper Methods for defining Map Options
------------------------------------------------------------------------------
function GetFamilyOption(shuffleName, familyName, default, infos)
	-- Generate a map shuffle family option, given the following params:
	--   familyName: family name
	--   default: default value for the family option
	--   infos: references to landmasses or climates in a global info struct
	--
	-- A map shuffle can have multiple families of options, such as continents,
	-- islands, lakes, and pangeas.
	local values = {};
	
	-- Generate choices based on info structs.
	for i, info in ipairs(infos) do								 
		table.insert(values, info.name);
	end
	
	-- Add all/none choices.
	table.insert(values, "All");
	table.insert(values, "None");
	
	local defaultVal = default;
	if (defaultVal < 0) then
		-- Negative default means all or none.
		defaultVal = table.maxn(infos) - default;
	end
	
	local option = 
	{
		Infos        = infos,
		Name         = familyName,
		Values       = values,
		DefaultValue = defaultVal,
	};
	
	return option;
end

function GetLandmassFamilyOption(name, default, landInfos)
	-- Generate a landmass family shuffle option, given the following params:
	return GetFamilyOption("LANDMASS", name, default, landInfos);
end
------------------------------------------------------------------------------
-- Map Option configs
------------------------------------------------------------------------------
OptionInfo =
{
	{
		Name         = "Resources",
		Values       = {"Sparse", "Standard", "Abundant", "Random"},
		DefaultValue = MapDefaults.RESOURCES,
	},

	{
		Name         = "Start Position",
		Values       = {"Balanced", "Standard", "Legendary"},
		DefaultValue = MapDefaults.START,
	},	

	{
		Name         = "World Age",
		Values       = {"New", "Standard", "Old", "Random"},
		DefaultValue = MapDefaults.WORLDAGE,
		RandSize     = 3,
	},

	{
		Name         = "Sea Level",
		Values       = {"Low", "Standard", "High", "Random"},
		DefaultValue = MapDefaults.SEALEVEL,
		RandSize     = 3,
	},

	{
		Name         = "Lake Level",
		Values       = {"Low", "Standard", "High", "Random"},
		DefaultValue = MapDefaults.LAKELEVEL,
		RandSize     = 3,
	},

	{
		Name         = "River Level",
		Values       = {"Low", "Standard", "High", "Random"},
		DefaultValue = MapDefaults.RIVERLEVEL,
		RandSize     = 3,
	},

	{
		Name         = "Temperature", -- "Temperature Offset" is too long of a name
		Values       = {"Cooler", "Standard", "Warmer", "Random"},
		DefaultValue = MapDefaults.TEMPERATURE,
		RandSize     = 3,
	},
	
	{
		Name         = "Tundra Level",
		Values       = {"Low", "Standard", "High", "Random"},
		DefaultValue = MapDefaults.TUNDRALEVEL,
		RandSize     = 3,
	},
	
	{
		Name         = "Rainfall",
		Values       = {"Drier", "Standard", "Wetter", "Random"},
		DefaultValue = MapDefaults.RAINFALL,
		RandSize     = 3,
	},

	{
		Name         = "Climate Granularity",
		Values       = {"Coarse", "Standard", "Fine", "Mixed", "Random"},
		DefaultValue = MapDefaults.CLIMGRAN,
		RandSize     = 4,
	},

	{
		Name         = "Grass/Plains Mix",
		Values       = {"More Grass", "Standard", "More Plains", "Random"},
		DefaultValue = MapDefaults.GRASSPLAINS,
		RandSize     = 3,
	},
	
	{
		Name         = "Biodiversity",
		Values       = 
		{
			"Very Low", 
			"Low", 
			"Standard", 
			"High", 
			"Very High", 
			"Climate Based",
			"Random Low-High", 
			"Random"
		},
		DefaultValue = MapDefaults.BIODIV,
		GotRandLH    = true,
		RandSize     = 6,
	},

	{
		Name         = "Mountains",
		Values       = 
		{
			"Tectonic Plates",
			"Fractal Ranges",
			"Scattered Crags",
			"Clustered Highlands",
			"Uncanny Valleys",
			"Winding Canyons",
			"Everything",
			"Random"
		},
		DefaultValue = MapDefaults.MOUNTAINS,
		RandSize     = 7,
	},

	{
		Name         = "Rivers",
		Values       = 
		{
			"Simple",
			"Detailed",
			"Branchy",
			"Snaky",
			"Everything",
			"Random"
		},
		DefaultValue = MapDefaults.RIVERS,
		RandSize     = 5,
	},

	{
		Name         = "Extras",
		Values       = 
		{
			"None",
			"Chains",
			"Clusters",
			"Mini Donuts",
			"Sprinkles",
			"Tectonic",
			"Tectonic and Chains",
			"Everything",
			"Random"
		},
		DefaultValue = MapDefaults.EXTRAS,
		RandSize     = 8,
	},
	
	{
		Name         = "World Wrap",
		Values       = {"Globe", "Region", "Random"},
		DefaultValue = MapDefaults.WORLDWRAP,
		RandSize     = 2,
	},
	
	{
		Name         = "Climate",
		Values       = 
		{
			"Snowball", 
			"Ice Age", 
			"Standard", 
			"Greenhouse", 
			"Sandstorm", 
			"Random Ice Age to Greenhouse",
			"Random"
		},
		DefaultValue = MapDefaults.CLIMATE,
		GotRandLH    = true,
		RandSize     = 5,
	},
	
	{
		Name         = "Biome",
		Values       = {"Arborea", "Prairie", "Standard", "Wetland", "Random"},
		DefaultValue = MapDefaults.BIOME,
		RandSize     = 4,
	},
	
	{
		Name         = "Sunlight",
		Values       = {"Standard", "Tilted Axis", "Two Suns", "Random"},
		DefaultValue = MapDefaults.SUNLIGHT,
		RandSize     = 3,
	},
	
	{
		Name         = "Icy Poles",
		Values       = {"Cropped", "Standard", "Random"},
		DefaultValue = MapDefaults.ICYPOLES,
		RandSize     = 2,
	},

	-- Landmass families
	GetLandmassFamilyOption("Continents", MapDefaults.CONTINENTS,	
	{ 
		LandInfo.bagels,
		LandInfo.continents,
		LandInfo.fractal,
		LandInfo.noodles,
		LandInfo.smallContinents,
	}),	

	GetLandmassFamilyOption("Islands", MapDefaults.ISLANDS,	
	{ 
		LandInfo.archipelago,
		LandInfo.clusters,
		LandInfo.islandPlates,
		LandInfo.largeIslands,
		LandInfo.miniDonuts
	}),					
		
	GetLandmassFamilyOption("Lakes", MapDefaults.LAKES,	
	{ 
		LandInfo.inlandSea,
		LandInfo.invertedExtras,
		LandInfo.lakes,
		LandInfo.largeLakes,
		LandInfo.sevenSeas
	}),
		
	GetLandmassFamilyOption("Pangea", MapDefaults.PANGEA,	
	{ 
		LandInfo.donut,
		LandInfo.maze,
		LandInfo.oval,
		LandInfo.pangea,
		LandInfo.snake
	}),

	-- Misc options
	{
		Name         = "Ageless Hills",
		DefaultValue = MapDefaults.AHILLS,
	},
	
	{
		Name         = "Connected Seas",
		DefaultValue = MapDefaults.CONNECTSEAS,
	},
	
	{
		Name         = "Fresh Lakes Landmasses",
		DefaultValue = MapDefaults.FRESHLAKES,
	},

	{
		Name         = "No Coastal Ice",
		DefaultValue = MapDefaults.NOCOASTICE,
	},

	{
		Name         = "No Coastal Mountains",
		DefaultValue = MapDefaults.NOCOASTMTS,
	},
	
	{
		Name         = "No Desert Forests",
		DefaultValue = MapDefaults.NODFORESTS,
	},
	
	{
		Name         = "No Desert Jungles",
		DefaultValue = MapDefaults.NODJUNGLES,
	},
	
	{
		Name         = "No Desert Oases",
		DefaultValue = MapDefaults.NODOASES,
	},

	{
		Name         = "No Grassland Jungles",
		DefaultValue = MapDefaults.NOGJUNGLES,
	},

	{
		Name         = "No Plains Marsh",
		DefaultValue = MapDefaults.NOPMARSH,
	},

	{
		Name         = "No Reefs",
		DefaultValue = MapDefaults.NOREEFS,
	},
	
	{
		Name         = "No Snow Forests",
		DefaultValue = MapDefaults.NOSFORESTS,
	},
	
	{
		Name         = "No Snow Oases",
		DefaultValue = MapDefaults.NOSOASES,
	},
	
	{
		Name         = "No Tundra Forests",
		DefaultValue = MapDefaults.NOTFORESTS,
	},

	{
		Name         = "Scrambled Land Luxuries",
		DefaultValue = MapDefaults.SCRALUX,
	},
};
------------------------------------------------------------------------------
-- Map Init
------------------------------------------------------------------------------
function GL_RandSeed(seed)
	-- Seed a native RNG with the map's seed
	-- so that we can randomize map options during map-data-init.
	local seed = seed or os.time();
	
	math.randomseed(seed);	
end

function GL_RandInt(upper, description)
	-- Native RNG that can substitute TerrainBuilder.GetRandomNumber()
	-- Args:
	--   upper: exclusive upper-bound integer
	--   description: ignored, but matches signature of TerrainBuilder.GetRandomNumber()
	-- Returns a random integer in the range [0,upper-1]
	
	local upper = upper or 1;
	
	-- Offset [1,N] to [0,N-1]
	return math.random(upper) - 1;
end

function GetOptionValueName(customOption, userInput)
	-- Return the display name of the selected value for an option.
	
	local indexedVal = customOption.Values[userInput];
	
	if (not indexedVal) then
		-- No corresponding display name, so just use the raw value.
		return tostring(userInput);
	end
	
	return indexedVal;
end

function GetUserInput(mapOptionName, defaultValue)
	-- Get user input for a map option.
	local userInput = nil;
	local valName   = "";
	
	if (ENABLE_UI == true) then
		-- UI options enabled. Determine what the user selected from the start menu.
		userInput = MapConfiguration.GetValue(mapOptionName);
		
		if (userInput == nil) then
			-- User input not available, so use default value instead.
			userInput = defaultValue;
			valName   = "Not Supported --> ";
		end
	else
		-- UI options disabled. Use hard-coded setting instead.
		userInput = defaultValue;
		valName   = "Lua --> ";
	end
	
	return userInput, valName;
end

function ChooseOption(optIndex)
	-- Choose a regular map option.
	local customOption = OptionInfo[optIndex];
	local optName      = customOption.Name;
	
	local userInput, valName = 
	  GetUserInput(MapOptionNames[optIndex], OptionInfo[optIndex].DefaultValue);
	
	--print("optIndex = " .. optIndex .. ", userInput = " .. NonNilStr(userInput));
	
	valName = valName .. GetOptionValueName(customOption, userInput);
	
	local randSize = customOption.RandSize;
	if randSize then
		-- The option supports random.
		-- Assume that "Random" is the last option in the list.
		local randOpt = #customOption.Values;
		
		local gotRandLH = customOption.GotRandLH;
		if gotRandLH then
			-- This option supports random low-high, which precedes "random".
			if (userInput == (randOpt - 1)) then
				-- The user selected "Random Low-High", 
				-- so randomize within that range, assuming that index 2 is "low"
				-- and and that index 4 is "high".
				userInput = 2 + ScriptData.configRandFcn(3, "Random " .. optName .. " in [low,high] - Lua");
				valName = valName .. " --> Chose " .. GetOptionValueName(customOption, userInput);
			end
		end
		
		if (userInput == randOpt) then
			-- The user selected "Random", so randomize the option.
			userInput = 1 + ScriptData.configRandFcn(randSize, "Random " .. optName .. " - Lua");
			valName = valName .. " --> Chose " .. GetOptionValueName(customOption, userInput);
		end
	end
	
	print(optName .. ": " .. valName);
	
	return userInput;
end

function ChooseBoolOption(optIndex)
	-- Choose a boolean map option.
	local userInput, valName = 
	  GetUserInput(MapOptionNames[optIndex], OptionInfo[optIndex].DefaultValue);
    
	--print("optIndex = " .. optIndex .. ", userInput = " .. NonNilStr(userInput));
			
	valName = valName .. NonNilStr(userInput);
	
	print(OptionInfo[optIndex].Name .. ": " .. valName);
	
	return userInput;
end

function ChooseInitDataOption(optIndex, fallback)
	-- Choose an option that initializes in GetMapInitData().
	-- Can only randomize if we have native RNG.
	--
	-- Args:
	--   optIndex: which option to initialize
	--   fallback: what to set if user selected random but RNG not available.
	--
	-- Returns: the value to set for the map option
	
	local userInput, valName = 
	  GetUserInput(MapOptionNames[optIndex], OptionInfo[optIndex].DefaultValue);
		
	local customOption = OptionInfo[optIndex];
	
	local optName = customOption.Name;
	
	valName = valName .. GetOptionValueName(customOption, userInput);
		
	local randSize = customOption.RandSize;
	
	if (userInput == (randSize + 1)) then
		-- The user selected "Random", so randomize the option if possible.
		if (ScriptData.configRandFcn == GL_RandInt) then
			-- Got a native RNG, so let's randomize this option.
			userInput = 1 + GL_RandInt(randSize, "Random " .. optName .. " - Lua");
			valName = valName .. " --> Chose " .. GetOptionValueName(customOption, userInput);
			
		else
			-- No RNG available because Civ RNG not yet seeded.
			userInput = fallback;
			valName = valName .. " --> RNG Not Available --> " .. 
				GetOptionValueName(customOption, userInput);
		end
	end
	
	print(optName .. ": " .. valName);
	
	return userInput;
end

function ChooseFromShuffle(firstOpt, lastOpt)
	-- Given a first and last option index, create a "deck" out of 
	-- map-filter user inputs and randomly choose an option.
	--
	-- Args:
	--   firstOpt: the first shuffle family option to consider
	--   lastOpt: the last shuffle family option to consider
	-- 
	-- Returns
	--   selectedInfo: config info corresponding to the user input
	
	local deck = {};
	local deckNames = {};
	local numOpts = lastOpt - firstOpt + 1;

	-- Separate deck containing all options in case the user selects
	-- "none" for everything. This is a fallback.
	local noneDeck = {};

	local familyOpt;
	local familyInfos;

	for iOpt=firstOpt,lastOpt do
		-- For each family option, determine what values to include

		-- Get info about the option
		local familyOpt = OptionInfo[iOpt];
				
		-- Get the value that the user selected.
		local familyChoice = GetUserInput(MapOptionNames[iOpt], familyOpt.DefaultValue);
		
		-- Get info about the choices for this option
		local familyInfos = familyOpt.Infos or {};
		
		local familyNumInfos = table.maxn(familyInfos);
		
		if (familyChoice == (familyNumInfos - GOT_ALL)) then
			-- ALL selected for this option family.
			for i, info in ipairs(familyInfos) do
				table.insert(deck, info);
				table.insert(deckNames, info.name);
			end
			
		elseif (familyChoice <= familyNumInfos) then
			-- Single landmass selected.
			table.insert(deck,      familyInfos[familyChoice]);
			table.insert(deckNames, familyInfos[familyChoice].name);
			
		else
			-- NONE selected. Populate the fallback deck.
			for i, info in ipairs(familyInfos) do
				table.insert(noneDeck, info);
			end
		end
	end

	local deckSize = table.maxn(deck);
	local selectedInfo;

	if (deckSize == 0) then
		-- Edge case: the deck is empty ("None" for every family!) 
		-- Revert to an even distribution of map types.
		print("Empty deck!  Choosing an option at random.");
		
		selectedInfo = noneDeck[1 + ScriptData.configRandFcn(table.maxn(noneDeck), 
			"Random option, even distribution")];
	else
		-- Choose a random map from the deck.
		print("Choosing from {");
		print(unpack(deckNames));
		print("}");
		selectedInfo = deck[1 + ScriptData.configRandFcn(deckSize, 
			"Random option, weighted by user selection")];
	end
	
	print("Chose " .. selectedInfo.name);

	return selectedInfo;
end

function InitUserInput()
	-- Populate most user-input variables based on map-config specs.
	-- Does not initialize world wrap or map size.
	UserInput.resources   = ChooseOption(MapOptions.RESOURCES);
	UserInput.start       = ChooseOption(MapOptions.START);
	
	UserInput.worldAge    = ChooseOption(MapOptions.WORLDAGE);
	UserInput.seaLevel    = ChooseOption(MapOptions.SEALEVEL);
	UserInput.lakeLevel   = ChooseOption(MapOptions.LAKELEVEL);
	UserInput.riverLevel  = ChooseOption(MapOptions.RIVERLEVEL);
	UserInput.temperature = ChooseOption(MapOptions.TEMPERATURE);
	UserInput.tundraLevel = ChooseOption(MapOptions.TUNDRALEVEL);
	UserInput.rainfall    = ChooseOption(MapOptions.RAINFALL);
	UserInput.climGran    = ChooseOption(MapOptions.CLIMGRAN);
	UserInput.grassPlains = ChooseOption(MapOptions.GRASSPLAINS);
	UserInput.biodiv      = ChooseOption(MapOptions.BIODIV);

	UserInput.mountains   = ChooseOption(MapOptions.MOUNTAINS);
	UserInput.rivers      = ChooseOption(MapOptions.RIVERS);
	UserInput.extras      = ChooseOption(MapOptions.EXTRAS);
	UserInput.climate     = ChooseOption(MapOptions.CLIMATE);
	UserInput.biome       = ChooseOption(MapOptions.BIOME);
	UserInput.sunlight    = ChooseOption(MapOptions.SUNLIGHT);
	UserInput.icyPoles    = ChooseOption(MapOptions.ICYPOLES);
	
	UserInput.aHills      = ChooseBoolOption(MapOptions.AHILLS);
	UserInput.connectSeas = ChooseBoolOption(MapOptions.CONNECTSEAS);
	UserInput.freshLakes  = ChooseBoolOption(MapOptions.FRESHLAKES);
	UserInput.noCoastIce  = ChooseBoolOption(MapOptions.NOCOASTICE);
	UserInput.noCoastMts  = ChooseBoolOption(MapOptions.NOCOASTMTS);
	UserInput.noDForests  = ChooseBoolOption(MapOptions.NODFORESTS);
	UserInput.noDJungles  = ChooseBoolOption(MapOptions.NODJUNGLES);
	UserInput.noDOases    = ChooseBoolOption(MapOptions.NODOASES);
	UserInput.noGJungles  = ChooseBoolOption(MapOptions.NOGJUNGLES);
	UserInput.noPMarsh    = ChooseBoolOption(MapOptions.NOPMARSH);
	UserInput.noReefs     = ChooseBoolOption(MapOptions.NOREEFS);
	UserInput.noSForests  = ChooseBoolOption(MapOptions.NOSFORESTS);
	UserInput.noSOases    = ChooseBoolOption(MapOptions.NOSOASES);
	UserInput.noTForests  = ChooseBoolOption(MapOptions.NOTFORESTS);
	UserInput.scraLux     = ChooseBoolOption(MapOptions.SCRALUX);
	
	-- Climate info
	local climateInfos = 
	{
		ClimateInfo.snowball,
		ClimateInfo.iceAge,
		ClimateInfo.default,
		ClimateInfo.greenhouse,
		ClimateInfo.sandstorm
	};
	ScriptData.climateInfo = GetConfigInfo(ClimateInfo.default, climateInfos[UserInput.climate]);
	
	if (UserInput.biodiv == Biodivs.CLIMBASE) then
		-- Biodiversity based on climate.
		UserInput.biodiv = ScriptData.climateInfo.biodiv;
	end
	
	local biodivInfos = 
	{
		BiodivInfo.veryLow, 
		BiodivInfo.low,
		BiodivInfo.default,
		BiodivInfo.high,
		BiodivInfo.veryHigh
	};
	ScriptData.biodivInfo = GetConfigInfo(BiodivInfo.default, biodivInfos[UserInput.biodiv]);
		
	-- Biome info
	local biomeInfos = 
	{
		BiomeInfo.arborea,
		BiomeInfo.prairie,
		BiomeInfo.default,
		BiomeInfo.wetland
	};
	ScriptData.biomeInfo = GetConfigInfo(BiomeInfo.default, biomeInfos[UserInput.biome]);
	
	-- Sunlight info
	local sunlightInfos = 
	{
		SunlightInfo.default,
		SunlightInfo.tilted,
		SunlightInfo.twoSuns
	};
	ScriptData.sunlightInfo = GetConfigInfo(
		SunlightInfo.default, sunlightInfos[UserInput.sunlight]);
	
	if (UserInput.icyPoles == ICYPOLES_FULL) then
		-- We're not cropping the map, so cancel-out the latitude multiplier.
		ScriptData.sunlightInfo.latMult = {1, 1, 1, 1, 1};
	end
end

function InitWorldWrap()
	-- Determine world wrap
	-- Note: Civ seeds its RNG *after* initializing world wrap.
	UserInput.worldWrap = ChooseInitDataOption(MapOptions.WORLDWRAP, WWRAP_GLOBE);
		
	if (UserInput.worldWrap == WWRAP_GLOBE) then
		-- Globe
		ScriptData.wrapX = true;
		ScriptData.wrapY = false;

		-- Let non-climate fractals touch the edges of the map.
		g_iFlags.FRAC_POLAR = false;			
	else
		-- Region
		ScriptData.wrapX = false;
		ScriptData.wrapY = false;
		
		-- Avoid edges for non-climate fractals.
		g_iFlags.FRAC_POLAR = true;
	end
	
	-- Set world-wrap for all fractals.
	g_iFlags.FRAC_WRAP_X = ScriptData.wrapX;
	g_iFlags.FRAC_WRAP_Y = ScriptData.wrapY;
	ScriptData.climateFracFlags.FRAC_WRAP_X = ScriptData.wrapX;
	ScriptData.climateFracFlags.FRAC_WRAP_Y = ScriptData.wrapY;
end

function InitShuffleOptions()
	-- Shuffle with supplied RNG.	
	print("Shuffling settings based on user input.");
	
	ScriptData.landInfo = GetConfigInfo(
		LandInfo.default, ChooseFromShuffle(FIRST_LAND_OPT, LAST_LAND_OPT));
	
	UserInput.landmass = ScriptData.landInfo.id;
end

function GetCalculatedMapSize(width, height)
	-- Map grid size to linear index using number of tiles.
	
	-- Size buckets mapped to number of tiles and midpoint thresholds for reference:
	-- duel     = 44 *26  = 1144  < 1712
	-- tiny     = 60 *38  = 2280  < 2842
	-- small    = 74 *46  = 3404  < 3970
	-- standard = 84 *54  = 4536  < 5148
	-- large    = 96 *60  = 5760  < 6378
	-- huge     = 106*66  = 6996  < 7790
	-- massive  = 116*74  = 8584  < 9412
	-- enormous = 128*80  = 10240 < 11280
	-- 18p      = 140*88  = 12320 < 13456
	-- 20p      = 152*96  = 14592 < 15824
	-- 22p      = 164*104 = 17056 < 18384
	-- 24p      = 176*112 = 19712
	
	-- The function of numTiles vs world size is a parabola:
	-- numTiles = y = ax^2 + bx + c
	--
	-- Use quadratic formula to solve for x.
	-- Coefficients are based on a MS Excel quadratic trendline of map sizes.
	local a = 88.068;
	local b = 496.71;
	local c = 886.36;
	
	local numTiles = width * height;
	
	-- Use the positive end of the quadratic inverse.
	local index = Round((-b + math.sqrt(b*b - 4*a*(c-numTiles)))/(2*a));
	
	-- Don't allow tiny maps to become smaller than duel.
	index = math.max(1,index);
	
	print("Grid size " .. CoordString(width, height) .." -> map size #" .. index);
	return index;
end

function CalculateWorldSizeInfo(width, height)
	-- Calculate world size info based on grid size.
	local mapSize = GetCalculatedMapSize(width, height);
	
	-- Base granularity for fractals that scale with map size.
	-- {0,0,1,1,2,2,3,3,4,4,5,5} original scale
	-- {0,0,0,1,1,1,2,2,2,3,3,3}
	local baseGrain = math.ceil(mapSize/3) - 1;
	
	-- Plate values > 39 might crash the system, so just use piecewise.
	local numRPlatesVals = {4,8,16,20,24,32,36};
	
	-- Target size for island clusters
	local clusterSize = 5 * (mapSize+1);
	
	local numExtraDonutsVals = {3,6};
	local numExtraDonuts     = mapSize*2;
		
	local sizeInfo = 
	{
		-- Map size as {Length, Width}
		size = {width, height}, -- Civ V: {84, 52},
		
		-- Indicates whether we have a custom map size
		isCustom = false,
		
		-- A simple linear scale starting at 1 for duel, 2 for tiny, etc.
		index = mapSize,
		
		-- The default number of civs for the map size.
		numCivs = mapSize * 2,
		
		-- Base granularity for fractals that scale with map size.
		fracGrain    = baseGrain,
		
		-- Number of plates in Fractal World's ridges
		numRPlates = numRPlatesVals[mapSize] or 36,
		
		-- Island Clusters configuration.
		clusters = {targetSize = clusterSize},
		
		-- Mini-Donut configuration.
		miniDonuts = 
		{
			numExtraDonuts = numExtraDonuts
		},
	};
	
	print("===========================================");
	print("World Size Info:");
	print("-------------------------------------------");
	print("General:");
	print("  Suggested Num Major Civs: ".. sizeInfo.numCivs);
	print("  Fractal grain:            ".. sizeInfo.fracGrain);
	print("-------------------------------------------");
	print("Landmass:");
	print("  Num fractal ridges: ".. sizeInfo.numRPlates);
	print("-------------------------------------------");
	print("Extras:");
	print("  Target cluster size: ".. sizeInfo.clusters.targetSize);
	print("  Num extra donuts:    ".. sizeInfo.miniDonuts.numExtraDonuts);
	print("===========================================");

	return sizeInfo;
end

function AdjustWorldHeight(sizeInfo, adjustment)
	-- Adjust settings for world size info.
	--
	-- Args:
	--   sizeInfo: info to adjust
	--   adjustment: multiply height and data by this much
	--
	-- Return adjusted size info
	
	-- Adjust height, rounding to nearest even integer.
	sizeInfo.size[2] = 2*Round(sizeInfo.size[2]*adjustment/2);

	return sizeInfo;
end

function InitWorldSizeInfo()
	-- Set the global world size info based on user inputs such as climate.	
	local worldSize = ScriptData.worldSize;
	
	-- Look for the world-size hash in game info.
	local mapSizeType = nil; -- Default val in case hash not found.
	local gridWidth = nil;
	local gridHeight = nil;
	for row in GameInfo.Maps() do    
		if(worldSize == row.Hash) then
			mapSizeType = row.MapSizeType;
			gridWidth = row.GridWidth;
			gridHeight = row.GridHeight;
			break;
		end
	end
	
	if (not mapSizeType) then
		print("Got an unidentified map size.");
		-- Just return and let map-gen calculate world size info based on grid size.
		return;
	end
	print("Map Size is " .. mapSizeType);
	
	if (not (gridWidth and gridHeight)) then
		print("Unable to determine grid dimensions.");
		-- Just return and let map-gen calculate world size info based on grid size.
		return;
	end
	print("Configured grid size (w,h) is " .. CoordString(gridWidth, gridHeight));
		
	local gridSize = PREFERRED_STD_SIZES[mapSizeType] or 
		{width = gridWidth, height = gridHeight};
	
	print("GL base grid size (w,h) is " .. CoordString(gridSize.width, gridSize.height));
	
	local gridSizeEnlarged = PREFERRED_STD_SIZES_ENLARGED[mapSizeType] or 
		{width = gridWidth+8, height = gridHeight+8};
	
	local sizeInfo = nil;
	if (UserInput.worldWrap == WWRAP_GLOBE) then
		-- Global world wrap: certain climates need cropping / resizing.
		
		if (UserInput.icyPoles == ICYPOLES_CROP) then
			-- Crop out the polar ice taking over more of the world by 
			-- using a "flatter" grid. This allows special plot modes
			-- to assign starting plots without having to worry about 
			-- icy regions.
			print("Adjusting map size (globe + cropped poles)");			
			local reductionMult = ScriptData.sunlightInfo.latMult[UserInput.climate];
			local gridSizeToCrop = gridSize;
			
			if (reductionMult < 0.6) then
				-- Significant height reduction; enlarge map size to compensate.
				print("Enlarging map size to compensate for height reduction.");
				gridSizeToCrop = gridSizeEnlarged;
			end
			
			sizeInfo = AdjustWorldHeight(CalculateWorldSizeInfo(
				gridSizeToCrop.width, gridSizeToCrop.height), reductionMult);
				
		elseif (UserInput.sunlight == Sunlights.TILTED) then
			-- Uncropped tilted axis.
			-- Increase map size to accomodate frozen wasteland
			print("Increasing map size (global tilted axis full)");
			sizeInfo = CalculateWorldSizeInfo(gridSizeEnlarged.width, gridSizeEnlarged.height);
		end
	end
	
	if (not sizeInfo) then
		-- Standard world size info.
		sizeInfo = CalculateWorldSizeInfo(gridSize.width, gridSize.height);
	end
	
	ScriptData.worldSizeInfo = sizeInfo;
end

function GetMapInitData(worldSize)
	-- This function can reset map grid sizes and world wrap settings.
    -- Args: worldSize: a hash that corresponds to a row in GameInfo.Maps
    --
    -- Note: does not take any other args, and for some reason custom map sizes
    -- each have a nil hash in GameInfo.Maps. So...not seeing any way to support
    -- custom map sizes via the MapSize option.
    
	print("Running Got Lakes v" .. glVersion);
	
	if ScriptData.gotGatheringStorm then
		print("Civ6 - Gathering Storm");
		
	elseif ScriptData.gotRiseAndFall then
		print("Civ6 - Rise and Fall");
	else
		print("Civ6 - Vanilla");
	end
	
	if (ENABLE_UI == true) then
		print("UI options enabled.");
	else
		print("UI options disabled. Taking options from lua instead.");
	end
	
	ScriptData.worldSize = worldSize;
    
	-- DO NOT generate random numbers with TerrainBuilder in this method.
	-- This method happens before initializing the TerrainBuilder's RNG.

	local mapSeed = MapConfiguration.GetValue("RANDOM_SEED");
	print("Got Lakes map seed: " .. tostring(mapSeed));

	if MapIsMultiplayer() then
		print("Loading options with no RNG (multiplayer map).");
		-- Since we don't have RNG, 
		-- get only the options necessary for world wrap and map size.
		
		-- Don't get user input because that could be random.
		
		-- Get non-random World Wrap.
		InitWorldWrap();
		
		-- Don't get shuffle options because those could be random.
		
		-- Determine world size (depends on world wrap).
		-- Since we don't know the climate yet, we can't factor climate 
		-- into the world size (no cropping/enlarging).
		InitWorldSizeInfo();
	else
		print("Loading options with native RNG (single-player map)");
		-- Use native RNG so that we can randomize world wrap.
		GL_RandSeed(mapSeed);	
	
		-- Shuffle all map options using native RNG.	
		ScriptData.configRandFcn = GL_RandInt;
		
		-- Get user input.
		InitUserInput();
		
		-- Get random world wrap.
		InitWorldWrap();
		
		-- Get landmass and climate (depends on user input).
		InitShuffleOptions();
		
		-- Determine world size based (depends on world wrap and shuffle options).
		InitWorldSizeInfo();
	end
	
	-- Set grid size based on user input.
	local grid_size = ScriptData.worldSizeInfo.size;
	
	if grid_size then
		-- Successfully mapped worldSize hash to a known map size.
		return {
			Width  = grid_size[1],
			Height = grid_size[2],
			WrapX  = ScriptData.wrapX,
			WrapY  = ScriptData.wrapY
		};
	end
	
	-- Else we have a custom map size.
	print("Got a custom map size; world-wrap is effectively a globe.");
	
	ScriptData.worldSize = nil;
	
	-- Reset directional world wrap specs to match reality.
	ScriptData.wrapX = true;
	ScriptData.wrapY = false;
	
	-- Honor user's choice of region vs globe world wrap for climates, etc.
	-- by keeping UserInput.worldWrap as-is.
	
	-- Return void - don't reset grid size or world wrap.
end
------------------------------------------------------------------------------
-- Map Generation
------------------------------------------------------------------------------
function InitOptionsWithTerrainBuilder()
	-- Obtain options based on user input.
	-- No-op if GetMapInitData() already generated this info.
	
	if ScriptData.configRandFcn then
		-- Already initialized.
		print("Already loaded options.");
		return;
	end
	
	-- Load all options into global variables.
	print("Loading options with TerrainBuilder RNG...");
	
	ScriptData.configRandFcn = TerrainBuilder.GetRandomNumber;
	
	-- Get user input.
	InitUserInput();
	
	-- Get landmass and climate.
	InitShuffleOptions();
end

function InitHelperFlags()
	-- Init global convenience flags based on user input.
	ExtrasGot.chains = 
		(UserInput.extras == ExtraIslesLakes.CHAINS) or
		(UserInput.extras == ExtraIslesLakes.TCHAINS) or
		(UserInput.extras == ExtraIslesLakes.ALL);
		
	ExtrasGot.clusters = 
		(UserInput.extras == ExtraIslesLakes.CLUSTERS) or
		(UserInput.extras == ExtraIslesLakes.ALL);
		
	ExtrasGot.miniDonuts = 
		(UserInput.extras == ExtraIslesLakes.DONUTS) or
		(UserInput.extras == ExtraIslesLakes.ALL);	

	ExtrasGot.sprinkles = 
		(UserInput.extras == ExtraIslesLakes.SPRNKLES) or
		(UserInput.extras == ExtraIslesLakes.ALL);
		
	ExtrasGot.tectonic = 
		(UserInput.extras == ExtraIslesLakes.TECTONIC) or
		(UserInput.extras == ExtraIslesLakes.TCHAINS) or
		(UserInput.extras == ExtraIslesLakes.ALL);
	
	ExtrasGot.tecAndChains	= 
		(UserInput.extras == ExtraIslesLakes.TCHAINS);
		
	ExtrasGot.everything = 
		(UserInput.extras == ExtraIslesLakes.ALL);	
		
	ExtrasGot.anything = 
		(ExtrasGot.chains      == true or 
		 ExtrasGot.clusters    == true or 
		 ExtrasGot.miniDonuts  == true or 
		 ExtrasGot.sprinkles   == true or
		 ExtrasGot.tectonic    == true);
	
	gotLakesFamily = 
		(UserInput.landmass == Landmasses.INLANDSEA) or
		(UserInput.landmass == Landmasses.INVEXTRAS) or
		(UserInput.landmass == Landmasses.LAKES) or
		(UserInput.landmass == Landmasses.LRGLAKES) or
		(UserInput.landmass == Landmasses.SEVENSEAS);
	
	gotIceAgeFamily = 
		(UserInput.climate == Climates.ICEAGE) or 
		(UserInput.climate == Climates.SNOWBALL);
		
	gotTiltedFamily = (UserInput.sunlight ~= Sunlights.STANDARD);
end

function GeneratePlotsWithFeatures()
	-- Generate plot types, terrain, and features.

	-- Initialize coastal plot map.
	ScriptData.coastPlots = table.fill(g_PLOT_TYPE_OCEAN, g_numTiles);
	
	-- Plot types are the core layer of the map, 
	-- determining land or sea, determining flatland, hills or mountains.
	local plotTypes = GeneratePlotTypes();
	
	-- Initialize terrain types.
	local terrainTypes = table.fill(g_TERRAIN_TYPE_GRASS, g_numTiles);
	
	-- Set shallow and deep water as terrain.
	GenerateCoasts(plotTypes, terrainTypes);

    -- Optional step: replace all coastal mountains with hills.
    -- Must do this after generating coasts and before setting terrain.
    if (UserInput.noCoastMts == true) then
        print("Removing coastal mountains.");
        RemoveCoastalMountains(plotTypes, terrainTypes);
    end
    
	-- Civ 6 doesn't "set" plot types, so instead we "set" terrain types 
	-- in order to unbreak rivers and lakes.
	SetTerrainTypes(terrainTypes); 
	
	-- Add some fresh lakes and rivers.
	-- River generation is affected by plot types, originating from 
	-- highlands and preferring to traverse towards lowlands.
	AddLakesAndRivers();
	
	-- Terrain covers climate: grassland, plains, desert, tundra, snow.
	GenerateTerrain();
	
	print("Analyzing chokepoints.");
	TerrainBuilder.AnalyzeChokepoints();
	
	-- Determines continental plates and possibly artwork as well.
	print("Stamping continents.");
	TerrainBuilder.StampContinents();
	
	if ScriptData.gotGatheringStorm then
		-- Additional steps for Gathering Storm expansion.
		-- These steps depend on stamped continents.
		print("Counting plots along continent boundaries.");
		local iContinentBoundaryPlots = CountContinentBoundaryPlots();
	
		-- Add voclanoes
		-- Must do this before adding natural wonders.
		AddVolcanicTerrain(iContinentBoundaryPlots);		
	end
	
    -- Features depend on plot types, terrain types, rivers and lakes 
	-- to help determine their placement.
	local featuregen = GenerateFeatures();
    
	-- Throw in some random natural wonders.
    -- Natural wonders depend on features for adjacency checks.
    --
	-- Natural wonders originally came after cliffs.
	-- But nat wonder cliffs don't check whether an area still has flat coast.
	GenerateNaturalWonders();
	
	-- Cliffs also depend on both plot types and terrain types.
	AddCliffs();
	
	if ScriptData.gotGatheringStorm then
		-- Additional steps for Gathering Storm expansion.
		-- These steps happen after natural wonders.
		print("Analyzing chokepoints (2nd pass).");
		TerrainBuilder.AnalyzeChokepoints();

		-- Add geothermal fissures.
		featuregen:AddFeaturesFromContinents();
	
		-- Set elevation for coastal land
		-- to control how rising sea-level affects coastal flooding.
		MarkCoastalLowlands();
	end
	
	-- Check for areas completely surrounded by 
    -- impassable natural wonders, mountains, volcanoes, cliffs, or ice.
    --
    -- Also normalize terrain and features under the remaining obstacles.
	EnsureTerrainReachability();
	
	-- Note that this does NOT fix wonders that block chokepoints.
	print("Analyzing post-continent chokepoints.");
	TerrainBuilder.AnalyzeChokepoints()
end

function GenerateMap()
	print("Generating GotLakes Map");
	-- This is the core map generation function.
		
	-- Shuffle map options if we haven't already.
	-- Use the TerrainBuilder RNG since that is now available.
	InitOptionsWithTerrainBuilder();
	InitHelperFlags();
	
	-- Set globals
	g_iW, g_iH = Map.GetGridSize();
	g_numTiles = g_iW * g_iH;
	
	print("Grid Size (w,h): " .. CoordString(g_iW, g_iH));

	print("Fractal flags:");
	PrintContentsOfTable(g_iFlags);
	
	print("Map.GetMapSize(): ", Map.GetMapSize());
	print("Default # players: ", GameInfo.Maps[Map.GetMapSize()].DefaultPlayers);
	
	if (not ScriptData.worldSize) then
		-- Init non-standard world-size info.
		print("Calculating custom world size info.");
		ScriptData.worldSizeInfo = CalculateWorldSizeInfo(g_iW, g_iH);
		ScriptData.worldSizeInfo.isCustom = true;
	end
	
	-- Generate most of the landmass and climate.
	GeneratePlotsWithFeatures();
	
	-- Analyze land, hills, mountains, oceans, and coast.
	AnalyzeLandmass();
	
	-- Analyze terrain and features.
	AnalyzeClimate();
	
	-- Add luxuries and whatnot.
	GenerateResources();
	
	-- Assign Starting Plots.
	DetermineStartingPlots();

	-- Goodies depend on not colliding with resources or Natural Wonders, 
	-- or being placed too near to start plots.
	AddGoodies(g_iW, g_iH);
end